import{r as c}from"./col-CIrkW6Bj.js";import{S as p,W as f,h as r,Y as g,p as a,i as m,o as y,w as d,a3 as w,H as _,n as v,a1 as o,a4 as R,G as S,a7 as b}from"./index-C7GhFfoB.js";const h=["start","center","end","space-around","space-between","space-evenly"],C=["top","middle","bottom"],j=p({tag:{type:String,default:"div"},gutter:{type:Number,default:0},justify:{type:String,values:h,default:"start"},align:{type:String,values:C}}),x=r({name:"ElRow"}),$=r({...x,props:j,setup(n){const t=n,e=g("row"),l=a(()=>t.gutter);S(c,{gutter:l});const i=a(()=>{const s={};return t.gutter&&(s.marginRight=s.marginLeft=`-${t.gutter/2}px`),s}),u=a(()=>[e.b(),e.is(`justify-${t.justify}`,t.justify!=="start"),e.is(`align-${t.align}`,!!t.align)]);return(s,k)=>(y(),m(R(s.tag),{class:v(o(u)),style:_(o(i))},{default:d(()=>[w(s.$slots,"default")]),_:3},8,["class","style"]))}});var E=f($,[["__file","row.vue"]]);const K=b(E);export{K as E};
