import{bA as v,bF as y,cB as O,cC as p,cD as x,bB as b,cE as m,cF as w,cG as i}from"./index-C7GhFfoB.js";var a=Object.create,P=(function(){function e(){}return function(r){if(!v(r))return{};if(a)return a(r);e.prototype=r;var n=new e;return e.prototype=void 0,n}})();function U(e,r){var n=-1,t=e.length;for(r||(r=Array(t));++n<t;)r[n]=e[n];return r}function F(e,r,n,t){var g=!n;n||(n={});for(var u=-1,h=r.length;++u<h;){var s=r[u],o=void 0;o===void 0&&(o=e[s]),g?y(n,s,o):O(n,s,o)}return n}function A(e){var r=[];if(e!=null)for(var n in Object(e))r.push(n);return r}var B=Object.prototype,C=B.hasOwnProperty;function E(e){if(!v(e))return A(e);var r=p(e),n=[];for(var t in e)t=="constructor"&&(r||!C.call(e,t))||n.push(t);return n}function z(e){return b(e)?x(e,!0):E(e)}var I=m(Object.getPrototypeOf,Object),d=typeof exports=="object"&&exports&&!exports.nodeType&&exports,f=d&&typeof module=="object"&&module&&!module.nodeType&&module,K=f&&f.exports===d,c=K?w.Buffer:void 0,l=c?c.allocUnsafe:void 0;function D(e,r){if(r)return e.slice();var n=e.length,t=l?l(n):new e.constructor(n);return e.copy(t),t}function L(e){var r=new e.constructor(e.byteLength);return new i(r).set(new i(e)),r}function G(e,r){var n=r?L(e.buffer):e.buffer;return new e.constructor(n,e.byteOffset,e.length)}function M(e){return typeof e.constructor=="function"&&!p(e)?P(I(e)):{}}export{U as a,D as b,F as c,G as d,L as e,I as g,M as i,z as k};
