import{_ as b,c as h,a as t,b as c,t as i,d as l,e as n,w as u,E as m,n as k,f as d,u as g,o as C}from"./index-C7GhFfoB.js";const v={name:"AboutPage",data(){const{t:s}=g();return{devClickCount:0,showDevelopMode:localStorage.getItem("showDevelopMode")==="true",t:s}},methods:{handleDevClick(){if(this.showDevelopMode)return;this.devClickCount++;const s=7-this.devClickCount;s>0&&s<6&&d.info(this.t("setting.develop_mode.message.info.remain",{remain:s})),this.devClickCount>=7&&(localStorage.setItem("showDevelopMode","true"),this.showDevelopMode=!0,d.success(this.t("setting.develop_mode.message.success")),this.devClickCount=0)},goToRepo(){window.open("https://github.com/Teahouse-Studios/akari-bot","_blank")},goToWebUIRepo(){window.open("https://github.com/Teahouse-Studios/akari-bot-webui","_blank")},goToI18N(){window.open("https://crowdin.com/project/akari-bot","_blank")},goToSponsor(){window.open("https://afdian.com/a/teahouse","_blank")}}},w={class:"container"},f={class:"quote"},_={class:"repo-buttons"},T={class:"github-link"},S=["title"],D={class:"github-link"},I=["title"],M={class:"other-links"},y={class:"footer-text"};function B(s,o,R,A,r,e){const a=m;return C(),h("div",w,[o[7]||(o[7]=t("img",{width:"300",src:c,alt:"Akaribot"},null,-1)),o[8]||(o[8]=t("h1",{class:"title"},"小可 · AkariBot",-1)),t("span",f,i(s.$t("about.slogan")),1),o[9]||(o[9]=t("span",{class:"text"},[l(" By "),t("a",{href:"https://github.com/OasisAkari"},"OasisAkari"),l(" via "),t("a",{href:"https://teahouse.team"},"Teahouse Studios")],-1)),t("div",_,[t("div",T,[n(a,{class:"repo-button",onClick:e.goToRepo},{default:u(()=>[o[1]||(o[1]=t("i",{class:"mdi mdi-github"},null,-1)),t("span",null,i(s.$t("about.button.repo.main")),1)]),_:1},8,["onClick"]),t("img",{src:"https://img.shields.io/github/stars/Teahouse-Studios/akari-bot?style=social",alt:"Repo Stars",title:s.$t("about.star.tooltip")},null,8,S)]),t("div",D,[n(a,{class:"repo-button",onClick:e.goToWebUIRepo},{default:u(()=>[o[2]||(o[2]=t("i",{class:"mdi mdi-github"},null,-1)),t("span",null,i(s.$t("about.button.repo.webui")),1)]),_:1},8,["onClick"]),t("img",{src:"https://img.shields.io/github/stars/Teahouse-Studios/akari-bot-webui?style=social",alt:"Repo Stars",title:s.$t("about.star.tooltip")},null,8,I)])]),t("div",M,[n(a,{class:"locale-button",onClick:e.goToI18N},{default:u(()=>[o[3]||(o[3]=t("i",{class:"mdi mdi-translate"},null,-1)),t("span",null,i(s.$t("about.button.locale")),1)]),_:1},8,["onClick"]),n(a,{class:"sponsor-button",onClick:e.goToSponsor},{default:u(()=>[o[4]||(o[4]=t("i",{class:"mdi mdi-heart-outline"},null,-1)),t("span",null,i(s.$t("about.button.sponsor")),1)]),_:1},8,["onClick"])]),t("span",y,[o[5]||(o[5]=l(" Made with love❤️ and ",-1)),t("span",{class:k(["python-text",{disabled:!r.showDevelopMode}]),onClick:o[0]||(o[0]=(...p)=>e.handleDevClick&&e.handleDevClick(...p))}," Python🐍 ",2),o[6]||(o[6]=l(". ",-1))])])}const E=b(v,[["render",B],["__scopeId","data-v-fd518c31"]]);export{E as default};
