import{S as h,ae as o,af as u,W as $,h as m,m as g,p as c,Y as N,as as f,bw as _,i as x,o as C,w as j,a3 as v,H as O,n as w,a1 as p,a4 as E,a7 as S}from"./index-C7GhFfoB.js";const K=h({tag:{type:String,default:"div"},span:{type:Number,default:24},offset:{type:Number,default:0},pull:{type:Number,default:0},push:{type:Number,default:0},xs:{type:u([Number,Object]),default:()=>o({})},sm:{type:u([Number,Object]),default:()=>o({})},md:{type:u([Number,Object]),default:()=>o({})},lg:{type:u([Number,Object]),default:()=>o({})},xl:{type:u([Number,Object]),default:()=>o({})}}),k=Symbol("rowContextKey"),B=m({name:"ElCol"}),P=m({...B,props:K,setup(b){const t=b,{gutter:n}=g(k,{gutter:c(()=>0)}),a=N("col"),d=c(()=>{const e={};return n.value&&(e.paddingLeft=e.paddingRight=`${n.value/2}px`),e}),i=c(()=>{const e=[];return["span","offset","pull","push"].forEach(s=>{const l=t[s];f(l)&&(s==="span"?e.push(a.b(`${t[s]}`)):l>0&&e.push(a.b(`${s}-${t[s]}`)))}),["xs","sm","md","lg","xl"].forEach(s=>{f(t[s])?e.push(a.b(`${s}-${t[s]}`)):_(t[s])&&Object.entries(t[s]).forEach(([l,r])=>{e.push(l!=="span"?a.b(`${s}-${l}-${r}`):a.b(`${s}-${r}`))})}),n.value&&e.push(a.is("guttered")),[a.b(),e]});return(e,y)=>(C(),x(E(e.tag),{class:w(p(i)),style:O(p(d))},{default:j(()=>[v(e.$slots,"default")]),_:3},8,["class","style"]))}});var D=$(P,[["__file","col.vue"]]);const L=S(D);export{L as E,k as r};
