import{bG as n,c8 as a,a0 as e}from"./index-C7GhFfoB.js";import{g as i}from"./_initCloneObject-DZEIHZP4.js";var s="[object Object]",u=Function.prototype,p=Object.prototype,c=u.toString,b=p.hasOwnProperty,f=c.call(Object);function j(t){if(!n(t)||a(t)!=s)return!1;var r=i(t);if(r===null)return!0;var o=b.call(r,"constructor")&&r.constructor;return typeof o=="function"&&o instanceof o&&c.call(o)==f}const g=t=>e?window.requestAnimationFrame(t):setTimeout(t,16),O=t=>e?window.cancelAnimationFrame(t):clearTimeout(t);export{O as c,j as i,g as r};
