import{_ as vh,aA as us,f as Bg,u as ch,i as Dr,w as Ot,e as Bt,A as pa,ay as Ng,a as O,d as _n,t as j,n as Fg,c as oi,F as Dv,y as Av,H as Lv,o as Jt,E as s1,I as l1}from"./index-C7GhFfoB.js";import{E as zg}from"./row-DpF5mSpd.js";import{E as u1}from"./empty-ORKmbKPa.js";import{E as f1,a as h1,b as v1}from"./select-CuPeM5Ao.js";import{E as Hg}from"./col-CIrkW6Bj.js";import{E as Vg}from"./card-DDgtSK9z.js";import{E as c1}from"./progress-DNV4CN-7.js";/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */var $u=function(e,t){return $u=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(r,n){r.__proto__=n}||function(r,n){for(var i in n)Object.prototype.hasOwnProperty.call(n,i)&&(r[i]=n[i])},$u(e,t)};function N(e,t){if(typeof t!="function"&&t!==null)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");$u(e,t);function r(){this.constructor=e}e.prototype=t===null?Object.create(t):(r.prototype=t.prototype,new r)}var dh=12,d1="sans-serif",Or=dh+"px "+d1,p1=20,g1=100,m1="007LLmW'55;N0500LLLLLLLLLL00NNNLzWW\\\\WQb\\0FWLg\\bWb\\WQ\\WrWWQ000CL5LLFLL0LL**F*gLLLL5F0LF\\FFF5.5N";function y1(e){var t={};if(typeof JSON>"u")return t;for(var r=0;r<e.length;r++){var n=String.fromCharCode(r+32),i=(e.charCodeAt(r)-p1)/g1;t[n]=i}return t}var _1=y1(m1),ur={createCanvas:function(){return typeof document<"u"&&document.createElement("canvas")},measureText:(function(){var e,t;return function(r,n){if(!e){var i=ur.createCanvas();e=i&&i.getContext("2d")}if(e)return t!==n&&(t=e.font=n||Or),e.measureText(r);r=r||"",n=n||Or;var a=/((?:\d+)?\.?\d*)px/.exec(n),o=a&&+a[1]||dh,s=0;if(n.indexOf("mono")>=0)s=o*r.length;else for(var l=0;l<r.length;l++){var u=_1[r[l]];s+=u==null?o:u*o}return{width:s}}})(),loadImage:function(e,t,r){var n=new Image;return n.onload=t,n.onerror=r,n.src=e,n}},Gg=Ri(["Function","RegExp","Date","Error","CanvasGradient","CanvasPattern","Image","Canvas"],function(e,t){return e["[object "+t+"]"]=!0,e},{}),Wg=Ri(["Int8","Uint8","Uint8Clamped","Int16","Uint16","Int32","Uint32","Float32","Float64"],function(e,t){return e["[object "+t+"Array]"]=!0,e},{}),Pi=Object.prototype.toString,Ks=Array.prototype,S1=Ks.forEach,b1=Ks.filter,ph=Ks.slice,w1=Ks.map,Iv=(function(){}).constructor,no=Iv?Iv.prototype:null,gh="__proto__",x1=2311;function Ug(){return x1++}function mh(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];typeof console<"u"&&console.error.apply(console,e)}function st(e){if(e==null||typeof e!="object")return e;var t=e,r=Pi.call(e);if(r==="[object Array]"){if(!ga(e)){t=[];for(var n=0,i=e.length;n<i;n++)t[n]=st(e[n])}}else if(Wg[r]){if(!ga(e)){var a=e.constructor;if(a.from)t=a.from(e);else{t=new a(e.length);for(var n=0,i=e.length;n<i;n++)t[n]=e[n]}}}else if(!Gg[r]&&!ga(e)&&!Aa(e)){t={};for(var o in e)e.hasOwnProperty(o)&&o!==gh&&(t[o]=st(e[o]))}return t}function vt(e,t,r){if(!X(t)||!X(e))return r?st(t):e;for(var n in t)if(t.hasOwnProperty(n)&&n!==gh){var i=e[n],a=t[n];X(a)&&X(i)&&!z(a)&&!z(i)&&!Aa(a)&&!Aa(i)&&!Pv(a)&&!Pv(i)&&!ga(a)&&!ga(i)?vt(i,a,r):(r||!(n in e))&&(e[n]=st(t[n]))}return e}function k(e,t){if(Object.assign)Object.assign(e,t);else for(var r in t)t.hasOwnProperty(r)&&r!==gh&&(e[r]=t[r]);return e}function at(e,t,r){for(var n=St(t),i=0,a=n.length;i<a;i++){var o=n[i];e[o]==null&&(e[o]=t[o])}return e}function ft(e,t){if(e){if(e.indexOf)return e.indexOf(t);for(var r=0,n=e.length;r<n;r++)if(e[r]===t)return r}return-1}function T1(e,t){var r=e.prototype;function n(){}n.prototype=t.prototype,e.prototype=new n;for(var i in r)r.hasOwnProperty(i)&&(e.prototype[i]=r[i]);e.prototype.constructor=e,e.superClass=t}function Ke(e,t,r){if(e="prototype"in e?e.prototype:e,t="prototype"in t?t.prototype:t,Object.getOwnPropertyNames)for(var n=Object.getOwnPropertyNames(t),i=0;i<n.length;i++){var a=n[i];a!=="constructor"&&e[a]==null&&(e[a]=t[a])}else at(e,t)}function Kt(e){return!e||typeof e=="string"?!1:typeof e.length=="number"}function M(e,t,r){if(e&&t)if(e.forEach&&e.forEach===S1)e.forEach(t,r);else if(e.length===+e.length)for(var n=0,i=e.length;n<i;n++)t.call(r,e[n],n,e);else for(var a in e)e.hasOwnProperty(a)&&t.call(r,e[a],a,e)}function $(e,t,r){if(!e)return[];if(!t)return yh(e);if(e.map&&e.map===w1)return e.map(t,r);for(var n=[],i=0,a=e.length;i<a;i++)n.push(t.call(r,e[i],i,e));return n}function Ri(e,t,r,n){if(e&&t){for(var i=0,a=e.length;i<a;i++)r=t.call(n,r,e[i],i,e);return r}}function wt(e,t,r){if(!e)return[];if(!t)return yh(e);if(e.filter&&e.filter===b1)return e.filter(t,r);for(var n=[],i=0,a=e.length;i<a;i++)t.call(r,e[i],i,e)&&n.push(e[i]);return n}function C1(e,t,r){if(e&&t){for(var n=0,i=e.length;n<i;n++)if(t.call(r,e[n],n,e))return e[n]}}function St(e){if(!e)return[];if(Object.keys)return Object.keys(e);var t=[];for(var r in e)e.hasOwnProperty(r)&&t.push(r);return t}function M1(e,t){for(var r=[],n=2;n<arguments.length;n++)r[n-2]=arguments[n];return function(){return e.apply(t,r.concat(ph.call(arguments)))}}var Q=no&&et(no.bind)?no.call.bind(no.bind):M1;function ne(e){for(var t=[],r=1;r<arguments.length;r++)t[r-1]=arguments[r];return function(){return e.apply(this,t.concat(ph.call(arguments)))}}function z(e){return Array.isArray?Array.isArray(e):Pi.call(e)==="[object Array]"}function et(e){return typeof e=="function"}function W(e){return typeof e=="string"}function qu(e){return Pi.call(e)==="[object String]"}function mt(e){return typeof e=="number"}function X(e){var t=typeof e;return t==="function"||!!e&&t==="object"}function Pv(e){return!!Gg[Pi.call(e)]}function ie(e){return!!Wg[Pi.call(e)]}function Aa(e){return typeof e=="object"&&typeof e.nodeType=="number"&&typeof e.ownerDocument=="object"}function Qs(e){return e.colorStops!=null}function D1(e){return e.image!=null}function A1(e){return Pi.call(e)==="[object RegExp]"}function La(e){return e!==e}function fs(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];for(var r=0,n=e.length;r<n;r++)if(e[r]!=null)return e[r]}function q(e,t){return e??t}function yi(e,t,r){return e??t??r}function yh(e){for(var t=[],r=1;r<arguments.length;r++)t[r-1]=arguments[r];return ph.apply(e,t)}function _h(e){if(typeof e=="number")return[e,e,e,e];var t=e.length;return t===2?[e[0],e[1],e[0],e[1]]:t===3?[e[0],e[1],e[2],e[1]]:e}function fr(e,t){if(!e)throw new Error(t)}function Ge(e){return e==null?null:typeof e.trim=="function"?e.trim():e.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,"")}var Yg="__ec_primitive__";function hs(e){e[Yg]=!0}function ga(e){return e[Yg]}var L1=(function(){function e(){this.data={}}return e.prototype.delete=function(t){var r=this.has(t);return r&&delete this.data[t],r},e.prototype.has=function(t){return this.data.hasOwnProperty(t)},e.prototype.get=function(t){return this.data[t]},e.prototype.set=function(t,r){return this.data[t]=r,this},e.prototype.keys=function(){return St(this.data)},e.prototype.forEach=function(t){var r=this.data;for(var n in r)r.hasOwnProperty(n)&&t(r[n],n)},e})(),Zg=typeof Map=="function";function I1(){return Zg?new Map:new L1}var P1=(function(){function e(t){var r=z(t);this.data=I1();var n=this;t instanceof e?t.each(i):t&&M(t,i);function i(a,o){r?n.set(a,o):n.set(o,a)}}return e.prototype.hasKey=function(t){return this.data.has(t)},e.prototype.get=function(t){return this.data.get(t)},e.prototype.set=function(t,r){return this.data.set(t,r),r},e.prototype.each=function(t,r){this.data.forEach(function(n,i){t.call(r,n,i)})},e.prototype.keys=function(){var t=this.data.keys();return Zg?Array.from(t):t},e.prototype.removeKey=function(t){this.data.delete(t)},e})();function K(e){return new P1(e)}function R1(e,t){for(var r=new e.constructor(e.length+t.length),n=0;n<e.length;n++)r[n]=e[n];for(var i=e.length,n=0;n<t.length;n++)r[n+i]=t[n];return r}function Js(e,t){var r;if(Object.create)r=Object.create(e);else{var n=function(){};n.prototype=e,r=new n}return t&&k(r,t),r}function Xg(e){var t=e.style;t.webkitUserSelect="none",t.userSelect="none",t.webkitTapHighlightColor="rgba(0,0,0,0)",t["-webkit-touch-callout"]="none"}function he(e,t){return e.hasOwnProperty(t)}function qt(){}var E1=180/Math.PI,k1=(function(){function e(){this.firefox=!1,this.ie=!1,this.edge=!1,this.newEdge=!1,this.weChat=!1}return e})(),O1=(function(){function e(){this.browser=new k1,this.node=!1,this.wxa=!1,this.worker=!1,this.svgSupported=!1,this.touchEventsSupported=!1,this.pointerEventsSupported=!1,this.domSupported=!1,this.transformSupported=!1,this.transform3dSupported=!1,this.hasGlobalWindow=typeof window<"u"}return e})(),nt=new O1;typeof wx=="object"&&typeof wx.getSystemInfoSync=="function"?(nt.wxa=!0,nt.touchEventsSupported=!0):typeof document>"u"&&typeof self<"u"?nt.worker=!0:!nt.hasGlobalWindow||"Deno"in window||typeof navigator<"u"&&typeof navigator.userAgent=="string"&&navigator.userAgent.indexOf("Node.js")>-1?(nt.node=!0,nt.svgSupported=!0):B1(navigator.userAgent,nt);function B1(e,t){var r=t.browser,n=e.match(/Firefox\/([\d.]+)/),i=e.match(/MSIE\s([\d.]+)/)||e.match(/Trident\/.+?rv:(([\d.]+))/),a=e.match(/Edge?\/([\d.]+)/),o=/micromessenger/i.test(e);n&&(r.firefox=!0,r.version=n[1]),i&&(r.ie=!0,r.version=i[1]),a&&(r.edge=!0,r.version=a[1],r.newEdge=+a[1].split(".")[0]>18),o&&(r.weChat=!0),t.svgSupported=typeof SVGRect<"u",t.touchEventsSupported="ontouchstart"in window&&!r.ie&&!r.edge,t.pointerEventsSupported="onpointerdown"in window&&(r.edge||r.ie&&+r.version>=11);var s=t.domSupported=typeof document<"u";if(s){var l=document.documentElement.style;t.transform3dSupported=(r.ie&&"transition"in l||r.edge||"WebKitCSSMatrix"in window&&"m11"in new WebKitCSSMatrix||"MozPerspective"in l)&&!("OTransition"in l),t.transformSupported=t.transform3dSupported||r.ie&&+r.version>=9}}var N1=".",Yr="___EC__COMPONENT__CONTAINER___",$g="___EC__EXTENDED_CLASS___";function We(e){var t={main:"",sub:""};if(e){var r=e.split(N1);t.main=r[0]||"",t.sub=r[1]||""}return t}function F1(e){fr(/^[a-zA-Z0-9_]+([.][a-zA-Z0-9_]+)?$/.test(e),'componentType "'+e+'" illegal')}function z1(e){return!!(e&&e[$g])}function Sh(e,t){e.$constructor=e,e.extend=function(r){var n=this,i;return H1(n)?i=(function(a){N(o,a);function o(){return a.apply(this,arguments)||this}return o})(n):(i=function(){(r.$constructor||n).apply(this,arguments)},T1(i,this)),k(i.prototype,r),i[$g]=!0,i.extend=this.extend,i.superCall=W1,i.superApply=U1,i.superClass=n,i}}function H1(e){return et(e)&&/^class\s/.test(Function.prototype.toString.call(e))}function qg(e,t){e.extend=t.extend}var V1=Math.round(Math.random()*10);function G1(e){var t=["__\0is_clz",V1++].join("_");e.prototype[t]=!0,e.isInstance=function(r){return!!(r&&r[t])}}function W1(e,t){for(var r=[],n=2;n<arguments.length;n++)r[n-2]=arguments[n];return this.superClass.prototype[t].apply(e,r)}function U1(e,t,r){return this.superClass.prototype[t].apply(e,r)}function js(e){var t={};e.registerClass=function(n){var i=n.type||n.prototype.type;if(i){F1(i),n.prototype.type=i;var a=We(i);if(!a.sub)t[a.main]=n;else if(a.sub!==Yr){var o=r(a);o[a.sub]=n}}return n},e.getClass=function(n,i,a){var o=t[n];if(o&&o[Yr]&&(o=i?o[i]:null),a&&!o)throw new Error(i?"Component "+n+"."+(i||"")+" is used but not imported.":n+".type should be specified.");return o},e.getClassesByMainType=function(n){var i=We(n),a=[],o=t[i.main];return o&&o[Yr]?M(o,function(s,l){l!==Yr&&a.push(s)}):a.push(o),a},e.hasClass=function(n){var i=We(n);return!!t[i.main]},e.getAllClassMainTypes=function(){var n=[];return M(t,function(i,a){n.push(a)}),n},e.hasSubTypes=function(n){var i=We(n),a=t[i.main];return a&&a[Yr]};function r(n){var i=t[n.main];return(!i||!i[Yr])&&(i=t[n.main]={},i[Yr]=!0),i}}function Ia(e,t){for(var r=0;r<e.length;r++)e[r][1]||(e[r][1]=e[r][0]);return t=t||!1,function(n,i,a){for(var o={},s=0;s<e.length;s++){var l=e[s][1];if(!(i&&ft(i,l)>=0||a&&ft(a,l)<0)){var u=n.getShallow(l,t);u!=null&&(o[e[s][0]]=u)}}return o}}var Y1=[["fill","color"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["opacity"],["shadowColor"]],Z1=Ia(Y1),X1=(function(){function e(){}return e.prototype.getAreaStyle=function(t,r){return Z1(this,t,r)},e})(),Kg=(function(){function e(t){this.value=t}return e})(),$1=(function(){function e(){this._len=0}return e.prototype.insert=function(t){var r=new Kg(t);return this.insertEntry(r),r},e.prototype.insertEntry=function(t){this.head?(this.tail.next=t,t.prev=this.tail,t.next=null,this.tail=t):this.head=this.tail=t,this._len++},e.prototype.remove=function(t){var r=t.prev,n=t.next;r?r.next=n:this.head=n,n?n.prev=r:this.tail=r,t.next=t.prev=null,this._len--},e.prototype.len=function(){return this._len},e.prototype.clear=function(){this.head=this.tail=null,this._len=0},e})(),xi=(function(){function e(t){this._list=new $1,this._maxSize=10,this._map={},this._maxSize=t}return e.prototype.put=function(t,r){var n=this._list,i=this._map,a=null;if(i[t]==null){var o=n.len(),s=this._lastRemovedEntry;if(o>=this._maxSize&&o>0){var l=n.head;n.remove(l),delete i[l.key],a=l.value,this._lastRemovedEntry=l}s?s.value=r:s=new Kg(r),s.key=t,n.insertEntry(s),i[t]=s}return a},e.prototype.get=function(t){var r=this._map[t],n=this._list;if(r!=null)return r!==n.tail&&(n.remove(r),n.insertEntry(r)),r.value},e.prototype.clear=function(){this._list.clear(),this._map={}},e.prototype.len=function(){return this._list.len()},e})(),Ku=new xi(50);function q1(e){if(typeof e=="string"){var t=Ku.get(e);return t&&t.image}else return e}function Qg(e,t,r,n,i){if(e)if(typeof e=="string"){if(t&&t.__zrImageSrc===e||!r)return t;var a=Ku.get(e),o={hostEl:r,cb:n,cbPayload:i};return a?(t=a.image,!tl(t)&&a.pending.push(o)):(t=ur.loadImage(e,Rv,Rv),t.__zrImageSrc=e,Ku.put(e,t.__cachedImgObj={image:t,pending:[o]})),t}else return e;else return t}function Rv(){var e=this.__cachedImgObj;this.onload=this.onerror=this.__cachedImgObj=null;for(var t=0;t<e.pending.length;t++){var r=e.pending[t],n=r.cb;n&&n(this,r.cbPayload),r.hostEl.dirty()}e.pending.length=0}function tl(e){return e&&e.width&&e.height}function sr(){return[1,0,0,1,0,0]}function bh(e){return e[0]=1,e[1]=0,e[2]=0,e[3]=1,e[4]=0,e[5]=0,e}function Jg(e,t){return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e}function ma(e,t,r){var n=t[0]*r[0]+t[2]*r[1],i=t[1]*r[0]+t[3]*r[1],a=t[0]*r[2]+t[2]*r[3],o=t[1]*r[2]+t[3]*r[3],s=t[0]*r[4]+t[2]*r[5]+t[4],l=t[1]*r[4]+t[3]*r[5]+t[5];return e[0]=n,e[1]=i,e[2]=a,e[3]=o,e[4]=s,e[5]=l,e}function Qu(e,t,r){return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4]+r[0],e[5]=t[5]+r[1],e}function wh(e,t,r,n){n===void 0&&(n=[0,0]);var i=t[0],a=t[2],o=t[4],s=t[1],l=t[3],u=t[5],f=Math.sin(r),h=Math.cos(r);return e[0]=i*h+s*f,e[1]=-i*f+s*h,e[2]=a*h+l*f,e[3]=-a*f+h*l,e[4]=h*(o-n[0])+f*(u-n[1])+n[0],e[5]=h*(u-n[1])-f*(o-n[0])+n[1],e}function K1(e,t,r){var n=r[0],i=r[1];return e[0]=t[0]*n,e[1]=t[1]*i,e[2]=t[2]*n,e[3]=t[3]*i,e[4]=t[4]*n,e[5]=t[5]*i,e}function Ei(e,t){var r=t[0],n=t[2],i=t[4],a=t[1],o=t[3],s=t[5],l=r*o-a*n;return l?(l=1/l,e[0]=o*l,e[1]=-a*l,e[2]=-n*l,e[3]=r*l,e[4]=(n*s-o*i)*l,e[5]=(a*i-r*s)*l,e):null}var tt=(function(){function e(t,r){this.x=t||0,this.y=r||0}return e.prototype.copy=function(t){return this.x=t.x,this.y=t.y,this},e.prototype.clone=function(){return new e(this.x,this.y)},e.prototype.set=function(t,r){return this.x=t,this.y=r,this},e.prototype.equal=function(t){return t.x===this.x&&t.y===this.y},e.prototype.add=function(t){return this.x+=t.x,this.y+=t.y,this},e.prototype.scale=function(t){this.x*=t,this.y*=t},e.prototype.scaleAndAdd=function(t,r){this.x+=t.x*r,this.y+=t.y*r},e.prototype.sub=function(t){return this.x-=t.x,this.y-=t.y,this},e.prototype.dot=function(t){return this.x*t.x+this.y*t.y},e.prototype.len=function(){return Math.sqrt(this.x*this.x+this.y*this.y)},e.prototype.lenSquare=function(){return this.x*this.x+this.y*this.y},e.prototype.normalize=function(){var t=this.len();return this.x/=t,this.y/=t,this},e.prototype.distance=function(t){var r=this.x-t.x,n=this.y-t.y;return Math.sqrt(r*r+n*n)},e.prototype.distanceSquare=function(t){var r=this.x-t.x,n=this.y-t.y;return r*r+n*n},e.prototype.negate=function(){return this.x=-this.x,this.y=-this.y,this},e.prototype.transform=function(t){if(t){var r=this.x,n=this.y;return this.x=t[0]*r+t[2]*n+t[4],this.y=t[1]*r+t[3]*n+t[5],this}},e.prototype.toArray=function(t){return t[0]=this.x,t[1]=this.y,t},e.prototype.fromArray=function(t){this.x=t[0],this.y=t[1]},e.set=function(t,r,n){t.x=r,t.y=n},e.copy=function(t,r){t.x=r.x,t.y=r.y},e.len=function(t){return Math.sqrt(t.x*t.x+t.y*t.y)},e.lenSquare=function(t){return t.x*t.x+t.y*t.y},e.dot=function(t,r){return t.x*r.x+t.y*r.y},e.add=function(t,r,n){t.x=r.x+n.x,t.y=r.y+n.y},e.sub=function(t,r,n){t.x=r.x-n.x,t.y=r.y-n.y},e.scale=function(t,r,n){t.x=r.x*n,t.y=r.y*n},e.scaleAndAdd=function(t,r,n,i){t.x=r.x+n.x*i,t.y=r.y+n.y*i},e.lerp=function(t,r,n,i){var a=1-i;t.x=a*r.x+i*n.x,t.y=a*r.y+i*n.y},e})(),bn=Math.min,ui=Math.max,Ju=Math.abs,Ev=["x","y"],Q1=["width","height"],Zr=new tt,Xr=new tt,$r=new tt,qr=new tt,le=jg(),sa=le.minTv,ju=le.maxTv,ya=[0,0],it=(function(){function e(t,r,n,i){e.set(this,t,r,n,i)}return e.set=function(t,r,n,i,a){return i<0&&(r=r+i,i=-i),a<0&&(n=n+a,a=-a),t.x=r,t.y=n,t.width=i,t.height=a,t},e.prototype.union=function(t){var r=bn(t.x,this.x),n=bn(t.y,this.y);isFinite(this.x)&&isFinite(this.width)?this.width=ui(t.x+t.width,this.x+this.width)-r:this.width=t.width,isFinite(this.y)&&isFinite(this.height)?this.height=ui(t.y+t.height,this.y+this.height)-n:this.height=t.height,this.x=r,this.y=n},e.prototype.applyTransform=function(t){e.applyTransform(this,this,t)},e.prototype.calculateTransform=function(t){var r=this,n=t.width/r.width,i=t.height/r.height,a=sr();return Qu(a,a,[-r.x,-r.y]),K1(a,a,[n,i]),Qu(a,a,[t.x,t.y]),a},e.prototype.intersect=function(t,r,n){return e.intersect(this,t,r,n)},e.intersect=function(t,r,n,i){n&&tt.set(n,0,0);var a=i&&i.outIntersectRect||null,o=i&&i.clamp;if(a&&(a.x=a.y=a.width=a.height=NaN),!t||!r)return!1;t instanceof e||(t=e.set(J1,t.x,t.y,t.width,t.height)),r instanceof e||(r=e.set(j1,r.x,r.y,r.width,r.height));var s=!!n;le.reset(i,s);var l=le.touchThreshold,u=t.x+l,f=t.x+t.width-l,h=t.y+l,c=t.y+t.height-l,v=r.x+l,d=r.x+r.width-l,p=r.y+l,g=r.y+r.height-l;if(u>f||h>c||v>d||p>g)return!1;var m=!(f<v||d<u||c<p||g<h);return(s||a)&&(ya[0]=1/0,ya[1]=0,kv(u,f,v,d,0,s,a,o),kv(h,c,p,g,1,s,a,o),s&&tt.copy(n,m?le.useDir?le.dirMinTv:sa:ju)),m},e.contain=function(t,r,n){return r>=t.x&&r<=t.x+t.width&&n>=t.y&&n<=t.y+t.height},e.prototype.contain=function(t,r){return e.contain(this,t,r)},e.prototype.clone=function(){return new e(this.x,this.y,this.width,this.height)},e.prototype.copy=function(t){e.copy(this,t)},e.prototype.plain=function(){return{x:this.x,y:this.y,width:this.width,height:this.height}},e.prototype.isFinite=function(){return isFinite(this.x)&&isFinite(this.y)&&isFinite(this.width)&&isFinite(this.height)},e.prototype.isZero=function(){return this.width===0||this.height===0},e.create=function(t){return new e(t.x,t.y,t.width,t.height)},e.copy=function(t,r){return t.x=r.x,t.y=r.y,t.width=r.width,t.height=r.height,t},e.applyTransform=function(t,r,n){if(!n){t!==r&&e.copy(t,r);return}if(n[1]<1e-5&&n[1]>-1e-5&&n[2]<1e-5&&n[2]>-1e-5){var i=n[0],a=n[3],o=n[4],s=n[5];t.x=r.x*i+o,t.y=r.y*a+s,t.width=r.width*i,t.height=r.height*a,t.width<0&&(t.x+=t.width,t.width=-t.width),t.height<0&&(t.y+=t.height,t.height=-t.height);return}Zr.x=$r.x=r.x,Zr.y=qr.y=r.y,Xr.x=qr.x=r.x+r.width,Xr.y=$r.y=r.y+r.height,Zr.transform(n),qr.transform(n),Xr.transform(n),$r.transform(n),t.x=bn(Zr.x,Xr.x,$r.x,qr.x),t.y=bn(Zr.y,Xr.y,$r.y,qr.y);var l=ui(Zr.x,Xr.x,$r.x,qr.x),u=ui(Zr.y,Xr.y,$r.y,qr.y);t.width=l-t.x,t.height=u-t.y},e})(),J1=new it(0,0,0,0),j1=new it(0,0,0,0);function kv(e,t,r,n,i,a,o,s){var l=Ju(t-r),u=Ju(n-e),f=bn(l,u),h=Ev[i],c=Ev[1-i],v=Q1[i];t<r||n<e?l<u?(a&&(ju[h]=-l),s&&(o[h]=t,o[v]=0)):(a&&(ju[h]=u),s&&(o[h]=e,o[v]=0)):(o&&(o[h]=ui(e,r),o[v]=bn(t,n)-o[h]),a&&(f<ya[0]||le.useDir)&&(ya[0]=bn(f,ya[0]),(l<u||!le.bidirectional)&&(sa[h]=l,sa[c]=0,le.useDir&&le.calcDirMTV()),(l>=u||!le.bidirectional)&&(sa[h]=-u,sa[c]=0,le.useDir&&le.calcDirMTV())))}function jg(){var e=0,t=new tt,r=new tt,n={minTv:new tt,maxTv:new tt,useDir:!1,dirMinTv:new tt,touchThreshold:0,bidirectional:!0,negativeSize:!1,reset:function(a,o){n.touchThreshold=0,a&&a.touchThreshold!=null&&(n.touchThreshold=ui(0,a.touchThreshold)),n.negativeSize=!1,o&&(n.minTv.set(1/0,1/0),n.maxTv.set(0,0),n.useDir=!1,a&&a.direction!=null&&(n.useDir=!0,n.dirMinTv.copy(n.minTv),r.copy(n.minTv),e=a.direction,n.bidirectional=a.bidirectional==null||!!a.bidirectional,n.bidirectional||t.set(Math.cos(e),Math.sin(e))))},calcDirMTV:function(){var a=n.minTv,o=n.dirMinTv,s=a.y*a.y+a.x*a.x,l=Math.sin(e),u=Math.cos(e),f=l*a.y+u*a.x;if(i(f)){i(a.x)&&i(a.y)&&o.set(0,0);return}if(r.x=s*u/f,r.y=s*l/f,i(r.x)&&i(r.y)){o.set(0,0);return}(n.bidirectional||t.dot(r)>0)&&r.len()<o.len()&&o.copy(r)}};function i(a){return Ju(a)<1e-10}return n}function Ye(e){io||(io=new xi(100)),e=e||Or;var t=io.get(e);return t||(t={font:e,strWidthCache:new xi(500),asciiWidthMap:null,asciiWidthMapTried:!1,stWideCharWidth:ur.measureText("国",e).width,asciiCharWidth:ur.measureText("a",e).width},io.put(e,t)),t}var io;function tS(e){if(!(Sl>=Ov)){e=e||Or;for(var t=[],r=+new Date,n=0;n<=127;n++)t[n]=ur.measureText(String.fromCharCode(n),e).width;var i=+new Date-r;return i>16?Sl=Ov:i>2&&Sl++,t}}var Sl=0,Ov=5;function tm(e,t){return e.asciiWidthMapTried||(e.asciiWidthMap=tS(e.font),e.asciiWidthMapTried=!0),0<=t&&t<=127?e.asciiWidthMap!=null?e.asciiWidthMap[t]:e.asciiCharWidth:e.stWideCharWidth}function Ze(e,t){var r=e.strWidthCache,n=r.get(t);return n==null&&(n=ur.measureText(t,e.font).width,r.put(t,n)),n}function Bv(e,t,r,n){var i=Ze(Ye(t),e),a=el(t),o=Ti(0,i,r),s=Mn(0,a,n),l=new it(o,s,i,a);return l}function em(e,t,r,n){var i=((e||"")+"").split(`
`),a=i.length;if(a===1)return Bv(i[0],t,r,n);for(var o=new it(0,0,0,0),s=0;s<i.length;s++){var l=Bv(i[s],t,r,n);s===0?o.copy(l):o.union(l)}return o}function Ti(e,t,r,n){return r==="right"?n?e+=t:e-=t:r==="center"&&(n?e+=t/2:e-=t/2),e}function Mn(e,t,r,n){return r==="middle"?n?e+=t/2:e-=t/2:r==="bottom"&&(n?e+=t:e-=t),e}function el(e){return Ye(e).stWideCharWidth}function Rn(e,t){return typeof e=="string"?e.lastIndexOf("%")>=0?parseFloat(e)/100*t:parseFloat(e):e}function rm(e,t,r){var n=t.position||"inside",i=t.distance!=null?t.distance:5,a=r.height,o=r.width,s=a/2,l=r.x,u=r.y,f="left",h="top";if(n instanceof Array)l+=Rn(n[0],r.width),u+=Rn(n[1],r.height),f=null,h=null;else switch(n){case"left":l-=i,u+=s,f="right",h="middle";break;case"right":l+=i+o,u+=s,h="middle";break;case"top":l+=o/2,u-=i,f="center",h="bottom";break;case"bottom":l+=o/2,u+=a+i,f="center";break;case"inside":l+=o/2,u+=s,f="center",h="middle";break;case"insideLeft":l+=i,u+=s,h="middle";break;case"insideRight":l+=o-i,u+=s,f="right",h="middle";break;case"insideTop":l+=o/2,u+=i,f="center";break;case"insideBottom":l+=o/2,u+=a-i,f="center",h="bottom";break;case"insideTopLeft":l+=i,u+=i;break;case"insideTopRight":l+=o-i,u+=i,f="right";break;case"insideBottomLeft":l+=i,u+=a-i,h="bottom";break;case"insideBottomRight":l+=o-i,u+=a-i,f="right",h="bottom";break}return e=e||{},e.x=l,e.y=u,e.align=f,e.verticalAlign=h,e}var bl=/\{([a-zA-Z0-9_]+)\|([^}]*)\}/g;function eS(e,t,r,n,i,a){if(!r){e.text="",e.isTruncated=!1;return}var o=(t+"").split(`
`);a=nm(r,n,i,a);for(var s=!1,l={},u=0,f=o.length;u<f;u++)im(l,o[u],a),o[u]=l.textLine,s=s||l.isTruncated;e.text=o.join(`
`),e.isTruncated=s}function nm(e,t,r,n){n=n||{};var i=k({},n);r=q(r,"..."),i.maxIterations=q(n.maxIterations,2);var a=i.minChar=q(n.minChar,0),o=i.fontMeasureInfo=Ye(t),s=o.asciiCharWidth;i.placeholder=q(n.placeholder,"");for(var l=e=Math.max(0,e-1),u=0;u<a&&l>=s;u++)l-=s;var f=Ze(o,r);return f>l&&(r="",f=0),l=e-f,i.ellipsis=r,i.ellipsisWidth=f,i.contentWidth=l,i.containerWidth=e,i}function im(e,t,r){var n=r.containerWidth,i=r.contentWidth,a=r.fontMeasureInfo;if(!n){e.textLine="",e.isTruncated=!1;return}var o=Ze(a,t);if(o<=n){e.textLine=t,e.isTruncated=!1;return}for(var s=0;;s++){if(o<=i||s>=r.maxIterations){t+=r.ellipsis;break}var l=s===0?rS(t,i,a):o>0?Math.floor(t.length*i/o):0;t=t.substr(0,l),o=Ze(a,t)}t===""&&(t=r.placeholder),e.textLine=t,e.isTruncated=!0}function rS(e,t,r){for(var n=0,i=0,a=e.length;i<a&&n<t;i++)n+=tm(r,e.charCodeAt(i));return i}function nS(e,t,r,n){var i=xh(e),a=t.overflow,o=t.padding,s=o?o[1]+o[3]:0,l=o?o[0]+o[2]:0,u=t.font,f=a==="truncate",h=el(u),c=q(t.lineHeight,h),v=t.lineOverflow==="truncate",d=!1,p=t.width;p==null&&r!=null&&(p=r-s);var g=t.height;g==null&&n!=null&&(g=n-l);var m;p!=null&&(a==="break"||a==="breakAll")?m=i?am(i,t.font,p,a==="breakAll",0).lines:[]:m=i?i.split(`
`):[];var y=m.length*c;if(g==null&&(g=y),y>g&&v){var _=Math.floor(g/c);d=d||m.length>_,m=m.slice(0,_),y=m.length*c}if(i&&f&&p!=null)for(var S=nm(p,u,t.ellipsis,{minChar:t.truncateMinChar,placeholder:t.placeholder}),w={},b=0;b<m.length;b++)im(w,m[b],S),m[b]=w.textLine,d=d||w.isTruncated;for(var x=g,C=0,T=Ye(u),b=0;b<m.length;b++)C=Math.max(Ze(T,m[b]),C);p==null&&(p=C);var D=p;return x+=l,D+=s,{lines:m,height:g,outerWidth:D,outerHeight:x,lineHeight:c,calculatedLineHeight:h,contentWidth:C,contentHeight:y,width:p,isTruncated:d}}var iS=(function(){function e(){}return e})(),Nv=(function(){function e(t){this.tokens=[],t&&(this.tokens=t)}return e})(),aS=(function(){function e(){this.width=0,this.height=0,this.contentWidth=0,this.contentHeight=0,this.outerWidth=0,this.outerHeight=0,this.lines=[],this.isTruncated=!1}return e})();function oS(e,t,r,n,i){var a=new aS,o=xh(e);if(!o)return a;var s=t.padding,l=s?s[1]+s[3]:0,u=s?s[0]+s[2]:0,f=t.width;f==null&&r!=null&&(f=r-l);var h=t.height;h==null&&n!=null&&(h=n-u);for(var c=t.overflow,v=(c==="break"||c==="breakAll")&&f!=null?{width:f,accumWidth:0,breakAll:c==="breakAll"}:null,d=bl.lastIndex=0,p;(p=bl.exec(o))!=null;){var g=p.index;g>d&&wl(a,o.substring(d,g),t,v),wl(a,p[2],t,v,p[1]),d=bl.lastIndex}d<o.length&&wl(a,o.substring(d,o.length),t,v);var m=[],y=0,_=0,S=c==="truncate",w=t.lineOverflow==="truncate",b={};function x(Ht,ce,de){Ht.width=ce,Ht.lineHeight=de,y+=de,_=Math.max(_,ce)}t:for(var C=0;C<a.lines.length;C++){for(var T=a.lines[C],D=0,A=0,P=0;P<T.tokens.length;P++){var L=T.tokens[P],I=L.styleName&&t.rich[L.styleName]||{},R=L.textPadding=I.padding,E=R?R[1]+R[3]:0,G=L.font=I.font||t.font;L.contentHeight=el(G);var F=q(I.height,L.contentHeight);if(L.innerHeight=F,R&&(F+=R[0]+R[2]),L.height=F,L.lineHeight=yi(I.lineHeight,t.lineHeight,F),L.align=I&&I.align||i,L.verticalAlign=I&&I.verticalAlign||"middle",w&&h!=null&&y+L.lineHeight>h){var H=a.lines.length;P>0?(T.tokens=T.tokens.slice(0,P),x(T,A,D),a.lines=a.lines.slice(0,C+1)):a.lines=a.lines.slice(0,C),a.isTruncated=a.isTruncated||a.lines.length<H;break t}var V=I.width,U=V==null||V==="auto";if(typeof V=="string"&&V.charAt(V.length-1)==="%")L.percentWidth=V,m.push(L),L.contentWidth=Ze(Ye(G),L.text);else{if(U){var Z=I.backgroundColor,J=Z&&Z.image;J&&(J=q1(J),tl(J)&&(L.width=Math.max(L.width,J.width*F/J.height)))}var ot=S&&f!=null?f-A:null;ot!=null&&ot<L.width?!U||ot<E?(L.text="",L.width=L.contentWidth=0):(eS(b,L.text,ot-E,G,t.ellipsis,{minChar:t.truncateMinChar}),L.text=b.text,a.isTruncated=a.isTruncated||b.isTruncated,L.width=L.contentWidth=Ze(Ye(G),L.text)):L.contentWidth=Ze(Ye(G),L.text)}L.width+=E,A+=L.width,I&&(D=Math.max(D,L.lineHeight))}x(T,A,D)}a.outerWidth=a.width=q(f,_),a.outerHeight=a.height=q(h,y),a.contentHeight=y,a.contentWidth=_,a.outerWidth+=l,a.outerHeight+=u;for(var C=0;C<m.length;C++){var L=m[C],yt=L.percentWidth;L.width=parseInt(yt,10)/100*a.width}return a}function wl(e,t,r,n,i){var a=t==="",o=i&&r.rich[i]||{},s=e.lines,l=o.font||r.font,u=!1,f,h;if(n){var c=o.padding,v=c?c[1]+c[3]:0;if(o.width!=null&&o.width!=="auto"){var d=Rn(o.width,n.width)+v;s.length>0&&d+n.accumWidth>n.width&&(f=t.split(`
`),u=!0),n.accumWidth=d}else{var p=am(t,l,n.width,n.breakAll,n.accumWidth);n.accumWidth=p.accumWidth+v,h=p.linesWidths,f=p.lines}}f||(f=t.split(`
`));for(var g=Ye(l),m=0;m<f.length;m++){var y=f[m],_=new iS;if(_.styleName=i,_.text=y,_.isLineHolder=!y&&!a,typeof o.width=="number"?_.width=o.width:_.width=h?h[m]:Ze(g,y),!m&&!u){var S=(s[s.length-1]||(s[0]=new Nv)).tokens,w=S.length;w===1&&S[0].isLineHolder?S[0]=_:(y||!w||a)&&S.push(_)}else s.push(new Nv([_]))}}function sS(e){var t=e.charCodeAt(0);return t>=32&&t<=591||t>=880&&t<=4351||t>=4608&&t<=5119||t>=7680&&t<=8303}var lS=Ri(",&?/;] ".split(""),function(e,t){return e[t]=!0,e},{});function uS(e){return sS(e)?!!lS[e]:!0}function am(e,t,r,n,i){for(var a=[],o=[],s="",l="",u=0,f=0,h=Ye(t),c=0;c<e.length;c++){var v=e.charAt(c);if(v===`
`){l&&(s+=l,f+=u),a.push(s),o.push(f),s="",l="",u=0,f=0;continue}var d=tm(h,v.charCodeAt(0)),p=n?!1:!uS(v);if(a.length?f+d>r:i+f+d>r){f?(s||l)&&(p?(s||(s=l,l="",u=0,f=u),a.push(s),o.push(f-u),l+=v,u+=d,s="",f=u):(l&&(s+=l,l="",u=0),a.push(s),o.push(f),s=v,f=d)):p?(a.push(l),o.push(u),l=v,u=d):(a.push(v),o.push(d));continue}f+=d,p?(l+=v,u+=d):(l&&(s+=l,l="",u=0),s+=v)}return l&&(s+=l),s&&(a.push(s),o.push(f)),a.length===1&&(f+=i),{accumWidth:f,lines:a,linesWidths:o}}function Fv(e,t,r,n,i,a){if(e.baseX=r,e.baseY=n,e.outerWidth=e.outerHeight=null,!!t){var o=t.width*2,s=t.height*2;it.set(zv,Ti(r,o,i),Mn(n,s,a),o,s),it.intersect(t,zv,null,Hv);var l=Hv.outIntersectRect;e.outerWidth=l.width,e.outerHeight=l.height,e.baseX=Ti(l.x,l.width,i,!0),e.baseY=Mn(l.y,l.height,a,!0)}}var zv=new it(0,0,0,0),Hv={outIntersectRect:{},clamp:!0};function xh(e){return e!=null?e+="":e=""}function fS(e){var t=xh(e.text),r=e.font,n=Ze(Ye(r),t),i=el(r);return tf(e,n,i,null)}function tf(e,t,r,n){var i=new it(Ti(e.x||0,t,e.textAlign),Mn(e.y||0,r,e.textBaseline),t,r),a=n??(om(e)?e.lineWidth:0);return a>0&&(i.x-=a/2,i.y-=a/2,i.width+=a,i.height+=a),i}function om(e){var t=e.stroke;return t!=null&&t!=="none"&&e.lineWidth>0}function ki(e,t){return e==null&&(e=0),t==null&&(t=0),[e,t]}function hS(e){return[e[0],e[1]]}function Vv(e,t,r){return e[0]=t[0]+r[0],e[1]=t[1]+r[1],e}function vS(e,t,r){return e[0]=t[0]-r[0],e[1]=t[1]-r[1],e}function cS(e){return Math.sqrt(dS(e))}function dS(e){return e[0]*e[0]+e[1]*e[1]}function xl(e,t,r){return e[0]=t[0]*r,e[1]=t[1]*r,e}function pS(e,t){var r=cS(t);return r===0?(e[0]=0,e[1]=0):(e[0]=t[0]/r,e[1]=t[1]/r),e}function ef(e,t){return Math.sqrt((e[0]-t[0])*(e[0]-t[0])+(e[1]-t[1])*(e[1]-t[1]))}var rf=ef;function gS(e,t){return(e[0]-t[0])*(e[0]-t[0])+(e[1]-t[1])*(e[1]-t[1])}var _i=gS;function Zo(e,t,r,n){return e[0]=t[0]+n*(r[0]-t[0]),e[1]=t[1]+n*(r[1]-t[1]),e}function we(e,t,r){var n=t[0],i=t[1];return e[0]=r[0]*n+r[2]*i+r[4],e[1]=r[1]*n+r[3]*i+r[5],e}function fi(e,t,r){return e[0]=Math.min(t[0],r[0]),e[1]=Math.min(t[1],r[1]),e}function hi(e,t,r){return e[0]=Math.max(t[0],r[0]),e[1]=Math.max(t[1],r[1]),e}var Gv=bh,Wv=5e-5;function Kr(e){return e>Wv||e<-Wv}var Qr=[],Vn=[],Tl=sr(),Cl=Math.abs,qa=(function(){function e(){}return e.prototype.getLocalTransform=function(t){return e.getLocalTransform(this,t)},e.prototype.setPosition=function(t){this.x=t[0],this.y=t[1]},e.prototype.setScale=function(t){this.scaleX=t[0],this.scaleY=t[1]},e.prototype.setSkew=function(t){this.skewX=t[0],this.skewY=t[1]},e.prototype.setOrigin=function(t){this.originX=t[0],this.originY=t[1]},e.prototype.needLocalTransform=function(){return Kr(this.rotation)||Kr(this.x)||Kr(this.y)||Kr(this.scaleX-1)||Kr(this.scaleY-1)||Kr(this.skewX)||Kr(this.skewY)},e.prototype.updateTransform=function(){var t=this.parent&&this.parent.transform,r=this.needLocalTransform(),n=this.transform;if(!(r||t)){n&&(Gv(n),this.invTransform=null);return}n=n||sr(),r?this.getLocalTransform(n):Gv(n),t&&(r?ma(n,t,n):Jg(n,t)),this.transform=n,this._resolveGlobalScaleRatio(n)},e.prototype._resolveGlobalScaleRatio=function(t){var r=this.globalScaleRatio;if(r!=null&&r!==1){this.getGlobalScale(Qr);var n=Qr[0]<0?-1:1,i=Qr[1]<0?-1:1,a=((Qr[0]-n)*r+n)/Qr[0]||0,o=((Qr[1]-i)*r+i)/Qr[1]||0;t[0]*=a,t[1]*=a,t[2]*=o,t[3]*=o}this.invTransform=this.invTransform||sr(),Ei(this.invTransform,t)},e.prototype.getComputedTransform=function(){for(var t=this,r=[];t;)r.push(t),t=t.parent;for(;t=r.pop();)t.updateTransform();return this.transform},e.prototype.setLocalTransform=function(t){if(t){var r=t[0]*t[0]+t[1]*t[1],n=t[2]*t[2]+t[3]*t[3],i=Math.atan2(t[1],t[0]),a=Math.PI/2+i-Math.atan2(t[3],t[2]);n=Math.sqrt(n)*Math.cos(a),r=Math.sqrt(r),this.skewX=a,this.skewY=0,this.rotation=-i,this.x=+t[4],this.y=+t[5],this.scaleX=r,this.scaleY=n,this.originX=0,this.originY=0}},e.prototype.decomposeTransform=function(){if(this.transform){var t=this.parent,r=this.transform;t&&t.transform&&(t.invTransform=t.invTransform||sr(),ma(Vn,t.invTransform,r),r=Vn);var n=this.originX,i=this.originY;(n||i)&&(Tl[4]=n,Tl[5]=i,ma(Vn,r,Tl),Vn[4]-=n,Vn[5]-=i,r=Vn),this.setLocalTransform(r)}},e.prototype.getGlobalScale=function(t){var r=this.transform;return t=t||[],r?(t[0]=Math.sqrt(r[0]*r[0]+r[1]*r[1]),t[1]=Math.sqrt(r[2]*r[2]+r[3]*r[3]),r[0]<0&&(t[0]=-t[0]),r[3]<0&&(t[1]=-t[1]),t):(t[0]=1,t[1]=1,t)},e.prototype.transformCoordToLocal=function(t,r){var n=[t,r],i=this.invTransform;return i&&we(n,n,i),n},e.prototype.transformCoordToGlobal=function(t,r){var n=[t,r],i=this.transform;return i&&we(n,n,i),n},e.prototype.getLineScale=function(){var t=this.transform;return t&&Cl(t[0]-1)>1e-10&&Cl(t[3]-1)>1e-10?Math.sqrt(Cl(t[0]*t[3]-t[2]*t[1])):1},e.prototype.copyTransform=function(t){nf(this,t)},e.getLocalTransform=function(t,r){r=r||[];var n=t.originX||0,i=t.originY||0,a=t.scaleX,o=t.scaleY,s=t.anchorX,l=t.anchorY,u=t.rotation||0,f=t.x,h=t.y,c=t.skewX?Math.tan(t.skewX):0,v=t.skewY?Math.tan(-t.skewY):0;if(n||i||s||l){var d=n+s,p=i+l;r[4]=-d*a-c*p*o,r[5]=-p*o-v*d*a}else r[4]=r[5]=0;return r[0]=a,r[3]=o,r[1]=v*a,r[2]=c*o,u&&wh(r,r,u),r[4]+=n+f,r[5]+=i+h,r},e.initDefaultProps=(function(){var t=e.prototype;t.scaleX=t.scaleY=t.globalScaleRatio=1,t.x=t.y=t.originX=t.originY=t.skewX=t.skewY=t.rotation=t.anchorX=t.anchorY=0})(),e})(),Pa=["x","y","originX","originY","anchorX","anchorY","rotation","scaleX","scaleY","skewX","skewY"];function nf(e,t){for(var r=0;r<Pa.length;r++){var n=Pa[r];e[n]=t[n]}}var _a={linear:function(e){return e},quadraticIn:function(e){return e*e},quadraticOut:function(e){return e*(2-e)},quadraticInOut:function(e){return(e*=2)<1?.5*e*e:-.5*(--e*(e-2)-1)},cubicIn:function(e){return e*e*e},cubicOut:function(e){return--e*e*e+1},cubicInOut:function(e){return(e*=2)<1?.5*e*e*e:.5*((e-=2)*e*e+2)},quarticIn:function(e){return e*e*e*e},quarticOut:function(e){return 1- --e*e*e*e},quarticInOut:function(e){return(e*=2)<1?.5*e*e*e*e:-.5*((e-=2)*e*e*e-2)},quinticIn:function(e){return e*e*e*e*e},quinticOut:function(e){return--e*e*e*e*e+1},quinticInOut:function(e){return(e*=2)<1?.5*e*e*e*e*e:.5*((e-=2)*e*e*e*e+2)},sinusoidalIn:function(e){return 1-Math.cos(e*Math.PI/2)},sinusoidalOut:function(e){return Math.sin(e*Math.PI/2)},sinusoidalInOut:function(e){return .5*(1-Math.cos(Math.PI*e))},exponentialIn:function(e){return e===0?0:Math.pow(1024,e-1)},exponentialOut:function(e){return e===1?1:1-Math.pow(2,-10*e)},exponentialInOut:function(e){return e===0?0:e===1?1:(e*=2)<1?.5*Math.pow(1024,e-1):.5*(-Math.pow(2,-10*(e-1))+2)},circularIn:function(e){return 1-Math.sqrt(1-e*e)},circularOut:function(e){return Math.sqrt(1- --e*e)},circularInOut:function(e){return(e*=2)<1?-.5*(Math.sqrt(1-e*e)-1):.5*(Math.sqrt(1-(e-=2)*e)+1)},elasticIn:function(e){var t,r=.1,n=.4;return e===0?0:e===1?1:(!r||r<1?(r=1,t=n/4):t=n*Math.asin(1/r)/(2*Math.PI),-(r*Math.pow(2,10*(e-=1))*Math.sin((e-t)*(2*Math.PI)/n)))},elasticOut:function(e){var t,r=.1,n=.4;return e===0?0:e===1?1:(!r||r<1?(r=1,t=n/4):t=n*Math.asin(1/r)/(2*Math.PI),r*Math.pow(2,-10*e)*Math.sin((e-t)*(2*Math.PI)/n)+1)},elasticInOut:function(e){var t,r=.1,n=.4;return e===0?0:e===1?1:(!r||r<1?(r=1,t=n/4):t=n*Math.asin(1/r)/(2*Math.PI),(e*=2)<1?-.5*(r*Math.pow(2,10*(e-=1))*Math.sin((e-t)*(2*Math.PI)/n)):r*Math.pow(2,-10*(e-=1))*Math.sin((e-t)*(2*Math.PI)/n)*.5+1)},backIn:function(e){var t=1.70158;return e*e*((t+1)*e-t)},backOut:function(e){var t=1.70158;return--e*e*((t+1)*e+t)+1},backInOut:function(e){var t=2.5949095;return(e*=2)<1?.5*(e*e*((t+1)*e-t)):.5*((e-=2)*e*((t+1)*e+t)+2)},bounceIn:function(e){return 1-_a.bounceOut(1-e)},bounceOut:function(e){return e<1/2.75?7.5625*e*e:e<2/2.75?7.5625*(e-=1.5/2.75)*e+.75:e<2.5/2.75?7.5625*(e-=2.25/2.75)*e+.9375:7.5625*(e-=2.625/2.75)*e+.984375},bounceInOut:function(e){return e<.5?_a.bounceIn(e*2)*.5:_a.bounceOut(e*2-1)*.5+.5}},ao=Math.pow,Pr=Math.sqrt,vs=1e-8,sm=1e-4,Uv=Pr(3),oo=1/3,Ve=ki(),Se=ki(),Si=ki();function Ar(e){return e>-vs&&e<vs}function lm(e){return e>vs||e<-vs}function Lt(e,t,r,n,i){var a=1-i;return a*a*(a*e+3*i*t)+i*i*(i*n+3*a*r)}function Yv(e,t,r,n,i){var a=1-i;return 3*(((t-e)*a+2*(r-t)*i)*a+(n-r)*i*i)}function cs(e,t,r,n,i,a){var o=n+3*(t-r)-e,s=3*(r-t*2+e),l=3*(t-e),u=e-i,f=s*s-3*o*l,h=s*l-9*o*u,c=l*l-3*s*u,v=0;if(Ar(f)&&Ar(h))if(Ar(s))a[0]=0;else{var d=-l/s;d>=0&&d<=1&&(a[v++]=d)}else{var p=h*h-4*f*c;if(Ar(p)){var g=h/f,d=-s/o+g,m=-g/2;d>=0&&d<=1&&(a[v++]=d),m>=0&&m<=1&&(a[v++]=m)}else if(p>0){var y=Pr(p),_=f*s+1.5*o*(-h+y),S=f*s+1.5*o*(-h-y);_<0?_=-ao(-_,oo):_=ao(_,oo),S<0?S=-ao(-S,oo):S=ao(S,oo);var d=(-s-(_+S))/(3*o);d>=0&&d<=1&&(a[v++]=d)}else{var w=(2*f*s-3*o*h)/(2*Pr(f*f*f)),b=Math.acos(w)/3,x=Pr(f),C=Math.cos(b),d=(-s-2*x*C)/(3*o),m=(-s+x*(C+Uv*Math.sin(b)))/(3*o),T=(-s+x*(C-Uv*Math.sin(b)))/(3*o);d>=0&&d<=1&&(a[v++]=d),m>=0&&m<=1&&(a[v++]=m),T>=0&&T<=1&&(a[v++]=T)}}return v}function um(e,t,r,n,i){var a=6*r-12*t+6*e,o=9*t+3*n-3*e-9*r,s=3*t-3*e,l=0;if(Ar(o)){if(lm(a)){var u=-s/a;u>=0&&u<=1&&(i[l++]=u)}}else{var f=a*a-4*o*s;if(Ar(f))i[0]=-a/(2*o);else if(f>0){var h=Pr(f),u=(-a+h)/(2*o),c=(-a-h)/(2*o);u>=0&&u<=1&&(i[l++]=u),c>=0&&c<=1&&(i[l++]=c)}}return l}function Br(e,t,r,n,i,a){var o=(t-e)*i+e,s=(r-t)*i+t,l=(n-r)*i+r,u=(s-o)*i+o,f=(l-s)*i+s,h=(f-u)*i+u;a[0]=e,a[1]=o,a[2]=u,a[3]=h,a[4]=h,a[5]=f,a[6]=l,a[7]=n}function fm(e,t,r,n,i,a,o,s,l,u,f){var h,c=.005,v=1/0,d,p,g,m;Ve[0]=l,Ve[1]=u;for(var y=0;y<1;y+=.05)Se[0]=Lt(e,r,i,o,y),Se[1]=Lt(t,n,a,s,y),g=_i(Ve,Se),g<v&&(h=y,v=g);v=1/0;for(var _=0;_<32&&!(c<sm);_++)d=h-c,p=h+c,Se[0]=Lt(e,r,i,o,d),Se[1]=Lt(t,n,a,s,d),g=_i(Se,Ve),d>=0&&g<v?(h=d,v=g):(Si[0]=Lt(e,r,i,o,p),Si[1]=Lt(t,n,a,s,p),m=_i(Si,Ve),p<=1&&m<v?(h=p,v=m):c*=.5);return f&&(f[0]=Lt(e,r,i,o,h),f[1]=Lt(t,n,a,s,h)),Pr(v)}function mS(e,t,r,n,i,a,o,s,l){for(var u=e,f=t,h=0,c=1/l,v=1;v<=l;v++){var d=v*c,p=Lt(e,r,i,o,d),g=Lt(t,n,a,s,d),m=p-u,y=g-f;h+=Math.sqrt(m*m+y*y),u=p,f=g}return h}function Wt(e,t,r,n){var i=1-n;return i*(i*e+2*n*t)+n*n*r}function Zv(e,t,r,n){return 2*((1-n)*(t-e)+n*(r-t))}function yS(e,t,r,n,i){var a=e-2*t+r,o=2*(t-e),s=e-n,l=0;if(Ar(a)){if(lm(o)){var u=-s/o;u>=0&&u<=1&&(i[l++]=u)}}else{var f=o*o-4*a*s;if(Ar(f)){var u=-o/(2*a);u>=0&&u<=1&&(i[l++]=u)}else if(f>0){var h=Pr(f),u=(-o+h)/(2*a),c=(-o-h)/(2*a);u>=0&&u<=1&&(i[l++]=u),c>=0&&c<=1&&(i[l++]=c)}}return l}function hm(e,t,r){var n=e+r-2*t;return n===0?.5:(e-t)/n}function ds(e,t,r,n,i){var a=(t-e)*n+e,o=(r-t)*n+t,s=(o-a)*n+a;i[0]=e,i[1]=a,i[2]=s,i[3]=s,i[4]=o,i[5]=r}function vm(e,t,r,n,i,a,o,s,l){var u,f=.005,h=1/0;Ve[0]=o,Ve[1]=s;for(var c=0;c<1;c+=.05){Se[0]=Wt(e,r,i,c),Se[1]=Wt(t,n,a,c);var v=_i(Ve,Se);v<h&&(u=c,h=v)}h=1/0;for(var d=0;d<32&&!(f<sm);d++){var p=u-f,g=u+f;Se[0]=Wt(e,r,i,p),Se[1]=Wt(t,n,a,p);var v=_i(Se,Ve);if(p>=0&&v<h)u=p,h=v;else{Si[0]=Wt(e,r,i,g),Si[1]=Wt(t,n,a,g);var m=_i(Si,Ve);g<=1&&m<h?(u=g,h=m):f*=.5}}return l&&(l[0]=Wt(e,r,i,u),l[1]=Wt(t,n,a,u)),Pr(h)}function _S(e,t,r,n,i,a,o){for(var s=e,l=t,u=0,f=1/o,h=1;h<=o;h++){var c=h*f,v=Wt(e,r,i,c),d=Wt(t,n,a,c),p=v-s,g=d-l;u+=Math.sqrt(p*p+g*g),s=v,l=d}return u}var SS=/cubic-bezier\(([0-9,\.e ]+)\)/;function cm(e){var t=e&&SS.exec(e);if(t){var r=t[1].split(","),n=+Ge(r[0]),i=+Ge(r[1]),a=+Ge(r[2]),o=+Ge(r[3]);if(isNaN(n+i+a+o))return;var s=[];return function(l){return l<=0?0:l>=1?1:cs(0,n,a,1,l,s)&&Lt(0,i,o,1,s[0])}}}var bS=(function(){function e(t){this._inited=!1,this._startTime=0,this._pausedTime=0,this._paused=!1,this._life=t.life||1e3,this._delay=t.delay||0,this.loop=t.loop||!1,this.onframe=t.onframe||qt,this.ondestroy=t.ondestroy||qt,this.onrestart=t.onrestart||qt,t.easing&&this.setEasing(t.easing)}return e.prototype.step=function(t,r){if(this._inited||(this._startTime=t+this._delay,this._inited=!0),this._paused){this._pausedTime+=r;return}var n=this._life,i=t-this._startTime-this._pausedTime,a=i/n;a<0&&(a=0),a=Math.min(a,1);var o=this.easingFunc,s=o?o(a):a;if(this.onframe(s),a===1)if(this.loop){var l=i%n;this._startTime=t-l,this._pausedTime=0,this.onrestart()}else return!0;return!1},e.prototype.pause=function(){this._paused=!0},e.prototype.resume=function(){this._paused=!1},e.prototype.setEasing=function(t){this.easing=t,this.easingFunc=et(t)?t:_a[t]||cm(t)},e})(),Xv={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function Rr(e){return e=Math.round(e),e<0?0:e>255?255:e}function af(e){return e<0?0:e>1?1:e}function Ml(e){var t=e;return t.length&&t.charAt(t.length-1)==="%"?Rr(parseFloat(t)/100*255):Rr(parseInt(t,10))}function Dn(e){var t=e;return t.length&&t.charAt(t.length-1)==="%"?af(parseFloat(t)/100):af(parseFloat(t))}function Dl(e,t,r){return r<0?r+=1:r>1&&(r-=1),r*6<1?e+(t-e)*r*6:r*2<1?t:r*3<2?e+(t-e)*(2/3-r)*6:e}function so(e,t,r){return e+(t-e)*r}function ge(e,t,r,n,i){return e[0]=t,e[1]=r,e[2]=n,e[3]=i,e}function of(e,t){return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e}var dm=new xi(20),lo=null;function Gn(e,t){lo&&of(lo,t),lo=dm.put(e,lo||t.slice())}function lr(e,t){if(e){t=t||[];var r=dm.get(e);if(r)return of(t,r);e=e+"";var n=e.replace(/ /g,"").toLowerCase();if(n in Xv)return of(t,Xv[n]),Gn(e,t),t;var i=n.length;if(n.charAt(0)==="#"){if(i===4||i===5){var a=parseInt(n.slice(1,4),16);if(!(a>=0&&a<=4095)){ge(t,0,0,0,1);return}return ge(t,(a&3840)>>4|(a&3840)>>8,a&240|(a&240)>>4,a&15|(a&15)<<4,i===5?parseInt(n.slice(4),16)/15:1),Gn(e,t),t}else if(i===7||i===9){var a=parseInt(n.slice(1,7),16);if(!(a>=0&&a<=16777215)){ge(t,0,0,0,1);return}return ge(t,(a&16711680)>>16,(a&65280)>>8,a&255,i===9?parseInt(n.slice(7),16)/255:1),Gn(e,t),t}return}var o=n.indexOf("("),s=n.indexOf(")");if(o!==-1&&s+1===i){var l=n.substr(0,o),u=n.substr(o+1,s-(o+1)).split(","),f=1;switch(l){case"rgba":if(u.length!==4)return u.length===3?ge(t,+u[0],+u[1],+u[2],1):ge(t,0,0,0,1);f=Dn(u.pop());case"rgb":if(u.length>=3)return ge(t,Ml(u[0]),Ml(u[1]),Ml(u[2]),u.length===3?f:Dn(u[3])),Gn(e,t),t;ge(t,0,0,0,1);return;case"hsla":if(u.length!==4){ge(t,0,0,0,1);return}return u[3]=Dn(u[3]),sf(u,t),Gn(e,t),t;case"hsl":if(u.length!==3){ge(t,0,0,0,1);return}return sf(u,t),Gn(e,t),t;default:return}}ge(t,0,0,0,1)}}function sf(e,t){var r=(parseFloat(e[0])%360+360)%360/360,n=Dn(e[1]),i=Dn(e[2]),a=i<=.5?i*(n+1):i+n-i*n,o=i*2-a;return t=t||[],ge(t,Rr(Dl(o,a,r+1/3)*255),Rr(Dl(o,a,r)*255),Rr(Dl(o,a,r-1/3)*255),1),e.length===4&&(t[3]=e[3]),t}function wS(e){if(e){var t=e[0]/255,r=e[1]/255,n=e[2]/255,i=Math.min(t,r,n),a=Math.max(t,r,n),o=a-i,s=(a+i)/2,l,u;if(o===0)l=0,u=0;else{s<.5?u=o/(a+i):u=o/(2-a-i);var f=((a-t)/6+o/2)/o,h=((a-r)/6+o/2)/o,c=((a-n)/6+o/2)/o;t===a?l=c-h:r===a?l=1/3+f-c:n===a&&(l=2/3+h-f),l<0&&(l+=1),l>1&&(l-=1)}var v=[l*360,u,s];return e[3]!=null&&v.push(e[3]),v}}function $v(e,t){var r=lr(e);if(r){for(var n=0;n<3;n++)r[n]=r[n]*(1-t)|0,r[n]>255?r[n]=255:r[n]<0&&(r[n]=0);return rl(r,r.length===4?"rgba":"rgb")}}function xS(e,t,r){if(!(!(t&&t.length)||!(e>=0&&e<=1))){var n=e*(t.length-1),i=Math.floor(n),a=Math.ceil(n),o=lr(t[i]),s=lr(t[a]),l=n-i,u=rl([Rr(so(o[0],s[0],l)),Rr(so(o[1],s[1],l)),Rr(so(o[2],s[2],l)),af(so(o[3],s[3],l))],"rgba");return r?{color:u,leftIndex:i,rightIndex:a,value:n}:u}}function lf(e,t,r,n){var i=lr(e);if(e)return i=wS(i),r!=null&&(i[1]=Dn(et(r)?r(i[1]):r)),n!=null&&(i[2]=Dn(et(n)?n(i[2]):n)),rl(sf(i),"rgba")}function rl(e,t){if(!(!e||!e.length)){var r=e[0]+","+e[1]+","+e[2];return(t==="rgba"||t==="hsva"||t==="hsla")&&(r+=","+e[3]),t+"("+r+")"}}function ps(e,t){var r=lr(e);return r?(.299*r[0]+.587*r[1]+.114*r[2])*r[3]/255+(1-r[3])*t:0}var qv=new xi(100);function Kv(e){if(W(e)){var t=qv.get(e);return t||(t=$v(e,-.1),qv.put(e,t)),t}else if(Qs(e)){var r=k({},e);return r.colorStops=$(e.colorStops,function(n){return{offset:n.offset,color:$v(n.color,-.1)}}),r}return e}function TS(e){return e.type==="linear"}function CS(e){return e.type==="radial"}(function(){return nt.hasGlobalWindow&&et(window.btoa)?function(e){return window.btoa(unescape(encodeURIComponent(e)))}:typeof Buffer<"u"?function(e){return Buffer.from(e).toString("base64")}:function(e){return null}})();var uf=Array.prototype.slice;function rr(e,t,r){return(t-e)*r+e}function Al(e,t,r,n){for(var i=t.length,a=0;a<i;a++)e[a]=rr(t[a],r[a],n);return e}function MS(e,t,r,n){for(var i=t.length,a=i&&t[0].length,o=0;o<i;o++){e[o]||(e[o]=[]);for(var s=0;s<a;s++)e[o][s]=rr(t[o][s],r[o][s],n)}return e}function uo(e,t,r,n){for(var i=t.length,a=0;a<i;a++)e[a]=t[a]+r[a]*n;return e}function Qv(e,t,r,n){for(var i=t.length,a=i&&t[0].length,o=0;o<i;o++){e[o]||(e[o]=[]);for(var s=0;s<a;s++)e[o][s]=t[o][s]+r[o][s]*n}return e}function DS(e,t){for(var r=e.length,n=t.length,i=r>n?t:e,a=Math.min(r,n),o=i[a-1]||{color:[0,0,0,0],offset:0},s=a;s<Math.max(r,n);s++)i.push({offset:o.offset,color:o.color.slice()})}function AS(e,t,r){var n=e,i=t;if(!(!n.push||!i.push)){var a=n.length,o=i.length;if(a!==o){var s=a>o;if(s)n.length=o;else for(var l=a;l<o;l++)n.push(r===1?i[l]:uf.call(i[l]))}for(var u=n[0]&&n[0].length,l=0;l<n.length;l++)if(r===1)isNaN(n[l])&&(n[l]=i[l]);else for(var f=0;f<u;f++)isNaN(n[l][f])&&(n[l][f]=i[l][f])}}function Xo(e){if(Kt(e)){var t=e.length;if(Kt(e[0])){for(var r=[],n=0;n<t;n++)r.push(uf.call(e[n]));return r}return uf.call(e)}return e}function $o(e){return e[0]=Math.floor(e[0])||0,e[1]=Math.floor(e[1])||0,e[2]=Math.floor(e[2])||0,e[3]=e[3]==null?1:e[3],"rgba("+e.join(",")+")"}function LS(e){return Kt(e&&e[0])?2:1}var fo=0,qo=1,pm=2,la=3,ff=4,hf=5,Jv=6;function jv(e){return e===ff||e===hf}function ho(e){return e===qo||e===pm}var Ni=[0,0,0,0],IS=(function(){function e(t){this.keyframes=[],this.discrete=!1,this._invalid=!1,this._needsSort=!1,this._lastFr=0,this._lastFrP=0,this.propName=t}return e.prototype.isFinished=function(){return this._finished},e.prototype.setFinished=function(){this._finished=!0,this._additiveTrack&&this._additiveTrack.setFinished()},e.prototype.needsAnimate=function(){return this.keyframes.length>=1},e.prototype.getAdditiveTrack=function(){return this._additiveTrack},e.prototype.addKeyframe=function(t,r,n){this._needsSort=!0;var i=this.keyframes,a=i.length,o=!1,s=Jv,l=r;if(Kt(r)){var u=LS(r);s=u,(u===1&&!mt(r[0])||u===2&&!mt(r[0][0]))&&(o=!0)}else if(mt(r)&&!La(r))s=fo;else if(W(r))if(!isNaN(+r))s=fo;else{var f=lr(r);f&&(l=f,s=la)}else if(Qs(r)){var h=k({},l);h.colorStops=$(r.colorStops,function(v){return{offset:v.offset,color:lr(v.color)}}),TS(r)?s=ff:CS(r)&&(s=hf),l=h}a===0?this.valType=s:(s!==this.valType||s===Jv)&&(o=!0),this.discrete=this.discrete||o;var c={time:t,value:l,rawValue:r,percent:0};return n&&(c.easing=n,c.easingFunc=et(n)?n:_a[n]||cm(n)),i.push(c),c},e.prototype.prepare=function(t,r){var n=this.keyframes;this._needsSort&&n.sort(function(p,g){return p.time-g.time});for(var i=this.valType,a=n.length,o=n[a-1],s=this.discrete,l=ho(i),u=jv(i),f=0;f<a;f++){var h=n[f],c=h.value,v=o.value;h.percent=h.time/t,s||(l&&f!==a-1?AS(c,v,i):u&&DS(c.colorStops,v.colorStops))}if(!s&&i!==hf&&r&&this.needsAnimate()&&r.needsAnimate()&&i===r.valType&&!r._finished){this._additiveTrack=r;for(var d=n[0].value,f=0;f<a;f++)i===fo?n[f].additiveValue=n[f].value-d:i===la?n[f].additiveValue=uo([],n[f].value,d,-1):ho(i)&&(n[f].additiveValue=i===qo?uo([],n[f].value,d,-1):Qv([],n[f].value,d,-1))}},e.prototype.step=function(t,r){if(!this._finished){this._additiveTrack&&this._additiveTrack._finished&&(this._additiveTrack=null);var n=this._additiveTrack!=null,i=n?"additiveValue":"value",a=this.valType,o=this.keyframes,s=o.length,l=this.propName,u=a===la,f,h=this._lastFr,c=Math.min,v,d;if(s===1)v=d=o[0];else{if(r<0)f=0;else if(r<this._lastFrP){var p=c(h+1,s-1);for(f=p;f>=0&&!(o[f].percent<=r);f--);f=c(f,s-2)}else{for(f=h;f<s&&!(o[f].percent>r);f++);f=c(f-1,s-2)}d=o[f+1],v=o[f]}if(v&&d){this._lastFr=f,this._lastFrP=r;var g=d.percent-v.percent,m=g===0?1:c((r-v.percent)/g,1);d.easingFunc&&(m=d.easingFunc(m));var y=n?this._additiveValue:u?Ni:t[l];if((ho(a)||u)&&!y&&(y=this._additiveValue=[]),this.discrete)t[l]=m<1?v.rawValue:d.rawValue;else if(ho(a))a===qo?Al(y,v[i],d[i],m):MS(y,v[i],d[i],m);else if(jv(a)){var _=v[i],S=d[i],w=a===ff;t[l]={type:w?"linear":"radial",x:rr(_.x,S.x,m),y:rr(_.y,S.y,m),colorStops:$(_.colorStops,function(x,C){var T=S.colorStops[C];return{offset:rr(x.offset,T.offset,m),color:$o(Al([],x.color,T.color,m))}}),global:S.global},w?(t[l].x2=rr(_.x2,S.x2,m),t[l].y2=rr(_.y2,S.y2,m)):t[l].r=rr(_.r,S.r,m)}else if(u)Al(y,v[i],d[i],m),n||(t[l]=$o(y));else{var b=rr(v[i],d[i],m);n?this._additiveValue=b:t[l]=b}n&&this._addToTarget(t)}}},e.prototype._addToTarget=function(t){var r=this.valType,n=this.propName,i=this._additiveValue;r===fo?t[n]=t[n]+i:r===la?(lr(t[n],Ni),uo(Ni,Ni,i,1),t[n]=$o(Ni)):r===qo?uo(t[n],t[n],i,1):r===pm&&Qv(t[n],t[n],i,1)},e})(),Th=(function(){function e(t,r,n,i){if(this._tracks={},this._trackKeys=[],this._maxTime=0,this._started=0,this._clip=null,this._target=t,this._loop=r,r&&i){mh("Can' use additive animation on looped animation.");return}this._additiveAnimators=i,this._allowDiscrete=n}return e.prototype.getMaxTime=function(){return this._maxTime},e.prototype.getDelay=function(){return this._delay},e.prototype.getLoop=function(){return this._loop},e.prototype.getTarget=function(){return this._target},e.prototype.changeTarget=function(t){this._target=t},e.prototype.when=function(t,r,n){return this.whenWithKeys(t,r,St(r),n)},e.prototype.whenWithKeys=function(t,r,n,i){for(var a=this._tracks,o=0;o<n.length;o++){var s=n[o],l=a[s];if(!l){l=a[s]=new IS(s);var u=void 0,f=this._getAdditiveTrack(s);if(f){var h=f.keyframes,c=h[h.length-1];u=c&&c.value,f.valType===la&&u&&(u=$o(u))}else u=this._target[s];if(u==null)continue;t>0&&l.addKeyframe(0,Xo(u),i),this._trackKeys.push(s)}l.addKeyframe(t,Xo(r[s]),i)}return this._maxTime=Math.max(this._maxTime,t),this},e.prototype.pause=function(){this._clip.pause(),this._paused=!0},e.prototype.resume=function(){this._clip.resume(),this._paused=!1},e.prototype.isPaused=function(){return!!this._paused},e.prototype.duration=function(t){return this._maxTime=t,this._force=!0,this},e.prototype._doneCallback=function(){this._setTracksFinished(),this._clip=null;var t=this._doneCbs;if(t)for(var r=t.length,n=0;n<r;n++)t[n].call(this)},e.prototype._abortedCallback=function(){this._setTracksFinished();var t=this.animation,r=this._abortedCbs;if(t&&t.removeClip(this._clip),this._clip=null,r)for(var n=0;n<r.length;n++)r[n].call(this)},e.prototype._setTracksFinished=function(){for(var t=this._tracks,r=this._trackKeys,n=0;n<r.length;n++)t[r[n]].setFinished()},e.prototype._getAdditiveTrack=function(t){var r,n=this._additiveAnimators;if(n)for(var i=0;i<n.length;i++){var a=n[i].getTrack(t);a&&(r=a)}return r},e.prototype.start=function(t){if(!(this._started>0)){this._started=1;for(var r=this,n=[],i=this._maxTime||0,a=0;a<this._trackKeys.length;a++){var o=this._trackKeys[a],s=this._tracks[o],l=this._getAdditiveTrack(o),u=s.keyframes,f=u.length;if(s.prepare(i,l),s.needsAnimate())if(!this._allowDiscrete&&s.discrete){var h=u[f-1];h&&(r._target[s.propName]=h.rawValue),s.setFinished()}else n.push(s)}if(n.length||this._force){var c=new bS({life:i,loop:this._loop,delay:this._delay||0,onframe:function(v){r._started=2;var d=r._additiveAnimators;if(d){for(var p=!1,g=0;g<d.length;g++)if(d[g]._clip){p=!0;break}p||(r._additiveAnimators=null)}for(var g=0;g<n.length;g++)n[g].step(r._target,v);var m=r._onframeCbs;if(m)for(var g=0;g<m.length;g++)m[g](r._target,v)},ondestroy:function(){r._doneCallback()}});this._clip=c,this.animation&&this.animation.addClip(c),t&&c.setEasing(t)}else this._doneCallback();return this}},e.prototype.stop=function(t){if(this._clip){var r=this._clip;t&&r.onframe(1),this._abortedCallback()}},e.prototype.delay=function(t){return this._delay=t,this},e.prototype.during=function(t){return t&&(this._onframeCbs||(this._onframeCbs=[]),this._onframeCbs.push(t)),this},e.prototype.done=function(t){return t&&(this._doneCbs||(this._doneCbs=[]),this._doneCbs.push(t)),this},e.prototype.aborted=function(t){return t&&(this._abortedCbs||(this._abortedCbs=[]),this._abortedCbs.push(t)),this},e.prototype.getClip=function(){return this._clip},e.prototype.getTrack=function(t){return this._tracks[t]},e.prototype.getTracks=function(){var t=this;return $(this._trackKeys,function(r){return t._tracks[r]})},e.prototype.stopTracks=function(t,r){if(!t.length||!this._clip)return!0;for(var n=this._tracks,i=this._trackKeys,a=0;a<t.length;a++){var o=n[t[a]];o&&!o.isFinished()&&(r?o.step(this._target,1):this._started===1&&o.step(this._target,0),o.setFinished())}for(var s=!0,a=0;a<i.length;a++)if(!n[i[a]].isFinished()){s=!1;break}return s&&this._abortedCallback(),s},e.prototype.saveTo=function(t,r,n){if(t){r=r||this._trackKeys;for(var i=0;i<r.length;i++){var a=r[i],o=this._tracks[a];if(!(!o||o.isFinished())){var s=o.keyframes,l=s[n?0:s.length-1];l&&(t[a]=Xo(l.rawValue))}}}},e.prototype.__changeFinalValue=function(t,r){r=r||St(t);for(var n=0;n<r.length;n++){var i=r[n],a=this._tracks[i];if(a){var o=a.keyframes;if(o.length>1){var s=o.pop();a.addKeyframe(s.time,t[i]),a.prepare(this._maxTime,a.getAdditiveTrack())}}}},e})(),Ee=(function(){function e(t){t&&(this._$eventProcessor=t)}return e.prototype.on=function(t,r,n,i){this._$handlers||(this._$handlers={});var a=this._$handlers;if(typeof r=="function"&&(i=n,n=r,r=null),!n||!t)return this;var o=this._$eventProcessor;r!=null&&o&&o.normalizeQuery&&(r=o.normalizeQuery(r)),a[t]||(a[t]=[]);for(var s=0;s<a[t].length;s++)if(a[t][s].h===n)return this;var l={h:n,query:r,ctx:i||this,callAtLast:n.zrEventfulCallAtLast},u=a[t].length-1,f=a[t][u];return f&&f.callAtLast?a[t].splice(u,0,l):a[t].push(l),this},e.prototype.isSilent=function(t){var r=this._$handlers;return!r||!r[t]||!r[t].length},e.prototype.off=function(t,r){var n=this._$handlers;if(!n)return this;if(!t)return this._$handlers={},this;if(r){if(n[t]){for(var i=[],a=0,o=n[t].length;a<o;a++)n[t][a].h!==r&&i.push(n[t][a]);n[t]=i}n[t]&&n[t].length===0&&delete n[t]}else delete n[t];return this},e.prototype.trigger=function(t){for(var r=[],n=1;n<arguments.length;n++)r[n-1]=arguments[n];if(!this._$handlers)return this;var i=this._$handlers[t],a=this._$eventProcessor;if(i)for(var o=r.length,s=i.length,l=0;l<s;l++){var u=i[l];if(!(a&&a.filter&&u.query!=null&&!a.filter(t,u.query)))switch(o){case 0:u.h.call(u.ctx);break;case 1:u.h.call(u.ctx,r[0]);break;case 2:u.h.call(u.ctx,r[0],r[1]);break;default:u.h.apply(u.ctx,r);break}}return a&&a.afterTrigger&&a.afterTrigger(t),this},e.prototype.triggerWithContext=function(t){for(var r=[],n=1;n<arguments.length;n++)r[n-1]=arguments[n];if(!this._$handlers)return this;var i=this._$handlers[t],a=this._$eventProcessor;if(i)for(var o=r.length,s=r[o-1],l=i.length,u=0;u<l;u++){var f=i[u];if(!(a&&a.filter&&f.query!=null&&!a.filter(t,f.query)))switch(o){case 0:f.h.call(s);break;case 1:f.h.call(s,r[0]);break;case 2:f.h.call(s,r[0],r[1]);break;default:f.h.apply(s,r.slice(1,o-1));break}}return a&&a.afterTrigger&&a.afterTrigger(t),this},e})(),gm=1;nt.hasGlobalWindow&&(gm=Math.max(window.devicePixelRatio||window.screen&&window.screen.deviceXDPI/window.screen.logicalXDPI||1,1));var gs=gm,vf=.4,cf="#333",df="#ccc",PS="#eee",ue=1,ua=2,si=4,Ll="__zr_normal__",Il=Pa.concat(["ignore"]),RS=Ri(Pa,function(e,t){return e[t]=!0,e},{ignore:!1}),Wn={},ES=new it(0,0,0,0),vo=[],nl=(function(){function e(t){this.id=Ug(),this.animators=[],this.currentStates=[],this.states={},this._init(t)}return e.prototype._init=function(t){this.attr(t)},e.prototype.drift=function(t,r,n){switch(this.draggable){case"horizontal":r=0;break;case"vertical":t=0;break}var i=this.transform;i||(i=this.transform=[1,0,0,1,0,0]),i[4]+=t,i[5]+=r,this.decomposeTransform(),this.markRedraw()},e.prototype.beforeUpdate=function(){},e.prototype.afterUpdate=function(){},e.prototype.update=function(){this.updateTransform(),this.__dirty&&this.updateInnerText()},e.prototype.updateInnerText=function(t){var r=this._textContent;if(r&&(!r.ignore||t)){this.textConfig||(this.textConfig={});var n=this.textConfig,i=n.local,a=r.innerTransformable,o=void 0,s=void 0,l=!1;a.parent=i?this:null;var u=!1;a.copyTransform(r);var f=n.position!=null,h=n.autoOverflowArea,c=void 0;if((h||f)&&(c=ES,n.layoutRect?c.copy(n.layoutRect):c.copy(this.getBoundingRect()),i||c.applyTransform(this.transform)),f){this.calculateTextPosition?this.calculateTextPosition(Wn,n,c):rm(Wn,n,c),a.x=Wn.x,a.y=Wn.y,o=Wn.align,s=Wn.verticalAlign;var v=n.origin;if(v&&n.rotation!=null){var d=void 0,p=void 0;v==="center"?(d=c.width*.5,p=c.height*.5):(d=Rn(v[0],c.width),p=Rn(v[1],c.height)),u=!0,a.originX=-a.x+d+(i?0:c.x),a.originY=-a.y+p+(i?0:c.y)}}n.rotation!=null&&(a.rotation=n.rotation);var g=n.offset;g&&(a.x+=g[0],a.y+=g[1],u||(a.originX=-g[0],a.originY=-g[1]));var m=this._innerTextDefaultStyle||(this._innerTextDefaultStyle={});if(h){var y=m.overflowRect=m.overflowRect||new it(0,0,0,0);a.getLocalTransform(vo),Ei(vo,vo),it.copy(y,c),y.applyTransform(vo)}else m.overflowRect=null;var _=n.inside==null?typeof n.position=="string"&&n.position.indexOf("inside")>=0:n.inside,S=void 0,w=void 0,b=void 0;_&&this.canBeInsideText()?(S=n.insideFill,w=n.insideStroke,(S==null||S==="auto")&&(S=this.getInsideTextFill()),(w==null||w==="auto")&&(w=this.getInsideTextStroke(S),b=!0)):(S=n.outsideFill,w=n.outsideStroke,(S==null||S==="auto")&&(S=this.getOutsideFill()),(w==null||w==="auto")&&(w=this.getOutsideStroke(S),b=!0)),S=S||"#000",(S!==m.fill||w!==m.stroke||b!==m.autoStroke||o!==m.align||s!==m.verticalAlign)&&(l=!0,m.fill=S,m.stroke=w,m.autoStroke=b,m.align=o,m.verticalAlign=s,r.setDefaultTextStyle(m)),r.__dirty|=ue,l&&r.dirtyStyle(!0)}},e.prototype.canBeInsideText=function(){return!0},e.prototype.getInsideTextFill=function(){return"#fff"},e.prototype.getInsideTextStroke=function(t){return"#000"},e.prototype.getOutsideFill=function(){return this.__zr&&this.__zr.isDarkMode()?df:cf},e.prototype.getOutsideStroke=function(t){var r=this.__zr&&this.__zr.getBackgroundColor(),n=typeof r=="string"&&lr(r);n||(n=[255,255,255,1]);for(var i=n[3],a=this.__zr.isDarkMode(),o=0;o<3;o++)n[o]=n[o]*i+(a?0:255)*(1-i);return n[3]=1,rl(n,"rgba")},e.prototype.traverse=function(t,r){},e.prototype.attrKV=function(t,r){t==="textConfig"?this.setTextConfig(r):t==="textContent"?this.setTextContent(r):t==="clipPath"?this.setClipPath(r):t==="extra"?(this.extra=this.extra||{},k(this.extra,r)):this[t]=r},e.prototype.hide=function(){this.ignore=!0,this.markRedraw()},e.prototype.show=function(){this.ignore=!1,this.markRedraw()},e.prototype.attr=function(t,r){if(typeof t=="string")this.attrKV(t,r);else if(X(t))for(var n=t,i=St(n),a=0;a<i.length;a++){var o=i[a];this.attrKV(o,t[o])}return this.markRedraw(),this},e.prototype.saveCurrentToNormalState=function(t){this._innerSaveToNormal(t);for(var r=this._normalState,n=0;n<this.animators.length;n++){var i=this.animators[n],a=i.__fromStateTransition;if(!(i.getLoop()||a&&a!==Ll)){var o=i.targetName,s=o?r[o]:r;i.saveTo(s)}}},e.prototype._innerSaveToNormal=function(t){var r=this._normalState;r||(r=this._normalState={}),t.textConfig&&!r.textConfig&&(r.textConfig=this.textConfig),this._savePrimaryToNormal(t,r,Il)},e.prototype._savePrimaryToNormal=function(t,r,n){for(var i=0;i<n.length;i++){var a=n[i];t[a]!=null&&!(a in r)&&(r[a]=this[a])}},e.prototype.hasState=function(){return this.currentStates.length>0},e.prototype.getState=function(t){return this.states[t]},e.prototype.ensureState=function(t){var r=this.states;return r[t]||(r[t]={}),r[t]},e.prototype.clearStates=function(t){this.useState(Ll,!1,t)},e.prototype.useState=function(t,r,n,i){var a=t===Ll,o=this.hasState();if(!(!o&&a)){var s=this.currentStates,l=this.stateTransition;if(!(ft(s,t)>=0&&(r||s.length===1))){var u;if(this.stateProxy&&!a&&(u=this.stateProxy(t)),u||(u=this.states&&this.states[t]),!u&&!a){mh("State "+t+" not exists.");return}a||this.saveCurrentToNormalState(u);var f=!!(u&&u.hoverLayer||i);f&&this._toggleHoverLayerFlag(!0),this._applyStateObj(t,u,this._normalState,r,!n&&!this.__inHover&&l&&l.duration>0,l);var h=this._textContent,c=this._textGuide;return h&&h.useState(t,r,n,f),c&&c.useState(t,r,n,f),a?(this.currentStates=[],this._normalState={}):r?this.currentStates.push(t):this.currentStates=[t],this._updateAnimationTargets(),this.markRedraw(),!f&&this.__inHover&&(this._toggleHoverLayerFlag(!1),this.__dirty&=~ue),u}}},e.prototype.useStates=function(t,r,n){if(!t.length)this.clearStates();else{var i=[],a=this.currentStates,o=t.length,s=o===a.length;if(s){for(var l=0;l<o;l++)if(t[l]!==a[l]){s=!1;break}}if(s)return;for(var l=0;l<o;l++){var u=t[l],f=void 0;this.stateProxy&&(f=this.stateProxy(u,t)),f||(f=this.states[u]),f&&i.push(f)}var h=i[o-1],c=!!(h&&h.hoverLayer||n);c&&this._toggleHoverLayerFlag(!0);var v=this._mergeStates(i),d=this.stateTransition;this.saveCurrentToNormalState(v),this._applyStateObj(t.join(","),v,this._normalState,!1,!r&&!this.__inHover&&d&&d.duration>0,d);var p=this._textContent,g=this._textGuide;p&&p.useStates(t,r,c),g&&g.useStates(t,r,c),this._updateAnimationTargets(),this.currentStates=t.slice(),this.markRedraw(),!c&&this.__inHover&&(this._toggleHoverLayerFlag(!1),this.__dirty&=~ue)}},e.prototype.isSilent=function(){for(var t=this;t;){if(t.silent)return!0;var r=t.__hostTarget;t=r?t.ignoreHostSilent?null:r:t.parent}return!1},e.prototype._updateAnimationTargets=function(){for(var t=0;t<this.animators.length;t++){var r=this.animators[t];r.targetName&&r.changeTarget(this[r.targetName])}},e.prototype.removeState=function(t){var r=ft(this.currentStates,t);if(r>=0){var n=this.currentStates.slice();n.splice(r,1),this.useStates(n)}},e.prototype.replaceState=function(t,r,n){var i=this.currentStates.slice(),a=ft(i,t),o=ft(i,r)>=0;a>=0?o?i.splice(a,1):i[a]=r:n&&!o&&i.push(r),this.useStates(i)},e.prototype.toggleState=function(t,r){r?this.useState(t,!0):this.removeState(t)},e.prototype._mergeStates=function(t){for(var r={},n,i=0;i<t.length;i++){var a=t[i];k(r,a),a.textConfig&&(n=n||{},k(n,a.textConfig))}return n&&(r.textConfig=n),r},e.prototype._applyStateObj=function(t,r,n,i,a,o){var s=!(r&&i);r&&r.textConfig?(this.textConfig=k({},i?this.textConfig:n.textConfig),k(this.textConfig,r.textConfig)):s&&n.textConfig&&(this.textConfig=n.textConfig);for(var l={},u=!1,f=0;f<Il.length;f++){var h=Il[f],c=a&&RS[h];r&&r[h]!=null?c?(u=!0,l[h]=r[h]):this[h]=r[h]:s&&n[h]!=null&&(c?(u=!0,l[h]=n[h]):this[h]=n[h])}if(!a)for(var f=0;f<this.animators.length;f++){var v=this.animators[f],d=v.targetName;v.getLoop()||v.__changeFinalValue(d?(r||n)[d]:r||n)}u&&this._transitionState(t,l,o)},e.prototype._attachComponent=function(t){if(!(t.__zr&&!t.__hostTarget)&&t!==this){var r=this.__zr;r&&t.addSelfToZr(r),t.__zr=r,t.__hostTarget=this}},e.prototype._detachComponent=function(t){t.__zr&&t.removeSelfFromZr(t.__zr),t.__zr=null,t.__hostTarget=null},e.prototype.getClipPath=function(){return this._clipPath},e.prototype.setClipPath=function(t){this._clipPath&&this._clipPath!==t&&this.removeClipPath(),this._attachComponent(t),this._clipPath=t,this.markRedraw()},e.prototype.removeClipPath=function(){var t=this._clipPath;t&&(this._detachComponent(t),this._clipPath=null,this.markRedraw())},e.prototype.getTextContent=function(){return this._textContent},e.prototype.setTextContent=function(t){var r=this._textContent;r!==t&&(r&&r!==t&&this.removeTextContent(),t.innerTransformable=new qa,this._attachComponent(t),this._textContent=t,this.markRedraw())},e.prototype.setTextConfig=function(t){this.textConfig||(this.textConfig={}),k(this.textConfig,t),this.markRedraw()},e.prototype.removeTextConfig=function(){this.textConfig=null,this.markRedraw()},e.prototype.removeTextContent=function(){var t=this._textContent;t&&(t.innerTransformable=null,this._detachComponent(t),this._textContent=null,this._innerTextDefaultStyle=null,this.markRedraw())},e.prototype.getTextGuideLine=function(){return this._textGuide},e.prototype.setTextGuideLine=function(t){this._textGuide&&this._textGuide!==t&&this.removeTextGuideLine(),this._attachComponent(t),this._textGuide=t,this.markRedraw()},e.prototype.removeTextGuideLine=function(){var t=this._textGuide;t&&(this._detachComponent(t),this._textGuide=null,this.markRedraw())},e.prototype.markRedraw=function(){this.__dirty|=ue;var t=this.__zr;t&&(this.__inHover?t.refreshHover():t.refresh()),this.__hostTarget&&this.__hostTarget.markRedraw()},e.prototype.dirty=function(){this.markRedraw()},e.prototype._toggleHoverLayerFlag=function(t){this.__inHover=t;var r=this._textContent,n=this._textGuide;r&&(r.__inHover=t),n&&(n.__inHover=t)},e.prototype.addSelfToZr=function(t){if(this.__zr!==t){this.__zr=t;var r=this.animators;if(r)for(var n=0;n<r.length;n++)t.animation.addAnimator(r[n]);this._clipPath&&this._clipPath.addSelfToZr(t),this._textContent&&this._textContent.addSelfToZr(t),this._textGuide&&this._textGuide.addSelfToZr(t)}},e.prototype.removeSelfFromZr=function(t){if(this.__zr){this.__zr=null;var r=this.animators;if(r)for(var n=0;n<r.length;n++)t.animation.removeAnimator(r[n]);this._clipPath&&this._clipPath.removeSelfFromZr(t),this._textContent&&this._textContent.removeSelfFromZr(t),this._textGuide&&this._textGuide.removeSelfFromZr(t)}},e.prototype.animate=function(t,r,n){var i=t?this[t]:this,a=new Th(i,r,n);return t&&(a.targetName=t),this.addAnimator(a,t),a},e.prototype.addAnimator=function(t,r){var n=this.__zr,i=this;t.during(function(){i.updateDuringAnimation(r)}).done(function(){var a=i.animators,o=ft(a,t);o>=0&&a.splice(o,1)}),this.animators.push(t),n&&n.animation.addAnimator(t),n&&n.wakeUp()},e.prototype.updateDuringAnimation=function(t){this.markRedraw()},e.prototype.stopAnimation=function(t,r){for(var n=this.animators,i=n.length,a=[],o=0;o<i;o++){var s=n[o];!t||t===s.scope?s.stop(r):a.push(s)}return this.animators=a,this},e.prototype.animateTo=function(t,r,n){Pl(this,t,r,n)},e.prototype.animateFrom=function(t,r,n){Pl(this,t,r,n,!0)},e.prototype._transitionState=function(t,r,n,i){for(var a=Pl(this,r,n,i),o=0;o<a.length;o++)a[o].__fromStateTransition=t},e.prototype.getBoundingRect=function(){return null},e.prototype.getPaintRect=function(){return null},e.initDefaultProps=(function(){var t=e.prototype;t.type="element",t.name="",t.ignore=t.silent=t.ignoreHostSilent=t.isGroup=t.draggable=t.dragging=t.ignoreClip=t.__inHover=!1,t.__dirty=ue;function r(n,i,a,o){Object.defineProperty(t,n,{get:function(){if(!this[i]){var l=this[i]=[];s(this,l)}return this[i]},set:function(l){this[a]=l[0],this[o]=l[1],this[i]=l,s(this,l)}});function s(l,u){Object.defineProperty(u,0,{get:function(){return l[a]},set:function(f){l[a]=f}}),Object.defineProperty(u,1,{get:function(){return l[o]},set:function(f){l[o]=f}})}}Object.defineProperty&&(r("position","_legacyPos","x","y"),r("scale","_legacyScale","scaleX","scaleY"),r("origin","_legacyOrigin","originX","originY"))})(),e})();Ke(nl,Ee);Ke(nl,qa);function Pl(e,t,r,n,i){r=r||{};var a=[];mm(e,"",e,t,r,n,a,i);var o=a.length,s=!1,l=r.done,u=r.aborted,f=function(){s=!0,o--,o<=0&&(s?l&&l():u&&u())},h=function(){o--,o<=0&&(s?l&&l():u&&u())};o||l&&l(),a.length>0&&r.during&&a[0].during(function(d,p){r.during(p)});for(var c=0;c<a.length;c++){var v=a[c];f&&v.done(f),h&&v.aborted(h),r.force&&v.duration(r.duration),v.start(r.easing)}return a}function Rl(e,t,r){for(var n=0;n<r;n++)e[n]=t[n]}function kS(e){return Kt(e[0])}function OS(e,t,r){if(Kt(t[r]))if(Kt(e[r])||(e[r]=[]),ie(t[r])){var n=t[r].length;e[r].length!==n&&(e[r]=new t[r].constructor(n),Rl(e[r],t[r],n))}else{var i=t[r],a=e[r],o=i.length;if(kS(i))for(var s=i[0].length,l=0;l<o;l++)a[l]?Rl(a[l],i[l],s):a[l]=Array.prototype.slice.call(i[l]);else Rl(a,i,o);a.length=i.length}else e[r]=t[r]}function BS(e,t){return e===t||Kt(e)&&Kt(t)&&NS(e,t)}function NS(e,t){var r=e.length;if(r!==t.length)return!1;for(var n=0;n<r;n++)if(e[n]!==t[n])return!1;return!0}function mm(e,t,r,n,i,a,o,s){for(var l=St(n),u=i.duration,f=i.delay,h=i.additive,c=i.setToFinal,v=!X(a),d=e.animators,p=[],g=0;g<l.length;g++){var m=l[g],y=n[m];if(y!=null&&r[m]!=null&&(v||a[m]))if(X(y)&&!Kt(y)&&!Qs(y)){if(t){s||(r[m]=y,e.updateDuringAnimation(t));continue}mm(e,m,r[m],y,i,a&&a[m],o,s)}else p.push(m);else s||(r[m]=y,e.updateDuringAnimation(t),p.push(m))}var _=p.length;if(!h&&_)for(var S=0;S<d.length;S++){var w=d[S];if(w.targetName===t){var b=w.stopTracks(p);if(b){var x=ft(d,w);d.splice(x,1)}}}if(i.force||(p=wt(p,function(A){return!BS(n[A],r[A])}),_=p.length),_>0||i.force&&!o.length){var C=void 0,T=void 0,D=void 0;if(s){T={},c&&(C={});for(var S=0;S<_;S++){var m=p[S];T[m]=r[m],c?C[m]=n[m]:r[m]=n[m]}}else if(c){D={};for(var S=0;S<_;S++){var m=p[S];D[m]=Xo(r[m]),OS(r,n,m)}}var w=new Th(r,!1,!1,h?wt(d,function(P){return P.targetName===t}):null);w.targetName=t,i.scope&&(w.scope=i.scope),c&&C&&w.whenWithKeys(0,C,p),D&&w.whenWithKeys(0,D,p),w.whenWithKeys(u??500,s?T:n,p).delay(f||0),e.addAnimator(w,t),o.push(w)}}var pf="__zr_style_"+Math.round(Math.random()*10),An={shadowBlur:0,shadowOffsetX:0,shadowOffsetY:0,shadowColor:"#000",opacity:1,blend:"source-over"},il={style:{shadowBlur:!0,shadowOffsetX:!0,shadowOffsetY:!0,shadowColor:!0,opacity:!0}};An[pf]=!0;var tc=["z","z2","invisible"],FS=["invisible"],Oi=(function(e){N(t,e);function t(r){return e.call(this,r)||this}return t.prototype._init=function(r){for(var n=St(r),i=0;i<n.length;i++){var a=n[i];a==="style"?this.useStyle(r[a]):e.prototype.attrKV.call(this,a,r[a])}this.style||this.useStyle({})},t.prototype.beforeBrush=function(){},t.prototype.afterBrush=function(){},t.prototype.innerBeforeBrush=function(){},t.prototype.innerAfterBrush=function(){},t.prototype.shouldBePainted=function(r,n,i,a){var o=this.transform;if(this.ignore||this.invisible||this.style.opacity===0||this.culling&&zS(this,r,n)||o&&!o[0]&&!o[3])return!1;if(i&&this.__clipPaths&&this.__clipPaths.length){for(var s=0;s<this.__clipPaths.length;++s)if(this.__clipPaths[s].isZeroArea())return!1}if(a&&this.parent)for(var l=this.parent;l;){if(l.ignore)return!1;l=l.parent}return!0},t.prototype.contain=function(r,n){return this.rectContain(r,n)},t.prototype.traverse=function(r,n){r.call(n,this)},t.prototype.rectContain=function(r,n){var i=this.transformCoordToLocal(r,n),a=this.getBoundingRect();return a.contain(i[0],i[1])},t.prototype.getPaintRect=function(){var r=this._paintRect;if(!this._paintRect||this.__dirty){var n=this.transform,i=this.getBoundingRect(),a=this.style,o=a.shadowBlur||0,s=a.shadowOffsetX||0,l=a.shadowOffsetY||0;r=this._paintRect||(this._paintRect=new it(0,0,0,0)),n?it.applyTransform(r,i,n):r.copy(i),(o||s||l)&&(r.width+=o*2+Math.abs(s),r.height+=o*2+Math.abs(l),r.x=Math.min(r.x,r.x+s-o),r.y=Math.min(r.y,r.y+l-o));var u=this.dirtyRectTolerance;r.isZero()||(r.x=Math.floor(r.x-u),r.y=Math.floor(r.y-u),r.width=Math.ceil(r.width+1+u*2),r.height=Math.ceil(r.height+1+u*2))}return r},t.prototype.setPrevPaintRect=function(r){r?(this._prevPaintRect=this._prevPaintRect||new it(0,0,0,0),this._prevPaintRect.copy(r)):this._prevPaintRect=null},t.prototype.getPrevPaintRect=function(){return this._prevPaintRect},t.prototype.animateStyle=function(r){return this.animate("style",r)},t.prototype.updateDuringAnimation=function(r){r==="style"?this.dirtyStyle():this.markRedraw()},t.prototype.attrKV=function(r,n){r!=="style"?e.prototype.attrKV.call(this,r,n):this.style?this.setStyle(n):this.useStyle(n)},t.prototype.setStyle=function(r,n){return typeof r=="string"?this.style[r]=n:k(this.style,r),this.dirtyStyle(),this},t.prototype.dirtyStyle=function(r){r||this.markRedraw(),this.__dirty|=ua,this._rect&&(this._rect=null)},t.prototype.dirty=function(){this.dirtyStyle()},t.prototype.styleChanged=function(){return!!(this.__dirty&ua)},t.prototype.styleUpdated=function(){this.__dirty&=~ua},t.prototype.createStyle=function(r){return Js(An,r)},t.prototype.useStyle=function(r){r[pf]||(r=this.createStyle(r)),this.__inHover?this.__hoverStyle=r:this.style=r,this.dirtyStyle()},t.prototype.isStyleObject=function(r){return r[pf]},t.prototype._innerSaveToNormal=function(r){e.prototype._innerSaveToNormal.call(this,r);var n=this._normalState;r.style&&!n.style&&(n.style=this._mergeStyle(this.createStyle(),this.style)),this._savePrimaryToNormal(r,n,tc)},t.prototype._applyStateObj=function(r,n,i,a,o,s){e.prototype._applyStateObj.call(this,r,n,i,a,o,s);var l=!(n&&a),u;if(n&&n.style?o?a?u=n.style:(u=this._mergeStyle(this.createStyle(),i.style),this._mergeStyle(u,n.style)):(u=this._mergeStyle(this.createStyle(),a?this.style:i.style),this._mergeStyle(u,n.style)):l&&(u=i.style),u)if(o){var f=this.style;if(this.style=this.createStyle(l?{}:f),l)for(var h=St(f),c=0;c<h.length;c++){var v=h[c];v in u&&(u[v]=u[v],this.style[v]=f[v])}for(var d=St(u),c=0;c<d.length;c++){var v=d[c];this.style[v]=this.style[v]}this._transitionState(r,{style:u},s,this.getAnimationStyleProps())}else this.useStyle(u);for(var p=this.__inHover?FS:tc,c=0;c<p.length;c++){var v=p[c];n&&n[v]!=null?this[v]=n[v]:l&&i[v]!=null&&(this[v]=i[v])}},t.prototype._mergeStates=function(r){for(var n=e.prototype._mergeStates.call(this,r),i,a=0;a<r.length;a++){var o=r[a];o.style&&(i=i||{},this._mergeStyle(i,o.style))}return i&&(n.style=i),n},t.prototype._mergeStyle=function(r,n){return k(r,n),r},t.prototype.getAnimationStyleProps=function(){return il},t.initDefaultProps=(function(){var r=t.prototype;r.type="displayable",r.invisible=!1,r.z=0,r.z2=0,r.zlevel=0,r.culling=!1,r.cursor="pointer",r.rectHover=!1,r.incremental=!1,r._rect=null,r.dirtyRectTolerance=0,r.__dirty=ue|ua})(),t})(nl),El=new it(0,0,0,0),kl=new it(0,0,0,0);function zS(e,t,r){return El.copy(e.getBoundingRect()),e.transform&&El.applyTransform(e.transform),kl.width=t,kl.height=r,!El.intersect(kl)}var jt=Math.min,te=Math.max,Ol=Math.sin,Bl=Math.cos,Jr=Math.PI*2,co=ki(),po=ki(),go=ki();function ym(e,t,r){if(e.length!==0){for(var n=e[0],i=n[0],a=n[0],o=n[1],s=n[1],l=1;l<e.length;l++)n=e[l],i=jt(i,n[0]),a=te(a,n[0]),o=jt(o,n[1]),s=te(s,n[1]);t[0]=i,t[1]=o,r[0]=a,r[1]=s}}function ec(e,t,r,n,i,a){i[0]=jt(e,r),i[1]=jt(t,n),a[0]=te(e,r),a[1]=te(t,n)}var rc=[],nc=[];function HS(e,t,r,n,i,a,o,s,l,u){var f=um,h=Lt,c=f(e,r,i,o,rc);l[0]=1/0,l[1]=1/0,u[0]=-1/0,u[1]=-1/0;for(var v=0;v<c;v++){var d=h(e,r,i,o,rc[v]);l[0]=jt(d,l[0]),u[0]=te(d,u[0])}c=f(t,n,a,s,nc);for(var v=0;v<c;v++){var p=h(t,n,a,s,nc[v]);l[1]=jt(p,l[1]),u[1]=te(p,u[1])}l[0]=jt(e,l[0]),u[0]=te(e,u[0]),l[0]=jt(o,l[0]),u[0]=te(o,u[0]),l[1]=jt(t,l[1]),u[1]=te(t,u[1]),l[1]=jt(s,l[1]),u[1]=te(s,u[1])}function VS(e,t,r,n,i,a,o,s){var l=hm,u=Wt,f=te(jt(l(e,r,i),1),0),h=te(jt(l(t,n,a),1),0),c=u(e,r,i,f),v=u(t,n,a,h);o[0]=jt(e,i,c),o[1]=jt(t,a,v),s[0]=te(e,i,c),s[1]=te(t,a,v)}function GS(e,t,r,n,i,a,o,s,l){var u=fi,f=hi,h=Math.abs(i-a);if(h%Jr<1e-4&&h>1e-4){s[0]=e-r,s[1]=t-n,l[0]=e+r,l[1]=t+n;return}if(co[0]=Bl(i)*r+e,co[1]=Ol(i)*n+t,po[0]=Bl(a)*r+e,po[1]=Ol(a)*n+t,u(s,co,po),f(l,co,po),i=i%Jr,i<0&&(i=i+Jr),a=a%Jr,a<0&&(a=a+Jr),i>a&&!o?a+=Jr:i<a&&o&&(i+=Jr),o){var c=a;a=i,i=c}for(var v=0;v<a;v+=Math.PI/2)v>i&&(go[0]=Bl(v)*r+e,go[1]=Ol(v)*n+t,u(s,go,s),f(l,go,l))}var ct={M:1,L:2,C:3,Q:4,A:5,Z:6,R:7},jr=[],tn=[],Oe=[],dr=[],Be=[],Ne=[],Nl=Math.min,Fl=Math.max,en=Math.cos,rn=Math.sin,Je=Math.abs,gf=Math.PI,xr=gf*2,zl=typeof Float32Array<"u",Fi=[];function Hl(e){var t=Math.round(e/gf*1e8)/1e8;return t%2*gf}function WS(e,t){var r=Hl(e[0]);r<0&&(r+=xr);var n=r-e[0],i=e[1];i+=n,!t&&i-r>=xr?i=r+xr:t&&r-i>=xr?i=r-xr:!t&&r>i?i=r+(xr-Hl(r-i)):t&&r<i&&(i=r-(xr-Hl(i-r))),e[0]=r,e[1]=i}var hr=(function(){function e(t){this.dpr=1,this._xi=0,this._yi=0,this._x0=0,this._y0=0,this._len=0,t&&(this._saveData=!1),this._saveData&&(this.data=[])}return e.prototype.increaseVersion=function(){this._version++},e.prototype.getVersion=function(){return this._version},e.prototype.setScale=function(t,r,n){n=n||0,n>0&&(this._ux=Je(n/gs/t)||0,this._uy=Je(n/gs/r)||0)},e.prototype.setDPR=function(t){this.dpr=t},e.prototype.setContext=function(t){this._ctx=t},e.prototype.getContext=function(){return this._ctx},e.prototype.beginPath=function(){return this._ctx&&this._ctx.beginPath(),this.reset(),this},e.prototype.reset=function(){this._saveData&&(this._len=0),this._pathSegLen&&(this._pathSegLen=null,this._pathLen=0),this._version++},e.prototype.moveTo=function(t,r){return this._drawPendingPt(),this.addData(ct.M,t,r),this._ctx&&this._ctx.moveTo(t,r),this._x0=t,this._y0=r,this._xi=t,this._yi=r,this},e.prototype.lineTo=function(t,r){var n=Je(t-this._xi),i=Je(r-this._yi),a=n>this._ux||i>this._uy;if(this.addData(ct.L,t,r),this._ctx&&a&&this._ctx.lineTo(t,r),a)this._xi=t,this._yi=r,this._pendingPtDist=0;else{var o=n*n+i*i;o>this._pendingPtDist&&(this._pendingPtX=t,this._pendingPtY=r,this._pendingPtDist=o)}return this},e.prototype.bezierCurveTo=function(t,r,n,i,a,o){return this._drawPendingPt(),this.addData(ct.C,t,r,n,i,a,o),this._ctx&&this._ctx.bezierCurveTo(t,r,n,i,a,o),this._xi=a,this._yi=o,this},e.prototype.quadraticCurveTo=function(t,r,n,i){return this._drawPendingPt(),this.addData(ct.Q,t,r,n,i),this._ctx&&this._ctx.quadraticCurveTo(t,r,n,i),this._xi=n,this._yi=i,this},e.prototype.arc=function(t,r,n,i,a,o){this._drawPendingPt(),Fi[0]=i,Fi[1]=a,WS(Fi,o),i=Fi[0],a=Fi[1];var s=a-i;return this.addData(ct.A,t,r,n,n,i,s,0,o?0:1),this._ctx&&this._ctx.arc(t,r,n,i,a,o),this._xi=en(a)*n+t,this._yi=rn(a)*n+r,this},e.prototype.arcTo=function(t,r,n,i,a){return this._drawPendingPt(),this._ctx&&this._ctx.arcTo(t,r,n,i,a),this},e.prototype.rect=function(t,r,n,i){return this._drawPendingPt(),this._ctx&&this._ctx.rect(t,r,n,i),this.addData(ct.R,t,r,n,i),this},e.prototype.closePath=function(){this._drawPendingPt(),this.addData(ct.Z);var t=this._ctx,r=this._x0,n=this._y0;return t&&t.closePath(),this._xi=r,this._yi=n,this},e.prototype.fill=function(t){t&&t.fill(),this.toStatic()},e.prototype.stroke=function(t){t&&t.stroke(),this.toStatic()},e.prototype.len=function(){return this._len},e.prototype.setData=function(t){if(this._saveData){var r=t.length;!(this.data&&this.data.length===r)&&zl&&(this.data=new Float32Array(r));for(var n=0;n<r;n++)this.data[n]=t[n];this._len=r}},e.prototype.appendPath=function(t){if(this._saveData){t instanceof Array||(t=[t]);for(var r=t.length,n=0,i=this._len,a=0;a<r;a++)n+=t[a].len();var o=this.data;if(zl&&(o instanceof Float32Array||!o)&&(this.data=new Float32Array(i+n),i>0&&o))for(var s=0;s<i;s++)this.data[s]=o[s];for(var a=0;a<r;a++)for(var l=t[a].data,s=0;s<l.length;s++)this.data[i++]=l[s];this._len=i}},e.prototype.addData=function(t,r,n,i,a,o,s,l,u){if(this._saveData){var f=this.data;this._len+arguments.length>f.length&&(this._expandData(),f=this.data);for(var h=0;h<arguments.length;h++)f[this._len++]=arguments[h]}},e.prototype._drawPendingPt=function(){this._pendingPtDist>0&&(this._ctx&&this._ctx.lineTo(this._pendingPtX,this._pendingPtY),this._pendingPtDist=0)},e.prototype._expandData=function(){if(!(this.data instanceof Array)){for(var t=[],r=0;r<this._len;r++)t[r]=this.data[r];this.data=t}},e.prototype.toStatic=function(){if(this._saveData){this._drawPendingPt();var t=this.data;t instanceof Array&&(t.length=this._len,zl&&this._len>11&&(this.data=new Float32Array(t)))}},e.prototype.getBoundingRect=function(){Oe[0]=Oe[1]=Be[0]=Be[1]=Number.MAX_VALUE,dr[0]=dr[1]=Ne[0]=Ne[1]=-Number.MAX_VALUE;var t=this.data,r=0,n=0,i=0,a=0,o;for(o=0;o<this._len;){var s=t[o++],l=o===1;switch(l&&(r=t[o],n=t[o+1],i=r,a=n),s){case ct.M:r=i=t[o++],n=a=t[o++],Be[0]=i,Be[1]=a,Ne[0]=i,Ne[1]=a;break;case ct.L:ec(r,n,t[o],t[o+1],Be,Ne),r=t[o++],n=t[o++];break;case ct.C:HS(r,n,t[o++],t[o++],t[o++],t[o++],t[o],t[o+1],Be,Ne),r=t[o++],n=t[o++];break;case ct.Q:VS(r,n,t[o++],t[o++],t[o],t[o+1],Be,Ne),r=t[o++],n=t[o++];break;case ct.A:var u=t[o++],f=t[o++],h=t[o++],c=t[o++],v=t[o++],d=t[o++]+v;o+=1;var p=!t[o++];l&&(i=en(v)*h+u,a=rn(v)*c+f),GS(u,f,h,c,v,d,p,Be,Ne),r=en(d)*h+u,n=rn(d)*c+f;break;case ct.R:i=r=t[o++],a=n=t[o++];var g=t[o++],m=t[o++];ec(i,a,i+g,a+m,Be,Ne);break;case ct.Z:r=i,n=a;break}fi(Oe,Oe,Be),hi(dr,dr,Ne)}return o===0&&(Oe[0]=Oe[1]=dr[0]=dr[1]=0),new it(Oe[0],Oe[1],dr[0]-Oe[0],dr[1]-Oe[1])},e.prototype._calculateLength=function(){var t=this.data,r=this._len,n=this._ux,i=this._uy,a=0,o=0,s=0,l=0;this._pathSegLen||(this._pathSegLen=[]);for(var u=this._pathSegLen,f=0,h=0,c=0;c<r;){var v=t[c++],d=c===1;d&&(a=t[c],o=t[c+1],s=a,l=o);var p=-1;switch(v){case ct.M:a=s=t[c++],o=l=t[c++];break;case ct.L:{var g=t[c++],m=t[c++],y=g-a,_=m-o;(Je(y)>n||Je(_)>i||c===r-1)&&(p=Math.sqrt(y*y+_*_),a=g,o=m);break}case ct.C:{var S=t[c++],w=t[c++],g=t[c++],m=t[c++],b=t[c++],x=t[c++];p=mS(a,o,S,w,g,m,b,x,10),a=b,o=x;break}case ct.Q:{var S=t[c++],w=t[c++],g=t[c++],m=t[c++];p=_S(a,o,S,w,g,m,10),a=g,o=m;break}case ct.A:var C=t[c++],T=t[c++],D=t[c++],A=t[c++],P=t[c++],L=t[c++],I=L+P;c+=1,d&&(s=en(P)*D+C,l=rn(P)*A+T),p=Fl(D,A)*Nl(xr,Math.abs(L)),a=en(I)*D+C,o=rn(I)*A+T;break;case ct.R:{s=a=t[c++],l=o=t[c++];var R=t[c++],E=t[c++];p=R*2+E*2;break}case ct.Z:{var y=s-a,_=l-o;p=Math.sqrt(y*y+_*_),a=s,o=l;break}}p>=0&&(u[h++]=p,f+=p)}return this._pathLen=f,f},e.prototype.rebuildPath=function(t,r){var n=this.data,i=this._ux,a=this._uy,o=this._len,s,l,u,f,h,c,v=r<1,d,p,g=0,m=0,y,_=0,S,w;if(!(v&&(this._pathSegLen||this._calculateLength(),d=this._pathSegLen,p=this._pathLen,y=r*p,!y)))t:for(var b=0;b<o;){var x=n[b++],C=b===1;switch(C&&(u=n[b],f=n[b+1],s=u,l=f),x!==ct.L&&_>0&&(t.lineTo(S,w),_=0),x){case ct.M:s=u=n[b++],l=f=n[b++],t.moveTo(u,f);break;case ct.L:{h=n[b++],c=n[b++];var T=Je(h-u),D=Je(c-f);if(T>i||D>a){if(v){var A=d[m++];if(g+A>y){var P=(y-g)/A;t.lineTo(u*(1-P)+h*P,f*(1-P)+c*P);break t}g+=A}t.lineTo(h,c),u=h,f=c,_=0}else{var L=T*T+D*D;L>_&&(S=h,w=c,_=L)}break}case ct.C:{var I=n[b++],R=n[b++],E=n[b++],G=n[b++],F=n[b++],H=n[b++];if(v){var A=d[m++];if(g+A>y){var P=(y-g)/A;Br(u,I,E,F,P,jr),Br(f,R,G,H,P,tn),t.bezierCurveTo(jr[1],tn[1],jr[2],tn[2],jr[3],tn[3]);break t}g+=A}t.bezierCurveTo(I,R,E,G,F,H),u=F,f=H;break}case ct.Q:{var I=n[b++],R=n[b++],E=n[b++],G=n[b++];if(v){var A=d[m++];if(g+A>y){var P=(y-g)/A;ds(u,I,E,P,jr),ds(f,R,G,P,tn),t.quadraticCurveTo(jr[1],tn[1],jr[2],tn[2]);break t}g+=A}t.quadraticCurveTo(I,R,E,G),u=E,f=G;break}case ct.A:var V=n[b++],U=n[b++],Z=n[b++],J=n[b++],ot=n[b++],yt=n[b++],Ht=n[b++],ce=!n[b++],de=Z>J?Z:J,Vt=Je(Z-J)>.001,Dt=ot+yt,rt=!1;if(v){var A=d[m++];g+A>y&&(Dt=ot+yt*(y-g)/A,rt=!0),g+=A}if(Vt&&t.ellipse?t.ellipse(V,U,Z,J,Ht,ot,Dt,ce):t.arc(V,U,de,ot,Dt,ce),rt)break t;C&&(s=en(ot)*Z+V,l=rn(ot)*J+U),u=en(Dt)*Z+V,f=rn(Dt)*J+U;break;case ct.R:s=u=n[b],l=f=n[b+1],h=n[b++],c=n[b++];var lt=n[b++],Ur=n[b++];if(v){var A=d[m++];if(g+A>y){var Yt=y-g;t.moveTo(h,c),t.lineTo(h+Nl(Yt,lt),c),Yt-=lt,Yt>0&&t.lineTo(h+lt,c+Nl(Yt,Ur)),Yt-=Ur,Yt>0&&t.lineTo(h+Fl(lt-Yt,0),c+Ur),Yt-=lt,Yt>0&&t.lineTo(h,c+Fl(Ur-Yt,0));break t}g+=A}t.rect(h,c,lt,Ur);break;case ct.Z:if(v){var A=d[m++];if(g+A>y){var P=(y-g)/A;t.lineTo(u*(1-P)+s*P,f*(1-P)+l*P);break t}g+=A}t.closePath(),u=s,f=l}}},e.prototype.clone=function(){var t=new e,r=this.data;return t.data=r.slice?r.slice():Array.prototype.slice.call(r),t._len=this._len,t},e.prototype.canSave=function(){return!!this._saveData},e.CMD=ct,e.initDefaultProps=(function(){var t=e.prototype;t._saveData=!0,t._ux=0,t._uy=0,t._pendingPtDist=0,t._version=0})(),e})();function Un(e,t,r,n,i,a,o){if(i===0)return!1;var s=i,l=0,u=e;if(o>t+s&&o>n+s||o<t-s&&o<n-s||a>e+s&&a>r+s||a<e-s&&a<r-s)return!1;if(e!==r)l=(t-n)/(e-r),u=(e*n-r*t)/(e-r);else return Math.abs(a-e)<=s/2;var f=l*a-o+u,h=f*f/(l*l+1);return h<=s/2*s/2}function US(e,t,r,n,i,a,o,s,l,u,f){if(l===0)return!1;var h=l;if(f>t+h&&f>n+h&&f>a+h&&f>s+h||f<t-h&&f<n-h&&f<a-h&&f<s-h||u>e+h&&u>r+h&&u>i+h&&u>o+h||u<e-h&&u<r-h&&u<i-h&&u<o-h)return!1;var c=fm(e,t,r,n,i,a,o,s,u,f,null);return c<=h/2}function YS(e,t,r,n,i,a,o,s,l){if(o===0)return!1;var u=o;if(l>t+u&&l>n+u&&l>a+u||l<t-u&&l<n-u&&l<a-u||s>e+u&&s>r+u&&s>i+u||s<e-u&&s<r-u&&s<i-u)return!1;var f=vm(e,t,r,n,i,a,s,l,null);return f<=u/2}var ic=Math.PI*2;function ir(e){return e%=ic,e<0&&(e+=ic),e}var zi=Math.PI*2;function ZS(e,t,r,n,i,a,o,s,l){if(o===0)return!1;var u=o;s-=e,l-=t;var f=Math.sqrt(s*s+l*l);if(f-u>r||f+u<r)return!1;if(Math.abs(n-i)%zi<1e-4)return!0;if(a){var h=n;n=ir(i),i=ir(h)}else n=ir(n),i=ir(i);n>i&&(i+=zi);var c=Math.atan2(l,s);return c<0&&(c+=zi),c>=n&&c<=i||c+zi>=n&&c+zi<=i}function nn(e,t,r,n,i,a){if(a>t&&a>n||a<t&&a<n||n===t)return 0;var o=(a-t)/(n-t),s=n<t?1:-1;(o===1||o===0)&&(s=n<t?.5:-.5);var l=o*(r-e)+e;return l===i?1/0:l>i?s:0}var pr=hr.CMD,an=Math.PI*2,XS=1e-4;function $S(e,t){return Math.abs(e-t)<XS}var Xt=[-1,-1,-1],_e=[-1,-1];function qS(){var e=_e[0];_e[0]=_e[1],_e[1]=e}function KS(e,t,r,n,i,a,o,s,l,u){if(u>t&&u>n&&u>a&&u>s||u<t&&u<n&&u<a&&u<s)return 0;var f=cs(t,n,a,s,u,Xt);if(f===0)return 0;for(var h=0,c=-1,v=void 0,d=void 0,p=0;p<f;p++){var g=Xt[p],m=g===0||g===1?.5:1,y=Lt(e,r,i,o,g);y<l||(c<0&&(c=um(t,n,a,s,_e),_e[1]<_e[0]&&c>1&&qS(),v=Lt(t,n,a,s,_e[0]),c>1&&(d=Lt(t,n,a,s,_e[1]))),c===2?g<_e[0]?h+=v<t?m:-m:g<_e[1]?h+=d<v?m:-m:h+=s<d?m:-m:g<_e[0]?h+=v<t?m:-m:h+=s<v?m:-m)}return h}function QS(e,t,r,n,i,a,o,s){if(s>t&&s>n&&s>a||s<t&&s<n&&s<a)return 0;var l=yS(t,n,a,s,Xt);if(l===0)return 0;var u=hm(t,n,a);if(u>=0&&u<=1){for(var f=0,h=Wt(t,n,a,u),c=0;c<l;c++){var v=Xt[c]===0||Xt[c]===1?.5:1,d=Wt(e,r,i,Xt[c]);d<o||(Xt[c]<u?f+=h<t?v:-v:f+=a<h?v:-v)}return f}else{var v=Xt[0]===0||Xt[0]===1?.5:1,d=Wt(e,r,i,Xt[0]);return d<o?0:a<t?v:-v}}function JS(e,t,r,n,i,a,o,s){if(s-=t,s>r||s<-r)return 0;var l=Math.sqrt(r*r-s*s);Xt[0]=-l,Xt[1]=l;var u=Math.abs(n-i);if(u<1e-4)return 0;if(u>=an-1e-4){n=0,i=an;var f=a?1:-1;return o>=Xt[0]+e&&o<=Xt[1]+e?f:0}if(n>i){var h=n;n=i,i=h}n<0&&(n+=an,i+=an);for(var c=0,v=0;v<2;v++){var d=Xt[v];if(d+e>o){var p=Math.atan2(s,d),f=a?1:-1;p<0&&(p=an+p),(p>=n&&p<=i||p+an>=n&&p+an<=i)&&(p>Math.PI/2&&p<Math.PI*1.5&&(f=-f),c+=f)}}return c}function _m(e,t,r,n,i){for(var a=e.data,o=e.len(),s=0,l=0,u=0,f=0,h=0,c,v,d=0;d<o;){var p=a[d++],g=d===1;switch(p===pr.M&&d>1&&(r||(s+=nn(l,u,f,h,n,i))),g&&(l=a[d],u=a[d+1],f=l,h=u),p){case pr.M:f=a[d++],h=a[d++],l=f,u=h;break;case pr.L:if(r){if(Un(l,u,a[d],a[d+1],t,n,i))return!0}else s+=nn(l,u,a[d],a[d+1],n,i)||0;l=a[d++],u=a[d++];break;case pr.C:if(r){if(US(l,u,a[d++],a[d++],a[d++],a[d++],a[d],a[d+1],t,n,i))return!0}else s+=KS(l,u,a[d++],a[d++],a[d++],a[d++],a[d],a[d+1],n,i)||0;l=a[d++],u=a[d++];break;case pr.Q:if(r){if(YS(l,u,a[d++],a[d++],a[d],a[d+1],t,n,i))return!0}else s+=QS(l,u,a[d++],a[d++],a[d],a[d+1],n,i)||0;l=a[d++],u=a[d++];break;case pr.A:var m=a[d++],y=a[d++],_=a[d++],S=a[d++],w=a[d++],b=a[d++];d+=1;var x=!!(1-a[d++]);c=Math.cos(w)*_+m,v=Math.sin(w)*S+y,g?(f=c,h=v):s+=nn(l,u,c,v,n,i);var C=(n-m)*S/_+m;if(r){if(ZS(m,y,S,w,w+b,x,t,C,i))return!0}else s+=JS(m,y,S,w,w+b,x,C,i);l=Math.cos(w+b)*_+m,u=Math.sin(w+b)*S+y;break;case pr.R:f=l=a[d++],h=u=a[d++];var T=a[d++],D=a[d++];if(c=f+T,v=h+D,r){if(Un(f,h,c,h,t,n,i)||Un(c,h,c,v,t,n,i)||Un(c,v,f,v,t,n,i)||Un(f,v,f,h,t,n,i))return!0}else s+=nn(c,h,c,v,n,i),s+=nn(f,v,f,h,n,i);break;case pr.Z:if(r){if(Un(l,u,f,h,t,n,i))return!0}else s+=nn(l,u,f,h,n,i);l=f,u=h;break}}return!r&&!$S(u,h)&&(s+=nn(l,u,f,h,n,i)||0),s!==0}function jS(e,t,r){return _m(e,0,!1,t,r)}function tb(e,t,r,n){return _m(e,t,!0,r,n)}var Sm=at({fill:"#000",stroke:null,strokePercent:1,fillOpacity:1,strokeOpacity:1,lineDashOffset:0,lineWidth:1,lineCap:"butt",miterLimit:10,strokeNoScale:!1,strokeFirst:!1},An),eb={style:at({fill:!0,stroke:!0,strokePercent:!0,fillOpacity:!0,strokeOpacity:!0,lineDashOffset:!0,lineWidth:!0,miterLimit:!0},il.style)},Vl=Pa.concat(["invisible","culling","z","z2","zlevel","parent"]),ht=(function(e){N(t,e);function t(r){return e.call(this,r)||this}return t.prototype.update=function(){var r=this;e.prototype.update.call(this);var n=this.style;if(n.decal){var i=this._decalEl=this._decalEl||new t;i.buildPath===t.prototype.buildPath&&(i.buildPath=function(l){r.buildPath(l,r.shape)}),i.silent=!0;var a=i.style;for(var o in n)a[o]!==n[o]&&(a[o]=n[o]);a.fill=n.fill?n.decal:null,a.decal=null,a.shadowColor=null,n.strokeFirst&&(a.stroke=null);for(var s=0;s<Vl.length;++s)i[Vl[s]]=this[Vl[s]];i.__dirty|=ue}else this._decalEl&&(this._decalEl=null)},t.prototype.getDecalElement=function(){return this._decalEl},t.prototype._init=function(r){var n=St(r);this.shape=this.getDefaultShape();var i=this.getDefaultStyle();i&&this.useStyle(i);for(var a=0;a<n.length;a++){var o=n[a],s=r[o];o==="style"?this.style?k(this.style,s):this.useStyle(s):o==="shape"?k(this.shape,s):e.prototype.attrKV.call(this,o,s)}this.style||this.useStyle({})},t.prototype.getDefaultStyle=function(){return null},t.prototype.getDefaultShape=function(){return{}},t.prototype.canBeInsideText=function(){return this.hasFill()},t.prototype.getInsideTextFill=function(){var r=this.style.fill;if(r!=="none"){if(W(r)){var n=ps(r,0);return n>.5?cf:n>.2?PS:df}else if(r)return df}return cf},t.prototype.getInsideTextStroke=function(r){var n=this.style.fill;if(W(n)){var i=this.__zr,a=!!(i&&i.isDarkMode()),o=ps(r,0)<vf;if(a===o)return n}},t.prototype.buildPath=function(r,n,i){},t.prototype.pathUpdated=function(){this.__dirty&=~si},t.prototype.getUpdatedPathProxy=function(r){return!this.path&&this.createPathProxy(),this.path.beginPath(),this.buildPath(this.path,this.shape,r),this.path},t.prototype.createPathProxy=function(){this.path=new hr(!1)},t.prototype.hasStroke=function(){var r=this.style,n=r.stroke;return!(n==null||n==="none"||!(r.lineWidth>0))},t.prototype.hasFill=function(){var r=this.style,n=r.fill;return n!=null&&n!=="none"},t.prototype.getBoundingRect=function(){var r=this._rect,n=this.style,i=!r;if(i){var a=!1;this.path||(a=!0,this.createPathProxy());var o=this.path;(a||this.__dirty&si)&&(o.beginPath(),this.buildPath(o,this.shape,!1),this.pathUpdated()),r=o.getBoundingRect()}if(this._rect=r,this.hasStroke()&&this.path&&this.path.len()>0){var s=this._rectStroke||(this._rectStroke=r.clone());if(this.__dirty||i){s.copy(r);var l=n.strokeNoScale?this.getLineScale():1,u=n.lineWidth;if(!this.hasFill()){var f=this.strokeContainThreshold;u=Math.max(u,f??4)}l>1e-10&&(s.width+=u/l,s.height+=u/l,s.x-=u/l/2,s.y-=u/l/2)}return s}return r},t.prototype.contain=function(r,n){var i=this.transformCoordToLocal(r,n),a=this.getBoundingRect(),o=this.style;if(r=i[0],n=i[1],a.contain(r,n)){var s=this.path;if(this.hasStroke()){var l=o.lineWidth,u=o.strokeNoScale?this.getLineScale():1;if(u>1e-10&&(this.hasFill()||(l=Math.max(l,this.strokeContainThreshold)),tb(s,l/u,r,n)))return!0}if(this.hasFill())return jS(s,r,n)}return!1},t.prototype.dirtyShape=function(){this.__dirty|=si,this._rect&&(this._rect=null),this._decalEl&&this._decalEl.dirtyShape(),this.markRedraw()},t.prototype.dirty=function(){this.dirtyStyle(),this.dirtyShape()},t.prototype.animateShape=function(r){return this.animate("shape",r)},t.prototype.updateDuringAnimation=function(r){r==="style"?this.dirtyStyle():r==="shape"?this.dirtyShape():this.markRedraw()},t.prototype.attrKV=function(r,n){r==="shape"?this.setShape(n):e.prototype.attrKV.call(this,r,n)},t.prototype.setShape=function(r,n){var i=this.shape;return i||(i=this.shape={}),typeof r=="string"?i[r]=n:k(i,r),this.dirtyShape(),this},t.prototype.shapeChanged=function(){return!!(this.__dirty&si)},t.prototype.createStyle=function(r){return Js(Sm,r)},t.prototype._innerSaveToNormal=function(r){e.prototype._innerSaveToNormal.call(this,r);var n=this._normalState;r.shape&&!n.shape&&(n.shape=k({},this.shape))},t.prototype._applyStateObj=function(r,n,i,a,o,s){e.prototype._applyStateObj.call(this,r,n,i,a,o,s);var l=!(n&&a),u;if(n&&n.shape?o?a?u=n.shape:(u=k({},i.shape),k(u,n.shape)):(u=k({},a?this.shape:i.shape),k(u,n.shape)):l&&(u=i.shape),u)if(o){this.shape=k({},this.shape);for(var f={},h=St(u),c=0;c<h.length;c++){var v=h[c];typeof u[v]=="object"?this.shape[v]=u[v]:f[v]=u[v]}this._transitionState(r,{shape:f},s)}else this.shape=u,this.dirtyShape()},t.prototype._mergeStates=function(r){for(var n=e.prototype._mergeStates.call(this,r),i,a=0;a<r.length;a++){var o=r[a];o.shape&&(i=i||{},this._mergeStyle(i,o.shape))}return i&&(n.shape=i),n},t.prototype.getAnimationStyleProps=function(){return eb},t.prototype.isZeroArea=function(){return!1},t.extend=function(r){var n=(function(a){N(o,a);function o(s){var l=a.call(this,s)||this;return r.init&&r.init.call(l,s),l}return o.prototype.getDefaultStyle=function(){return st(r.style)},o.prototype.getDefaultShape=function(){return st(r.shape)},o})(t);for(var i in r)typeof r[i]=="function"&&(n.prototype[i]=r[i]);return n},t.initDefaultProps=(function(){var r=t.prototype;r.type="path",r.strokeContainThreshold=5,r.segmentIgnoreThreshold=0,r.subPixelOptimize=!1,r.autoBatch=!1,r.__dirty=ue|ua|si})(),t})(Oi),rb=at({strokeFirst:!0,font:Or,x:0,y:0,textAlign:"left",textBaseline:"top",miterLimit:2},Sm),ms=(function(e){N(t,e);function t(){return e!==null&&e.apply(this,arguments)||this}return t.prototype.hasStroke=function(){return om(this.style)},t.prototype.hasFill=function(){var r=this.style,n=r.fill;return n!=null&&n!=="none"},t.prototype.createStyle=function(r){return Js(rb,r)},t.prototype.setBoundingRect=function(r){this._rect=r},t.prototype.getBoundingRect=function(){return this._rect||(this._rect=fS(this.style)),this._rect},t.initDefaultProps=(function(){var r=t.prototype;r.dirtyRectTolerance=10})(),t})(Oi);ms.prototype.type="tspan";var nb=at({x:0,y:0},An),ib={style:at({x:!0,y:!0,width:!0,height:!0,sx:!0,sy:!0,sWidth:!0,sHeight:!0},il.style)};function ab(e){return!!(e&&typeof e!="string"&&e.width&&e.height)}var Gr=(function(e){N(t,e);function t(){return e!==null&&e.apply(this,arguments)||this}return t.prototype.createStyle=function(r){return Js(nb,r)},t.prototype._getSize=function(r){var n=this.style,i=n[r];if(i!=null)return i;var a=ab(n.image)?n.image:this.__image;if(!a)return 0;var o=r==="width"?"height":"width",s=n[o];return s==null?a[r]:a[r]/a[o]*s},t.prototype.getWidth=function(){return this._getSize("width")},t.prototype.getHeight=function(){return this._getSize("height")},t.prototype.getAnimationStyleProps=function(){return ib},t.prototype.getBoundingRect=function(){var r=this.style;return this._rect||(this._rect=new it(r.x||0,r.y||0,this.getWidth(),this.getHeight())),this._rect},t})(Oi);Gr.prototype.type="image";function ob(e,t){var r=t.x,n=t.y,i=t.width,a=t.height,o=t.r,s,l,u,f;i<0&&(r=r+i,i=-i),a<0&&(n=n+a,a=-a),typeof o=="number"?s=l=u=f=o:o instanceof Array?o.length===1?s=l=u=f=o[0]:o.length===2?(s=u=o[0],l=f=o[1]):o.length===3?(s=o[0],l=f=o[1],u=o[2]):(s=o[0],l=o[1],u=o[2],f=o[3]):s=l=u=f=0;var h;s+l>i&&(h=s+l,s*=i/h,l*=i/h),u+f>i&&(h=u+f,u*=i/h,f*=i/h),l+u>a&&(h=l+u,l*=a/h,u*=a/h),s+f>a&&(h=s+f,s*=a/h,f*=a/h),e.moveTo(r+s,n),e.lineTo(r+i-l,n),l!==0&&e.arc(r+i-l,n+l,l,-Math.PI/2,0),e.lineTo(r+i,n+a-u),u!==0&&e.arc(r+i-u,n+a-u,u,0,Math.PI/2),e.lineTo(r+f,n+a),f!==0&&e.arc(r+f,n+a-f,f,Math.PI/2,Math.PI),e.lineTo(r,n+s),s!==0&&e.arc(r+s,n+s,s,Math.PI,Math.PI*1.5)}var vi=Math.round;function bm(e,t,r){if(t){var n=t.x1,i=t.x2,a=t.y1,o=t.y2;e.x1=n,e.x2=i,e.y1=a,e.y2=o;var s=r&&r.lineWidth;return s&&(vi(n*2)===vi(i*2)&&(e.x1=e.x2=wn(n,s,!0)),vi(a*2)===vi(o*2)&&(e.y1=e.y2=wn(a,s,!0))),e}}function wm(e,t,r){if(t){var n=t.x,i=t.y,a=t.width,o=t.height;e.x=n,e.y=i,e.width=a,e.height=o;var s=r&&r.lineWidth;return s&&(e.x=wn(n,s,!0),e.y=wn(i,s,!0),e.width=Math.max(wn(n+a,s,!1)-e.x,a===0?0:1),e.height=Math.max(wn(i+o,s,!1)-e.y,o===0?0:1)),e}}function wn(e,t,r){if(!t)return e;var n=vi(e*2);return(n+vi(t))%2===0?n/2:(n+(r?1:-1))/2}var sb=(function(){function e(){this.x=0,this.y=0,this.width=0,this.height=0}return e})(),lb={},Tt=(function(e){N(t,e);function t(r){return e.call(this,r)||this}return t.prototype.getDefaultShape=function(){return new sb},t.prototype.buildPath=function(r,n){var i,a,o,s;if(this.subPixelOptimize){var l=wm(lb,n,this.style);i=l.x,a=l.y,o=l.width,s=l.height,l.r=n.r,n=l}else i=n.x,a=n.y,o=n.width,s=n.height;n.r?ob(r,n):r.rect(i,a,o,s)},t.prototype.isZeroArea=function(){return!this.shape.width||!this.shape.height},t})(ht);Tt.prototype.type="rect";var ac={fill:"#000"},oc=2,Fe={},ub={style:at({fill:!0,stroke:!0,fillOpacity:!0,strokeOpacity:!0,lineWidth:!0,fontSize:!0,lineHeight:!0,width:!0,height:!0,textShadowColor:!0,textShadowBlur:!0,textShadowOffsetX:!0,textShadowOffsetY:!0,backgroundColor:!0,padding:!0,borderColor:!0,borderWidth:!0,borderRadius:!0},il.style)},ae=(function(e){N(t,e);function t(r){var n=e.call(this)||this;return n.type="text",n._children=[],n._defaultStyle=ac,n.attr(r),n}return t.prototype.childrenRef=function(){return this._children},t.prototype.update=function(){e.prototype.update.call(this),this.styleChanged()&&this._updateSubTexts();for(var r=0;r<this._children.length;r++){var n=this._children[r];n.zlevel=this.zlevel,n.z=this.z,n.z2=this.z2,n.culling=this.culling,n.cursor=this.cursor,n.invisible=this.invisible}},t.prototype.updateTransform=function(){var r=this.innerTransformable;r?(r.updateTransform(),r.transform&&(this.transform=r.transform)):e.prototype.updateTransform.call(this)},t.prototype.getLocalTransform=function(r){var n=this.innerTransformable;return n?n.getLocalTransform(r):e.prototype.getLocalTransform.call(this,r)},t.prototype.getComputedTransform=function(){return this.__hostTarget&&(this.__hostTarget.getComputedTransform(),this.__hostTarget.updateInnerText(!0)),e.prototype.getComputedTransform.call(this)},t.prototype._updateSubTexts=function(){this._childCursor=0,db(this.style),this.style.rich?this._updateRichTexts():this._updatePlainTexts(),this._children.length=this._childCursor,this.styleUpdated()},t.prototype.addSelfToZr=function(r){e.prototype.addSelfToZr.call(this,r);for(var n=0;n<this._children.length;n++)this._children[n].__zr=r},t.prototype.removeSelfFromZr=function(r){e.prototype.removeSelfFromZr.call(this,r);for(var n=0;n<this._children.length;n++)this._children[n].__zr=null},t.prototype.getBoundingRect=function(){if(this.styleChanged()&&this._updateSubTexts(),!this._rect){for(var r=new it(0,0,0,0),n=this._children,i=[],a=null,o=0;o<n.length;o++){var s=n[o],l=s.getBoundingRect(),u=s.getLocalTransform(i);u?(r.copy(l),r.applyTransform(u),a=a||r.clone(),a.union(r)):(a=a||l.clone(),a.union(l))}this._rect=a||r}return this._rect},t.prototype.setDefaultTextStyle=function(r){this._defaultStyle=r||ac},t.prototype.setTextContent=function(r){},t.prototype._mergeStyle=function(r,n){if(!n)return r;var i=n.rich,a=r.rich||i&&{};return k(r,n),i&&a?(this._mergeRich(a,i),r.rich=a):a&&(r.rich=a),r},t.prototype._mergeRich=function(r,n){for(var i=St(n),a=0;a<i.length;a++){var o=i[a];r[o]=r[o]||{},k(r[o],n[o])}},t.prototype.getAnimationStyleProps=function(){return ub},t.prototype._getOrCreateChild=function(r){var n=this._children[this._childCursor];return(!n||!(n instanceof r))&&(n=new r),this._children[this._childCursor++]=n,n.__zr=this.__zr,n.parent=this,n},t.prototype._updatePlainTexts=function(){var r=this.style,n=r.font||Or,i=r.padding,a=this._defaultStyle,o=r.x||0,s=r.y||0,l=r.align||a.align||"left",u=r.verticalAlign||a.verticalAlign||"top";Fv(Fe,a.overflowRect,o,s,l,u),o=Fe.baseX,s=Fe.baseY;var f=cc(r),h=nS(f,r,Fe.outerWidth,Fe.outerHeight),c=Gl(r),v=!!r.backgroundColor,d=h.outerHeight,p=h.outerWidth,g=h.lines,m=h.lineHeight;this.isTruncated=!!h.isTruncated;var y=o,_=Mn(s,h.contentHeight,u);if(c||i){var S=Ti(o,p,l),w=Mn(s,d,u);c&&this._renderBackground(r,r,S,w,p,d)}_+=m/2,i&&(y=vc(o,l,i),u==="top"?_+=i[0]:u==="bottom"&&(_-=i[2]));for(var b=0,x=!1,C=!1,T=hc("fill"in r?r.fill:(C=!0,a.fill)),D=fc("stroke"in r?r.stroke:!v&&(!a.autoStroke||C)?(b=oc,x=!0,a.stroke):null),A=r.textShadowBlur>0,P=0;P<g.length;P++){var L=this._getOrCreateChild(ms),I=L.createStyle();L.useStyle(I),I.text=g[P],I.x=y,I.y=_,I.textAlign=l,I.textBaseline="middle",I.opacity=r.opacity,I.strokeFirst=!0,A&&(I.shadowBlur=r.textShadowBlur||0,I.shadowColor=r.textShadowColor||"transparent",I.shadowOffsetX=r.textShadowOffsetX||0,I.shadowOffsetY=r.textShadowOffsetY||0),I.stroke=D,I.fill=T,D&&(I.lineWidth=r.lineWidth||b,I.lineDash=r.lineDash,I.lineDashOffset=r.lineDashOffset||0),I.font=n,lc(I,r),_+=m,L.setBoundingRect(tf(I,h.contentWidth,h.calculatedLineHeight,x?0:null))}},t.prototype._updateRichTexts=function(){var r=this.style,n=this._defaultStyle,i=r.align||n.align,a=r.verticalAlign||n.verticalAlign,o=r.x||0,s=r.y||0;Fv(Fe,n.overflowRect,o,s,i,a),o=Fe.baseX,s=Fe.baseY;var l=cc(r),u=oS(l,r,Fe.outerWidth,Fe.outerHeight,i),f=u.width,h=u.outerWidth,c=u.outerHeight,v=r.padding;this.isTruncated=!!u.isTruncated;var d=Ti(o,h,i),p=Mn(s,c,a),g=d,m=p;v&&(g+=v[3],m+=v[0]);var y=g+f;Gl(r)&&this._renderBackground(r,r,d,p,h,c);for(var _=!!r.backgroundColor,S=0;S<u.lines.length;S++){for(var w=u.lines[S],b=w.tokens,x=b.length,C=w.lineHeight,T=w.width,D=0,A=g,P=y,L=x-1,I=void 0;D<x&&(I=b[D],!I.align||I.align==="left");)this._placeToken(I,r,C,m,A,"left",_),T-=I.width,A+=I.width,D++;for(;L>=0&&(I=b[L],I.align==="right");)this._placeToken(I,r,C,m,P,"right",_),T-=I.width,P-=I.width,L--;for(A+=(f-(A-g)-(y-P)-T)/2;D<=L;)I=b[D],this._placeToken(I,r,C,m,A+I.width/2,"center",_),A+=I.width,D++;m+=C}},t.prototype._placeToken=function(r,n,i,a,o,s,l){var u=n.rich[r.styleName]||{};u.text=r.text;var f=r.verticalAlign,h=a+i/2;f==="top"?h=a+r.height/2:f==="bottom"&&(h=a+i-r.height/2);var c=!r.isLineHolder&&Gl(u);c&&this._renderBackground(u,n,s==="right"?o-r.width:s==="center"?o-r.width/2:o,h-r.height/2,r.width,r.height);var v=!!u.backgroundColor,d=r.textPadding;d&&(o=vc(o,s,d),h-=r.height/2-d[0]-r.innerHeight/2);var p=this._getOrCreateChild(ms),g=p.createStyle();p.useStyle(g);var m=this._defaultStyle,y=!1,_=0,S=!1,w=hc("fill"in u?u.fill:"fill"in n?n.fill:(y=!0,m.fill)),b=fc("stroke"in u?u.stroke:"stroke"in n?n.stroke:!v&&!l&&(!m.autoStroke||y)?(_=oc,S=!0,m.stroke):null),x=u.textShadowBlur>0||n.textShadowBlur>0;g.text=r.text,g.x=o,g.y=h,x&&(g.shadowBlur=u.textShadowBlur||n.textShadowBlur||0,g.shadowColor=u.textShadowColor||n.textShadowColor||"transparent",g.shadowOffsetX=u.textShadowOffsetX||n.textShadowOffsetX||0,g.shadowOffsetY=u.textShadowOffsetY||n.textShadowOffsetY||0),g.textAlign=s,g.textBaseline="middle",g.font=r.font||Or,g.opacity=yi(u.opacity,n.opacity,1),lc(g,u),b&&(g.lineWidth=yi(u.lineWidth,n.lineWidth,_),g.lineDash=q(u.lineDash,n.lineDash),g.lineDashOffset=n.lineDashOffset||0,g.stroke=b),w&&(g.fill=w),p.setBoundingRect(tf(g,r.contentWidth,r.contentHeight,S?0:null))},t.prototype._renderBackground=function(r,n,i,a,o,s){var l=r.backgroundColor,u=r.borderWidth,f=r.borderColor,h=l&&l.image,c=l&&!h,v=r.borderRadius,d=this,p,g;if(c||r.lineHeight||u&&f){p=this._getOrCreateChild(Tt),p.useStyle(p.createStyle()),p.style.fill=null;var m=p.shape;m.x=i,m.y=a,m.width=o,m.height=s,m.r=v,p.dirtyShape()}if(c){var y=p.style;y.fill=l||null,y.fillOpacity=q(r.fillOpacity,1)}else if(h){g=this._getOrCreateChild(Gr),g.onload=function(){d.dirtyStyle()};var _=g.style;_.image=l.image,_.x=i,_.y=a,_.width=o,_.height=s}if(u&&f){var y=p.style;y.lineWidth=u,y.stroke=f,y.strokeOpacity=q(r.strokeOpacity,1),y.lineDash=r.borderDash,y.lineDashOffset=r.borderDashOffset||0,p.strokeContainThreshold=0,p.hasFill()&&p.hasStroke()&&(y.strokeFirst=!0,y.lineWidth*=2)}var S=(p||g).style;S.shadowBlur=r.shadowBlur||0,S.shadowColor=r.shadowColor||"transparent",S.shadowOffsetX=r.shadowOffsetX||0,S.shadowOffsetY=r.shadowOffsetY||0,S.opacity=yi(r.opacity,n.opacity,1)},t.makeFont=function(r){var n="";return cb(r)&&(n=[r.fontStyle,r.fontWeight,vb(r.fontSize),r.fontFamily||"sans-serif"].join(" ")),n&&Ge(n)||r.textFont||r.font},t})(Oi),fb={left:!0,right:1,center:1},hb={top:1,bottom:1,middle:1},sc=["fontStyle","fontWeight","fontSize","fontFamily"];function vb(e){return typeof e=="string"&&(e.indexOf("px")!==-1||e.indexOf("rem")!==-1||e.indexOf("em")!==-1)?e:isNaN(+e)?dh+"px":e+"px"}function lc(e,t){for(var r=0;r<sc.length;r++){var n=sc[r],i=t[n];i!=null&&(e[n]=i)}}function cb(e){return e.fontSize!=null||e.fontFamily||e.fontWeight}function db(e){return uc(e),M(e.rich,uc),e}function uc(e){if(e){e.font=ae.makeFont(e);var t=e.align;t==="middle"&&(t="center"),e.align=t==null||fb[t]?t:"left";var r=e.verticalAlign;r==="center"&&(r="middle"),e.verticalAlign=r==null||hb[r]?r:"top";var n=e.padding;n&&(e.padding=_h(e.padding))}}function fc(e,t){return e==null||t<=0||e==="transparent"||e==="none"?null:e.image||e.colorStops?"#000":e}function hc(e){return e==null||e==="none"?null:e.image||e.colorStops?"#000":e}function vc(e,t,r){return t==="right"?e-r[1]:t==="center"?e+r[3]/2-r[1]/2:e+r[3]}function cc(e){var t=e.text;return t!=null&&(t+=""),t}function Gl(e){return!!(e.backgroundColor||e.lineHeight||e.borderWidth&&e.borderColor)}var dc=1e-4,xm=20;function pb(e){return e.replace(/^\s+|\s+$/g,"")}var Ra=Math.min,fe=Math.max,Ue=Math.abs;function Et(e,t,r,n){var i=t[0],a=t[1],o=r[0],s=r[1],l=a-i,u=s-o;if(l===0)return u===0?o:(o+s)/2;if(n)if(l>0){if(e<=i)return o;if(e>=a)return s}else{if(e>=i)return o;if(e<=a)return s}else{if(e===i)return o;if(e===a)return s}return(e-i)/l*u+o}var It=gb;function gb(e,t,r){switch(e){case"center":case"middle":e="50%";break;case"left":case"top":e="0%";break;case"right":case"bottom":e="100%";break}return mf(e,t,r)}function mf(e,t,r){return W(e)?pb(e).match(/%$/)?parseFloat(e)/100*t+(r||0):parseFloat(e):e==null?NaN:+e}function Nt(e,t,r){return t==null&&(t=10),t=Math.min(Math.max(0,t),xm),e=(+e).toFixed(t),r?e:+e}function fa(e){return e.sort(function(t,r){return t-r}),e}function ar(e){if(e=+e,isNaN(e))return 0;if(e>1e-14){for(var t=1,r=0;r<15;r++,t*=10)if(Math.round(e*t)/t===e)return r}return mb(e)}function mb(e){var t=e.toString().toLowerCase(),r=t.indexOf("e"),n=r>0?+t.slice(r+1):0,i=r>0?r:t.length,a=t.indexOf("."),o=a<0?0:i-1-a;return Math.max(0,o-n)}function Tm(e,t){var r=Math.log,n=Math.LN10,i=Math.floor(r(e[1]-e[0])/n),a=Math.round(r(Ue(t[1]-t[0]))/n),o=Math.min(Math.max(-i+a,0),20);return isFinite(o)?o:20}function yb(e,t){var r=Math.max(ar(e),ar(t)),n=e+t;return r>xm?n:Nt(n,r)}function Cm(e){var t=Math.PI*2;return(e%t+t)%t}function ys(e){return e>-dc&&e<dc}var _b=/^(?:(\d{4})(?:[-\/](\d{1,2})(?:[-\/](\d{1,2})(?:[T ](\d{1,2})(?::(\d{1,2})(?::(\d{1,2})(?:[.,](\d+))?)?)?(Z|[\+\-]\d\d:?\d\d)?)?)?)?)?$/;function Bi(e){if(e instanceof Date)return e;if(W(e)){var t=_b.exec(e);if(!t)return new Date(NaN);if(t[8]){var r=+t[4]||0;return t[8].toUpperCase()!=="Z"&&(r-=+t[8].slice(0,3)),new Date(Date.UTC(+t[1],+(t[2]||1)-1,+t[3]||1,r,+(t[5]||0),+t[6]||0,t[7]?+t[7].substring(0,3):0))}else return new Date(+t[1],+(t[2]||1)-1,+t[3]||1,+t[4]||0,+(t[5]||0),+t[6]||0,t[7]?+t[7].substring(0,3):0)}else if(e==null)return new Date(NaN);return new Date(Math.round(e))}function Sb(e){return Math.pow(10,Ch(e))}function Ch(e){if(e===0)return 0;var t=Math.floor(Math.log(e)/Math.LN10);return e/Math.pow(10,t)>=10&&t++,t}function Mm(e,t){var r=Ch(e),n=Math.pow(10,r),i=e/n,a;return i<1.5?a=1:i<2.5?a=2:i<4?a=3:i<7?a=5:a=10,e=a*n,r>=-20?+e.toFixed(r<0?-r:0):e}function Nr(e){var t=parseFloat(e);return t==e&&(t!==0||!W(e)||e.indexOf("x")<=0)?t:NaN}function bb(e){return!isNaN(Nr(e))}function Dm(){return Math.round(Math.random()*9)}function Am(e,t){return t===0?e:Am(t,e%t)}function pc(e,t){return e==null?t:t==null?e:e*t/Am(e,t)}var wb="[ECharts] ",xb=typeof console<"u"&&console.warn&&console.log;function Tb(e,t,r){xb&&console[e](wb+t)}function Lm(e,t){Tb("error",e)}function ut(e){throw new Error(e)}function gc(e,t,r){return(t-e)*r+e}var Im="series\0",Cb="\0_ec_\0";function Mt(e){return e instanceof Array?e:e==null?[]:[e]}function mc(e,t,r){if(e){e[t]=e[t]||{},e.emphasis=e.emphasis||{},e.emphasis[t]=e.emphasis[t]||{};for(var n=0,i=r.length;n<i;n++){var a=r[n];!e.emphasis[t].hasOwnProperty(a)&&e[t].hasOwnProperty(a)&&(e.emphasis[t][a]=e[t][a])}}}var yc=["fontStyle","fontWeight","fontSize","fontFamily","rich","tag","color","textBorderColor","textBorderWidth","width","height","lineHeight","align","verticalAlign","baseline","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY","textShadowColor","textShadowBlur","textShadowOffsetX","textShadowOffsetY","backgroundColor","borderColor","borderWidth","borderRadius","padding"];function Ka(e){return X(e)&&!z(e)&&!(e instanceof Date)?e.value:e}function Mb(e){return X(e)&&!(e instanceof Array)}function Db(e,t,r){var n=r==="normalMerge",i=r==="replaceMerge",a=r==="replaceAll";e=e||[],t=(t||[]).slice();var o=K();M(t,function(l,u){if(!X(l)){t[u]=null;return}});var s=Ab(e,o,r);return(n||i)&&Lb(s,e,o,t),n&&Ib(s,t),n||i?Pb(s,t,i):a&&Rb(s,t),Eb(s),s}function Ab(e,t,r){var n=[];if(r==="replaceAll")return n;for(var i=0;i<e.length;i++){var a=e[i];a&&a.id!=null&&t.set(a.id,i),n.push({existing:r==="replaceMerge"||Ea(a)?null:a,newOption:null,keyInfo:null,brandNew:null})}return n}function Lb(e,t,r,n){M(n,function(i,a){if(!(!i||i.id==null)){var o=Sa(i.id),s=r.get(o);if(s!=null){var l=e[s];fr(!l.newOption,'Duplicated option on id "'+o+'".'),l.newOption=i,l.existing=t[s],n[a]=null}}})}function Ib(e,t){M(t,function(r,n){if(!(!r||r.name==null))for(var i=0;i<e.length;i++){var a=e[i].existing;if(!e[i].newOption&&a&&(a.id==null||r.id==null)&&!Ea(r)&&!Ea(a)&&Pm("name",a,r)){e[i].newOption=r,t[n]=null;return}}})}function Pb(e,t,r){M(t,function(n){if(n){for(var i,a=0;(i=e[a])&&(i.newOption||Ea(i.existing)||i.existing&&n.id!=null&&!Pm("id",n,i.existing));)a++;i?(i.newOption=n,i.brandNew=r):e.push({newOption:n,brandNew:r,existing:null,keyInfo:null}),a++}})}function Rb(e,t){M(t,function(r){e.push({newOption:r,brandNew:!0,existing:null,keyInfo:null})})}function Eb(e){var t=K();M(e,function(r){var n=r.existing;n&&t.set(n.id,r)}),M(e,function(r){var n=r.newOption;fr(!n||n.id==null||!t.get(n.id)||t.get(n.id)===r,"id duplicates: "+(n&&n.id)),n&&n.id!=null&&t.set(n.id,r),!r.keyInfo&&(r.keyInfo={})}),M(e,function(r,n){var i=r.existing,a=r.newOption,o=r.keyInfo;if(X(a)){if(o.name=a.name!=null?Sa(a.name):i?i.name:Im+n,i)o.id=Sa(i.id);else if(a.id!=null)o.id=Sa(a.id);else{var s=0;do o.id="\0"+o.name+"\0"+s++;while(t.get(o.id))}t.set(o.id,r)}})}function Pm(e,t,r){var n=Xe(t[e],null),i=Xe(r[e],null);return n!=null&&i!=null&&n===i}function Sa(e){return Xe(e,"")}function Xe(e,t){return e==null?t:W(e)?e:mt(e)||qu(e)?e+"":t}function Rm(e){var t=e.name;return!!(t&&t.indexOf(Im))}function Ea(e){return e&&e.id!=null&&Sa(e.id).indexOf(Cb)===0}function kb(e,t,r){M(e,function(n){var i=n.newOption;X(i)&&(n.keyInfo.mainType=t,n.keyInfo.subType=Ob(t,i,n.existing,r))})}function Ob(e,t,r,n){var i=t.type?t.type:r?r.subType:n.determineSubType(e,t);return i}function En(e,t){if(t.dataIndexInside!=null)return t.dataIndexInside;if(t.dataIndex!=null)return z(t.dataIndex)?$(t.dataIndex,function(r){return e.indexOfRawIndex(r)}):e.indexOfRawIndex(t.dataIndex);if(t.name!=null)return z(t.name)?$(t.name,function(r){return e.indexOfName(r)}):e.indexOfName(t.name)}function gt(){var e="__ec_inner_"+Bb++;return function(t){return t[e]||(t[e]={})}}var Bb=Dm();function Wl(e,t,r){var n=Mh(t,r),i=n.mainTypeSpecified,a=n.queryOptionMap,o=n.others,s=o,l=r?r.defaultMainType:null;return!i&&l&&a.set(l,{}),a.each(function(u,f){var h=Qa(e,f,u,{useDefault:l===f,enableAll:r&&r.enableAll!=null?r.enableAll:!0,enableNone:r&&r.enableNone!=null?r.enableNone:!0});s[f+"Models"]=h.models,s[f+"Model"]=h.models[0]}),s}function Mh(e,t){var r;if(W(e)){var n={};n[e+"Index"]=0,r=n}else r=e;var i=K(),a={},o=!1;return M(r,function(s,l){if(l==="dataIndex"||l==="dataIndexInside"){a[l]=s;return}var u=l.match(/^(\w+)(Index|Id|Name)$/)||[],f=u[1],h=(u[2]||"").toLowerCase();if(!(!f||!h||t&&t.includeMainTypes&&ft(t.includeMainTypes,f)<0)){o=o||!!f;var c=i.get(f)||i.set(f,{});c[h]=s}}),{mainTypeSpecified:o,queryOptionMap:i,others:a}}var $t={useDefault:!0,enableAll:!1,enableNone:!1},Nb={useDefault:!1,enableAll:!0,enableNone:!0};function Qa(e,t,r,n){n=n||$t;var i=r.index,a=r.id,o=r.name,s={models:null,specified:i!=null||a!=null||o!=null};if(!s.specified){var l=void 0;return s.models=n.useDefault&&(l=e.getComponent(t))?[l]:[],s}if(i==="none"||i===!1){if(n.enableNone)return s.models=[],s;i=-1}return i==="all"&&(n.enableAll?i=a=o=null:i=-1),s.models=e.queryComponents({mainType:t,index:i,id:a,name:o}),s}function Em(e,t,r){e.setAttribute?e.setAttribute(t,r):e[t]=r}function Fb(e,t){return e.getAttribute?e.getAttribute(t):e[t]}function zb(e){return e==="auto"?nt.domSupported?"html":"richText":e||"html"}function km(e,t,r,n,i){var a=t==null||t==="auto";if(n==null)return n;if(mt(n)){var o=gc(r||0,n,i);return Nt(o,a?Math.max(ar(r||0),ar(n)):t)}else{if(W(n))return i<1?r:n;for(var s=[],l=r,u=n,f=Math.max(l?l.length:0,u.length),h=0;h<f;++h){var c=e.getDimensionInfo(h);if(c&&c.type==="ordinal")s[h]=(i<1&&l?l:u)[h];else{var v=l&&l[h]?l[h]:0,d=u[h],o=gc(v,d,i);s[h]=Nt(o,a?Math.max(ar(v),ar(d)):t)}}return s}}var pt=gt(),Hb=function(e,t,r,n){if(n){var i=pt(n);i.dataIndex=r,i.dataType=t,i.seriesIndex=e,i.ssrType="chart",n.type==="group"&&n.traverse(function(a){var o=pt(a);o.seriesIndex=e,o.dataIndex=r,o.dataType=t,o.ssrType="chart"})}},_c=1,Sc={},Om=gt(),Dh=gt(),Ah=0,al=1,ol=2,xe=["emphasis","blur","select"],_s=["normal","emphasis","blur","select"],Vb=10,Gb=9,Ln="highlight",Ko="downplay",Ss="select",yf="unselect",bs="toggleSelect",Lh="selectchanged";function Yn(e){return e!=null&&e!=="none"}function sl(e,t,r){e.onHoverStateChange&&(e.hoverState||0)!==r&&e.onHoverStateChange(t),e.hoverState=r}function Bm(e){sl(e,"emphasis",ol)}function Nm(e){e.hoverState===ol&&sl(e,"normal",Ah)}function Ih(e){sl(e,"blur",al)}function Fm(e){e.hoverState===al&&sl(e,"normal",Ah)}function Wb(e){e.selected=!0}function Ub(e){e.selected=!1}function bc(e,t,r){t(e,r)}function cr(e,t,r){bc(e,t,r),e.isGroup&&e.traverse(function(n){bc(n,t,r)})}function wc(e,t){switch(t){case"emphasis":e.hoverState=ol;break;case"normal":e.hoverState=Ah;break;case"blur":e.hoverState=al;break;case"select":e.selected=!0}}function Yb(e,t,r,n){for(var i=e.style,a={},o=0;o<t.length;o++){var s=t[o],l=i[s];a[s]=l??(n&&n[s])}for(var o=0;o<e.animators.length;o++){var u=e.animators[o];u.__fromStateTransition&&u.__fromStateTransition.indexOf(r)<0&&u.targetName==="style"&&u.saveTo(a,t)}return a}function Zb(e,t,r,n){var i=r&&ft(r,"select")>=0,a=!1;if(e instanceof ht){var o=Om(e),s=i&&o.selectFill||o.normalFill,l=i&&o.selectStroke||o.normalStroke;if(Yn(s)||Yn(l)){n=n||{};var u=n.style||{};u.fill==="inherit"?(a=!0,n=k({},n),u=k({},u),u.fill=s):!Yn(u.fill)&&Yn(s)?(a=!0,n=k({},n),u=k({},u),u.fill=Kv(s)):!Yn(u.stroke)&&Yn(l)&&(a||(n=k({},n),u=k({},u)),u.stroke=Kv(l)),n.style=u}}if(n&&n.z2==null){a||(n=k({},n));var f=e.z2EmphasisLift;n.z2=e.z2+(f??Vb)}return n}function Xb(e,t,r){if(r&&r.z2==null){r=k({},r);var n=e.z2SelectLift;r.z2=e.z2+(n??Gb)}return r}function $b(e,t,r){var n=ft(e.currentStates,t)>=0,i=e.style.opacity,a=n?null:Yb(e,["opacity"],t,{opacity:1});r=r||{};var o=r.style||{};return o.opacity==null&&(r=k({},r),o=k({opacity:n?i:a.opacity*.1},o),r.style=o),r}function Ul(e,t){var r=this.states[e];if(this.style){if(e==="emphasis")return Zb(this,e,t,r);if(e==="blur")return $b(this,e,r);if(e==="select")return Xb(this,e,r)}return r}function qb(e){e.stateProxy=Ul;var t=e.getTextContent(),r=e.getTextGuideLine();t&&(t.stateProxy=Ul),r&&(r.stateProxy=Ul)}function xc(e,t){!Gm(e,t)&&!e.__highByOuter&&cr(e,Bm)}function Tc(e,t){!Gm(e,t)&&!e.__highByOuter&&cr(e,Nm)}function ws(e,t){e.__highByOuter|=1<<(t||0),cr(e,Bm)}function xs(e,t){!(e.__highByOuter&=~(1<<(t||0)))&&cr(e,Nm)}function Kb(e){cr(e,Ih)}function zm(e){cr(e,Fm)}function Hm(e){cr(e,Wb)}function Vm(e){cr(e,Ub)}function Gm(e,t){return e.__highDownSilentOnTouch&&t.zrByTouch}function Wm(e){var t=e.getModel(),r=[],n=[];t.eachComponent(function(i,a){var o=Dh(a),s=i==="series",l=s?e.getViewOfSeriesModel(a):e.getViewOfComponentModel(a);!s&&n.push(l),o.isBlured&&(l.group.traverse(function(u){Fm(u)}),s&&r.push(a)),o.isBlured=!1}),M(n,function(i){i&&i.toggleBlurSeries&&i.toggleBlurSeries(r,!1,t)})}function _f(e,t,r,n){var i=n.getModel();r=r||"coordinateSystem";function a(u,f){for(var h=0;h<f.length;h++){var c=u.getItemGraphicEl(f[h]);c&&zm(c)}}if(e!=null&&!(!t||t==="none")){var o=i.getSeriesByIndex(e),s=o.coordinateSystem;s&&s.master&&(s=s.master);var l=[];i.eachSeries(function(u){var f=o===u,h=u.coordinateSystem;h&&h.master&&(h=h.master);var c=h&&s?h===s:f;if(!(r==="series"&&!f||r==="coordinateSystem"&&!c||t==="series"&&f)){var v=n.getViewOfSeriesModel(u);if(v.group.traverse(function(g){g.__highByOuter&&f&&t==="self"||Ih(g)}),Kt(t))a(u.getData(),t);else if(X(t))for(var d=St(t),p=0;p<d.length;p++)a(u.getData(d[p]),t[d[p]]);l.push(u),Dh(u).isBlured=!0}}),i.eachComponent(function(u,f){if(u!=="series"){var h=n.getViewOfComponentModel(f);h&&h.toggleBlurSeries&&h.toggleBlurSeries(l,!0,i)}})}}function Sf(e,t,r){if(!(e==null||t==null)){var n=r.getModel().getComponent(e,t);if(n){Dh(n).isBlured=!0;var i=r.getViewOfComponentModel(n);!i||!i.focusBlurEnabled||i.group.traverse(function(a){Ih(a)})}}}function Qb(e,t,r){var n=e.seriesIndex,i=e.getData(t.dataType);if(i){var a=En(i,t);a=(z(a)?a[0]:a)||0;var o=i.getItemGraphicEl(a);if(!o)for(var s=i.count(),l=0;!o&&l<s;)o=i.getItemGraphicEl(l++);if(o){var u=pt(o);_f(n,u.focus,u.blurScope,r)}else{var f=e.get(["emphasis","focus"]),h=e.get(["emphasis","blurScope"]);f!=null&&_f(n,f,h,r)}}}function Ph(e,t,r,n){var i={focusSelf:!1,dispatchers:null};if(e==null||e==="series"||t==null||r==null)return i;var a=n.getModel().getComponent(e,t);if(!a)return i;var o=n.getViewOfComponentModel(a);if(!o||!o.findHighDownDispatchers)return i;for(var s=o.findHighDownDispatchers(r),l,u=0;u<s.length;u++)if(pt(s[u]).focus==="self"){l=!0;break}return{focusSelf:l,dispatchers:s}}function Jb(e,t,r){var n=pt(e),i=Ph(n.componentMainType,n.componentIndex,n.componentHighDownName,r),a=i.dispatchers,o=i.focusSelf;a?(o&&Sf(n.componentMainType,n.componentIndex,r),M(a,function(s){return xc(s,t)})):(_f(n.seriesIndex,n.focus,n.blurScope,r),n.focus==="self"&&Sf(n.componentMainType,n.componentIndex,r),xc(e,t))}function jb(e,t,r){Wm(r);var n=pt(e),i=Ph(n.componentMainType,n.componentIndex,n.componentHighDownName,r).dispatchers;i?M(i,function(a){return Tc(a,t)}):Tc(e,t)}function tw(e,t,r){if(xf(t)){var n=t.dataType,i=e.getData(n),a=En(i,t);z(a)||(a=[a]),e[t.type===bs?"toggleSelect":t.type===Ss?"select":"unselect"](a,n)}}function Cc(e){var t=e.getAllData();M(t,function(r){var n=r.data,i=r.type;n.eachItemGraphicEl(function(a,o){e.isSelected(o,i)?Hm(a):Vm(a)})})}function ew(e){var t=[];return e.eachSeries(function(r){var n=r.getAllData();M(n,function(i){i.data;var a=i.type,o=r.getSelectedDataIndices();if(o.length>0){var s={dataIndex:o,seriesIndex:r.seriesIndex};a!=null&&(s.dataType=a),t.push(s)}})}),t}function Um(e,t,r){Ym(e,!0),cr(e,qb),nw(e,t,r)}function rw(e){Ym(e,!1)}function bf(e,t,r,n){n?rw(e):Um(e,t,r)}function nw(e,t,r){var n=pt(e);t!=null?(n.focus=t,n.blurScope=r):n.focus&&(n.focus=null)}var Mc=["emphasis","blur","select"],iw={itemStyle:"getItemStyle",lineStyle:"getLineStyle",areaStyle:"getAreaStyle"};function Dc(e,t,r,n){r=r||"itemStyle";for(var i=0;i<Mc.length;i++){var a=Mc[i],o=t.getModel([a,r]),s=e.ensureState(a);s.style=o[iw[r]]()}}function Ym(e,t){var r=t===!1,n=e;e.highDownSilentOnTouch&&(n.__highDownSilentOnTouch=e.highDownSilentOnTouch),(!r||n.__highDownDispatcher)&&(n.__highByOuter=n.__highByOuter||0,n.__highDownDispatcher=!r)}function wf(e){return!!(e&&e.__highDownDispatcher)}function aw(e){var t=Sc[e];return t==null&&_c<=32&&(t=Sc[e]=_c++),t}function xf(e){var t=e.type;return t===Ss||t===yf||t===bs}function Ac(e){var t=e.type;return t===Ln||t===Ko}function ow(e){var t=Om(e);t.normalFill=e.style.fill,t.normalStroke=e.style.stroke;var r=e.states.select||{};t.selectFill=r.style&&r.style.fill||null,t.selectStroke=r.style&&r.style.stroke||null}var Zn=hr.CMD,sw=[[],[],[]],Lc=Math.sqrt,lw=Math.atan2;function Zm(e,t){if(t){var r=e.data,n=e.len(),i,a,o,s,l,u,f=Zn.M,h=Zn.C,c=Zn.L,v=Zn.R,d=Zn.A,p=Zn.Q;for(o=0,s=0;o<n;){switch(i=r[o++],s=o,a=0,i){case f:a=1;break;case c:a=1;break;case h:a=3;break;case p:a=2;break;case d:var g=t[4],m=t[5],y=Lc(t[0]*t[0]+t[1]*t[1]),_=Lc(t[2]*t[2]+t[3]*t[3]),S=lw(-t[1]/_,t[0]/y);r[o]*=y,r[o++]+=g,r[o]*=_,r[o++]+=m,r[o++]*=y,r[o++]*=_,r[o++]+=S,r[o++]+=S,o+=2,s=o;break;case v:u[0]=r[o++],u[1]=r[o++],we(u,u,t),r[s++]=u[0],r[s++]=u[1],u[0]+=r[o++],u[1]+=r[o++],we(u,u,t),r[s++]=u[0],r[s++]=u[1]}for(l=0;l<a;l++){var w=sw[l];w[0]=r[o++],w[1]=r[o++],we(w,w,t),r[s++]=w[0],r[s++]=w[1]}}e.increaseVersion()}}var Yl=Math.sqrt,mo=Math.sin,yo=Math.cos,Hi=Math.PI;function Ic(e){return Math.sqrt(e[0]*e[0]+e[1]*e[1])}function Tf(e,t){return(e[0]*t[0]+e[1]*t[1])/(Ic(e)*Ic(t))}function Pc(e,t){return(e[0]*t[1]<e[1]*t[0]?-1:1)*Math.acos(Tf(e,t))}function Rc(e,t,r,n,i,a,o,s,l,u,f){var h=l*(Hi/180),c=yo(h)*(e-r)/2+mo(h)*(t-n)/2,v=-1*mo(h)*(e-r)/2+yo(h)*(t-n)/2,d=c*c/(o*o)+v*v/(s*s);d>1&&(o*=Yl(d),s*=Yl(d));var p=(i===a?-1:1)*Yl((o*o*(s*s)-o*o*(v*v)-s*s*(c*c))/(o*o*(v*v)+s*s*(c*c)))||0,g=p*o*v/s,m=p*-s*c/o,y=(e+r)/2+yo(h)*g-mo(h)*m,_=(t+n)/2+mo(h)*g+yo(h)*m,S=Pc([1,0],[(c-g)/o,(v-m)/s]),w=[(c-g)/o,(v-m)/s],b=[(-1*c-g)/o,(-1*v-m)/s],x=Pc(w,b);if(Tf(w,b)<=-1&&(x=Hi),Tf(w,b)>=1&&(x=0),x<0){var C=Math.round(x/Hi*1e6)/1e6;x=Hi*2+C%2*Hi}f.addData(u,y,_,o,s,S,x,h,a)}var uw=/([mlvhzcqtsa])([^mlvhzcqtsa]*)/ig,fw=/-?([0-9]*\.)?[0-9]+([eE]-?[0-9]+)?/g;function hw(e){var t=new hr;if(!e)return t;var r=0,n=0,i=r,a=n,o,s=hr.CMD,l=e.match(uw);if(!l)return t;for(var u=0;u<l.length;u++){for(var f=l[u],h=f.charAt(0),c=void 0,v=f.match(fw)||[],d=v.length,p=0;p<d;p++)v[p]=parseFloat(v[p]);for(var g=0;g<d;){var m=void 0,y=void 0,_=void 0,S=void 0,w=void 0,b=void 0,x=void 0,C=r,T=n,D=void 0,A=void 0;switch(h){case"l":r+=v[g++],n+=v[g++],c=s.L,t.addData(c,r,n);break;case"L":r=v[g++],n=v[g++],c=s.L,t.addData(c,r,n);break;case"m":r+=v[g++],n+=v[g++],c=s.M,t.addData(c,r,n),i=r,a=n,h="l";break;case"M":r=v[g++],n=v[g++],c=s.M,t.addData(c,r,n),i=r,a=n,h="L";break;case"h":r+=v[g++],c=s.L,t.addData(c,r,n);break;case"H":r=v[g++],c=s.L,t.addData(c,r,n);break;case"v":n+=v[g++],c=s.L,t.addData(c,r,n);break;case"V":n=v[g++],c=s.L,t.addData(c,r,n);break;case"C":c=s.C,t.addData(c,v[g++],v[g++],v[g++],v[g++],v[g++],v[g++]),r=v[g-2],n=v[g-1];break;case"c":c=s.C,t.addData(c,v[g++]+r,v[g++]+n,v[g++]+r,v[g++]+n,v[g++]+r,v[g++]+n),r+=v[g-2],n+=v[g-1];break;case"S":m=r,y=n,D=t.len(),A=t.data,o===s.C&&(m+=r-A[D-4],y+=n-A[D-3]),c=s.C,C=v[g++],T=v[g++],r=v[g++],n=v[g++],t.addData(c,m,y,C,T,r,n);break;case"s":m=r,y=n,D=t.len(),A=t.data,o===s.C&&(m+=r-A[D-4],y+=n-A[D-3]),c=s.C,C=r+v[g++],T=n+v[g++],r+=v[g++],n+=v[g++],t.addData(c,m,y,C,T,r,n);break;case"Q":C=v[g++],T=v[g++],r=v[g++],n=v[g++],c=s.Q,t.addData(c,C,T,r,n);break;case"q":C=v[g++]+r,T=v[g++]+n,r+=v[g++],n+=v[g++],c=s.Q,t.addData(c,C,T,r,n);break;case"T":m=r,y=n,D=t.len(),A=t.data,o===s.Q&&(m+=r-A[D-4],y+=n-A[D-3]),r=v[g++],n=v[g++],c=s.Q,t.addData(c,m,y,r,n);break;case"t":m=r,y=n,D=t.len(),A=t.data,o===s.Q&&(m+=r-A[D-4],y+=n-A[D-3]),r+=v[g++],n+=v[g++],c=s.Q,t.addData(c,m,y,r,n);break;case"A":_=v[g++],S=v[g++],w=v[g++],b=v[g++],x=v[g++],C=r,T=n,r=v[g++],n=v[g++],c=s.A,Rc(C,T,r,n,b,x,_,S,w,c,t);break;case"a":_=v[g++],S=v[g++],w=v[g++],b=v[g++],x=v[g++],C=r,T=n,r+=v[g++],n+=v[g++],c=s.A,Rc(C,T,r,n,b,x,_,S,w,c,t);break}}(h==="z"||h==="Z")&&(c=s.Z,t.addData(c),r=i,n=a),o=c}return t.toStatic(),t}var Xm=(function(e){N(t,e);function t(){return e!==null&&e.apply(this,arguments)||this}return t.prototype.applyTransform=function(r){},t})(ht);function $m(e){return e.setData!=null}function qm(e,t){var r=hw(e),n=k({},t);return n.buildPath=function(i){var a=$m(i);if(a&&i.canSave()){i.appendPath(r);var o=i.getContext();o&&i.rebuildPath(o,1)}else{var o=a?i.getContext():i;o&&r.rebuildPath(o,1)}},n.applyTransform=function(i){Zm(r,i),this.dirtyShape()},n}function vw(e,t){return new Xm(qm(e,t))}function cw(e,t){var r=qm(e,t),n=(function(i){N(a,i);function a(o){var s=i.call(this,o)||this;return s.applyTransform=r.applyTransform,s.buildPath=r.buildPath,s}return a})(Xm);return n}function dw(e,t){for(var r=[],n=e.length,i=0;i<n;i++){var a=e[i];r.push(a.getUpdatedPathProxy(!0))}var o=new ht(t);return o.createPathProxy(),o.buildPath=function(s){if($m(s)){s.appendPath(r);var l=s.getContext();l&&s.rebuildPath(l,1)}},o}function Rh(e,t){t=t||{};var r=new ht;return e.shape&&r.setShape(e.shape),r.setStyle(e.style),t.bakeTransform?Zm(r.path,e.getComputedTransform()):t.toLocal?r.setLocalTransform(e.getComputedTransform()):r.copyTransform(e),r.buildPath=e.buildPath,r.applyTransform=r.applyTransform,r.z=e.z,r.z2=e.z2,r.zlevel=e.zlevel,r}var Ft=(function(e){N(t,e);function t(r){var n=e.call(this)||this;return n.isGroup=!0,n._children=[],n.attr(r),n}return t.prototype.childrenRef=function(){return this._children},t.prototype.children=function(){return this._children.slice()},t.prototype.childAt=function(r){return this._children[r]},t.prototype.childOfName=function(r){for(var n=this._children,i=0;i<n.length;i++)if(n[i].name===r)return n[i]},t.prototype.childCount=function(){return this._children.length},t.prototype.add=function(r){return r&&r!==this&&r.parent!==this&&(this._children.push(r),this._doAdd(r)),this},t.prototype.addBefore=function(r,n){if(r&&r!==this&&r.parent!==this&&n&&n.parent===this){var i=this._children,a=i.indexOf(n);a>=0&&(i.splice(a,0,r),this._doAdd(r))}return this},t.prototype.replace=function(r,n){var i=ft(this._children,r);return i>=0&&this.replaceAt(n,i),this},t.prototype.replaceAt=function(r,n){var i=this._children,a=i[n];if(r&&r!==this&&r.parent!==this&&r!==a){i[n]=r,a.parent=null;var o=this.__zr;o&&a.removeSelfFromZr(o),this._doAdd(r)}return this},t.prototype._doAdd=function(r){r.parent&&r.parent.remove(r),r.parent=this;var n=this.__zr;n&&n!==r.__zr&&r.addSelfToZr(n),n&&n.refresh()},t.prototype.remove=function(r){var n=this.__zr,i=this._children,a=ft(i,r);return a<0?this:(i.splice(a,1),r.parent=null,n&&r.removeSelfFromZr(n),n&&n.refresh(),this)},t.prototype.removeAll=function(){for(var r=this._children,n=this.__zr,i=0;i<r.length;i++){var a=r[i];n&&a.removeSelfFromZr(n),a.parent=null}return r.length=0,this},t.prototype.eachChild=function(r,n){for(var i=this._children,a=0;a<i.length;a++){var o=i[a];r.call(n,o,a)}return this},t.prototype.traverse=function(r,n){for(var i=0;i<this._children.length;i++){var a=this._children[i],o=r.call(n,a);a.isGroup&&!o&&a.traverse(r,n)}return this},t.prototype.addSelfToZr=function(r){e.prototype.addSelfToZr.call(this,r);for(var n=0;n<this._children.length;n++){var i=this._children[n];i.addSelfToZr(r)}},t.prototype.removeSelfFromZr=function(r){e.prototype.removeSelfFromZr.call(this,r);for(var n=0;n<this._children.length;n++){var i=this._children[n];i.removeSelfFromZr(r)}},t.prototype.getBoundingRect=function(r){for(var n=new it(0,0,0,0),i=r||this._children,a=[],o=null,s=0;s<i.length;s++){var l=i[s];if(!(l.ignore||l.invisible)){var u=l.getBoundingRect(),f=l.getLocalTransform(a);f?(it.applyTransform(n,u,f),o=o||n.clone(),o.union(n)):(o=o||u.clone(),o.union(u))}}return o||n},t})(nl);Ft.prototype.type="group";var pw=(function(){function e(){this.cx=0,this.cy=0,this.r=0}return e})(),ll=(function(e){N(t,e);function t(r){return e.call(this,r)||this}return t.prototype.getDefaultShape=function(){return new pw},t.prototype.buildPath=function(r,n){r.moveTo(n.cx+n.r,n.cy),r.arc(n.cx,n.cy,n.r,0,Math.PI*2)},t})(ht);ll.prototype.type="circle";var gw=(function(){function e(){this.cx=0,this.cy=0,this.rx=0,this.ry=0}return e})(),Eh=(function(e){N(t,e);function t(r){return e.call(this,r)||this}return t.prototype.getDefaultShape=function(){return new gw},t.prototype.buildPath=function(r,n){var i=.5522848,a=n.cx,o=n.cy,s=n.rx,l=n.ry,u=s*i,f=l*i;r.moveTo(a-s,o),r.bezierCurveTo(a-s,o-f,a-u,o-l,a,o-l),r.bezierCurveTo(a+u,o-l,a+s,o-f,a+s,o),r.bezierCurveTo(a+s,o+f,a+u,o+l,a,o+l),r.bezierCurveTo(a-u,o+l,a-s,o+f,a-s,o),r.closePath()},t})(ht);Eh.prototype.type="ellipse";var Km=Math.PI,Zl=Km*2,on=Math.sin,Xn=Math.cos,mw=Math.acos,Gt=Math.atan2,Ec=Math.abs,ba=Math.sqrt,ha=Math.max,ze=Math.min,De=1e-4;function yw(e,t,r,n,i,a,o,s){var l=r-e,u=n-t,f=o-i,h=s-a,c=h*l-f*u;if(!(c*c<De))return c=(f*(t-a)-h*(e-i))/c,[e+c*l,t+c*u]}function _o(e,t,r,n,i,a,o){var s=e-r,l=t-n,u=(o?a:-a)/ba(s*s+l*l),f=u*l,h=-u*s,c=e+f,v=t+h,d=r+f,p=n+h,g=(c+d)/2,m=(v+p)/2,y=d-c,_=p-v,S=y*y+_*_,w=i-a,b=c*p-d*v,x=(_<0?-1:1)*ba(ha(0,w*w*S-b*b)),C=(b*_-y*x)/S,T=(-b*y-_*x)/S,D=(b*_+y*x)/S,A=(-b*y+_*x)/S,P=C-g,L=T-m,I=D-g,R=A-m;return P*P+L*L>I*I+R*R&&(C=D,T=A),{cx:C,cy:T,x0:-f,y0:-h,x1:C*(i/w-1),y1:T*(i/w-1)}}function _w(e){var t;if(z(e)){var r=e.length;if(!r)return e;r===1?t=[e[0],e[0],0,0]:r===2?t=[e[0],e[0],e[1],e[1]]:r===3?t=e.concat(e[2]):t=e}else t=[e,e,e,e];return t}function Sw(e,t){var r,n=ha(t.r,0),i=ha(t.r0||0,0),a=n>0,o=i>0;if(!(!a&&!o)){if(a||(n=i,i=0),i>n){var s=n;n=i,i=s}var l=t.startAngle,u=t.endAngle;if(!(isNaN(l)||isNaN(u))){var f=t.cx,h=t.cy,c=!!t.clockwise,v=Ec(u-l),d=v>Zl&&v%Zl;if(d>De&&(v=d),!(n>De))e.moveTo(f,h);else if(v>Zl-De)e.moveTo(f+n*Xn(l),h+n*on(l)),e.arc(f,h,n,l,u,!c),i>De&&(e.moveTo(f+i*Xn(u),h+i*on(u)),e.arc(f,h,i,u,l,c));else{var p=void 0,g=void 0,m=void 0,y=void 0,_=void 0,S=void 0,w=void 0,b=void 0,x=void 0,C=void 0,T=void 0,D=void 0,A=void 0,P=void 0,L=void 0,I=void 0,R=n*Xn(l),E=n*on(l),G=i*Xn(u),F=i*on(u),H=v>De;if(H){var V=t.cornerRadius;V&&(r=_w(V),p=r[0],g=r[1],m=r[2],y=r[3]);var U=Ec(n-i)/2;if(_=ze(U,m),S=ze(U,y),w=ze(U,p),b=ze(U,g),T=x=ha(_,S),D=C=ha(w,b),(x>De||C>De)&&(A=n*Xn(u),P=n*on(u),L=i*Xn(l),I=i*on(l),v<Km)){var Z=yw(R,E,L,I,A,P,G,F);if(Z){var J=R-Z[0],ot=E-Z[1],yt=A-Z[0],Ht=P-Z[1],ce=1/on(mw((J*yt+ot*Ht)/(ba(J*J+ot*ot)*ba(yt*yt+Ht*Ht)))/2),de=ba(Z[0]*Z[0]+Z[1]*Z[1]);T=ze(x,(n-de)/(ce+1)),D=ze(C,(i-de)/(ce-1))}}}if(!H)e.moveTo(f+R,h+E);else if(T>De){var Vt=ze(m,T),Dt=ze(y,T),rt=_o(L,I,R,E,n,Vt,c),lt=_o(A,P,G,F,n,Dt,c);e.moveTo(f+rt.cx+rt.x0,h+rt.cy+rt.y0),T<x&&Vt===Dt?e.arc(f+rt.cx,h+rt.cy,T,Gt(rt.y0,rt.x0),Gt(lt.y0,lt.x0),!c):(Vt>0&&e.arc(f+rt.cx,h+rt.cy,Vt,Gt(rt.y0,rt.x0),Gt(rt.y1,rt.x1),!c),e.arc(f,h,n,Gt(rt.cy+rt.y1,rt.cx+rt.x1),Gt(lt.cy+lt.y1,lt.cx+lt.x1),!c),Dt>0&&e.arc(f+lt.cx,h+lt.cy,Dt,Gt(lt.y1,lt.x1),Gt(lt.y0,lt.x0),!c))}else e.moveTo(f+R,h+E),e.arc(f,h,n,l,u,!c);if(!(i>De)||!H)e.lineTo(f+G,h+F);else if(D>De){var Vt=ze(p,D),Dt=ze(g,D),rt=_o(G,F,A,P,i,-Dt,c),lt=_o(R,E,L,I,i,-Vt,c);e.lineTo(f+rt.cx+rt.x0,h+rt.cy+rt.y0),D<C&&Vt===Dt?e.arc(f+rt.cx,h+rt.cy,D,Gt(rt.y0,rt.x0),Gt(lt.y0,lt.x0),!c):(Dt>0&&e.arc(f+rt.cx,h+rt.cy,Dt,Gt(rt.y0,rt.x0),Gt(rt.y1,rt.x1),!c),e.arc(f,h,i,Gt(rt.cy+rt.y1,rt.cx+rt.x1),Gt(lt.cy+lt.y1,lt.cx+lt.x1),c),Vt>0&&e.arc(f+lt.cx,h+lt.cy,Vt,Gt(lt.y1,lt.x1),Gt(lt.y0,lt.x0),!c))}else e.lineTo(f+G,h+F),e.arc(f,h,i,u,l,c)}e.closePath()}}}var bw=(function(){function e(){this.cx=0,this.cy=0,this.r0=0,this.r=0,this.startAngle=0,this.endAngle=Math.PI*2,this.clockwise=!0,this.cornerRadius=0}return e})(),Ci=(function(e){N(t,e);function t(r){return e.call(this,r)||this}return t.prototype.getDefaultShape=function(){return new bw},t.prototype.buildPath=function(r,n){Sw(r,n)},t.prototype.isZeroArea=function(){return this.shape.startAngle===this.shape.endAngle||this.shape.r===this.shape.r0},t})(ht);Ci.prototype.type="sector";var ww=(function(){function e(){this.cx=0,this.cy=0,this.r=0,this.r0=0}return e})(),kh=(function(e){N(t,e);function t(r){return e.call(this,r)||this}return t.prototype.getDefaultShape=function(){return new ww},t.prototype.buildPath=function(r,n){var i=n.cx,a=n.cy,o=Math.PI*2;r.moveTo(i+n.r,a),r.arc(i,a,n.r,0,o,!1),r.moveTo(i+n.r0,a),r.arc(i,a,n.r0,0,o,!0)},t})(ht);kh.prototype.type="ring";function xw(e,t,r,n){var i=[],a=[],o=[],s=[],l,u,f,h;if(n){f=[1/0,1/0],h=[-1/0,-1/0];for(var c=0,v=e.length;c<v;c++)fi(f,f,e[c]),hi(h,h,e[c]);fi(f,f,n[0]),hi(h,h,n[1])}for(var c=0,v=e.length;c<v;c++){var d=e[c];if(r)l=e[c?c-1:v-1],u=e[(c+1)%v];else if(c===0||c===v-1){i.push(hS(e[c]));continue}else l=e[c-1],u=e[c+1];vS(a,u,l),xl(a,a,t);var p=ef(d,l),g=ef(d,u),m=p+g;m!==0&&(p/=m,g/=m),xl(o,a,-p),xl(s,a,g);var y=Vv([],d,o),_=Vv([],d,s);n&&(hi(y,y,f),fi(y,y,h),hi(_,_,f),fi(_,_,h)),i.push(y),i.push(_)}return r&&i.push(i.shift()),i}function Qm(e,t,r){var n=t.smooth,i=t.points;if(i&&i.length>=2){if(n){var a=xw(i,n,r,t.smoothConstraint);e.moveTo(i[0][0],i[0][1]);for(var o=i.length,s=0;s<(r?o:o-1);s++){var l=a[s*2],u=a[s*2+1],f=i[(s+1)%o];e.bezierCurveTo(l[0],l[1],u[0],u[1],f[0],f[1])}}else{e.moveTo(i[0][0],i[0][1]);for(var s=1,h=i.length;s<h;s++)e.lineTo(i[s][0],i[s][1])}r&&e.closePath()}}var Tw=(function(){function e(){this.points=null,this.smooth=0,this.smoothConstraint=null}return e})(),Ja=(function(e){N(t,e);function t(r){return e.call(this,r)||this}return t.prototype.getDefaultShape=function(){return new Tw},t.prototype.buildPath=function(r,n){Qm(r,n,!0)},t})(ht);Ja.prototype.type="polygon";var Cw=(function(){function e(){this.points=null,this.percent=1,this.smooth=0,this.smoothConstraint=null}return e})(),ja=(function(e){N(t,e);function t(r){return e.call(this,r)||this}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new Cw},t.prototype.buildPath=function(r,n){Qm(r,n,!1)},t})(ht);ja.prototype.type="polyline";var Mw={},Dw=(function(){function e(){this.x1=0,this.y1=0,this.x2=0,this.y2=0,this.percent=1}return e})(),Fr=(function(e){N(t,e);function t(r){return e.call(this,r)||this}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new Dw},t.prototype.buildPath=function(r,n){var i,a,o,s;if(this.subPixelOptimize){var l=bm(Mw,n,this.style);i=l.x1,a=l.y1,o=l.x2,s=l.y2}else i=n.x1,a=n.y1,o=n.x2,s=n.y2;var u=n.percent;u!==0&&(r.moveTo(i,a),u<1&&(o=i*(1-u)+o*u,s=a*(1-u)+s*u),r.lineTo(o,s))},t.prototype.pointAt=function(r){var n=this.shape;return[n.x1*(1-r)+n.x2*r,n.y1*(1-r)+n.y2*r]},t})(ht);Fr.prototype.type="line";var Qt=[],Aw=(function(){function e(){this.x1=0,this.y1=0,this.x2=0,this.y2=0,this.cpx1=0,this.cpy1=0,this.percent=1}return e})();function kc(e,t,r){var n=e.cpx2,i=e.cpy2;return n!=null||i!=null?[(r?Yv:Lt)(e.x1,e.cpx1,e.cpx2,e.x2,t),(r?Yv:Lt)(e.y1,e.cpy1,e.cpy2,e.y2,t)]:[(r?Zv:Wt)(e.x1,e.cpx1,e.x2,t),(r?Zv:Wt)(e.y1,e.cpy1,e.y2,t)]}var Oh=(function(e){N(t,e);function t(r){return e.call(this,r)||this}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new Aw},t.prototype.buildPath=function(r,n){var i=n.x1,a=n.y1,o=n.x2,s=n.y2,l=n.cpx1,u=n.cpy1,f=n.cpx2,h=n.cpy2,c=n.percent;c!==0&&(r.moveTo(i,a),f==null||h==null?(c<1&&(ds(i,l,o,c,Qt),l=Qt[1],o=Qt[2],ds(a,u,s,c,Qt),u=Qt[1],s=Qt[2]),r.quadraticCurveTo(l,u,o,s)):(c<1&&(Br(i,l,f,o,c,Qt),l=Qt[1],f=Qt[2],o=Qt[3],Br(a,u,h,s,c,Qt),u=Qt[1],h=Qt[2],s=Qt[3]),r.bezierCurveTo(l,u,f,h,o,s)))},t.prototype.pointAt=function(r){return kc(this.shape,r,!1)},t.prototype.tangentAt=function(r){var n=kc(this.shape,r,!0);return pS(n,n)},t})(ht);Oh.prototype.type="bezier-curve";var Lw=(function(){function e(){this.cx=0,this.cy=0,this.r=0,this.startAngle=0,this.endAngle=Math.PI*2,this.clockwise=!0}return e})(),ul=(function(e){N(t,e);function t(r){return e.call(this,r)||this}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new Lw},t.prototype.buildPath=function(r,n){var i=n.cx,a=n.cy,o=Math.max(n.r,0),s=n.startAngle,l=n.endAngle,u=n.clockwise,f=Math.cos(s),h=Math.sin(s);r.moveTo(f*o+i,h*o+a),r.arc(i,a,o,s,l,!u)},t})(ht);ul.prototype.type="arc";var Iw=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type="compound",r}return t.prototype._updatePathDirty=function(){for(var r=this.shape.paths,n=this.shapeChanged(),i=0;i<r.length;i++)n=n||r[i].shapeChanged();n&&this.dirtyShape()},t.prototype.beforeBrush=function(){this._updatePathDirty();for(var r=this.shape.paths||[],n=this.getGlobalScale(),i=0;i<r.length;i++)r[i].path||r[i].createPathProxy(),r[i].path.setScale(n[0],n[1],r[i].segmentIgnoreThreshold)},t.prototype.buildPath=function(r,n){for(var i=n.paths||[],a=0;a<i.length;a++)i[a].buildPath(r,i[a].shape,!0)},t.prototype.afterBrush=function(){for(var r=this.shape.paths||[],n=0;n<r.length;n++)r[n].pathUpdated()},t.prototype.getBoundingRect=function(){return this._updatePathDirty.call(this),ht.prototype.getBoundingRect.call(this)},t})(ht),Jm=(function(){function e(t){this.colorStops=t||[]}return e.prototype.addColorStop=function(t,r){this.colorStops.push({offset:t,color:r})},e})(),jm=(function(e){N(t,e);function t(r,n,i,a,o,s){var l=e.call(this,o)||this;return l.x=r??0,l.y=n??0,l.x2=i??1,l.y2=a??0,l.type="linear",l.global=s||!1,l}return t})(Jm),Pw=(function(e){N(t,e);function t(r,n,i,a,o){var s=e.call(this,a)||this;return s.x=r??.5,s.y=n??.5,s.r=i??.5,s.type="radial",s.global=o||!1,s}return t})(Jm),Xl=Math.min,Rw=Math.max,So=Math.abs,sn=[0,0],ln=[0,0],Rt=jg(),bo=Rt.minTv,wo=Rt.maxTv,ty=(function(){function e(t,r){this._corners=[],this._axes=[],this._origin=[0,0];for(var n=0;n<4;n++)this._corners[n]=new tt;for(var n=0;n<2;n++)this._axes[n]=new tt;t&&this.fromBoundingRect(t,r)}return e.prototype.fromBoundingRect=function(t,r){var n=this._corners,i=this._axes,a=t.x,o=t.y,s=a+t.width,l=o+t.height;if(n[0].set(a,o),n[1].set(s,o),n[2].set(s,l),n[3].set(a,l),r)for(var u=0;u<4;u++)n[u].transform(r);tt.sub(i[0],n[1],n[0]),tt.sub(i[1],n[3],n[0]),i[0].normalize(),i[1].normalize();for(var u=0;u<2;u++)this._origin[u]=i[u].dot(n[0])},e.prototype.intersect=function(t,r,n){var i=!0,a=!r;return r&&tt.set(r,0,0),Rt.reset(n,!a),!this._intersectCheckOneSide(this,t,a,1)&&(i=!1,a)||!this._intersectCheckOneSide(t,this,a,-1)&&(i=!1,a)||!a&&!Rt.negativeSize&&tt.copy(r,i?Rt.useDir?Rt.dirMinTv:bo:wo),i},e.prototype._intersectCheckOneSide=function(t,r,n,i){for(var a=!0,o=0;o<2;o++){var s=t._axes[o];if(t._getProjMinMaxOnAxis(o,t._corners,sn),t._getProjMinMaxOnAxis(o,r._corners,ln),Rt.negativeSize||sn[1]<ln[0]||sn[0]>ln[1]){if(a=!1,Rt.negativeSize||n)return a;var l=So(ln[0]-sn[1]),u=So(sn[0]-ln[1]);Xl(l,u)>wo.len()&&(l<u?tt.scale(wo,s,-l*i):tt.scale(wo,s,u*i))}else if(!n){var l=So(ln[0]-sn[1]),u=So(sn[0]-ln[1]);(Rt.useDir||Xl(l,u)<bo.len())&&((l<u||!Rt.bidirectional)&&(tt.scale(bo,s,l*i),Rt.useDir&&Rt.calcDirMTV()),(l>=u||!Rt.bidirectional)&&(tt.scale(bo,s,-u*i),Rt.useDir&&Rt.calcDirMTV()))}}return a},e.prototype._getProjMinMaxOnAxis=function(t,r,n){for(var i=this._axes[t],a=this._origin,o=r[0].dot(i)+a[t],s=o,l=o,u=1;u<r.length;u++){var f=r[u].dot(i)+a[t];s=Xl(f,s),l=Rw(f,l)}n[0]=s+Rt.touchThreshold,n[1]=l-Rt.touchThreshold,Rt.negativeSize=n[1]<n[0]},e})(),Ew=[],kw=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.notClear=!0,r.incremental=!0,r._displayables=[],r._temporaryDisplayables=[],r._cursor=0,r}return t.prototype.traverse=function(r,n){r.call(n,this)},t.prototype.useStyle=function(){this.style={}},t.prototype.getCursor=function(){return this._cursor},t.prototype.innerAfterBrush=function(){this._cursor=this._displayables.length},t.prototype.clearDisplaybles=function(){this._displayables=[],this._temporaryDisplayables=[],this._cursor=0,this.markRedraw(),this.notClear=!1},t.prototype.clearTemporalDisplayables=function(){this._temporaryDisplayables=[]},t.prototype.addDisplayable=function(r,n){n?this._temporaryDisplayables.push(r):this._displayables.push(r),this.markRedraw()},t.prototype.addDisplayables=function(r,n){n=n||!1;for(var i=0;i<r.length;i++)this.addDisplayable(r[i],n)},t.prototype.getDisplayables=function(){return this._displayables},t.prototype.getTemporalDisplayables=function(){return this._temporaryDisplayables},t.prototype.eachPendingDisplayable=function(r){for(var n=this._cursor;n<this._displayables.length;n++)r&&r(this._displayables[n]);for(var n=0;n<this._temporaryDisplayables.length;n++)r&&r(this._temporaryDisplayables[n])},t.prototype.update=function(){this.updateTransform();for(var r=this._cursor;r<this._displayables.length;r++){var n=this._displayables[r];n.parent=this,n.update(),n.parent=null}for(var r=0;r<this._temporaryDisplayables.length;r++){var n=this._temporaryDisplayables[r];n.parent=this,n.update(),n.parent=null}},t.prototype.getBoundingRect=function(){if(!this._rect){for(var r=new it(1/0,1/0,-1/0,-1/0),n=0;n<this._displayables.length;n++){var i=this._displayables[n],a=i.getBoundingRect().clone();i.needLocalTransform()&&a.applyTransform(i.getLocalTransform(Ew)),r.union(a)}this._rect=r}return this._rect},t.prototype.contain=function(r,n){var i=this.transformCoordToLocal(r,n),a=this.getBoundingRect();if(a.contain(i[0],i[1]))for(var o=0;o<this._displayables.length;o++){var s=this._displayables[o];if(s.contain(r,n))return!0}return!1},t})(Oi),ey=gt();function fl(e,t,r,n,i){var a;if(t&&t.ecModel){var o=t.ecModel.getUpdatePayload();a=o&&o.animation}var s=t&&t.isAnimationEnabled(),l=e==="update";if(s){var u=void 0,f=void 0,h=void 0;n?(u=q(n.duration,200),f=q(n.easing,"cubicOut"),h=0):(u=t.getShallow(l?"animationDurationUpdate":"animationDuration"),f=t.getShallow(l?"animationEasingUpdate":"animationEasing"),h=t.getShallow(l?"animationDelayUpdate":"animationDelay")),a&&(a.duration!=null&&(u=a.duration),a.easing!=null&&(f=a.easing),a.delay!=null&&(h=a.delay)),et(h)&&(h=h(r,i)),et(u)&&(u=u(r));var c={duration:u||0,delay:h,easing:f};return c}else return null}function Bh(e,t,r,n,i,a,o){var s=!1,l;et(i)?(o=a,a=i,i=null):X(i)&&(a=i.cb,o=i.during,s=i.isFrom,l=i.removeOpt,i=i.dataIndex);var u=e==="leave";u||t.stopAnimation("leave");var f=fl(e,n,i,u?l||{}:null,n&&n.getAnimationDelayParams?n.getAnimationDelayParams(t,i):null);if(f&&f.duration>0){var h=f.duration,c=f.delay,v=f.easing,d={duration:h,delay:c||0,easing:v,done:a,force:!!a||!!o,setToFinal:!u,scope:e,during:o};s?t.animateFrom(r,d):t.animateTo(r,d)}else t.stopAnimation(),!s&&t.attr(r),o&&o(1),a&&a()}function qe(e,t,r,n,i,a){Bh("update",e,t,r,n,i,a)}function vr(e,t,r,n,i,a){Bh("enter",e,t,r,n,i,a)}function bi(e){if(!e.__zr)return!0;for(var t=0;t<e.animators.length;t++){var r=e.animators[t];if(r.scope==="leave")return!0}return!1}function Ts(e,t,r,n,i,a){bi(e)||Bh("leave",e,t,r,n,i,a)}function Oc(e,t,r,n){e.removeTextContent(),e.removeTextGuideLine(),Ts(e,{style:{opacity:0}},t,r,n)}function Ow(e,t,r){function n(){e.parent&&e.parent.remove(e)}e.isGroup?e.traverse(function(i){i.isGroup||Oc(i,t,r,n)}):Oc(e,t,r,n)}function Bw(e){ey(e).oldStyle=e.style}function Nw(e){return ey(e).oldStyle}var Cf={},Mr=["x","y"],Mi=["width","height"];function Fw(e){return ht.extend(e)}var zw=cw;function Hw(e,t){return zw(e,t)}function ke(e,t){Cf[e]=t}function Vw(e){if(Cf.hasOwnProperty(e))return Cf[e]}function Nh(e,t,r,n){var i=vw(e,t);return r&&(n==="center"&&(r=ny(r,i.getBoundingRect())),iy(i,r)),i}function ry(e,t,r){var n=new Gr({style:{image:e,x:t.x,y:t.y,width:t.width,height:t.height},onload:function(i){if(r==="center"){var a={width:i.width,height:i.height};n.setStyle(ny(t,a))}}});return n}function ny(e,t){var r=t.width/t.height,n=e.height*r,i;n<=e.width?i=e.height:(n=e.width,i=n/r);var a=e.x+e.width/2,o=e.y+e.height/2;return{x:a-n/2,y:o-i/2,width:n,height:i}}var Gw=dw;function iy(e,t){if(e.applyTransform){var r=e.getBoundingRect(),n=r.calculateTransform(t);e.applyTransform(n)}}function ka(e,t){return bm(e,e,{lineWidth:t}),e}function Ww(e,t){return wm(e,e,t),e}var Uw=wn;function ay(e,t){for(var r=bh([]);e&&e!==t;)ma(r,e.getLocalTransform(),r),e=e.parent;return r}function Oa(e,t,r){return t&&!Kt(t)&&(t=qa.getLocalTransform(t)),r&&(t=Ei([],t)),we([],e,t)}function oy(e,t,r){var n=t[4]===0||t[5]===0||t[0]===0?1:Ue(2*t[4]/t[0]),i=t[4]===0||t[5]===0||t[2]===0?1:Ue(2*t[4]/t[2]),a=[e==="left"?-n:e==="right"?n:0,e==="top"?-i:e==="bottom"?i:0];return a=Oa(a,t,r),Ue(a[0])>Ue(a[1])?a[0]>0?"right":"left":a[1]>0?"bottom":"top"}function Bc(e){return!e.isGroup}function Yw(e){return e.shape!=null}function sy(e,t,r){if(!e||!t)return;function n(o){var s={};return o.traverse(function(l){Bc(l)&&l.anid&&(s[l.anid]=l)}),s}function i(o){var s={x:o.x,y:o.y,rotation:o.rotation};return Yw(o)&&(s.shape=st(o.shape)),s}var a=n(e);t.traverse(function(o){if(Bc(o)&&o.anid){var s=a[o.anid];if(s){var l=i(o);o.attr(i(s)),qe(o,l,r,pt(o).dataIndex)}}})}function Zw(e,t){return $(e,function(r){var n=r[0];n=fe(n,t.x),n=Ra(n,t.x+t.width);var i=r[1];return i=fe(i,t.y),i=Ra(i,t.y+t.height),[n,i]})}function Xw(e,t){var r=fe(e.x,t.x),n=Ra(e.x+e.width,t.x+t.width),i=fe(e.y,t.y),a=Ra(e.y+e.height,t.y+t.height);if(n>=r&&a>=i)return{x:r,y:i,width:n-r,height:a-i}}function ly(e,t,r){var n=k({rectHover:!0},t),i=n.style={strokeNoScale:!0};if(r=r||{x:-1,y:-1,width:2,height:2},e)return e.indexOf("image://")===0?(i.image=e.slice(8),at(i,r),new Gr(n)):Nh(e.replace("path://",""),n,r,"center")}function $w(e,t,r,n,i){for(var a=0,o=i[i.length-1];a<i.length;a++){var s=i[a];if(uy(e,t,r,n,s[0],s[1],o[0],o[1]))return!0;o=s}}function uy(e,t,r,n,i,a,o,s){var l=r-e,u=n-t,f=o-i,h=s-a,c=$l(f,h,l,u);if(qw(c))return!1;var v=e-i,d=t-a,p=$l(v,d,l,u)/c;if(p<0||p>1)return!1;var g=$l(v,d,f,h)/c;return!(g<0||g>1)}function $l(e,t,r,n){return e*n-r*t}function qw(e){return e<=1e-6&&e>=-1e-6}function Cs(e,t,r,n,i){return t==null||(mt(t)?_t[0]=_t[1]=_t[2]=_t[3]=t:(_t[0]=t[0],_t[1]=t[1],_t[2]=t[2],_t[3]=t[3]),n&&(_t[0]=fe(0,_t[0]),_t[1]=fe(0,_t[1]),_t[2]=fe(0,_t[2]),_t[3]=fe(0,_t[3])),r&&(_t[0]=-_t[0],_t[1]=-_t[1],_t[2]=-_t[2],_t[3]=-_t[3]),Nc(e,_t,"x","width",3,1,i&&i[0]||0),Nc(e,_t,"y","height",0,2,i&&i[1]||0)),e}var _t=[0,0,0,0];function Nc(e,t,r,n,i,a,o){var s=t[a]+t[i],l=e[n];e[n]+=s,o=fe(0,Ra(o,l)),e[n]<o?(e[n]=o,e[r]+=t[i]>=0?-t[i]:t[a]>=0?l+t[a]:Ue(s)>1e-8?(l-o)*t[i]/s:0):e[r]-=t[i]}function Fh(e){var t=e.itemTooltipOption,r=e.componentModel,n=e.itemName,i=W(t)?{formatter:t}:t,a=r.mainType,o=r.componentIndex,s={componentType:a,name:n,$vars:["name"]};s[a+"Index"]=o;var l=e.formatterParamsExtra;l&&M(St(l),function(f){he(s,f)||(s[f]=l[f],s.$vars.push(f))});var u=pt(e.el);u.componentMainType=a,u.componentIndex=o,u.tooltipConfig={name:n,option:at({content:n,encodeHTMLContent:!0,formatterParams:s},i)}}function Mf(e,t){var r;e.isGroup&&(r=t(e)),r||e.traverse(t)}function zh(e,t){if(e)if(z(e))for(var r=0;r<e.length;r++)Mf(e[r],t);else Mf(e,t)}function Hh(e){return!e||Ue(e[1])<xo&&Ue(e[2])<xo||Ue(e[0])<xo&&Ue(e[3])<xo}var xo=1e-5;function Ba(e,t){return e?it.copy(e,t):t.clone()}function Vh(e,t){return t?Jg(e||sr(),t):void 0}function Na(e){return{z:e.get("z")||0,zlevel:e.get("zlevel")||0}}function Kw(e){var t=-1/0,r=1/0;Mf(e,function(a){n(a),n(a.getTextContent()),n(a.getTextGuideLine())});function n(a){if(!(!a||a.isGroup)){var o=a.currentStates;if(o.length)for(var s=0;s<o.length;s++)i(a.states[o[s]]);i(a)}}function i(a){if(a){var o=a.z2;o>t&&(t=o),o<r&&(r=o)}}return r>t&&(r=t=0),{min:r,max:t}}function fy(e,t,r){hy(e,t,r,-1/0)}function hy(e,t,r,n){if(e.ignoreModelZ)return n;var i=e.getTextContent(),a=e.getTextGuideLine(),o=e.isGroup;if(o)for(var s=e.childrenRef(),l=0;l<s.length;l++)n=fe(hy(s[l],t,r,n),n);else e.z=t,e.zlevel=r,n=fe(e.z2||0,n);if(i&&(i.z=t,i.zlevel=r,isFinite(n)&&(i.z2=n+2)),a){var u=e.textGuideLineConfig;a.z=t,a.zlevel=r,isFinite(n)&&(a.z2=n+(u&&u.showAbove?1:-1))}return n}ke("circle",ll);ke("ellipse",Eh);ke("sector",Ci);ke("ring",kh);ke("polygon",Ja);ke("polyline",ja);ke("rect",Tt);ke("line",Fr);ke("bezierCurve",Oh);ke("arc",ul);const Qw=Object.freeze(Object.defineProperty({__proto__:null,Arc:ul,BezierCurve:Oh,BoundingRect:it,Circle:ll,CompoundPath:Iw,Ellipse:Eh,Group:Ft,Image:Gr,IncrementalDisplayable:kw,Line:Fr,LinearGradient:jm,OrientedBoundingRect:ty,Path:ht,Point:tt,Polygon:Ja,Polyline:ja,RadialGradient:Pw,Rect:Tt,Ring:kh,Sector:Ci,Text:ae,WH:Mi,XY:Mr,applyTransform:Oa,calcZ2Range:Kw,clipPointsByRect:Zw,clipRectByRect:Xw,createIcon:ly,ensureCopyRect:Ba,ensureCopyTransform:Vh,expandOrShrinkRect:Cs,extendPath:Hw,extendShape:Fw,getShapeClass:Vw,getTransform:ay,groupTransition:sy,initProps:vr,isBoundingRectAxisAligned:Hh,isElementRemoved:bi,lineLineIntersect:uy,linePolygonIntersect:$w,makeImage:ry,makePath:Nh,mergePath:Gw,registerShape:ke,removeElement:Ts,removeElementWithFadeOut:Ow,resizePath:iy,retrieveZInfo:Na,setTooltipConfig:Fh,subPixelOptimize:Uw,subPixelOptimizeLine:ka,subPixelOptimizeRect:Ww,transformDirection:oy,traverseElements:zh,traverseUpdateZ:fy,updateProps:qe},Symbol.toStringTag,{value:"Module"}));var hl={};function vy(e,t){for(var r=0;r<xe.length;r++){var n=xe[r],i=t[n],a=e.ensureState(n);a.style=a.style||{},a.style.text=i}var o=e.currentStates.slice();e.clearStates(!0),e.setStyle({text:t.normal}),e.useStates(o,!0)}function Df(e,t,r){var n=e.labelFetcher,i=e.labelDataIndex,a=e.labelDimIndex,o=t.normal,s;n&&(s=n.getFormattedLabel(i,"normal",null,a,o&&o.get("formatter"),r!=null?{interpolatedValue:r}:null)),s==null&&(s=et(e.defaultText)?e.defaultText(i,e,r):e.defaultText);for(var l={normal:s},u=0;u<xe.length;u++){var f=xe[u],h=t[f];l[f]=q(n?n.getFormattedLabel(i,f,null,a,h&&h.get("formatter")):null,s)}return l}function cy(e,t,r,n){r=r||hl;for(var i=e instanceof ae,a=!1,o=0;o<_s.length;o++){var s=t[_s[o]];if(s&&s.getShallow("show")){a=!0;break}}var l=i?e:e.getTextContent();if(a){i||(l||(l=new ae,e.setTextContent(l)),e.stateProxy&&(l.stateProxy=e.stateProxy));var u=Df(r,t),f=t.normal,h=!!f.getShallow("show"),c=zr(f,n&&n.normal,r,!1,!i);c.text=u.normal,i||e.setTextConfig(Fc(f,r,!1));for(var o=0;o<xe.length;o++){var v=xe[o],s=t[v];if(s){var d=l.ensureState(v),p=!!q(s.getShallow("show"),h);if(p!==h&&(d.ignore=!p),d.style=zr(s,n&&n[v],r,!0,!i),d.style.text=u[v],!i){var g=e.ensureState(v);g.textConfig=Fc(s,r,!0)}}}l.silent=!!f.getShallow("silent"),l.style.x!=null&&(c.x=l.style.x),l.style.y!=null&&(c.y=l.style.y),l.ignore=!h,l.useStyle(c),l.dirty(),r.enableTextSetter&&(vl(l).setLabelText=function(m){var y=Df(r,t,m);vy(l,y)})}else l&&(l.ignore=!0);e.dirty()}function Gh(e,t){t=t||"label";for(var r={normal:e.getModel(t)},n=0;n<xe.length;n++){var i=xe[n];r[i]=e.getModel([i,t])}return r}function zr(e,t,r,n,i){var a={};return Jw(a,e,r,n,i),t&&k(a,t),a}function Fc(e,t,r){t=t||{};var n={},i,a=e.getShallow("rotate"),o=q(e.getShallow("distance"),r?null:5),s=e.getShallow("offset");return i=e.getShallow("position")||(r?null:"inside"),i==="outside"&&(i=t.defaultOutsidePosition||"top"),i!=null&&(n.position=i),s!=null&&(n.offset=s),a!=null&&(a*=Math.PI/180,n.rotation=a),o!=null&&(n.distance=o),n.outsideFill=e.get("color")==="inherit"?t.inheritColor||null:"auto",t.autoOverflowArea!=null&&(n.autoOverflowArea=t.autoOverflowArea),t.layoutRect!=null&&(n.layoutRect=t.layoutRect),n}function Jw(e,t,r,n,i){r=r||hl;var a=t.ecModel,o=a&&a.option.textStyle,s=jw(t),l;if(s){l={};var u="richInheritPlainLabel",f=q(t.get(u),a?a.get(u):void 0);for(var h in s)if(s.hasOwnProperty(h)){var c=t.getModel(["rich",h]);Gc(l[h]={},c,o,t,f,r,n,i,!1,!0)}}l&&(e.rich=l);var v=t.get("overflow");v&&(e.overflow=v);var d=t.get("lineOverflow");d&&(e.lineOverflow=d);var p=e,g=t.get("minMargin");if(g!=null)g=mt(g)?g/2:0,p.margin=[g,g,g,g],p.__marginType=ci.minMargin;else{var m=t.get("textMargin");m!=null&&(p.margin=_h(m),p.__marginType=ci.textMargin)}Gc(e,t,o,null,null,r,n,i,!0,!1)}function jw(e){for(var t;e&&e!==e.ecModel;){var r=(e.option||hl).rich;if(r){t=t||{};for(var n=St(r),i=0;i<n.length;i++){var a=n[i];t[a]=1}}e=e.parentModel}return t}var zc=["fontStyle","fontWeight","fontSize","fontFamily","textShadowColor","textShadowBlur","textShadowOffsetX","textShadowOffsetY"],Hc=["align","lineHeight","width","height","tag","verticalAlign","ellipsis"],Vc=["padding","borderWidth","borderRadius","borderDashOffset","backgroundColor","borderColor","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"];function Gc(e,t,r,n,i,a,o,s,l,u){r=!o&&r||hl;var f=a&&a.inheritColor,h=t.getShallow("color"),c=t.getShallow("textBorderColor"),v=q(t.getShallow("opacity"),r.opacity);(h==="inherit"||h==="auto")&&(f?h=f:h=null),(c==="inherit"||c==="auto")&&(f?c=f:c=null),s||(h=h||r.color,c=c||r.textBorderColor),h!=null&&(e.fill=h),c!=null&&(e.stroke=c);var d=q(t.getShallow("textBorderWidth"),r.textBorderWidth);d!=null&&(e.lineWidth=d);var p=q(t.getShallow("textBorderType"),r.textBorderType);p!=null&&(e.lineDash=p);var g=q(t.getShallow("textBorderDashOffset"),r.textBorderDashOffset);g!=null&&(e.lineDashOffset=g),!o&&v==null&&!u&&(v=a&&a.defaultOpacity),v!=null&&(e.opacity=v),!o&&!s&&e.fill==null&&a.inheritColor&&(e.fill=a.inheritColor);for(var m=0;m<zc.length;m++){var y=zc[m],_=i!==!1&&n?yi(t.getShallow(y),n.getShallow(y),r[y]):q(t.getShallow(y),r[y]);_!=null&&(e[y]=_)}for(var m=0;m<Hc.length;m++){var y=Hc[m],_=t.getShallow(y);_!=null&&(e[y]=_)}if(e.verticalAlign==null){var S=t.getShallow("baseline");S!=null&&(e.verticalAlign=S)}if(!l||!a.disableBox){for(var m=0;m<Vc.length;m++){var y=Vc[m],_=t.getShallow(y);_!=null&&(e[y]=_)}var w=t.getShallow("borderType");w!=null&&(e.borderDash=w),(e.backgroundColor==="auto"||e.backgroundColor==="inherit")&&f&&(e.backgroundColor=f),(e.borderColor==="auto"||e.borderColor==="inherit")&&f&&(e.borderColor=f)}}function tx(e,t){var r=t&&t.getModel("textStyle");return Ge([e.fontStyle||r&&r.getShallow("fontStyle")||"",e.fontWeight||r&&r.getShallow("fontWeight")||"",(e.fontSize||r&&r.getShallow("fontSize")||12)+"px",e.fontFamily||r&&r.getShallow("fontFamily")||"sans-serif"].join(" "))}var vl=gt();function ex(e,t,r,n,i){var a=vl(e);if(!a.valueAnimation||a.prevValue===a.value)return;var o=a.defaultInterpolatedText,s=q(a.interpolatedValue,a.prevValue),l=a.value;function u(f){var h=km(r,a.precision,s,l,f);a.interpolatedValue=f===1?null:h;var c=Df({labelDataIndex:t,labelFetcher:i,defaultText:o?o(h):h+""},a.statesModels,h);vy(e,c)}e.percent=0,(a.prevValue==null?vr:qe)(e,{percent:1},n,t,null,u)}var ci={minMargin:1,textMargin:2},rx=["textStyle","color"],ql=["fontStyle","fontWeight","fontSize","fontFamily","padding","lineHeight","rich","width","height","overflow"],Kl=new ae,nx=(function(){function e(){}return e.prototype.getTextColor=function(t){var r=this.ecModel;return this.getShallow("color")||(!t&&r?r.get(rx):null)},e.prototype.getFont=function(){return tx({fontStyle:this.getShallow("fontStyle"),fontWeight:this.getShallow("fontWeight"),fontSize:this.getShallow("fontSize"),fontFamily:this.getShallow("fontFamily")},this.ecModel)},e.prototype.getTextRect=function(t){for(var r={text:t,verticalAlign:this.getShallow("verticalAlign")||this.getShallow("baseline")},n=0;n<ql.length;n++)r[ql[n]]=this.getShallow(ql[n]);return Kl.useStyle(r),Kl.update(),Kl.getBoundingRect()},e})(),dy=[["lineWidth","width"],["stroke","color"],["opacity"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["shadowColor"],["lineDash","type"],["lineDashOffset","dashOffset"],["lineCap","cap"],["lineJoin","join"],["miterLimit"]],ix=Ia(dy),ax=(function(){function e(){}return e.prototype.getLineStyle=function(t){return ix(this,t)},e})(),py=[["fill","color"],["stroke","borderColor"],["lineWidth","borderWidth"],["opacity"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["shadowColor"],["lineDash","borderType"],["lineDashOffset","borderDashOffset"],["lineCap","borderCap"],["lineJoin","borderJoin"],["miterLimit","borderMiterLimit"]],ox=Ia(py),sx=(function(){function e(){}return e.prototype.getItemStyle=function(t,r){return ox(this,t,r)},e})(),xt=(function(){function e(t,r,n){this.parentModel=r,this.ecModel=n,this.option=t}return e.prototype.init=function(t,r,n){},e.prototype.mergeOption=function(t,r){vt(this.option,t,!0)},e.prototype.get=function(t,r){return t==null?this.option:this._doGet(this.parsePath(t),!r&&this.parentModel)},e.prototype.getShallow=function(t,r){var n=this.option,i=n==null?n:n[t];if(i==null&&!r){var a=this.parentModel;a&&(i=a.getShallow(t))}return i},e.prototype.getModel=function(t,r){var n=t!=null,i=n?this.parsePath(t):null,a=n?this._doGet(i):this.option;return r=r||this.parentModel&&this.parentModel.getModel(this.resolveParentPath(i)),new e(a,r,this.ecModel)},e.prototype.isEmpty=function(){return this.option==null},e.prototype.restoreData=function(){},e.prototype.clone=function(){var t=this.constructor;return new t(st(this.option))},e.prototype.parsePath=function(t){return typeof t=="string"?t.split("."):t},e.prototype.resolveParentPath=function(t){return t},e.prototype.isAnimationEnabled=function(){if(!nt.node&&this.option){if(this.option.animation!=null)return!!this.option.animation;if(this.parentModel)return this.parentModel.isAnimationEnabled()}},e.prototype._doGet=function(t,r){var n=this.option;if(!t)return n;for(var i=0;i<t.length&&!(t[i]&&(n=n&&typeof n=="object"?n[t[i]]:null,n==null));i++);return n==null&&r&&(n=r._doGet(this.resolveParentPath(t),r.parentModel)),n},e})();Sh(xt);G1(xt);Ke(xt,ax);Ke(xt,sx);Ke(xt,X1);Ke(xt,nx);function Vi(e){return e==null?0:e.length||1}function Wc(e){return e}var Af=(function(){function e(t,r,n,i,a,o){this._old=t,this._new=r,this._oldKeyGetter=n||Wc,this._newKeyGetter=i||Wc,this.context=a,this._diffModeMultiple=o==="multiple"}return e.prototype.add=function(t){return this._add=t,this},e.prototype.update=function(t){return this._update=t,this},e.prototype.updateManyToOne=function(t){return this._updateManyToOne=t,this},e.prototype.updateOneToMany=function(t){return this._updateOneToMany=t,this},e.prototype.updateManyToMany=function(t){return this._updateManyToMany=t,this},e.prototype.remove=function(t){return this._remove=t,this},e.prototype.execute=function(){this[this._diffModeMultiple?"_executeMultiple":"_executeOneToOne"]()},e.prototype._executeOneToOne=function(){var t=this._old,r=this._new,n={},i=new Array(t.length),a=new Array(r.length);this._initIndexMap(t,null,i,"_oldKeyGetter"),this._initIndexMap(r,n,a,"_newKeyGetter");for(var o=0;o<t.length;o++){var s=i[o],l=n[s],u=Vi(l);if(u>1){var f=l.shift();l.length===1&&(n[s]=l[0]),this._update&&this._update(f,o)}else u===1?(n[s]=null,this._update&&this._update(l,o)):this._remove&&this._remove(o)}this._performRestAdd(a,n)},e.prototype._executeMultiple=function(){var t=this._old,r=this._new,n={},i={},a=[],o=[];this._initIndexMap(t,n,a,"_oldKeyGetter"),this._initIndexMap(r,i,o,"_newKeyGetter");for(var s=0;s<a.length;s++){var l=a[s],u=n[l],f=i[l],h=Vi(u),c=Vi(f);if(h>1&&c===1)this._updateManyToOne&&this._updateManyToOne(f,u),i[l]=null;else if(h===1&&c>1)this._updateOneToMany&&this._updateOneToMany(f,u),i[l]=null;else if(h===1&&c===1)this._update&&this._update(f,u),i[l]=null;else if(h>1&&c>1)this._updateManyToMany&&this._updateManyToMany(f,u),i[l]=null;else if(h>1)for(var v=0;v<h;v++)this._remove&&this._remove(u[v]);else this._remove&&this._remove(u)}this._performRestAdd(o,i)},e.prototype._performRestAdd=function(t,r){for(var n=0;n<t.length;n++){var i=t[n],a=r[i],o=Vi(a);if(o>1)for(var s=0;s<o;s++)this._add&&this._add(a[s]);else o===1&&this._add&&this._add(a);r[i]=null}},e.prototype._initIndexMap=function(t,r,n,i){for(var a=this._diffModeMultiple,o=0;o<t.length;o++){var s="_ec_"+this[i](t[o],o);if(a||(n[o]=s),!!r){var l=r[s],u=Vi(l);u===0?(r[s]=o,a&&n.push(s)):u===1?r[s]=[l,o]:l.push(o)}}},e})(),gy=K(["tooltip","label","itemName","itemId","itemGroupId","itemChildGroupId","seriesName"]),ve="original",zt="arrayRows",Ce="objectRows",Qe="keyedColumns",Er="typedArray",my="unknown",Pe="column",Fn="row",oe={Must:1,Might:2,Not:3},yy=gt();function lx(e){yy(e).datasetMap=K()}function ux(e,t,r){var n={},i=_y(t);if(!i||!e)return n;var a=[],o=[],s=t.ecModel,l=yy(s).datasetMap,u=i.uid+"_"+r.seriesLayoutBy,f,h;e=e.slice(),M(e,function(p,g){var m=X(p)?p:e[g]={name:p};m.type==="ordinal"&&f==null&&(f=g,h=d(m)),n[m.name]=[]});var c=l.get(u)||l.set(u,{categoryWayDim:h,valueWayDim:0});M(e,function(p,g){var m=p.name,y=d(p);if(f==null){var _=c.valueWayDim;v(n[m],_,y),v(o,_,y),c.valueWayDim+=y}else if(f===g)v(n[m],0,y),v(a,0,y);else{var _=c.categoryWayDim;v(n[m],_,y),v(o,_,y),c.categoryWayDim+=y}});function v(p,g,m){for(var y=0;y<m;y++)p.push(g+y)}function d(p){var g=p.dimsDef;return g?g.length:1}return a.length&&(n.itemName=a),o.length&&(n.seriesName=o),n}function _y(e){var t=e.get("data",!0);if(!t)return Qa(e.ecModel,"dataset",{index:e.get("datasetIndex",!0),id:e.get("datasetId",!0)},$t).models[0]}function fx(e){return!e.get("transform",!0)&&!e.get("fromTransformResult",!0)?[]:Qa(e.ecModel,"dataset",{index:e.get("fromDatasetIndex",!0),id:e.get("fromDatasetId",!0)},$t).models}function Sy(e,t){return hx(e.data,e.sourceFormat,e.seriesLayoutBy,e.dimensionsDefine,e.startIndex,t)}function hx(e,t,r,n,i,a){var o,s=5;if(ie(e))return oe.Not;var l,u;if(n){var f=n[a];X(f)?(l=f.name,u=f.type):W(f)&&(l=f)}if(u!=null)return u==="ordinal"?oe.Must:oe.Not;if(t===zt){var h=e;if(r===Fn){for(var c=h[a],v=0;v<(c||[]).length&&v<s;v++)if((o=S(c[i+v]))!=null)return o}else for(var v=0;v<h.length&&v<s;v++){var d=h[i+v];if(d&&(o=S(d[a]))!=null)return o}}else if(t===Ce){var p=e;if(!l)return oe.Not;for(var v=0;v<p.length&&v<s;v++){var g=p[v];if(g&&(o=S(g[l]))!=null)return o}}else if(t===Qe){var m=e;if(!l)return oe.Not;var c=m[l];if(!c||ie(c))return oe.Not;for(var v=0;v<c.length&&v<s;v++)if((o=S(c[v]))!=null)return o}else if(t===ve)for(var y=e,v=0;v<y.length&&v<s;v++){var g=y[v],_=Ka(g);if(!z(_))return oe.Not;if((o=S(_[a]))!=null)return o}function S(w){var b=W(w);if(w!=null&&Number.isFinite(Number(w))&&w!=="")return b?oe.Might:oe.Not;if(b&&w!=="-")return oe.Must}return oe.Not}var cl=(function(){function e(t){this.data=t.data||(t.sourceFormat===Qe?{}:[]),this.sourceFormat=t.sourceFormat||my,this.seriesLayoutBy=t.seriesLayoutBy||Pe,this.startIndex=t.startIndex||0,this.dimensionsDetectedCount=t.dimensionsDetectedCount,this.metaRawOption=t.metaRawOption;var r=this.dimensionsDefine=t.dimensionsDefine;if(r)for(var n=0;n<r.length;n++){var i=r[n];i.type==null&&Sy(this,n)===oe.Must&&(i.type="ordinal")}}return e})();function Wh(e){return e instanceof cl}function Lf(e,t,r){r=r||wy(e);var n=t.seriesLayoutBy,i=cx(e,r,n,t.sourceHeader,t.dimensions),a=new cl({data:e,sourceFormat:r,seriesLayoutBy:n,dimensionsDefine:i.dimensionsDefine,startIndex:i.startIndex,dimensionsDetectedCount:i.dimensionsDetectedCount,metaRawOption:st(t)});return a}function by(e){return new cl({data:e,sourceFormat:ie(e)?Er:ve})}function vx(e){return new cl({data:e.data,sourceFormat:e.sourceFormat,seriesLayoutBy:e.seriesLayoutBy,dimensionsDefine:st(e.dimensionsDefine),startIndex:e.startIndex,dimensionsDetectedCount:e.dimensionsDetectedCount})}function wy(e){var t=my;if(ie(e))t=Er;else if(z(e)){e.length===0&&(t=zt);for(var r=0,n=e.length;r<n;r++){var i=e[r];if(i!=null){if(z(i)||ie(i)){t=zt;break}else if(X(i)){t=Ce;break}}}}else if(X(e)){for(var a in e)if(he(e,a)&&Kt(e[a])){t=Qe;break}}return t}function cx(e,t,r,n,i){var a,o;if(!e)return{dimensionsDefine:Uc(i),startIndex:o,dimensionsDetectedCount:a};if(t===zt){var s=e;n==="auto"||n==null?Yc(function(u){u!=null&&u!=="-"&&(W(u)?o==null&&(o=1):o=0)},r,s,10):o=mt(n)?n:n?1:0,!i&&o===1&&(i=[],Yc(function(u,f){i[f]=u!=null?u+"":""},r,s,1/0)),a=i?i.length:r===Fn?s.length:s[0]?s[0].length:null}else if(t===Ce)i||(i=dx(e));else if(t===Qe)i||(i=[],M(e,function(u,f){i.push(f)}));else if(t===ve){var l=Ka(e[0]);a=z(l)&&l.length||1}return{startIndex:o,dimensionsDefine:Uc(i),dimensionsDetectedCount:a}}function dx(e){for(var t=0,r;t<e.length&&!(r=e[t++]););if(r)return St(r)}function Uc(e){if(e){var t=K();return $(e,function(r,n){r=X(r)?r:{name:r};var i={name:r.name,displayName:r.displayName,type:r.type};if(i.name==null)return i;i.name+="",i.displayName==null&&(i.displayName=i.name);var a=t.get(i.name);return a?i.name+="-"+a.count++:t.set(i.name,{count:1}),i})}}function Yc(e,t,r,n){if(t===Fn)for(var i=0;i<r.length&&i<n;i++)e(r[i]?r[i][0]:null,i);else for(var a=r[0]||[],i=0;i<a.length&&i<n;i++)e(a[i],i)}function xy(e){var t=e.sourceFormat;return t===Ce||t===Qe}var un,fn,hn,vn,Zc,Xc,Ty=(function(){function e(t,r){var n=Wh(t)?t:by(t);this._source=n;var i=this._data=n.data,a=n.sourceFormat;n.seriesLayoutBy,a===Er&&(this._offset=0,this._dimSize=r,this._data=i),Xc(this,i,n)}return e.prototype.getSource=function(){return this._source},e.prototype.count=function(){return 0},e.prototype.getItem=function(t,r){},e.prototype.appendData=function(t){},e.prototype.clean=function(){},e.protoInitialize=(function(){var t=e.prototype;t.pure=!1,t.persistent=!0})(),e.internalField=(function(){var t;Xc=function(o,s,l){var u=l.sourceFormat,f=l.seriesLayoutBy,h=l.startIndex,c=l.dimensionsDefine,v=Zc[Uh(u,f)];if(k(o,v),u===Er)o.getItem=r,o.count=i,o.fillStorage=n;else{var d=Cy(u,f);o.getItem=Q(d,null,s,h,c);var p=My(u,f);o.count=Q(p,null,s,h,c)}};var r=function(o,s){o=o-this._offset,s=s||[];for(var l=this._data,u=this._dimSize,f=u*o,h=0;h<u;h++)s[h]=l[f+h];return s},n=function(o,s,l,u){for(var f=this._data,h=this._dimSize,c=0;c<h;c++){for(var v=u[c],d=v[0]==null?1/0:v[0],p=v[1]==null?-1/0:v[1],g=s-o,m=l[c],y=0;y<g;y++){var _=f[y*h+c];m[o+y]=_,_<d&&(d=_),_>p&&(p=_)}v[0]=d,v[1]=p}},i=function(){return this._data?this._data.length/this._dimSize:0};Zc=(t={},t[zt+"_"+Pe]={pure:!0,appendData:a},t[zt+"_"+Fn]={pure:!0,appendData:function(){throw new Error('Do not support appendData when set seriesLayoutBy: "row".')}},t[Ce]={pure:!0,appendData:a},t[Qe]={pure:!0,appendData:function(o){var s=this._data;M(o,function(l,u){for(var f=s[u]||(s[u]=[]),h=0;h<(l||[]).length;h++)f.push(l[h])})}},t[ve]={appendData:a},t[Er]={persistent:!1,pure:!0,appendData:function(o){this._data=o},clean:function(){this._offset+=this.count(),this._data=null}},t);function a(o){for(var s=0;s<o.length;s++)this._data.push(o[s])}})(),e})(),To=function(e){z(e)||Lm("series.data or dataset.source must be an array.")};un={},un[zt+"_"+Pe]=To,un[zt+"_"+Fn]=To,un[Ce]=To,un[Qe]=function(e,t){for(var r=0;r<t.length;r++){var n=t[r].name;n==null&&Lm("dimension name must not be null/undefined.")}},un[ve]=To;var $c=function(e,t,r,n){return e[n]},px=(fn={},fn[zt+"_"+Pe]=function(e,t,r,n){return e[n+t]},fn[zt+"_"+Fn]=function(e,t,r,n,i){n+=t;for(var a=i||[],o=e,s=0;s<o.length;s++){var l=o[s];a[s]=l?l[n]:null}return a},fn[Ce]=$c,fn[Qe]=function(e,t,r,n,i){for(var a=i||[],o=0;o<r.length;o++){var s=r[o].name,l=s!=null?e[s]:null;a[o]=l?l[n]:null}return a},fn[ve]=$c,fn);function Cy(e,t){var r=px[Uh(e,t)];return r}var qc=function(e,t,r){return e.length},gx=(hn={},hn[zt+"_"+Pe]=function(e,t,r){return Math.max(0,e.length-t)},hn[zt+"_"+Fn]=function(e,t,r){var n=e[0];return n?Math.max(0,n.length-t):0},hn[Ce]=qc,hn[Qe]=function(e,t,r){var n=r[0].name,i=n!=null?e[n]:null;return i?i.length:0},hn[ve]=qc,hn);function My(e,t){var r=gx[Uh(e,t)];return r}var Ql=function(e,t,r){return e[t]},mx=(vn={},vn[zt]=Ql,vn[Ce]=function(e,t,r){return e[r]},vn[Qe]=Ql,vn[ve]=function(e,t,r){var n=Ka(e);return n instanceof Array?n[t]:n},vn[Er]=Ql,vn);function Dy(e){var t=mx[e];return t}function Uh(e,t){return e===zt?e+"_"+t:e}function Di(e,t,r){if(e){var n=e.getRawDataItem(t);if(n!=null){var i=e.getStore(),a=i.getSource().sourceFormat;if(r!=null){var o=e.getDimensionIndex(r),s=i.getDimensionProperty(o);return Dy(a)(n,o,s)}else{var l=n;return a===ve&&(l=Ka(n)),l}}}}var yx=(function(){function e(t,r){this._encode=t,this._schema=r}return e.prototype.get=function(){return{fullDimensions:this._getFullDimensionNames(),encode:this._encode}},e.prototype._getFullDimensionNames=function(){return this._cachedDimNames||(this._cachedDimNames=this._schema?this._schema.makeOutputDimensionNames():[]),this._cachedDimNames},e})();function _x(e,t){var r={},n=r.encode={},i=K(),a=[],o=[],s={};M(e.dimensions,function(c){var v=e.getDimensionInfo(c),d=v.coordDim;if(d){var p=v.coordDimIndex;Jl(n,d)[p]=c,v.isExtraCoord||(i.set(d,1),bx(v.type)&&(a[0]=c),Jl(s,d)[p]=e.getDimensionIndex(v.name)),v.defaultTooltip&&o.push(c)}gy.each(function(g,m){var y=Jl(n,m),_=v.otherDims[m];_!=null&&_!==!1&&(y[_]=v.name)})});var l=[],u={};i.each(function(c,v){var d=n[v];u[v]=d[0],l=l.concat(d)}),r.dataDimsOnCoord=l,r.dataDimIndicesOnCoord=$(l,function(c){return e.getDimensionInfo(c).storeDimIndex}),r.encodeFirstDimNotExtra=u;var f=n.label;f&&f.length&&(a=f.slice());var h=n.tooltip;return h&&h.length?o=h.slice():o.length||(o=a.slice()),n.defaultedLabel=a,n.defaultedTooltip=o,r.userOutput=new yx(s,t),r}function Jl(e,t){return e.hasOwnProperty(t)||(e[t]=[]),e[t]}function Sx(e){return e==="category"?"ordinal":e==="time"?"time":"float"}function bx(e){return!(e==="ordinal"||e==="time")}var Qo=(function(){function e(t){this.otherDims={},t!=null&&k(this,t)}return e})();function Jo(e,t){var r=t&&t.type;return r==="ordinal"?e:(r==="time"&&!mt(e)&&e!=null&&e!=="-"&&(e=+Bi(e)),e==null||e===""?NaN:Number(e))}var xx=K({number:function(e){return parseFloat(e)},time:function(e){return+Bi(e)},trim:function(e){return W(e)?Ge(e):e}});function Ay(e){return xx.get(e)}var Ly={lt:function(e,t){return e<t},lte:function(e,t){return e<=t},gt:function(e,t){return e>t},gte:function(e,t){return e>=t}},Tx=(function(){function e(t,r){if(!mt(r)){var n="";ut(n)}this._opFn=Ly[t],this._rvalFloat=Nr(r)}return e.prototype.evaluate=function(t){return mt(t)?this._opFn(t,this._rvalFloat):this._opFn(Nr(t),this._rvalFloat)},e})(),Iy=(function(){function e(t,r){var n=t==="desc";this._resultLT=n?1:-1,r==null&&(r=n?"min":"max"),this._incomparable=r==="min"?-1/0:1/0}return e.prototype.evaluate=function(t,r){var n=mt(t)?t:Nr(t),i=mt(r)?r:Nr(r),a=isNaN(n),o=isNaN(i);if(a&&(n=this._incomparable),o&&(i=this._incomparable),a&&o){var s=W(t),l=W(r);s&&(n=l?t:0),l&&(i=s?r:0)}return n<i?this._resultLT:n>i?-this._resultLT:0},e})(),Cx=(function(){function e(t,r){this._rval=r,this._isEQ=t,this._rvalTypeof=typeof r,this._rvalFloat=Nr(r)}return e.prototype.evaluate=function(t){var r=t===this._rval;if(!r){var n=typeof t;n!==this._rvalTypeof&&(n==="number"||this._rvalTypeof==="number")&&(r=Nr(t)===this._rvalFloat)}return this._isEQ?r:!r},e})();function Mx(e,t){return e==="eq"||e==="ne"?new Cx(e==="eq",t):he(Ly,e)?new Tx(e,t):null}var dl="undefined",Dx=typeof Uint32Array===dl?Array:Uint32Array,Ax=typeof Uint16Array===dl?Array:Uint16Array,Py=typeof Int32Array===dl?Array:Int32Array,Kc=typeof Float64Array===dl?Array:Float64Array,Ry={float:Kc,int:Py,ordinal:Array,number:Array,time:Kc},jl;function $n(e){return e>65535?Dx:Ax}function qn(){return[1/0,-1/0]}function Lx(e){var t=e.constructor;return t===Array?e.slice():new t(e)}function Qc(e,t,r,n,i){var a=Ry[r||"float"];if(i){var o=e[t],s=o&&o.length;if(s!==n){for(var l=new a(n),u=0;u<s;u++)l[u]=o[u];e[t]=l}}else e[t]=new a(n)}var If=(function(){function e(){this._chunks=[],this._rawExtent=[],this._extent=[],this._count=0,this._rawCount=0,this._calcDimNameToIdx=K()}return e.prototype.initData=function(t,r,n){this._provider=t,this._chunks=[],this._indices=null,this.getRawIndex=this._getRawIdxIdentity;var i=t.getSource(),a=this.defaultDimValueGetter=jl[i.sourceFormat];this._dimValueGetter=n||a,this._rawExtent=[],xy(i),this._dimensions=$(r,function(o){return{type:o.type,property:o.property}}),this._initDataFromProvider(0,t.count())},e.prototype.getProvider=function(){return this._provider},e.prototype.getSource=function(){return this._provider.getSource()},e.prototype.ensureCalculationDimension=function(t,r){var n=this._calcDimNameToIdx,i=this._dimensions,a=n.get(t);if(a!=null){if(i[a].type===r)return a}else a=i.length;return i[a]={type:r},n.set(t,a),this._chunks[a]=new Ry[r||"float"](this._rawCount),this._rawExtent[a]=qn(),a},e.prototype.collectOrdinalMeta=function(t,r){var n=this._chunks[t],i=this._dimensions[t],a=this._rawExtent,o=i.ordinalOffset||0,s=n.length;o===0&&(a[t]=qn());for(var l=a[t],u=o;u<s;u++){var f=n[u]=r.parseAndCollect(n[u]);isNaN(f)||(l[0]=Math.min(f,l[0]),l[1]=Math.max(f,l[1]))}i.ordinalMeta=r,i.ordinalOffset=s,i.type="ordinal"},e.prototype.getOrdinalMeta=function(t){var r=this._dimensions[t],n=r.ordinalMeta;return n},e.prototype.getDimensionProperty=function(t){var r=this._dimensions[t];return r&&r.property},e.prototype.appendData=function(t){var r=this._provider,n=this.count();r.appendData(t);var i=r.count();return r.persistent||(i+=n),n<i&&this._initDataFromProvider(n,i,!0),[n,i]},e.prototype.appendValues=function(t,r){for(var n=this._chunks,i=this._dimensions,a=i.length,o=this._rawExtent,s=this.count(),l=s+Math.max(t.length,r||0),u=0;u<a;u++){var f=i[u];Qc(n,u,f.type,l,!0)}for(var h=[],c=s;c<l;c++)for(var v=c-s,d=0;d<a;d++){var f=i[d],p=jl.arrayRows.call(this,t[v]||h,f.property,v,d);n[d][c]=p;var g=o[d];p<g[0]&&(g[0]=p),p>g[1]&&(g[1]=p)}return this._rawCount=this._count=l,{start:s,end:l}},e.prototype._initDataFromProvider=function(t,r,n){for(var i=this._provider,a=this._chunks,o=this._dimensions,s=o.length,l=this._rawExtent,u=$(o,function(y){return y.property}),f=0;f<s;f++){var h=o[f];l[f]||(l[f]=qn()),Qc(a,f,h.type,r,n)}if(i.fillStorage)i.fillStorage(t,r,a,l);else for(var c=[],v=t;v<r;v++){c=i.getItem(v,c);for(var d=0;d<s;d++){var p=a[d],g=this._dimValueGetter(c,u[d],v,d);p[v]=g;var m=l[d];g<m[0]&&(m[0]=g),g>m[1]&&(m[1]=g)}}!i.persistent&&i.clean&&i.clean(),this._rawCount=this._count=r,this._extent=[]},e.prototype.count=function(){return this._count},e.prototype.get=function(t,r){if(!(r>=0&&r<this._count))return NaN;var n=this._chunks[t];return n?n[this.getRawIndex(r)]:NaN},e.prototype.getValues=function(t,r){var n=[],i=[];if(r==null){r=t,t=[];for(var a=0;a<this._dimensions.length;a++)i.push(a)}else i=t;for(var a=0,o=i.length;a<o;a++)n.push(this.get(i[a],r));return n},e.prototype.getByRawIndex=function(t,r){if(!(r>=0&&r<this._rawCount))return NaN;var n=this._chunks[t];return n?n[r]:NaN},e.prototype.getSum=function(t){var r=this._chunks[t],n=0;if(r)for(var i=0,a=this.count();i<a;i++){var o=this.get(t,i);isNaN(o)||(n+=o)}return n},e.prototype.getMedian=function(t){var r=[];this.each([t],function(a){isNaN(a)||r.push(a)});var n=r.sort(function(a,o){return a-o}),i=this.count();return i===0?0:i%2===1?n[(i-1)/2]:(n[i/2]+n[i/2-1])/2},e.prototype.indexOfRawIndex=function(t){if(t>=this._rawCount||t<0)return-1;if(!this._indices)return t;var r=this._indices,n=r[t];if(n!=null&&n<this._count&&n===t)return t;for(var i=0,a=this._count-1;i<=a;){var o=(i+a)/2|0;if(r[o]<t)i=o+1;else if(r[o]>t)a=o-1;else return o}return-1},e.prototype.getIndices=function(){var t,r=this._indices;if(r){var n=r.constructor,i=this._count;if(n===Array){t=new n(i);for(var a=0;a<i;a++)t[a]=r[a]}else t=new n(r.buffer,0,i)}else{var n=$n(this._rawCount);t=new n(this.count());for(var a=0;a<t.length;a++)t[a]=a}return t},e.prototype.filter=function(t,r){if(!this._count)return this;for(var n=this.clone(),i=n.count(),a=$n(n._rawCount),o=new a(i),s=[],l=t.length,u=0,f=t[0],h=n._chunks,c=0;c<i;c++){var v=void 0,d=n.getRawIndex(c);if(l===0)v=r(c);else if(l===1){var p=h[f][d];v=r(p,c)}else{for(var g=0;g<l;g++)s[g]=h[t[g]][d];s[g]=c,v=r.apply(null,s)}v&&(o[u++]=d)}return u<i&&(n._indices=o),n._count=u,n._extent=[],n._updateGetRawIdx(),n},e.prototype.selectRange=function(t){var r=this.clone(),n=r._count;if(!n)return this;var i=St(t),a=i.length;if(!a)return this;var o=r.count(),s=$n(r._rawCount),l=new s(o),u=0,f=i[0],h=t[f][0],c=t[f][1],v=r._chunks,d=!1;if(!r._indices){var p=0;if(a===1){for(var g=v[i[0]],m=0;m<n;m++){var y=g[m];(y>=h&&y<=c||isNaN(y))&&(l[u++]=p),p++}d=!0}else if(a===2){for(var g=v[i[0]],_=v[i[1]],S=t[i[1]][0],w=t[i[1]][1],m=0;m<n;m++){var y=g[m],b=_[m];(y>=h&&y<=c||isNaN(y))&&(b>=S&&b<=w||isNaN(b))&&(l[u++]=p),p++}d=!0}}if(!d)if(a===1)for(var m=0;m<o;m++){var x=r.getRawIndex(m),y=v[i[0]][x];(y>=h&&y<=c||isNaN(y))&&(l[u++]=x)}else for(var m=0;m<o;m++){for(var C=!0,x=r.getRawIndex(m),T=0;T<a;T++){var D=i[T],y=v[D][x];(y<t[D][0]||y>t[D][1])&&(C=!1)}C&&(l[u++]=r.getRawIndex(m))}return u<o&&(r._indices=l),r._count=u,r._extent=[],r._updateGetRawIdx(),r},e.prototype.map=function(t,r){var n=this.clone(t);return this._updateDims(n,t,r),n},e.prototype.modify=function(t,r){this._updateDims(this,t,r)},e.prototype._updateDims=function(t,r,n){for(var i=t._chunks,a=[],o=r.length,s=t.count(),l=[],u=t._rawExtent,f=0;f<r.length;f++)u[r[f]]=qn();for(var h=0;h<s;h++){for(var c=t.getRawIndex(h),v=0;v<o;v++)l[v]=i[r[v]][c];l[o]=h;var d=n&&n.apply(null,l);if(d!=null){typeof d!="object"&&(a[0]=d,d=a);for(var f=0;f<d.length;f++){var p=r[f],g=d[f],m=u[p],y=i[p];y&&(y[c]=g),g<m[0]&&(m[0]=g),g>m[1]&&(m[1]=g)}}}},e.prototype.lttbDownSample=function(t,r){var n=this.clone([t],!0),i=n._chunks,a=i[t],o=this.count(),s=0,l=Math.floor(1/r),u=this.getRawIndex(0),f,h,c,v=new($n(this._rawCount))(Math.min((Math.ceil(o/l)+2)*2,o));v[s++]=u;for(var d=1;d<o-1;d+=l){for(var p=Math.min(d+l,o-1),g=Math.min(d+l*2,o),m=(g+p)/2,y=0,_=p;_<g;_++){var S=this.getRawIndex(_),w=a[S];isNaN(w)||(y+=w)}y/=g-p;var b=d,x=Math.min(d+l,o),C=d-1,T=a[u];f=-1,c=b;for(var D=-1,A=0,_=b;_<x;_++){var S=this.getRawIndex(_),w=a[S];if(isNaN(w)){A++,D<0&&(D=S);continue}h=Math.abs((C-m)*(w-T)-(C-_)*(y-T)),h>f&&(f=h,c=S)}A>0&&A<x-b&&(v[s++]=Math.min(D,c),c=Math.max(D,c)),v[s++]=c,u=c}return v[s++]=this.getRawIndex(o-1),n._count=s,n._indices=v,n.getRawIndex=this._getRawIdx,n},e.prototype.minmaxDownSample=function(t,r){for(var n=this.clone([t],!0),i=n._chunks,a=Math.floor(1/r),o=i[t],s=this.count(),l=new($n(this._rawCount))(Math.ceil(s/a)*2),u=0,f=0;f<s;f+=a){var h=f,c=o[this.getRawIndex(h)],v=f,d=o[this.getRawIndex(v)],p=a;f+a>s&&(p=s-f);for(var g=0;g<p;g++){var m=this.getRawIndex(f+g),y=o[m];y<c&&(c=y,h=f+g),y>d&&(d=y,v=f+g)}var _=this.getRawIndex(h),S=this.getRawIndex(v);h<v?(l[u++]=_,l[u++]=S):(l[u++]=S,l[u++]=_)}return n._count=u,n._indices=l,n._updateGetRawIdx(),n},e.prototype.downSample=function(t,r,n,i){for(var a=this.clone([t],!0),o=a._chunks,s=[],l=Math.floor(1/r),u=o[t],f=this.count(),h=a._rawExtent[t]=qn(),c=new($n(this._rawCount))(Math.ceil(f/l)),v=0,d=0;d<f;d+=l){l>f-d&&(l=f-d,s.length=l);for(var p=0;p<l;p++){var g=this.getRawIndex(d+p);s[p]=u[g]}var m=n(s),y=this.getRawIndex(Math.min(d+i(s,m)||0,f-1));u[y]=m,m<h[0]&&(h[0]=m),m>h[1]&&(h[1]=m),c[v++]=y}return a._count=v,a._indices=c,a._updateGetRawIdx(),a},e.prototype.each=function(t,r){if(this._count)for(var n=t.length,i=this._chunks,a=0,o=this.count();a<o;a++){var s=this.getRawIndex(a);switch(n){case 0:r(a);break;case 1:r(i[t[0]][s],a);break;case 2:r(i[t[0]][s],i[t[1]][s],a);break;default:for(var l=0,u=[];l<n;l++)u[l]=i[t[l]][s];u[l]=a,r.apply(null,u)}}},e.prototype.getDataExtent=function(t){var r=this._chunks[t],n=qn();if(!r)return n;var i=this.count(),a=!this._indices,o;if(a)return this._rawExtent[t].slice();if(o=this._extent[t],o)return o.slice();o=n;for(var s=o[0],l=o[1],u=0;u<i;u++){var f=this.getRawIndex(u),h=r[f];h<s&&(s=h),h>l&&(l=h)}return o=[s,l],this._extent[t]=o,o},e.prototype.getRawDataItem=function(t){var r=this.getRawIndex(t);if(this._provider.persistent)return this._provider.getItem(r);for(var n=[],i=this._chunks,a=0;a<i.length;a++)n.push(i[a][r]);return n},e.prototype.clone=function(t,r){var n=new e,i=this._chunks,a=t&&Ri(t,function(s,l){return s[l]=!0,s},{});if(a)for(var o=0;o<i.length;o++)n._chunks[o]=a[o]?Lx(i[o]):i[o];else n._chunks=i;return this._copyCommonProps(n),r||(n._indices=this._cloneIndices()),n._updateGetRawIdx(),n},e.prototype._copyCommonProps=function(t){t._count=this._count,t._rawCount=this._rawCount,t._provider=this._provider,t._dimensions=this._dimensions,t._extent=st(this._extent),t._rawExtent=st(this._rawExtent)},e.prototype._cloneIndices=function(){if(this._indices){var t=this._indices.constructor,r=void 0;if(t===Array){var n=this._indices.length;r=new t(n);for(var i=0;i<n;i++)r[i]=this._indices[i]}else r=new t(this._indices);return r}return null},e.prototype._getRawIdxIdentity=function(t){return t},e.prototype._getRawIdx=function(t){return t<this._count&&t>=0?this._indices[t]:-1},e.prototype._updateGetRawIdx=function(){this.getRawIndex=this._indices?this._getRawIdx:this._getRawIdxIdentity},e.internalField=(function(){function t(r,n,i,a){return Jo(r[a],this._dimensions[a])}jl={arrayRows:t,objectRows:function(r,n,i,a){return Jo(r[n],this._dimensions[a])},keyedColumns:t,original:function(r,n,i,a){var o=r&&(r.value==null?r:r.value);return Jo(o instanceof Array?o[a]:o,this._dimensions[a])},typedArray:function(r,n,i,a){return r[a]}}})(),e})(),Ix=gt(),Px={float:"f",int:"i",ordinal:"o",number:"n",time:"t"},Ey=(function(){function e(t){this.dimensions=t.dimensions,this._dimOmitted=t.dimensionOmitted,this.source=t.source,this._fullDimCount=t.fullDimensionCount,this._updateDimOmitted(t.dimensionOmitted)}return e.prototype.isDimensionOmitted=function(){return this._dimOmitted},e.prototype._updateDimOmitted=function(t){this._dimOmitted=t,t&&(this._dimNameMap||(this._dimNameMap=By(this.source)))},e.prototype.getSourceDimensionIndex=function(t){return q(this._dimNameMap.get(t),-1)},e.prototype.getSourceDimension=function(t){var r=this.source.dimensionsDefine;if(r)return r[t]},e.prototype.makeStoreSchema=function(){for(var t=this._fullDimCount,r=xy(this.source),n=!Ny(t),i="",a=[],o=0,s=0;o<t;o++){var l=void 0,u=void 0,f=void 0,h=this.dimensions[s];if(h&&h.storeDimIndex===o)l=r?h.name:null,u=h.type,f=h.ordinalMeta,s++;else{var c=this.getSourceDimension(o);c&&(l=r?c.name:null,u=c.type)}a.push({property:l,type:u,ordinalMeta:f}),r&&l!=null&&(!h||!h.isCalculationCoord)&&(i+=n?l.replace(/\`/g,"`1").replace(/\$/g,"`2"):l),i+="$",i+=Px[u]||"f",f&&(i+=f.uid),i+="$"}var v=this.source,d=[v.seriesLayoutBy,v.startIndex,i].join("$$");return{dimensions:a,hash:d}},e.prototype.makeOutputDimensionNames=function(){for(var t=[],r=0,n=0;r<this._fullDimCount;r++){var i=void 0,a=this.dimensions[n];if(a&&a.storeDimIndex===r)a.isCalculationCoord||(i=a.name),n++;else{var o=this.getSourceDimension(r);o&&(i=o.name)}t.push(i)}return t},e.prototype.appendCalculationDimension=function(t){this.dimensions.push(t),t.isCalculationCoord=!0,this._fullDimCount++,this._updateDimOmitted(!0)},e})();function ky(e){return e instanceof Ey}function Oy(e){for(var t=K(),r=0;r<(e||[]).length;r++){var n=e[r],i=X(n)?n.name:n;i!=null&&t.get(i)==null&&t.set(i,r)}return t}function By(e){var t=Ix(e);return t.dimNameMap||(t.dimNameMap=Oy(e.dimensionsDefine))}function Ny(e){return e>30}var Gi=X,gr=$,Rx=typeof Int32Array>"u"?Array:Int32Array,Ex="e\0\0",Jc=-1,kx=["hasItemOption","_nameList","_idList","_invertedIndicesMap","_dimSummary","userOutput","_rawData","_dimValueGetter","_nameDimIdx","_idDimIdx","_nameRepeatCount"],Ox=["_approximateExtent"],jc,Co,Wi,Ui,tu,Yi,eu,Bx=(function(){function e(t,r){this.type="list",this._dimOmitted=!1,this._nameList=[],this._idList=[],this._visual={},this._layout={},this._itemVisuals=[],this._itemLayouts=[],this._graphicEls=[],this._approximateExtent={},this._calculationInfo={},this.hasItemOption=!1,this.TRANSFERABLE_METHODS=["cloneShallow","downSample","minmaxDownSample","lttbDownSample","map"],this.CHANGABLE_METHODS=["filterSelf","selectRange"],this.DOWNSAMPLE_METHODS=["downSample","minmaxDownSample","lttbDownSample"];var n,i=!1;ky(t)?(n=t.dimensions,this._dimOmitted=t.isDimensionOmitted(),this._schema=t):(i=!0,n=t),n=n||["x","y"];for(var a={},o=[],s={},l=!1,u={},f=0;f<n.length;f++){var h=n[f],c=W(h)?new Qo({name:h}):h instanceof Qo?h:new Qo(h),v=c.name;c.type=c.type||"float",c.coordDim||(c.coordDim=v,c.coordDimIndex=0);var d=c.otherDims=c.otherDims||{};o.push(v),a[v]=c,u[v]!=null&&(l=!0),c.createInvertedIndices&&(s[v]=[]);var p=f;mt(c.storeDimIndex)&&(p=c.storeDimIndex),d.itemName===0&&(this._nameDimIdx=p),d.itemId===0&&(this._idDimIdx=p),i&&(c.storeDimIndex=f)}if(this.dimensions=o,this._dimInfos=a,this._initGetDimensionInfo(l),this.hostModel=r,this._invertedIndicesMap=s,this._dimOmitted){var g=this._dimIdxToName=K();M(o,function(m){g.set(a[m].storeDimIndex,m)})}}return e.prototype.getDimension=function(t){var r=this._recognizeDimIndex(t);if(r==null)return t;if(r=t,!this._dimOmitted)return this.dimensions[r];var n=this._dimIdxToName.get(r);if(n!=null)return n;var i=this._schema.getSourceDimension(r);if(i)return i.name},e.prototype.getDimensionIndex=function(t){var r=this._recognizeDimIndex(t);if(r!=null)return r;if(t==null)return-1;var n=this._getDimInfo(t);return n?n.storeDimIndex:this._dimOmitted?this._schema.getSourceDimensionIndex(t):-1},e.prototype._recognizeDimIndex=function(t){if(mt(t)||t!=null&&!isNaN(t)&&!this._getDimInfo(t)&&(!this._dimOmitted||this._schema.getSourceDimensionIndex(t)<0))return+t},e.prototype._getStoreDimIndex=function(t){var r=this.getDimensionIndex(t);return r},e.prototype.getDimensionInfo=function(t){return this._getDimInfo(this.getDimension(t))},e.prototype._initGetDimensionInfo=function(t){var r=this._dimInfos;this._getDimInfo=t?function(n){return r.hasOwnProperty(n)?r[n]:void 0}:function(n){return r[n]}},e.prototype.getDimensionsOnCoord=function(){return this._dimSummary.dataDimsOnCoord.slice()},e.prototype.mapDimension=function(t,r){var n=this._dimSummary;if(r==null)return n.encodeFirstDimNotExtra[t];var i=n.encode[t];return i?i[r]:null},e.prototype.mapDimensionsAll=function(t){var r=this._dimSummary,n=r.encode[t];return(n||[]).slice()},e.prototype.getStore=function(){return this._store},e.prototype.initData=function(t,r,n){var i=this,a;if(t instanceof If&&(a=t),!a){var o=this.dimensions,s=Wh(t)||Kt(t)?new Ty(t,o.length):t;a=new If;var l=gr(o,function(u){return{type:i._dimInfos[u].type,property:u}});a.initData(s,l,n)}this._store=a,this._nameList=(r||[]).slice(),this._idList=[],this._nameRepeatCount={},this._doInit(0,a.count()),this._dimSummary=_x(this,this._schema),this.userOutput=this._dimSummary.userOutput},e.prototype.appendData=function(t){var r=this._store.appendData(t);this._doInit(r[0],r[1])},e.prototype.appendValues=function(t,r){var n=this._store.appendValues(t,r&&r.length),i=n.start,a=n.end,o=this._shouldMakeIdFromName();if(this._updateOrdinalMeta(),r)for(var s=i;s<a;s++){var l=s-i;this._nameList[s]=r[l],o&&eu(this,s)}},e.prototype._updateOrdinalMeta=function(){for(var t=this._store,r=this.dimensions,n=0;n<r.length;n++){var i=this._dimInfos[r[n]];i.ordinalMeta&&t.collectOrdinalMeta(i.storeDimIndex,i.ordinalMeta)}},e.prototype._shouldMakeIdFromName=function(){var t=this._store.getProvider();return this._idDimIdx==null&&t.getSource().sourceFormat!==Er&&!t.fillStorage},e.prototype._doInit=function(t,r){if(!(t>=r)){var n=this._store,i=n.getProvider();this._updateOrdinalMeta();var a=this._nameList,o=this._idList,s=i.getSource().sourceFormat,l=s===ve;if(l&&!i.pure)for(var u=[],f=t;f<r;f++){var h=i.getItem(f,u);if(!this.hasItemOption&&Mb(h)&&(this.hasItemOption=!0),h){var c=h.name;a[f]==null&&c!=null&&(a[f]=Xe(c,null));var v=h.id;o[f]==null&&v!=null&&(o[f]=Xe(v,null))}}if(this._shouldMakeIdFromName())for(var f=t;f<r;f++)eu(this,f);jc(this)}},e.prototype.getApproximateExtent=function(t){return this._approximateExtent[t]||this._store.getDataExtent(this._getStoreDimIndex(t))},e.prototype.setApproximateExtent=function(t,r){r=this.getDimension(r),this._approximateExtent[r]=t.slice()},e.prototype.getCalculationInfo=function(t){return this._calculationInfo[t]},e.prototype.setCalculationInfo=function(t,r){Gi(t)?k(this._calculationInfo,t):this._calculationInfo[t]=r},e.prototype.getName=function(t){var r=this.getRawIndex(t),n=this._nameList[r];return n==null&&this._nameDimIdx!=null&&(n=Wi(this,this._nameDimIdx,r)),n==null&&(n=""),n},e.prototype._getCategory=function(t,r){var n=this._store.get(t,r),i=this._store.getOrdinalMeta(t);return i?i.categories[n]:n},e.prototype.getId=function(t){return Co(this,this.getRawIndex(t))},e.prototype.count=function(){return this._store.count()},e.prototype.get=function(t,r){var n=this._store,i=this._dimInfos[t];if(i)return n.get(i.storeDimIndex,r)},e.prototype.getByRawIndex=function(t,r){var n=this._store,i=this._dimInfos[t];if(i)return n.getByRawIndex(i.storeDimIndex,r)},e.prototype.getIndices=function(){return this._store.getIndices()},e.prototype.getDataExtent=function(t){return this._store.getDataExtent(this._getStoreDimIndex(t))},e.prototype.getSum=function(t){return this._store.getSum(this._getStoreDimIndex(t))},e.prototype.getMedian=function(t){return this._store.getMedian(this._getStoreDimIndex(t))},e.prototype.getValues=function(t,r){var n=this,i=this._store;return z(t)?i.getValues(gr(t,function(a){return n._getStoreDimIndex(a)}),r):i.getValues(t)},e.prototype.hasValue=function(t){for(var r=this._dimSummary.dataDimIndicesOnCoord,n=0,i=r.length;n<i;n++)if(isNaN(this._store.get(r[n],t)))return!1;return!0},e.prototype.indexOfName=function(t){for(var r=0,n=this._store.count();r<n;r++)if(this.getName(r)===t)return r;return-1},e.prototype.getRawIndex=function(t){return this._store.getRawIndex(t)},e.prototype.indexOfRawIndex=function(t){return this._store.indexOfRawIndex(t)},e.prototype.rawIndexOf=function(t,r){var n=t&&this._invertedIndicesMap[t],i=n&&n[r];return i==null||isNaN(i)?Jc:i},e.prototype.each=function(t,r,n){et(t)&&(n=r,r=t,t=[]);var i=n||this,a=gr(Ui(t),this._getStoreDimIndex,this);this._store.each(a,i?Q(r,i):r)},e.prototype.filterSelf=function(t,r,n){et(t)&&(n=r,r=t,t=[]);var i=n||this,a=gr(Ui(t),this._getStoreDimIndex,this);return this._store=this._store.filter(a,i?Q(r,i):r),this},e.prototype.selectRange=function(t){var r=this,n={},i=St(t);return M(i,function(a){var o=r._getStoreDimIndex(a);n[o]=t[a]}),this._store=this._store.selectRange(n),this},e.prototype.mapArray=function(t,r,n){et(t)&&(n=r,r=t,t=[]),n=n||this;var i=[];return this.each(t,function(){i.push(r&&r.apply(this,arguments))},n),i},e.prototype.map=function(t,r,n,i){var a=n||i||this,o=gr(Ui(t),this._getStoreDimIndex,this),s=Yi(this);return s._store=this._store.map(o,a?Q(r,a):r),s},e.prototype.modify=function(t,r,n,i){var a=n||i||this,o=gr(Ui(t),this._getStoreDimIndex,this);this._store.modify(o,a?Q(r,a):r)},e.prototype.downSample=function(t,r,n,i){var a=Yi(this);return a._store=this._store.downSample(this._getStoreDimIndex(t),r,n,i),a},e.prototype.minmaxDownSample=function(t,r){var n=Yi(this);return n._store=this._store.minmaxDownSample(this._getStoreDimIndex(t),r),n},e.prototype.lttbDownSample=function(t,r){var n=Yi(this);return n._store=this._store.lttbDownSample(this._getStoreDimIndex(t),r),n},e.prototype.getRawDataItem=function(t){return this._store.getRawDataItem(t)},e.prototype.getItemModel=function(t){var r=this.hostModel,n=this.getRawDataItem(t);return new xt(n,r,r&&r.ecModel)},e.prototype.diff=function(t){var r=this;return new Af(t?t.getStore().getIndices():[],this.getStore().getIndices(),function(n){return Co(t,n)},function(n){return Co(r,n)})},e.prototype.getVisual=function(t){var r=this._visual;return r&&r[t]},e.prototype.setVisual=function(t,r){this._visual=this._visual||{},Gi(t)?k(this._visual,t):this._visual[t]=r},e.prototype.getItemVisual=function(t,r){var n=this._itemVisuals[t],i=n&&n[r];return i??this.getVisual(r)},e.prototype.hasItemVisual=function(){return this._itemVisuals.length>0},e.prototype.ensureUniqueItemVisual=function(t,r){var n=this._itemVisuals,i=n[t];i||(i=n[t]={});var a=i[r];return a==null&&(a=this.getVisual(r),z(a)?a=a.slice():Gi(a)&&(a=k({},a)),i[r]=a),a},e.prototype.setItemVisual=function(t,r,n){var i=this._itemVisuals[t]||{};this._itemVisuals[t]=i,Gi(r)?k(i,r):i[r]=n},e.prototype.clearAllVisual=function(){this._visual={},this._itemVisuals=[]},e.prototype.setLayout=function(t,r){Gi(t)?k(this._layout,t):this._layout[t]=r},e.prototype.getLayout=function(t){return this._layout[t]},e.prototype.getItemLayout=function(t){return this._itemLayouts[t]},e.prototype.setItemLayout=function(t,r,n){this._itemLayouts[t]=n?k(this._itemLayouts[t]||{},r):r},e.prototype.clearItemLayouts=function(){this._itemLayouts.length=0},e.prototype.setItemGraphicEl=function(t,r){var n=this.hostModel&&this.hostModel.seriesIndex;Hb(n,this.dataType,t,r),this._graphicEls[t]=r},e.prototype.getItemGraphicEl=function(t){return this._graphicEls[t]},e.prototype.eachItemGraphicEl=function(t,r){M(this._graphicEls,function(n,i){n&&t&&t.call(r,n,i)})},e.prototype.cloneShallow=function(t){return t||(t=new e(this._schema?this._schema:gr(this.dimensions,this._getDimInfo,this),this.hostModel)),tu(t,this),t._store=this._store,t},e.prototype.wrapMethod=function(t,r){var n=this[t];et(n)&&(this.__wrappedMethods=this.__wrappedMethods||[],this.__wrappedMethods.push(t),this[t]=function(){var i=n.apply(this,arguments);return r.apply(this,[i].concat(yh(arguments)))})},e.internalField=(function(){jc=function(t){var r=t._invertedIndicesMap;M(r,function(n,i){var a=t._dimInfos[i],o=a.ordinalMeta,s=t._store;if(o){n=r[i]=new Rx(o.categories.length);for(var l=0;l<n.length;l++)n[l]=Jc;for(var l=0;l<s.count();l++)n[s.get(a.storeDimIndex,l)]=l}})},Wi=function(t,r,n){return Xe(t._getCategory(r,n),null)},Co=function(t,r){var n=t._idList[r];return n==null&&t._idDimIdx!=null&&(n=Wi(t,t._idDimIdx,r)),n==null&&(n=Ex+r),n},Ui=function(t){return z(t)||(t=t!=null?[t]:[]),t},Yi=function(t){var r=new e(t._schema?t._schema:gr(t.dimensions,t._getDimInfo,t),t.hostModel);return tu(r,t),r},tu=function(t,r){M(kx.concat(r.__wrappedMethods||[]),function(n){r.hasOwnProperty(n)&&(t[n]=r[n])}),t.__wrappedMethods=r.__wrappedMethods,M(Ox,function(n){t[n]=st(r[n])}),t._calculationInfo=k({},r._calculationInfo)},eu=function(t,r){var n=t._nameList,i=t._idList,a=t._nameDimIdx,o=t._idDimIdx,s=n[r],l=i[r];if(s==null&&a!=null&&(n[r]=s=Wi(t,a,r)),l==null&&o!=null&&(i[r]=l=Wi(t,o,r)),l==null&&s!=null){var u=t._nameRepeatCount,f=u[s]=(u[s]||0)+1;l=s,f>1&&(l+="__ec__"+f),i[r]=l}}})(),e})();function Nx(e,t){Wh(e)||(e=by(e)),t=t||{};var r=t.coordDimensions||[],n=t.dimensionsDefine||e.dimensionsDefine||[],i=K(),a=[],o=zx(e,r,n,t.dimensionsCount),s=t.canOmitUnusedDimensions&&Ny(o),l=n===e.dimensionsDefine,u=l?By(e):Oy(n),f=t.encodeDefine;!f&&t.encodeDefaulter&&(f=t.encodeDefaulter(e,o));for(var h=K(f),c=new Py(o),v=0;v<c.length;v++)c[v]=-1;function d(T){var D=c[T];if(D<0){var A=n[T],P=X(A)?A:{name:A},L=new Qo,I=P.name;I!=null&&u.get(I)!=null&&(L.name=L.displayName=I),P.type!=null&&(L.type=P.type),P.displayName!=null&&(L.displayName=P.displayName);var R=a.length;return c[T]=R,L.storeDimIndex=T,a.push(L),L}return a[D]}if(!s)for(var v=0;v<o;v++)d(v);h.each(function(T,D){var A=Mt(T).slice();if(A.length===1&&!W(A[0])&&A[0]<0){h.set(D,!1);return}var P=h.set(D,[]);M(A,function(L,I){var R=W(L)?u.get(L):L;R!=null&&R<o&&(P[I]=R,g(d(R),D,I))})});var p=0;M(r,function(T){var D,A,P,L;if(W(T))D=T,L={};else{L=T,D=L.name;var I=L.ordinalMeta;L.ordinalMeta=null,L=k({},L),L.ordinalMeta=I,A=L.dimsDef,P=L.otherDims,L.name=L.coordDim=L.coordDimIndex=L.dimsDef=L.otherDims=null}var R=h.get(D);if(R!==!1){if(R=Mt(R),!R.length)for(var E=0;E<(A&&A.length||1);E++){for(;p<o&&d(p).coordDim!=null;)p++;p<o&&R.push(p++)}M(R,function(G,F){var H=d(G);if(l&&L.type!=null&&(H.type=L.type),g(at(H,L),D,F),H.name==null&&A){var V=A[F];!X(V)&&(V={name:V}),H.name=H.displayName=V.name,H.defaultTooltip=V.defaultTooltip}P&&at(H.otherDims,P)})}});function g(T,D,A){gy.get(D)!=null?T.otherDims[D]=A:(T.coordDim=D,T.coordDimIndex=A,i.set(D,!0))}var m=t.generateCoord,y=t.generateCoordCount,_=y!=null;y=m?y||1:0;var S=m||"value";function w(T){T.name==null&&(T.name=T.coordDim)}if(s)M(a,function(T){w(T)}),a.sort(function(T,D){return T.storeDimIndex-D.storeDimIndex});else for(var b=0;b<o;b++){var x=d(b),C=x.coordDim;C==null&&(x.coordDim=Hx(S,i,_),x.coordDimIndex=0,(!m||y<=0)&&(x.isExtraCoord=!0),y--),w(x),x.type==null&&(Sy(e,b)===oe.Must||x.isExtraCoord&&(x.otherDims.itemName!=null||x.otherDims.seriesName!=null))&&(x.type="ordinal")}return Fx(a),new Ey({source:e,dimensions:a,fullDimensionCount:o,dimensionOmitted:s})}function Fx(e){for(var t=K(),r=0;r<e.length;r++){var n=e[r],i=n.name,a=t.get(i)||0;a>0&&(n.name=i+(a-1)),a++,t.set(i,a)}}function zx(e,t,r,n){var i=Math.max(e.dimensionsDetectedCount||1,t.length,r.length,n||0);return M(t,function(a){var o;X(a)&&(o=a.dimsDef)&&(i=Math.max(i,o.length))}),i}function Hx(e,t,r){if(r||t.hasKey(e)){for(var n=0;t.hasKey(e+n);)n++;e+=n}return t.set(e,!0),e}var jo={},ru={},Yh=(function(){function e(){this._normalMasterList=[],this._nonSeriesBoxMasterList=[]}return e.prototype.create=function(t,r){this._nonSeriesBoxMasterList=n(jo),this._normalMasterList=n(ru);function n(i,a){var o=[];return M(i,function(s,l){var u=s.create(t,r);o=o.concat(u||[])}),o}},e.prototype.update=function(t,r){M(this._normalMasterList,function(n){n.update&&n.update(t,r)})},e.prototype.getCoordinateSystems=function(){return this._normalMasterList.concat(this._nonSeriesBoxMasterList)},e.register=function(t,r){if(t==="matrix"||t==="calendar"){jo[t]=r;return}ru[t]=r},e.get=function(t){return ru[t]||jo[t]},e})();function Vx(e){return!!jo[e]}var td={coord:1,coord2:2},Gx=K();function Wx(e){var t=e.getShallow("coord",!0),r=td.coord;if(t==null){var n=Gx.get(e.type);n&&n.getCoord2&&(r=td.coord2,t=n.getCoord2(e))}return{coord:t,from:r}}var nr={none:0,dataCoordSys:1,boxCoordSys:2};function Ux(e,t){var r=e.getShallow("coordinateSystem"),n=e.getShallow("coordinateSystemUsage",!0),i=nr.none;if(r){var a=e.mainType==="series";n==null&&(n=a?"data":"box"),n==="data"?(i=nr.dataCoordSys,a||(i=nr.none)):n==="box"&&(i=nr.boxCoordSys,!a&&!Vx(r)&&(i=nr.none))}return{coordSysType:r,kind:i}}function Yx(e){var t=e.targetModel,r=e.coordSysType,n=e.coordSysProvider,i=e.isDefaultDataCoordSys,a=Ux(t),o=a.kind,s=a.coordSysType;if(i&&o!==nr.dataCoordSys&&(o=nr.dataCoordSys,s=r),o===nr.none||s!==r)return!1;var l=n(r,t);return l?(o===nr.dataCoordSys?t.coordinateSystem=l:t.boxCoordinateSystem=l,!0):!1}var Zx=(function(){function e(t){this.coordSysDims=[],this.axisMap=K(),this.categoryAxisMap=K(),this.coordSysName=t}return e})();function Xx(e){var t=e.get("coordinateSystem"),r=new Zx(t),n=$x[t];if(n)return n(e,r,r.axisMap,r.categoryAxisMap),r}var $x={cartesian2d:function(e,t,r,n){var i=e.getReferringComponents("xAxis",$t).models[0],a=e.getReferringComponents("yAxis",$t).models[0];t.coordSysDims=["x","y"],r.set("x",i),r.set("y",a),Kn(i)&&(n.set("x",i),t.firstCategoryDimIndex=0),Kn(a)&&(n.set("y",a),t.firstCategoryDimIndex==null&&(t.firstCategoryDimIndex=1))},singleAxis:function(e,t,r,n){var i=e.getReferringComponents("singleAxis",$t).models[0];t.coordSysDims=["single"],r.set("single",i),Kn(i)&&(n.set("single",i),t.firstCategoryDimIndex=0)},polar:function(e,t,r,n){var i=e.getReferringComponents("polar",$t).models[0],a=i.findAxisModel("radiusAxis"),o=i.findAxisModel("angleAxis");t.coordSysDims=["radius","angle"],r.set("radius",a),r.set("angle",o),Kn(a)&&(n.set("radius",a),t.firstCategoryDimIndex=0),Kn(o)&&(n.set("angle",o),t.firstCategoryDimIndex==null&&(t.firstCategoryDimIndex=1))},geo:function(e,t,r,n){t.coordSysDims=["lng","lat"]},parallel:function(e,t,r,n){var i=e.ecModel,a=i.getComponent("parallel",e.get("parallelIndex")),o=t.coordSysDims=a.dimensions.slice();M(a.parallelAxisIndex,function(s,l){var u=i.getComponent("parallelAxis",s),f=o[l];r.set(f,u),Kn(u)&&(n.set(f,u),t.firstCategoryDimIndex==null&&(t.firstCategoryDimIndex=l))})},matrix:function(e,t,r,n){var i=e.getReferringComponents("matrix",$t).models[0];t.coordSysDims=["x","y"];var a=i.getDimensionModel("x"),o=i.getDimensionModel("y");r.set("x",a),r.set("y",o),n.set("x",a),n.set("y",o)}};function Kn(e){return e.get("type")==="category"}function qx(e,t,r){r=r||{};var n=r.byIndex,i=r.stackedCoordDimension,a,o,s;Kx(t)?a=t:(o=t.schema,a=o.dimensions,s=t.store);var l=!!(e&&e.get("stack")),u,f,h,c;if(M(a,function(y,_){W(y)&&(a[_]=y={name:y}),l&&!y.isExtraCoord&&(!n&&!u&&y.ordinalMeta&&(u=y),!f&&y.type!=="ordinal"&&y.type!=="time"&&(!i||i===y.coordDim)&&(f=y))}),f&&!n&&!u&&(n=!0),f){h="__\0ecstackresult_"+e.id,c="__\0ecstackedover_"+e.id,u&&(u.createInvertedIndices=!0);var v=f.coordDim,d=f.type,p=0;M(a,function(y){y.coordDim===v&&p++});var g={name:h,coordDim:v,coordDimIndex:p,type:d,isExtraCoord:!0,isCalculationCoord:!0,storeDimIndex:a.length},m={name:c,coordDim:c,coordDimIndex:p+1,type:d,isExtraCoord:!0,isCalculationCoord:!0,storeDimIndex:a.length+1};o?(s&&(g.storeDimIndex=s.ensureCalculationDimension(c,d),m.storeDimIndex=s.ensureCalculationDimension(h,d)),o.appendCalculationDimension(g),o.appendCalculationDimension(m)):(a.push(g),a.push(m))}return{stackedDimension:f&&f.name,stackedByDimension:u&&u.name,isStackedByIndex:n,stackedOverDimension:c,stackResultDimension:h}}function Kx(e){return!ky(e.schema)}function Fa(e,t){return!!t&&t===e.getCalculationInfo("stackedDimension")}function Qx(e,t){return Fa(e,t)?e.getCalculationInfo("stackResultDimension"):t}function Jx(e,t){var r=e.get("coordinateSystem"),n=Yh.get(r),i;return t&&t.coordSysDims&&(i=$(t.coordSysDims,function(a){var o={name:a},s=t.axisMap.get(a);if(s){var l=s.get("type");o.type=Sx(l)}return o})),i||(i=n&&(n.getDimensionsInfo?n.getDimensionsInfo():n.dimensions.slice())||["x","y"]),i}function jx(e,t,r){var n,i;return r&&M(e,function(a,o){var s=a.coordDim,l=r.categoryAxisMap.get(s);l&&(n==null&&(n=o),a.ordinalMeta=l.getOrdinalMeta(),t&&(a.createInvertedIndices=!0)),a.otherDims.itemName!=null&&(i=!0)}),!i&&n!=null&&(e[n].otherDims.itemName=0),n}function tT(e,t,r){r=r||{};var n=t.getSourceManager(),i,a=!1;i=n.getSource(),a=i.sourceFormat===ve;var o=Xx(t),s=Jx(t,o),l=r.useEncodeDefaulter,u=et(l)?l:l?ne(ux,s,t):null,f={coordDimensions:s,generateCoord:r.generateCoord,encodeDefine:t.getEncode(),encodeDefaulter:u,canOmitUnusedDimensions:!a},h=Nx(i,f),c=jx(h.dimensions,r.createInvertedIndices,o),v=a?null:n.getSharedDataStore(h),d=qx(t,{schema:h,store:v}),p=new Bx(h,t);p.setCalculationInfo(d);var g=c!=null&&eT(i)?function(m,y,_,S){return S===c?_:this.defaultDimValueGetter(m,y,_,S)}:null;return p.hasItemOption=!1,p.initData(a?i:v,null,g),p}function eT(e){if(e.sourceFormat===ve){var t=rT(e.data||[]);return!z(Ka(t))}}function rT(e){for(var t=0;t<e.length&&e[t]==null;)t++;return e[t]}var nT=Math.round(Math.random()*10);function pl(e){return[e||"",nT++].join("_")}function iT(e){var t={};e.registerSubTypeDefaulter=function(r,n){var i=We(r);t[i.main]=n},e.determineSubType=function(r,n){var i=n.type;if(!i){var a=We(r).main;e.hasSubTypes(r)&&t[a]&&(i=t[a](n))}return i}}function aT(e,t){e.topologicalTravel=function(a,o,s,l){if(!a.length)return;var u=r(o),f=u.graph,h=u.noEntryList,c={};for(M(a,function(y){c[y]=!0});h.length;){var v=h.pop(),d=f[v],p=!!c[v];p&&(s.call(l,v,d.originalDeps.slice()),delete c[v]),M(d.successor,p?m:g)}M(c,function(){var y="";throw new Error(y)});function g(y){f[y].entryCount--,f[y].entryCount===0&&h.push(y)}function m(y){c[y]=!0,g(y)}};function r(a){var o={},s=[];return M(a,function(l){var u=n(o,l),f=u.originalDeps=t(l),h=i(f,a);u.entryCount=h.length,u.entryCount===0&&s.push(l),M(h,function(c){ft(u.predecessor,c)<0&&u.predecessor.push(c);var v=n(o,c);ft(v.successor,c)<0&&v.successor.push(l)})}),{graph:o,noEntryList:s}}function n(a,o){return a[o]||(a[o]={predecessor:[],successor:[]}),a[o]}function i(a,o){var s=[];return M(a,function(l){ft(o,l)>=0&&s.push(l)}),s}}function Fy(e,t){return vt(vt({},e,!0),t,!0)}var oT=Math.log(2);function Pf(e,t,r,n,i,a){var o=n+"-"+i,s=e.length;if(a.hasOwnProperty(o))return a[o];if(t===1){var l=Math.round(Math.log((1<<s)-1&~i)/oT);return e[r][l]}for(var u=n|1<<r,f=r+1;n&1<<f;)f++;for(var h=0,c=0,v=0;c<s;c++){var d=1<<c;d&i||(h+=(v%2?-1:1)*e[r][c]*Pf(e,t-1,f,u,i|d,a),v++)}return a[o]=h,h}function ed(e,t){var r=[[e[0],e[1],1,0,0,0,-t[0]*e[0],-t[0]*e[1]],[0,0,0,e[0],e[1],1,-t[1]*e[0],-t[1]*e[1]],[e[2],e[3],1,0,0,0,-t[2]*e[2],-t[2]*e[3]],[0,0,0,e[2],e[3],1,-t[3]*e[2],-t[3]*e[3]],[e[4],e[5],1,0,0,0,-t[4]*e[4],-t[4]*e[5]],[0,0,0,e[4],e[5],1,-t[5]*e[4],-t[5]*e[5]],[e[6],e[7],1,0,0,0,-t[6]*e[6],-t[6]*e[7]],[0,0,0,e[6],e[7],1,-t[7]*e[6],-t[7]*e[7]]],n={},i=Pf(r,8,0,0,0,n);if(i!==0){for(var a=[],o=0;o<8;o++)for(var s=0;s<8;s++)a[s]==null&&(a[s]=0),a[s]+=((o+s)%2?-1:1)*Pf(r,7,o===0?1:0,1<<o,1<<s,n)/i*t[o];return function(l,u,f){var h=u*a[6]+f*a[7]+1;l[0]=(u*a[0]+f*a[1]+a[2])/h,l[1]=(u*a[3]+f*a[4]+a[5])/h}}}var Ms="___zrEVENTSAVED",nu=[];function sT(e,t,r,n,i){return Rf(nu,t,n,i,!0)&&Rf(e,r,nu[0],nu[1])}function lT(e,t){e&&r(e),t&&r(t);function r(n){var i=n[Ms];i&&(i.clearMarkers&&i.clearMarkers(),delete n[Ms])}}function Rf(e,t,r,n,i){if(t.getBoundingClientRect&&nt.domSupported&&!zy(t)){var a=t[Ms]||(t[Ms]={}),o=uT(t,a),s=fT(o,a,i);if(s)return s(e,r,n),!0}return!1}function uT(e,t){var r=t.markers;if(r)return r;r=t.markers=[];for(var n=["left","right"],i=["top","bottom"],a=0;a<4;a++){var o=document.createElement("div"),s=o.style,l=a%2,u=(a>>1)%2;s.cssText=["position: absolute","visibility: hidden","padding: 0","margin: 0","border-width: 0","user-select: none","width:0","height:0",n[l]+":0",i[u]+":0",n[1-l]+":auto",i[1-u]+":auto",""].join("!important;"),e.appendChild(o),r.push(o)}return t.clearMarkers=function(){M(r,function(f){f.parentNode&&f.parentNode.removeChild(f)})},r}function fT(e,t,r){for(var n=r?"invTrans":"trans",i=t[n],a=t.srcCoords,o=[],s=[],l=!0,u=0;u<4;u++){var f=e[u].getBoundingClientRect(),h=2*u,c=f.left,v=f.top;o.push(c,v),l=l&&a&&c===a[h]&&v===a[h+1],s.push(e[u].offsetLeft,e[u].offsetTop)}return l&&i?i:(t.srcCoords=o,t[n]=r?ed(s,o):ed(o,s))}function zy(e){return e.nodeName.toUpperCase()==="CANVAS"}var hT=/([&<>"'])/g,vT={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;"};function ee(e){return e==null?"":(e+"").replace(hT,function(t,r){return vT[r]})}const cT={time:{month:["January","February","March","April","May","June","July","August","September","October","November","December"],monthAbbr:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],dayOfWeek:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayOfWeekAbbr:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"]},legend:{selector:{all:"All",inverse:"Inv"}},toolbox:{brush:{title:{rect:"Box Select",polygon:"Lasso Select",lineX:"Horizontally Select",lineY:"Vertically Select",keep:"Keep Selections",clear:"Clear Selections"}},dataView:{title:"Data View",lang:["Data View","Close","Refresh"]},dataZoom:{title:{zoom:"Zoom",back:"Zoom Reset"}},magicType:{title:{line:"Switch to Line Chart",bar:"Switch to Bar Chart",stack:"Stack",tiled:"Tile"}},restore:{title:"Restore"},saveAsImage:{title:"Save as Image",lang:["Right Click to Save Image"]}},series:{typeNames:{pie:"Pie chart",bar:"Bar chart",line:"Line chart",scatter:"Scatter plot",effectScatter:"Ripple scatter plot",radar:"Radar chart",tree:"Tree",treemap:"Treemap",boxplot:"Boxplot",candlestick:"Candlestick",k:"K line chart",heatmap:"Heat map",map:"Map",parallel:"Parallel coordinate map",lines:"Line graph",graph:"Relationship graph",sankey:"Sankey diagram",funnel:"Funnel chart",gauge:"Gauge",pictorialBar:"Pictorial bar",themeRiver:"Theme River Map",sunburst:"Sunburst",custom:"Custom chart",chart:"Chart"}},aria:{general:{withTitle:'This is a chart about "{title}"',withoutTitle:"This is a chart"},series:{single:{prefix:"",withName:" with type {seriesType} named {seriesName}.",withoutName:" with type {seriesType}."},multiple:{prefix:". It consists of {seriesCount} series count.",withName:" The {seriesId} series is a {seriesType} representing {seriesName}.",withoutName:" The {seriesId} series is a {seriesType}.",separator:{middle:"",end:""}}},data:{allData:"The data is as follows: ",partialData:"The first {displayCnt} items are: ",withName:"the data for {name} is {value}",withoutName:"{value}",separator:{middle:", ",end:". "}}}},dT={time:{month:["一月","二月","三月","四月","五月","六月","七月","八月","九月","十月","十一月","十二月"],monthAbbr:["1月","2月","3月","4月","5月","6月","7月","8月","9月","10月","11月","12月"],dayOfWeek:["星期日","星期一","星期二","星期三","星期四","星期五","星期六"],dayOfWeekAbbr:["日","一","二","三","四","五","六"]},legend:{selector:{all:"全选",inverse:"反选"}},toolbox:{brush:{title:{rect:"矩形选择",polygon:"圈选",lineX:"横向选择",lineY:"纵向选择",keep:"保持选择",clear:"清除选择"}},dataView:{title:"数据视图",lang:["数据视图","关闭","刷新"]},dataZoom:{title:{zoom:"区域缩放",back:"区域缩放还原"}},magicType:{title:{line:"切换为折线图",bar:"切换为柱状图",stack:"切换为堆叠",tiled:"切换为平铺"}},restore:{title:"还原"},saveAsImage:{title:"保存为图片",lang:["右键另存为图片"]}},series:{typeNames:{pie:"饼图",bar:"柱状图",line:"折线图",scatter:"散点图",effectScatter:"涟漪散点图",radar:"雷达图",tree:"树图",treemap:"矩形树图",boxplot:"箱型图",candlestick:"K线图",k:"K线图",heatmap:"热力图",map:"地图",parallel:"平行坐标图",lines:"线图",graph:"关系图",sankey:"桑基图",funnel:"漏斗图",gauge:"仪表盘图",pictorialBar:"象形柱图",themeRiver:"主题河流图",sunburst:"旭日图",custom:"自定义图表",chart:"图表"}},aria:{general:{withTitle:"这是一个关于“{title}”的图表。",withoutTitle:"这是一个图表，"},series:{single:{prefix:"",withName:"图表类型是{seriesType}，表示{seriesName}。",withoutName:"图表类型是{seriesType}。"},multiple:{prefix:"它由{seriesCount}个图表系列组成。",withName:"第{seriesId}个系列是一个表示{seriesName}的{seriesType}，",withoutName:"第{seriesId}个系列是一个{seriesType}，",separator:{middle:"；",end:"。"}}},data:{allData:"其数据是——",partialData:"其中，前{displayCnt}项是——",withName:"{name}的数据是{value}",withoutName:"{value}",separator:{middle:"，",end:""}}}};var Ds="ZH",Zh="EN",wi=Zh,ts={},Xh={},Hy=nt.domSupported?(function(){var e=(document.documentElement.lang||navigator.language||navigator.browserLanguage||wi).toUpperCase();return e.indexOf(Ds)>-1?Ds:wi})():wi;function Vy(e,t){e=e.toUpperCase(),Xh[e]=new xt(t),ts[e]=t}function pT(e){if(W(e)){var t=ts[e.toUpperCase()]||{};return e===Ds||e===Zh?st(t):vt(st(t),st(ts[wi]),!1)}else return vt(st(e),st(ts[wi]),!1)}function gT(e){return Xh[e]}function mT(){return Xh[wi]}Vy(Zh,cT);Vy(Ds,dT);var yT=null;function As(){return yT}var $h=1e3,qh=$h*60,wa=qh*60,be=wa*24,rd=be*365,_T={year:/({yyyy}|{yy})/,month:/({MMMM}|{MMM}|{MM}|{M})/,day:/({dd}|{d})/,hour:/({HH}|{H}|{hh}|{h})/,minute:/({mm}|{m})/,second:/({ss}|{s})/,millisecond:/({SSS}|{S})/},es={year:"{yyyy}",month:"{MMM}",day:"{d}",hour:"{HH}:{mm}",minute:"{HH}:{mm}",second:"{HH}:{mm}:{ss}",millisecond:"{HH}:{mm}:{ss} {SSS}"},ST="{yyyy}-{MM}-{dd} {HH}:{mm}:{ss} {SSS}",Mo="{yyyy}-{MM}-{dd}",nd={year:"{yyyy}",month:"{yyyy}-{MM}",day:Mo,hour:Mo+" "+es.hour,minute:Mo+" "+es.minute,second:Mo+" "+es.second,millisecond:ST},In=["year","month","day","hour","minute","second","millisecond"],bT=["year","half-year","quarter","month","week","half-week","day","half-day","quarter-day","hour","minute","second","millisecond"];function wT(e){return!W(e)&&!et(e)?xT(e):e}function xT(e){e=e||{};var t={},r=!0;return M(In,function(n){r&&(r=e[n]==null)}),M(In,function(n,i){var a=e[n];t[n]={};for(var o=null,s=i;s>=0;s--){var l=In[s],u=X(a)&&!z(a)?a[l]:a,f=void 0;z(u)?(f=u.slice(),o=f[0]||""):W(u)?(o=u,f=[o]):(o==null?o=es[n]:_T[l].test(o)||(o=t[l][l][0]+" "+o),f=[o],r&&(f[1]="{primary|"+o+"}")),t[n][l]=f}}),t}function mr(e,t){return e+="","0000".substr(0,t-e.length)+e}function xa(e){switch(e){case"half-year":case"quarter":return"month";case"week":case"half-week":return"day";case"half-day":case"quarter-day":return"hour";default:return e}}function TT(e){return e===xa(e)}function CT(e){switch(e){case"year":case"month":return"day";case"millisecond":return"millisecond";default:return"second"}}function gl(e,t,r,n){var i=Bi(e),a=i[Gy(r)](),o=i[Kh(r)]()+1,s=Math.floor((o-1)/3)+1,l=i[Qh(r)](),u=i["get"+(r?"UTC":"")+"Day"](),f=i[Jh(r)](),h=(f-1)%12+1,c=i[jh(r)](),v=i[tv(r)](),d=i[ev(r)](),p=f>=12?"pm":"am",g=p.toUpperCase(),m=n instanceof xt?n:gT(n||Hy)||mT(),y=m.getModel("time"),_=y.get("month"),S=y.get("monthAbbr"),w=y.get("dayOfWeek"),b=y.get("dayOfWeekAbbr");return(t||"").replace(/{a}/g,p+"").replace(/{A}/g,g+"").replace(/{yyyy}/g,a+"").replace(/{yy}/g,mr(a%100+"",2)).replace(/{Q}/g,s+"").replace(/{MMMM}/g,_[o-1]).replace(/{MMM}/g,S[o-1]).replace(/{MM}/g,mr(o,2)).replace(/{M}/g,o+"").replace(/{dd}/g,mr(l,2)).replace(/{d}/g,l+"").replace(/{eeee}/g,w[u]).replace(/{ee}/g,b[u]).replace(/{e}/g,u+"").replace(/{HH}/g,mr(f,2)).replace(/{H}/g,f+"").replace(/{hh}/g,mr(h+"",2)).replace(/{h}/g,h+"").replace(/{mm}/g,mr(c,2)).replace(/{m}/g,c+"").replace(/{ss}/g,mr(v,2)).replace(/{s}/g,v+"").replace(/{SSS}/g,mr(d,3)).replace(/{S}/g,d+"")}function MT(e,t,r,n,i){var a=null;if(W(r))a=r;else if(et(r)){var o={time:e.time,level:e.time.level},s=As();s&&s.makeAxisLabelFormatterParamBreak(o,e.break),a=r(e.value,t,o)}else{var l=e.time;if(l){var u=r[l.lowerTimeUnit][l.upperTimeUnit];a=u[Math.min(l.level,u.length-1)]||""}else{var f=Ls(e.value,i);a=r[f][f][0]}}return gl(new Date(e.value),a,i,n)}function Ls(e,t){var r=Bi(e),n=r[Kh(t)]()+1,i=r[Qh(t)](),a=r[Jh(t)](),o=r[jh(t)](),s=r[tv(t)](),l=r[ev(t)](),u=l===0,f=u&&s===0,h=f&&o===0,c=h&&a===0,v=c&&i===1,d=v&&n===1;return d?"year":v?"month":c?"day":h?"hour":f?"minute":u?"second":"millisecond"}function Ef(e,t,r){switch(t){case"year":e[Wy(r)](0);case"month":e[Uy(r)](1);case"day":e[Yy(r)](0);case"hour":e[Zy(r)](0);case"minute":e[Xy(r)](0);case"second":e[$y(r)](0)}return e}function Gy(e){return e?"getUTCFullYear":"getFullYear"}function Kh(e){return e?"getUTCMonth":"getMonth"}function Qh(e){return e?"getUTCDate":"getDate"}function Jh(e){return e?"getUTCHours":"getHours"}function jh(e){return e?"getUTCMinutes":"getMinutes"}function tv(e){return e?"getUTCSeconds":"getSeconds"}function ev(e){return e?"getUTCMilliseconds":"getMilliseconds"}function DT(e){return e?"setUTCFullYear":"setFullYear"}function Wy(e){return e?"setUTCMonth":"setMonth"}function Uy(e){return e?"setUTCDate":"setDate"}function Yy(e){return e?"setUTCHours":"setHours"}function Zy(e){return e?"setUTCMinutes":"setMinutes"}function Xy(e){return e?"setUTCSeconds":"setSeconds"}function $y(e){return e?"setUTCMilliseconds":"setMilliseconds"}function qy(e){if(!bb(e))return W(e)?e:"-";var t=(e+"").split(".");return t[0].replace(/(\d{1,3})(?=(?:\d{3})+(?!\d))/g,"$1,")+(t.length>1?"."+t[1]:"")}function Ky(e,t){return e=(e||"").toLowerCase().replace(/-(.)/g,function(r,n){return n.toUpperCase()}),t&&e&&(e=e.charAt(0).toUpperCase()+e.slice(1)),e}var rv=_h;function kf(e,t,r){var n="{yyyy}-{MM}-{dd} {HH}:{mm}:{ss}";function i(f){return f&&Ge(f)?f:"-"}function a(f){return!!(f!=null&&!isNaN(f)&&isFinite(f))}var o=t==="time",s=e instanceof Date;if(o||s){var l=o?Bi(e):e;if(isNaN(+l)){if(s)return"-"}else return gl(l,n,r)}if(t==="ordinal")return qu(e)?i(e):mt(e)&&a(e)?e+"":"-";var u=Nr(e);return a(u)?qy(u):qu(e)?i(e):typeof e=="boolean"?e+"":"-"}var id=["a","b","c","d","e","f","g"],iu=function(e,t){return"{"+e+(t??"")+"}"};function Qy(e,t,r){z(t)||(t=[t]);var n=t.length;if(!n)return"";for(var i=t[0].$vars||[],a=0;a<i.length;a++){var o=id[a];e=e.replace(iu(o),iu(o,0))}for(var s=0;s<n;s++)for(var l=0;l<i.length;l++){var u=t[s][i[l]];e=e.replace(iu(id[l],s),r?ee(u):u)}return e}function AT(e,t){var r=W(e)?{color:e,extraCssText:t}:e||{},n=r.color,i=r.type;t=r.extraCssText;var a=r.renderMode||"html";if(!n)return"";if(a==="html")return i==="subItem"?'<span style="display:inline-block;vertical-align:middle;margin-right:8px;margin-left:3px;border-radius:4px;width:4px;height:4px;background-color:'+ee(n)+";"+(t||"")+'"></span>':'<span style="display:inline-block;margin-right:4px;border-radius:10px;width:10px;height:10px;background-color:'+ee(n)+";"+(t||"")+'"></span>';var o=r.markerId||"markerX";return{renderMode:a,content:"{"+o+"|}  ",style:i==="subItem"?{width:4,height:4,borderRadius:2,backgroundColor:n}:{width:10,height:10,borderRadius:5,backgroundColor:n}}}function kn(e,t){return t=t||"transparent",W(e)?e:X(e)&&e.colorStops&&(e.colorStops[0]||{}).color||t}function ad(e,t){if(t==="_blank"||t==="blank"){var r=window.open();r.opener=null,r.location.href=e}else window.open(e,t)}var rs=M,LT=["left","right","top","bottom","width","height"],Do=[["width","left","right"],["height","top","bottom"]];function Jy(e,t,r,n,i){var a=0,o=0;n==null&&(n=1/0),i==null&&(i=1/0);var s=0;t.eachChild(function(l,u){var f=l.getBoundingRect(),h=t.childAt(u+1),c=h&&h.getBoundingRect(),v,d;if(e==="horizontal"){var p=f.width+(c?-c.x+f.x:0);v=a+p,v>n||l.newline?(a=0,v=p,o+=s+r,s=f.height):s=Math.max(s,f.height)}else{var g=f.height+(c?-c.y+f.y:0);d=o+g,d>i||l.newline?(a+=s+r,o=0,d=g,s=f.width):s=Math.max(s,f.width)}l.newline||(l.x=a,l.y=o,l.markRedraw(),e==="horizontal"?a=v+r:o=d+r)})}ne(Jy,"vertical");ne(Jy,"horizontal");function IT(e,t){return{left:e.getShallow("left",t),top:e.getShallow("top",t),right:e.getShallow("right",t),bottom:e.getShallow("bottom",t),width:e.getShallow("width",t),height:e.getShallow("height",t)}}function to(e,t,r){r=rv(r||0);var n=t.width,i=t.height,a=It(e.left,n),o=It(e.top,i),s=It(e.right,n),l=It(e.bottom,i),u=It(e.width,n),f=It(e.height,i),h=r[2]+r[0],c=r[1]+r[3],v=e.aspect;switch(isNaN(u)&&(u=n-s-c-a),isNaN(f)&&(f=i-l-h-o),v!=null&&(isNaN(u)&&isNaN(f)&&(v>n/i?u=n*.8:f=i*.8),isNaN(u)&&(u=v*f),isNaN(f)&&(f=u/v)),isNaN(a)&&(a=n-s-u-c),isNaN(o)&&(o=i-l-f-h),e.left||e.right){case"center":a=n/2-u/2-r[3];break;case"right":a=n-u-c;break}switch(e.top||e.bottom){case"middle":case"center":o=i/2-f/2-r[0];break;case"bottom":o=i-f-h;break}a=a||0,o=o||0,isNaN(u)&&(u=n-c-a-(s||0)),isNaN(f)&&(f=i-h-o-(l||0));var d=new it((t.x||0)+a+r[3],(t.y||0)+o+r[0],u,f);return d.margin=r,d}var au={rect:1};function nv(e,t,r){var n,i,a,o=e.boxCoordinateSystem,s;if(o){var l=Wx(e),u=l.coord,f=l.from;if(o.dataToLayout){a=au.rect,s=f;var h=o.dataToLayout(u);n=h.contentRect||h.rect}}return a==null&&(a=au.rect),a===au.rect&&(n||(n={x:0,y:0,width:t.getWidth(),height:t.getHeight()}),i=[n.x+n.width/2,n.y+n.height/2]),{type:a,refContainer:n,refPoint:i,boxCoordFrom:s}}function za(e){var t=e.layoutMode||e.constructor.layoutMode;return X(t)?t:t?{type:t}:null}function On(e,t,r){var n=r&&r.ignoreSize;!z(n)&&(n=[n,n]);var i=o(Do[0],0),a=o(Do[1],1);l(Do[0],e,i),l(Do[1],e,a);function o(u,f){var h={},c=0,v={},d=0,p=2;if(rs(u,function(y){v[y]=e[y]}),rs(u,function(y){he(t,y)&&(h[y]=v[y]=t[y]),s(h,y)&&c++,s(v,y)&&d++}),n[f])return s(t,u[1])?v[u[2]]=null:s(t,u[2])&&(v[u[1]]=null),v;if(d===p||!c)return v;if(c>=p)return h;for(var g=0;g<u.length;g++){var m=u[g];if(!he(h,m)&&he(e,m)){h[m]=e[m];break}}return h}function s(u,f){return u[f]!=null&&u[f]!=="auto"}function l(u,f,h){rs(u,function(c){f[c]=h[c]})}}function eo(e){return PT({},e)}function PT(e,t){return t&&e&&rs(LT,function(r){he(t,r)&&(e[r]=t[r])}),e}var RT=gt(),dt=(function(e){N(t,e);function t(r,n,i){var a=e.call(this,r,n,i)||this;return a.uid=pl("ec_cpt_model"),a}return t.prototype.init=function(r,n,i){this.mergeDefaultAndTheme(r,i)},t.prototype.mergeDefaultAndTheme=function(r,n){var i=za(this),a=i?eo(r):{},o=n.getTheme();vt(r,o.get(this.mainType)),vt(r,this.getDefaultOption()),i&&On(r,a,i)},t.prototype.mergeOption=function(r,n){vt(this.option,r,!0);var i=za(this);i&&On(this.option,r,i)},t.prototype.optionUpdated=function(r,n){},t.prototype.getDefaultOption=function(){var r=this.constructor;if(!z1(r))return r.defaultOption;var n=RT(this);if(!n.defaultOption){for(var i=[],a=r;a;){var o=a.prototype.defaultOption;o&&i.push(o),a=a.superClass}for(var s={},l=i.length-1;l>=0;l--)s=vt(s,i[l],!0);n.defaultOption=s}return n.defaultOption},t.prototype.getReferringComponents=function(r,n){var i=r+"Index",a=r+"Id";return Qa(this.ecModel,r,{index:this.get(i,!0),id:this.get(a,!0)},n)},t.prototype.getBoxLayoutParams=function(){return IT(this,!1)},t.prototype.getZLevelKey=function(){return""},t.prototype.setZLevel=function(r){this.option.zlevel=r},t.protoInitialize=(function(){var r=t.prototype;r.type="component",r.id="",r.name="",r.mainType="",r.subType="",r.componentIndex=0})(),t})(xt);qg(dt,xt);js(dt);iT(dt);aT(dt,ET);function ET(e){var t=[];return M(dt.getClassesByMainType(e),function(r){t=t.concat(r.dependencies||r.prototype.dependencies||[])}),t=$(t,function(r){return We(r).main}),e!=="dataset"&&ft(t,"dataset")<=0&&t.unshift("dataset"),t}var od=gt();gt();var iv=(function(){function e(){}return e.prototype.getColorFromPalette=function(t,r,n){var i=Mt(this.get("color",!0)),a=this.get("colorLayer",!0);return OT(this,od,i,a,t,r,n)},e.prototype.clearColorPalette=function(){BT(this,od)},e})();function kT(e,t){for(var r=e.length,n=0;n<r;n++)if(e[n].length>t)return e[n];return e[r-1]}function OT(e,t,r,n,i,a,o){a=a||e;var s=t(a),l=s.paletteIdx||0,u=s.paletteNameMap=s.paletteNameMap||{};if(u.hasOwnProperty(i))return u[i];var f=o==null||!n?r:kT(n,o);if(f=f||r,!(!f||!f.length)){var h=f[l];return i&&(u[i]=h),s.paletteIdx=(l+1)%f.length,h}}function BT(e,t){t(e).paletteIdx=0,t(e).paletteNameMap={}}var NT=/\{@(.+?)\}/g,FT=(function(){function e(){}return e.prototype.getDataParams=function(t,r){var n=this.getData(r),i=this.getRawValue(t,r),a=n.getRawIndex(t),o=n.getName(t),s=n.getRawDataItem(t),l=n.getItemVisual(t,"style"),u=l&&l[n.getItemVisual(t,"drawType")||"fill"],f=l&&l.stroke,h=this.mainType,c=h==="series",v=n.userOutput&&n.userOutput.get();return{componentType:h,componentSubType:this.subType,componentIndex:this.componentIndex,seriesType:c?this.subType:null,seriesIndex:this.seriesIndex,seriesId:c?this.id:null,seriesName:c?this.name:null,name:o,dataIndex:a,data:s,dataType:r,value:i,color:u,borderColor:f,dimensionNames:v?v.fullDimensions:null,encode:v?v.encode:null,$vars:["seriesName","name","value"]}},e.prototype.getFormattedLabel=function(t,r,n,i,a,o){r=r||"normal";var s=this.getData(n),l=this.getDataParams(t,n);if(o&&(l.value=o.interpolatedValue),i!=null&&z(l.value)&&(l.value=l.value[i]),!a){var u=s.getItemModel(t);a=u.get(r==="normal"?["label","formatter"]:[r,"label","formatter"])}if(et(a))return l.status=r,l.dimensionIndex=i,a(l);if(W(a)){var f=Qy(a,l);return f.replace(NT,function(h,c){var v=c.length,d=c;d.charAt(0)==="["&&d.charAt(v-1)==="]"&&(d=+d.slice(1,v-1));var p=Di(s,t,d);if(o&&z(o.interpolatedValue)){var g=s.getDimensionIndex(d);g>=0&&(p=o.interpolatedValue[g])}return p!=null?p+"":""})}},e.prototype.getRawValue=function(t,r){return Di(this.getData(r),t)},e.prototype.formatTooltip=function(t,r,n){},e})();function sd(e){var t,r;return X(e)?e.type&&(r=e):t=e,{text:t,frag:r}}function Ta(e){return new zT(e)}var zT=(function(){function e(t){t=t||{},this._reset=t.reset,this._plan=t.plan,this._count=t.count,this._onDirty=t.onDirty,this._dirty=!0}return e.prototype.perform=function(t){var r=this._upstream,n=t&&t.skip;if(this._dirty&&r){var i=this.context;i.data=i.outputData=r.context.outputData}this.__pipeline&&(this.__pipeline.currentTask=this);var a;this._plan&&!n&&(a=this._plan(this.context));var o=f(this._modBy),s=this._modDataCount||0,l=f(t&&t.modBy),u=t&&t.modDataCount||0;(o!==l||s!==u)&&(a="reset");function f(y){return!(y>=1)&&(y=1),y}var h;(this._dirty||a==="reset")&&(this._dirty=!1,h=this._doReset(n)),this._modBy=l,this._modDataCount=u;var c=t&&t.step;if(r?this._dueEnd=r._outputDueEnd:this._dueEnd=this._count?this._count(this.context):1/0,this._progress){var v=this._dueIndex,d=Math.min(c!=null?this._dueIndex+c:1/0,this._dueEnd);if(!n&&(h||v<d)){var p=this._progress;if(z(p))for(var g=0;g<p.length;g++)this._doProgress(p[g],v,d,l,u);else this._doProgress(p,v,d,l,u)}this._dueIndex=d;var m=this._settedOutputEnd!=null?this._settedOutputEnd:d;this._outputDueEnd=m}else this._dueIndex=this._outputDueEnd=this._settedOutputEnd!=null?this._settedOutputEnd:this._dueEnd;return this.unfinished()},e.prototype.dirty=function(){this._dirty=!0,this._onDirty&&this._onDirty(this.context)},e.prototype._doProgress=function(t,r,n,i,a){ld.reset(r,n,i,a),this._callingProgress=t,this._callingProgress({start:r,end:n,count:n-r,next:ld.next},this.context)},e.prototype._doReset=function(t){this._dueIndex=this._outputDueEnd=this._dueEnd=0,this._settedOutputEnd=null;var r,n;!t&&this._reset&&(r=this._reset(this.context),r&&r.progress&&(n=r.forceFirstProgress,r=r.progress),z(r)&&!r.length&&(r=null)),this._progress=r,this._modBy=this._modDataCount=null;var i=this._downstream;return i&&i.dirty(),n},e.prototype.unfinished=function(){return this._progress&&this._dueIndex<this._dueEnd},e.prototype.pipe=function(t){(this._downstream!==t||this._dirty)&&(this._downstream=t,t._upstream=this,t.dirty())},e.prototype.dispose=function(){this._disposed||(this._upstream&&(this._upstream._downstream=null),this._downstream&&(this._downstream._upstream=null),this._dirty=!1,this._disposed=!0)},e.prototype.getUpstream=function(){return this._upstream},e.prototype.getDownstream=function(){return this._downstream},e.prototype.setOutputEnd=function(t){this._outputDueEnd=this._settedOutputEnd=t},e})(),ld=(function(){var e,t,r,n,i,a={reset:function(l,u,f,h){t=l,e=u,r=f,n=h,i=Math.ceil(n/r),a.next=r>1&&n>0?s:o}};return a;function o(){return t<e?t++:null}function s(){var l=t%i*r+Math.ceil(t/i),u=t>=e?null:l<n?l:t;return t++,u}})(),HT=(function(){function e(){}return e.prototype.getRawData=function(){throw new Error("not supported")},e.prototype.getRawDataItem=function(t){throw new Error("not supported")},e.prototype.cloneRawData=function(){},e.prototype.getDimensionInfo=function(t){},e.prototype.cloneAllDimensionInfo=function(){},e.prototype.count=function(){},e.prototype.retrieveValue=function(t,r){},e.prototype.retrieveValueFromItem=function(t,r){},e.prototype.convertValue=function(t,r){return Jo(t,r)},e})();function VT(e,t){var r=new HT,n=e.data,i=r.sourceFormat=e.sourceFormat,a=e.startIndex,o="";e.seriesLayoutBy!==Pe&&ut(o);var s=[],l={},u=e.dimensionsDefine;if(u)M(u,function(p,g){var m=p.name,y={index:g,name:m,displayName:p.displayName};if(s.push(y),m!=null){var _="";he(l,m)&&ut(_),l[m]=y}});else for(var f=0;f<e.dimensionsDetectedCount;f++)s.push({index:f});var h=Cy(i,Pe);t.__isBuiltIn&&(r.getRawDataItem=function(p){return h(n,a,s,p)},r.getRawData=Q(GT,null,e)),r.cloneRawData=Q(WT,null,e);var c=My(i,Pe);r.count=Q(c,null,n,a,s);var v=Dy(i);r.retrieveValue=function(p,g){var m=h(n,a,s,p);return d(m,g)};var d=r.retrieveValueFromItem=function(p,g){if(p!=null){var m=s[g];if(m)return v(p,g,m.name)}};return r.getDimensionInfo=Q(UT,null,s,l),r.cloneAllDimensionInfo=Q(YT,null,s),r}function GT(e){var t=e.sourceFormat;if(!av(t)){var r="";ut(r)}return e.data}function WT(e){var t=e.sourceFormat,r=e.data;if(!av(t)){var n="";ut(n)}if(t===zt){for(var i=[],a=0,o=r.length;a<o;a++)i.push(r[a].slice());return i}else if(t===Ce){for(var i=[],a=0,o=r.length;a<o;a++)i.push(k({},r[a]));return i}}function UT(e,t,r){if(r!=null){if(mt(r)||!isNaN(r)&&!he(t,r))return e[r];if(he(t,r))return t[r]}}function YT(e){return st(e)}var jy=K();function ZT(e){e=st(e);var t=e.type,r="";t||ut(r);var n=t.split(":");n.length!==2&&ut(r);var i=!1;n[0]==="echarts"&&(t=n[1],i=!0),e.__isBuiltIn=i,jy.set(t,e)}function XT(e,t,r){var n=Mt(e),i=n.length,a="";i||ut(a);for(var o=0,s=i;o<s;o++){var l=n[o];t=$T(l,t),o!==s-1&&(t.length=Math.max(t.length,1))}return t}function $T(e,t,r,n){var i="";t.length||ut(i),X(e)||ut(i);var a=e.type,o=jy.get(a);o||ut(i);var s=$(t,function(u){return VT(u,o)}),l=Mt(o.transform({upstream:s[0],upstreamList:s,config:st(e.config)}));return $(l,function(u,f){var h="";X(u)||ut(h),u.data||ut(h);var c=wy(u.data);av(c)||ut(h);var v,d=t[0];if(d&&f===0&&!u.dimensions){var p=d.startIndex;p&&(u.data=d.data.slice(0,p).concat(u.data)),v={seriesLayoutBy:Pe,sourceHeader:p,dimensions:d.metaRawOption.dimensions}}else v={seriesLayoutBy:Pe,sourceHeader:0,dimensions:u.dimensions};return Lf(u.data,v,null)})}function av(e){return e===zt||e===Ce}var t0=(function(){function e(t){this._sourceList=[],this._storeList=[],this._upstreamSignList=[],this._versionSignBase=0,this._dirty=!0,this._sourceHost=t}return e.prototype.dirty=function(){this._setLocalSource([],[]),this._storeList=[],this._dirty=!0},e.prototype._setLocalSource=function(t,r){this._sourceList=t,this._upstreamSignList=r,this._versionSignBase++,this._versionSignBase>9e10&&(this._versionSignBase=0)},e.prototype._getVersionSign=function(){return this._sourceHost.uid+"_"+this._versionSignBase},e.prototype.prepareSource=function(){this._isDirty()&&(this._createSource(),this._dirty=!1)},e.prototype._createSource=function(){this._setLocalSource([],[]);var t=this._sourceHost,r=this._getUpstreamSourceManagers(),n=!!r.length,i,a;if(Ao(t)){var o=t,s=void 0,l=void 0,u=void 0;if(n){var f=r[0];f.prepareSource(),u=f.getSource(),s=u.data,l=u.sourceFormat,a=[f._getVersionSign()]}else s=o.get("data",!0),l=ie(s)?Er:ve,a=[];var h=this._getSourceMetaRawOption()||{},c=u&&u.metaRawOption||{},v=q(h.seriesLayoutBy,c.seriesLayoutBy)||null,d=q(h.sourceHeader,c.sourceHeader),p=q(h.dimensions,c.dimensions),g=v!==c.seriesLayoutBy||!!d!=!!c.sourceHeader||p;i=g?[Lf(s,{seriesLayoutBy:v,sourceHeader:d,dimensions:p},l)]:[]}else{var m=t;if(n){var y=this._applyTransform(r);i=y.sourceList,a=y.upstreamSignList}else{var _=m.get("source",!0);i=[Lf(_,this._getSourceMetaRawOption(),null)],a=[]}}this._setLocalSource(i,a)},e.prototype._applyTransform=function(t){var r=this._sourceHost,n=r.get("transform",!0),i=r.get("fromTransformResult",!0);if(i!=null){var a="";t.length!==1&&fd(a)}var o,s=[],l=[];return M(t,function(u){u.prepareSource();var f=u.getSource(i||0),h="";i!=null&&!f&&fd(h),s.push(f),l.push(u._getVersionSign())}),n?o=XT(n,s,{datasetIndex:r.componentIndex}):i!=null&&(o=[vx(s[0])]),{sourceList:o,upstreamSignList:l}},e.prototype._isDirty=function(){if(this._dirty)return!0;for(var t=this._getUpstreamSourceManagers(),r=0;r<t.length;r++){var n=t[r];if(n._isDirty()||this._upstreamSignList[r]!==n._getVersionSign())return!0}},e.prototype.getSource=function(t){t=t||0;var r=this._sourceList[t];if(!r){var n=this._getUpstreamSourceManagers();return n[0]&&n[0].getSource(t)}return r},e.prototype.getSharedDataStore=function(t){var r=t.makeStoreSchema();return this._innerGetDataStore(r.dimensions,t.source,r.hash)},e.prototype._innerGetDataStore=function(t,r,n){var i=0,a=this._storeList,o=a[i];o||(o=a[i]={});var s=o[n];if(!s){var l=this._getUpstreamSourceManagers()[0];Ao(this._sourceHost)&&l?s=l._innerGetDataStore(t,r,n):(s=new If,s.initData(new Ty(r,t.length),t)),o[n]=s}return s},e.prototype._getUpstreamSourceManagers=function(){var t=this._sourceHost;if(Ao(t)){var r=_y(t);return r?[r.getSourceManager()]:[]}else return $(fx(t),function(n){return n.getSourceManager()})},e.prototype._getSourceMetaRawOption=function(){var t=this._sourceHost,r,n,i;if(Ao(t))r=t.get("seriesLayoutBy",!0),n=t.get("sourceHeader",!0),i=t.get("dimensions",!0);else if(!this._getUpstreamSourceManagers().length){var a=t;r=a.get("seriesLayoutBy",!0),n=a.get("sourceHeader",!0),i=a.get("dimensions",!0)}return{seriesLayoutBy:r,sourceHeader:n,dimensions:i}},e})();function ud(e){var t=e.option.transform;t&&hs(e.option.transform)}function Ao(e){return e.mainType==="series"}function fd(e){throw new Error(e)}var Y={color:{},darkColor:{},size:{}},bt=Y.color={theme:["#5070dd","#b6d634","#505372","#ff994d","#0ca8df","#ffd10a","#fb628b","#785db0","#3fbe95"],neutral00:"#fff",neutral05:"#f4f7fd",neutral10:"#e8ebf0",neutral15:"#dbdee4",neutral20:"#cfd2d7",neutral25:"#c3c5cb",neutral30:"#b7b9be",neutral35:"#aaacb2",neutral40:"#9ea0a5",neutral45:"#929399",neutral50:"#86878c",neutral55:"#797b7f",neutral60:"#6d6e73",neutral65:"#616266",neutral70:"#54555a",neutral75:"#48494d",neutral80:"#3c3c41",neutral85:"#303034",neutral90:"#232328",neutral95:"#17171b",neutral99:"#000",accent05:"#eff1f9",accent10:"#e0e4f2",accent15:"#d0d6ec",accent20:"#c0c9e6",accent25:"#b1bbdf",accent30:"#a1aed9",accent35:"#91a0d3",accent40:"#8292cc",accent45:"#7285c6",accent50:"#6578ba",accent55:"#5c6da9",accent60:"#536298",accent65:"#4a5787",accent70:"#404c76",accent75:"#374165",accent80:"#2e3654",accent85:"#252b43",accent90:"#1b2032",accent95:"#121521",transparent:"rgba(0,0,0,0)",highlight:"rgba(255,231,130,0.8)"};k(bt,{primary:bt.neutral80,secondary:bt.neutral70,tertiary:bt.neutral60,quaternary:bt.neutral50,disabled:bt.neutral20,border:bt.neutral30,borderTint:bt.neutral20,borderShade:bt.neutral40,background:bt.neutral05,backgroundTint:"rgba(234,237,245,0.5)",backgroundTransparent:"rgba(255,255,255,0)",backgroundShade:bt.neutral10,shadow:"rgba(0,0,0,0.2)",shadowTint:"rgba(129,130,136,0.2)",axisLine:bt.neutral70,axisLineTint:bt.neutral40,axisTick:bt.neutral70,axisTickMinor:bt.neutral60,axisLabel:bt.neutral70,axisSplitLine:bt.neutral15,axisMinorSplitLine:bt.neutral05});for(var cn in bt)if(bt.hasOwnProperty(cn)){var hd=bt[cn];cn==="theme"?Y.darkColor.theme=bt.theme.slice():cn==="highlight"?Y.darkColor.highlight="rgba(255,231,130,0.4)":cn.indexOf("accent")===0?Y.darkColor[cn]=lf(hd,null,function(e){return e*.5},function(e){return Math.min(1,1.3-e)}):Y.darkColor[cn]=lf(hd,null,function(e){return e*.9},function(e){return 1-Math.pow(e,1.5)})}Y.size={xxs:2,xs:5,s:10,m:15,l:20,xl:30,xxl:40,xxxl:50};var qT="line-height:1";function e0(e){var t=e.lineHeight;return t==null?qT:"line-height:"+ee(t+"")+"px"}function r0(e,t){var r=e.color||Y.color.tertiary,n=e.fontSize||12,i=e.fontWeight||"400",a=e.color||Y.color.secondary,o=e.fontSize||14,s=e.fontWeight||"900";return t==="html"?{nameStyle:"font-size:"+ee(n+"")+"px;color:"+ee(r)+";font-weight:"+ee(i+""),valueStyle:"font-size:"+ee(o+"")+"px;color:"+ee(a)+";font-weight:"+ee(s+"")}:{nameStyle:{fontSize:n,fill:r,fontWeight:i},valueStyle:{fontSize:o,fill:a,fontWeight:s}}}var KT=[0,10,20,30],QT=["",`
`,`

`,`


`];function Ha(e,t){return t.type=e,t}function Of(e){return e.type==="section"}function n0(e){return Of(e)?JT:jT}function i0(e){if(Of(e)){var t=0,r=e.blocks.length,n=r>1||r>0&&!e.noHeader;return M(e.blocks,function(i){var a=i0(i);a>=t&&(t=a+ +(n&&(!a||Of(i)&&!i.noHeader)))}),t}return 0}function JT(e,t,r,n){var i=t.noHeader,a=tC(i0(t)),o=[],s=t.blocks||[];fr(!s||z(s)),s=s||[];var l=e.orderMode;if(t.sortBlocks&&l){s=s.slice();var u={valueAsc:"asc",valueDesc:"desc"};if(he(u,l)){var f=new Iy(u[l],null);s.sort(function(p,g){return f.evaluate(p.sortParam,g.sortParam)})}else l==="seriesDesc"&&s.reverse()}M(s,function(p,g){var m=t.valueFormatter,y=n0(p)(m?k(k({},e),{valueFormatter:m}):e,p,g>0?a.html:0,n);y!=null&&o.push(y)});var h=e.renderMode==="richText"?o.join(a.richText):Bf(n,o.join(""),i?r:a.html);if(i)return h;var c=kf(t.header,"ordinal",e.useUTC),v=r0(n,e.renderMode).nameStyle,d=e0(n);return e.renderMode==="richText"?a0(e,c,v)+a.richText+h:Bf(n,'<div style="'+v+";"+d+';">'+ee(c)+"</div>"+h,r)}function jT(e,t,r,n){var i=e.renderMode,a=t.noName,o=t.noValue,s=!t.markerType,l=t.name,u=e.useUTC,f=t.valueFormatter||e.valueFormatter||function(S){return S=z(S)?S:[S],$(S,function(w,b){return kf(w,z(v)?v[b]:v,u)})};if(!(a&&o)){var h=s?"":e.markupStyleCreator.makeTooltipMarker(t.markerType,t.markerColor||Y.color.secondary,i),c=a?"":kf(l,"ordinal",u),v=t.valueType,d=o?[]:f(t.value,t.dataIndex),p=!s||!a,g=!s&&a,m=r0(n,i),y=m.nameStyle,_=m.valueStyle;return i==="richText"?(s?"":h)+(a?"":a0(e,c,y))+(o?"":nC(e,d,p,g,_)):Bf(n,(s?"":h)+(a?"":eC(c,!s,y))+(o?"":rC(d,p,g,_)),r)}}function vd(e,t,r,n,i,a){if(e){var o=n0(e),s={useUTC:i,renderMode:r,orderMode:n,markupStyleCreator:t,valueFormatter:e.valueFormatter};return o(s,e,0,a)}}function tC(e){return{html:KT[e],richText:QT[e]}}function Bf(e,t,r){var n='<div style="clear:both"></div>',i="margin: "+r+"px 0 0",a=e0(e);return'<div style="'+i+";"+a+';">'+t+n+"</div>"}function eC(e,t,r){var n=t?"margin-left:2px":"";return'<span style="'+r+";"+n+'">'+ee(e)+"</span>"}function rC(e,t,r,n){var i=r?"10px":"20px",a=t?"float:right;margin-left:"+i:"";return e=z(e)?e:[e],'<span style="'+a+";"+n+'">'+$(e,function(o){return ee(o)}).join("&nbsp;&nbsp;")+"</span>"}function a0(e,t,r){return e.markupStyleCreator.wrapRichTextStyle(t,r)}function nC(e,t,r,n,i){var a=[i],o=n?10:20;return r&&a.push({padding:[0,0,0,o],align:"right"}),e.markupStyleCreator.wrapRichTextStyle(z(t)?t.join("  "):t,a)}function iC(e,t){var r=e.getData().getItemVisual(t,"style"),n=r[e.visualDrawType];return kn(n)}function o0(e,t){var r=e.get("padding");return r??(t==="richText"?[8,10]:10)}var ou=(function(){function e(){this.richTextStyles={},this._nextStyleNameId=Dm()}return e.prototype._generateStyleName=function(){return"__EC_aUTo_"+this._nextStyleNameId++},e.prototype.makeTooltipMarker=function(t,r,n){var i=n==="richText"?this._generateStyleName():null,a=AT({color:r,type:t,renderMode:n,markerId:i});return W(a)?a:(this.richTextStyles[i]=a.style,a.content)},e.prototype.wrapRichTextStyle=function(t,r){var n={};z(r)?M(r,function(a){return k(n,a)}):k(n,r);var i=this._generateStyleName();return this.richTextStyles[i]=n,"{"+i+"|"+t+"}"},e})();function aC(e){var t=e.series,r=e.dataIndex,n=e.multipleSeries,i=t.getData(),a=i.mapDimensionsAll("defaultedTooltip"),o=a.length,s=t.getRawValue(r),l=z(s),u=iC(t,r),f,h,c,v;if(o>1||l&&!o){var d=oC(s,t,r,a,u);f=d.inlineValues,h=d.inlineValueTypes,c=d.blocks,v=d.inlineValues[0]}else if(o){var p=i.getDimensionInfo(a[0]);v=f=Di(i,r,a[0]),h=p.type}else v=f=l?s[0]:s;var g=Rm(t),m=g&&t.name||"",y=i.getName(r),_=n?m:y;return Ha("section",{header:m,noHeader:n||!g,sortParam:v,blocks:[Ha("nameValue",{markerType:"item",markerColor:u,name:_,noName:!Ge(_),value:f,valueType:h,dataIndex:r})].concat(c||[])})}function oC(e,t,r,n,i){var a=t.getData(),o=Ri(e,function(h,c,v){var d=a.getDimensionInfo(v);return h=h||d&&d.tooltip!==!1&&d.displayName!=null},!1),s=[],l=[],u=[];n.length?M(n,function(h){f(Di(a,r,h),h)}):M(e,f);function f(h,c){var v=a.getDimensionInfo(c);!v||v.otherDims.tooltip===!1||(o?u.push(Ha("nameValue",{markerType:"subItem",markerColor:i,name:v.displayName,value:h,valueType:v.type})):(s.push(h),l.push(v.type)))}return{inlineValues:s,inlineValueTypes:l,blocks:u}}var yr=gt();function Lo(e,t){return e.getName(t)||e.getId(t)}var ns="__universalTransitionEnabled",Hr=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r._selectedDataIndicesMap={},r}return t.prototype.init=function(r,n,i){this.seriesIndex=this.componentIndex,this.dataTask=Ta({count:lC,reset:uC}),this.dataTask.context={model:this},this.mergeDefaultAndTheme(r,i);var a=yr(this).sourceManager=new t0(this);a.prepareSource();var o=this.getInitialData(r,i);dd(o,this),this.dataTask.context.data=o,yr(this).dataBeforeProcessed=o,cd(this),this._initSelectedMapFromData(o)},t.prototype.mergeDefaultAndTheme=function(r,n){var i=za(this),a=i?eo(r):{},o=this.subType;dt.hasClass(o)&&(o+="Series"),vt(r,n.getTheme().get(this.subType)),vt(r,this.getDefaultOption()),mc(r,"label",["show"]),this.fillDataTextStyle(r.data),i&&On(r,a,i)},t.prototype.mergeOption=function(r,n){r=vt(this.option,r,!0),this.fillDataTextStyle(r.data);var i=za(this);i&&On(this.option,r,i);var a=yr(this).sourceManager;a.dirty(),a.prepareSource();var o=this.getInitialData(r,n);dd(o,this),this.dataTask.dirty(),this.dataTask.context.data=o,yr(this).dataBeforeProcessed=o,cd(this),this._initSelectedMapFromData(o)},t.prototype.fillDataTextStyle=function(r){if(r&&!ie(r))for(var n=["show"],i=0;i<r.length;i++)r[i]&&r[i].label&&mc(r[i],"label",n)},t.prototype.getInitialData=function(r,n){},t.prototype.appendData=function(r){var n=this.getRawData();n.appendData(r.data)},t.prototype.getData=function(r){var n=Nf(this);if(n){var i=n.context.data;return r==null||!i.getLinkedData?i:i.getLinkedData(r)}else return yr(this).data},t.prototype.getAllData=function(){var r=this.getData();return r&&r.getLinkedDataAll?r.getLinkedDataAll():[{data:r}]},t.prototype.setData=function(r){var n=Nf(this);if(n){var i=n.context;i.outputData=r,n!==this.dataTask&&(i.data=r)}yr(this).data=r},t.prototype.getEncode=function(){var r=this.get("encode",!0);if(r)return K(r)},t.prototype.getSourceManager=function(){return yr(this).sourceManager},t.prototype.getSource=function(){return this.getSourceManager().getSource()},t.prototype.getRawData=function(){return yr(this).dataBeforeProcessed},t.prototype.getColorBy=function(){var r=this.get("colorBy");return r||"series"},t.prototype.isColorBySeries=function(){return this.getColorBy()==="series"},t.prototype.getBaseAxis=function(){var r=this.coordinateSystem;return r&&r.getBaseAxis&&r.getBaseAxis()},t.prototype.indicesOfNearest=function(r,n,i,a){var o=this.getData(),s=this.coordinateSystem,l=s&&s.getAxis(r);if(!s||!l)return[];var u=l.dataToCoord(i);a==null&&(a=1/0);var f=[],h=1/0,c=-1,v=0;return o.each(n,function(d,p){var g=l.dataToCoord(d),m=u-g,y=Math.abs(m);y<=a&&((y<h||y===h&&m>=0&&c<0)&&(h=y,c=m,v=0),m===c&&(f[v++]=p))}),f.length=v,f},t.prototype.formatTooltip=function(r,n,i){return aC({series:this,dataIndex:r,multipleSeries:n})},t.prototype.isAnimationEnabled=function(){var r=this.ecModel;if(nt.node&&!(r&&r.ssr))return!1;var n=this.getShallow("animation");return n&&this.getData().count()>this.getShallow("animationThreshold")&&(n=!1),!!n},t.prototype.restoreData=function(){this.dataTask.dirty()},t.prototype.getColorFromPalette=function(r,n,i){var a=this.ecModel,o=iv.prototype.getColorFromPalette.call(this,r,n,i);return o||(o=a.getColorFromPalette(r,n,i)),o},t.prototype.coordDimToDataDim=function(r){return this.getRawData().mapDimensionsAll(r)},t.prototype.getProgressive=function(){return this.get("progressive")},t.prototype.getProgressiveThreshold=function(){return this.get("progressiveThreshold")},t.prototype.select=function(r,n){this._innerSelect(this.getData(n),r)},t.prototype.unselect=function(r,n){var i=this.option.selectedMap;if(i){var a=this.option.selectedMode,o=this.getData(n);if(a==="series"||i==="all"){this.option.selectedMap={},this._selectedDataIndicesMap={};return}for(var s=0;s<r.length;s++){var l=r[s],u=Lo(o,l);i[u]=!1,this._selectedDataIndicesMap[u]=-1}}},t.prototype.toggleSelect=function(r,n){for(var i=[],a=0;a<r.length;a++)i[0]=r[a],this.isSelected(r[a],n)?this.unselect(i,n):this.select(i,n)},t.prototype.getSelectedDataIndices=function(){if(this.option.selectedMap==="all")return[].slice.call(this.getData().getIndices());for(var r=this._selectedDataIndicesMap,n=St(r),i=[],a=0;a<n.length;a++){var o=r[n[a]];o>=0&&i.push(o)}return i},t.prototype.isSelected=function(r,n){var i=this.option.selectedMap;if(!i)return!1;var a=this.getData(n);return(i==="all"||i[Lo(a,r)])&&!a.getItemModel(r).get(["select","disabled"])},t.prototype.isUniversalTransitionEnabled=function(){if(this[ns])return!0;var r=this.option.universalTransition;return r?r===!0?!0:r&&r.enabled:!1},t.prototype._innerSelect=function(r,n){var i,a,o=this.option,s=o.selectedMode,l=n.length;if(!(!s||!l)){if(s==="series")o.selectedMap="all";else if(s==="multiple"){X(o.selectedMap)||(o.selectedMap={});for(var u=o.selectedMap,f=0;f<l;f++){var h=n[f],c=Lo(r,h);u[c]=!0,this._selectedDataIndicesMap[c]=r.getRawIndex(h)}}else if(s==="single"||s===!0){var v=n[l-1],c=Lo(r,v);o.selectedMap=(i={},i[c]=!0,i),this._selectedDataIndicesMap=(a={},a[c]=r.getRawIndex(v),a)}}},t.prototype._initSelectedMapFromData=function(r){if(!this.option.selectedMap){var n=[];r.hasItemOption&&r.each(function(i){var a=r.getRawDataItem(i);a&&a.selected&&n.push(i)}),n.length>0&&this._innerSelect(r,n)}},t.registerClass=function(r){return dt.registerClass(r)},t.protoInitialize=(function(){var r=t.prototype;r.type="series.__base__",r.seriesIndex=0,r.ignoreStyleOnData=!1,r.hasSymbolVisual=!1,r.defaultSymbol="circle",r.visualStyleAccessPath="itemStyle",r.visualDrawType="fill"})(),t})(dt);Ke(Hr,FT);Ke(Hr,iv);qg(Hr,dt);function cd(e){var t=e.name;Rm(e)||(e.name=sC(e)||t)}function sC(e){var t=e.getRawData(),r=t.mapDimensionsAll("seriesName"),n=[];return M(r,function(i){var a=t.getDimensionInfo(i);a.displayName&&n.push(a.displayName)}),n.join(" ")}function lC(e){return e.model.getRawData().count()}function uC(e){var t=e.model;return t.setData(t.getRawData().cloneShallow()),fC}function fC(e,t){t.outputData&&e.end>t.outputData.count()&&t.model.getRawData().cloneShallow(t.outputData)}function dd(e,t){M(R1(e.CHANGABLE_METHODS,e.DOWNSAMPLE_METHODS),function(r){e.wrapMethod(r,ne(hC,t))})}function hC(e,t){var r=Nf(e);return r&&r.setOutputEnd((t||this).count()),t}function Nf(e){var t=(e.ecModel||{}).scheduler,r=t&&t.getPipeline(e.uid);if(r){var n=r.currentTask;if(n){var i=n.agentStubMap;i&&(n=i.get(e.uid))}return n}}var vC=ht.extend({type:"triangle",shape:{cx:0,cy:0,width:0,height:0},buildPath:function(e,t){var r=t.cx,n=t.cy,i=t.width/2,a=t.height/2;e.moveTo(r,n-a),e.lineTo(r+i,n+a),e.lineTo(r-i,n+a),e.closePath()}}),cC=ht.extend({type:"diamond",shape:{cx:0,cy:0,width:0,height:0},buildPath:function(e,t){var r=t.cx,n=t.cy,i=t.width/2,a=t.height/2;e.moveTo(r,n-a),e.lineTo(r+i,n),e.lineTo(r,n+a),e.lineTo(r-i,n),e.closePath()}}),dC=ht.extend({type:"pin",shape:{x:0,y:0,width:0,height:0},buildPath:function(e,t){var r=t.x,n=t.y,i=t.width/5*3,a=Math.max(i,t.height),o=i/2,s=o*o/(a-o),l=n-a+o+s,u=Math.asin(s/o),f=Math.cos(u)*o,h=Math.sin(u),c=Math.cos(u),v=o*.6,d=o*.7;e.moveTo(r-f,l+s),e.arc(r,l,o,Math.PI-u,Math.PI*2+u),e.bezierCurveTo(r+f-h*v,l+s+c*v,r,n-d,r,n),e.bezierCurveTo(r,n-d,r-f+h*v,l+s+c*v,r-f,l+s),e.closePath()}}),pC=ht.extend({type:"arrow",shape:{x:0,y:0,width:0,height:0},buildPath:function(e,t){var r=t.height,n=t.width,i=t.x,a=t.y,o=n/3*2;e.moveTo(i,a),e.lineTo(i+o,a+r),e.lineTo(i,a+r/4*3),e.lineTo(i-o,a+r),e.lineTo(i,a),e.closePath()}}),gC={line:Fr,rect:Tt,roundRect:Tt,square:Tt,circle:ll,diamond:cC,pin:dC,arrow:pC,triangle:vC},mC={line:function(e,t,r,n,i){i.x1=e,i.y1=t+n/2,i.x2=e+r,i.y2=t+n/2},rect:function(e,t,r,n,i){i.x=e,i.y=t,i.width=r,i.height=n},roundRect:function(e,t,r,n,i){i.x=e,i.y=t,i.width=r,i.height=n,i.r=Math.min(r,n)/4},square:function(e,t,r,n,i){var a=Math.min(r,n);i.x=e,i.y=t,i.width=a,i.height=a},circle:function(e,t,r,n,i){i.cx=e+r/2,i.cy=t+n/2,i.r=Math.min(r,n)/2},diamond:function(e,t,r,n,i){i.cx=e+r/2,i.cy=t+n/2,i.width=r,i.height=n},pin:function(e,t,r,n,i){i.x=e+r/2,i.y=t+n/2,i.width=r,i.height=n},arrow:function(e,t,r,n,i){i.x=e+r/2,i.y=t+n/2,i.width=r,i.height=n},triangle:function(e,t,r,n,i){i.cx=e+r/2,i.cy=t+n/2,i.width=r,i.height=n}},Is={};M(gC,function(e,t){Is[t]=new e});var yC=ht.extend({type:"symbol",shape:{symbolType:"",x:0,y:0,width:0,height:0},calculateTextPosition:function(e,t,r){var n=rm(e,t,r),i=this.shape;return i&&i.symbolType==="pin"&&t.position==="inside"&&(n.y=r.y+r.height*.4),n},buildPath:function(e,t,r){var n=t.symbolType;if(n!=="none"){var i=Is[n];i||(n="rect",i=Is[n]),mC[n](t.x,t.y,t.width,t.height,i.shape),i.buildPath(e,i.shape,r)}}});function _C(e,t){if(this.type!=="image"){var r=this.style;this.__isEmptyBrush?(r.stroke=e,r.fill=t||Y.color.neutral00,r.lineWidth=2):this.shape.symbolType==="line"?r.stroke=e:r.fill=e,this.markRedraw()}}function Bn(e,t,r,n,i,a,o){var s=e.indexOf("empty")===0;s&&(e=e.substr(5,1).toLowerCase()+e.substr(6));var l;return e.indexOf("image://")===0?l=ry(e.slice(8),new it(t,r,n,i),o?"center":"cover"):e.indexOf("path://")===0?l=Nh(e.slice(7),{},new it(t,r,n,i),o?"center":"cover"):l=new yC({shape:{symbolType:e,x:t,y:r,width:n,height:i}}),l.__isEmptyBrush=s,l.setColor=_C,a&&l.setColor(a),l}function SC(e){return z(e)||(e=[+e,+e]),[e[0]||0,e[1]||0]}function s0(e,t){if(e!=null)return z(e)||(e=[e,e]),[It(e[0],t[0])||0,It(q(e[1],e[0]),t[1])||0]}var bC=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type=t.type,r.hasSymbolVisual=!0,r}return t.prototype.getInitialData=function(r){return tT(null,this,{useEncodeDefaulter:!0})},t.prototype.getLegendIcon=function(r){var n=new Ft,i=Bn("line",0,r.itemHeight/2,r.itemWidth,0,r.lineStyle.stroke,!1);n.add(i),i.setStyle(r.lineStyle);var a=this.getData().getVisual("symbol"),o=this.getData().getVisual("symbolRotate"),s=a==="none"?"circle":a,l=r.itemHeight*.8,u=Bn(s,(r.itemWidth-l)/2,(r.itemHeight-l)/2,l,l,r.itemStyle.fill);n.add(u),u.setStyle(r.itemStyle);var f=r.iconRotate==="inherit"?o:r.iconRotate||0;return u.rotation=f*Math.PI/180,u.setOrigin([r.itemWidth/2,r.itemHeight/2]),s.indexOf("empty")>-1&&(u.style.stroke=u.style.fill,u.style.fill=Y.color.neutral00,u.style.lineWidth=2),n},t.type="series.line",t.dependencies=["grid","polar"],t.defaultOption={z:3,coordinateSystem:"cartesian2d",legendHoverLink:!0,clip:!0,label:{position:"top"},endLabel:{show:!1,valueAnimation:!0,distance:8},lineStyle:{width:2,type:"solid"},emphasis:{scale:!0},step:!1,smooth:!1,smoothMonotone:null,symbol:"emptyCircle",symbolSize:6,symbolRotate:null,showSymbol:!0,showAllSymbol:"auto",connectNulls:!1,sampling:"none",animationEasing:"linear",progressive:0,hoverLayerThreshold:1/0,universalTransition:{divideShape:"clone"},triggerLineEvent:!1},t})(Hr);function l0(e,t){var r=e.mapDimensionsAll("defaultedLabel"),n=r.length;if(n===1){var i=Di(e,t,r[0]);return i!=null?i+"":null}else if(n){for(var a=[],o=0;o<r.length;o++)a.push(Di(e,t,r[o]));return a.join(" ")}}function wC(e,t){var r=e.mapDimensionsAll("defaultedLabel");if(!z(t))return t+"";for(var n=[],i=0;i<r.length;i++){var a=e.getDimensionIndex(r[i]);a>=0&&n.push(t[a])}return n.join(" ")}var ov=(function(e){N(t,e);function t(r,n,i,a){var o=e.call(this)||this;return o.updateData(r,n,i,a),o}return t.prototype._createSymbol=function(r,n,i,a,o,s){this.removeAll();var l=Bn(r,-1,-1,2,2,null,s);l.attr({z2:q(o,100),culling:!0,scaleX:a[0]/2,scaleY:a[1]/2}),l.drift=xC,this._symbolType=r,this.add(l)},t.prototype.stopSymbolAnimation=function(r){this.childAt(0).stopAnimation(null,r)},t.prototype.getSymbolType=function(){return this._symbolType},t.prototype.getSymbolPath=function(){return this.childAt(0)},t.prototype.highlight=function(){ws(this.childAt(0))},t.prototype.downplay=function(){xs(this.childAt(0))},t.prototype.setZ=function(r,n){var i=this.childAt(0);i.zlevel=r,i.z=n},t.prototype.setDraggable=function(r,n){var i=this.childAt(0);i.draggable=r,i.cursor=!n&&r?"move":i.cursor},t.prototype.updateData=function(r,n,i,a){this.silent=!1;var o=r.getItemVisual(n,"symbol")||"circle",s=r.hostModel,l=t.getSymbolSize(r,n),u=t.getSymbolZ2(r,n),f=o!==this._symbolType,h=a&&a.disableAnimation;if(f){var c=r.getItemVisual(n,"symbolKeepAspect");this._createSymbol(o,r,n,l,u,c)}else{var v=this.childAt(0);v.silent=!1;var d={scaleX:l[0]/2,scaleY:l[1]/2};h?v.attr(d):qe(v,d,s,n),Bw(v)}if(this._updateCommon(r,n,l,i,a),f){var v=this.childAt(0);if(!h){var d={scaleX:this._sizeX,scaleY:this._sizeY,style:{opacity:v.style.opacity}};v.scaleX=v.scaleY=0,v.style.opacity=0,vr(v,d,s,n)}}h&&this.childAt(0).stopAnimation("leave")},t.prototype._updateCommon=function(r,n,i,a,o){var s=this.childAt(0),l=r.hostModel,u,f,h,c,v,d,p,g,m;if(a&&(u=a.emphasisItemStyle,f=a.blurItemStyle,h=a.selectItemStyle,c=a.focus,v=a.blurScope,p=a.labelStatesModels,g=a.hoverScale,m=a.cursorStyle,d=a.emphasisDisabled),!a||r.hasItemOption){var y=a&&a.itemModel?a.itemModel:r.getItemModel(n),_=y.getModel("emphasis");u=_.getModel("itemStyle").getItemStyle(),h=y.getModel(["select","itemStyle"]).getItemStyle(),f=y.getModel(["blur","itemStyle"]).getItemStyle(),c=_.get("focus"),v=_.get("blurScope"),d=_.get("disabled"),p=Gh(y),g=_.getShallow("scale"),m=y.getShallow("cursor")}var S=r.getItemVisual(n,"symbolRotate");s.attr("rotation",(S||0)*Math.PI/180||0);var w=s0(r.getItemVisual(n,"symbolOffset"),i);w&&(s.x=w[0],s.y=w[1]),m&&s.attr("cursor",m);var b=r.getItemVisual(n,"style"),x=b.fill;if(s instanceof Gr){var C=s.style;s.useStyle(k({image:C.image,x:C.x,y:C.y,width:C.width,height:C.height},b))}else s.__isEmptyBrush?s.useStyle(k({},b)):s.useStyle(b),s.style.decal=null,s.setColor(x,o&&o.symbolInnerColor),s.style.strokeNoScale=!0;var T=r.getItemVisual(n,"liftZ"),D=this._z2;T!=null?D==null&&(this._z2=s.z2,s.z2+=T):D!=null&&(s.z2=D,this._z2=null);var A=o&&o.useNameLabel;cy(s,p,{labelFetcher:l,labelDataIndex:n,defaultText:P,inheritColor:x,defaultOpacity:b.opacity});function P(R){return A?r.getName(R):l0(r,R)}this._sizeX=i[0]/2,this._sizeY=i[1]/2;var L=s.ensureState("emphasis");L.style=u,s.ensureState("select").style=h,s.ensureState("blur").style=f;var I=g==null||g===!0?Math.max(1.1,3/this._sizeY):isFinite(g)&&g>0?+g:1;L.scaleX=this._sizeX*I,L.scaleY=this._sizeY*I,this.setSymbolScale(1),bf(this,c,v,d)},t.prototype.setSymbolScale=function(r){this.scaleX=this.scaleY=r},t.prototype.fadeOut=function(r,n,i){var a=this.childAt(0),o=pt(this).dataIndex,s=i&&i.animation;if(this.silent=a.silent=!0,i&&i.fadeLabel){var l=a.getTextContent();l&&Ts(l,{style:{opacity:0}},n,{dataIndex:o,removeOpt:s,cb:function(){a.removeTextContent()}})}else a.removeTextContent();Ts(a,{style:{opacity:0},scaleX:0,scaleY:0},n,{dataIndex:o,cb:r,removeOpt:s})},t.getSymbolSize=function(r,n){return SC(r.getItemVisual(n,"symbolSize"))},t.getSymbolZ2=function(r,n){return r.getItemVisual(n,"z2")},t})(Ft);function xC(e,t){this.parent.drift(e,t)}function su(e,t,r,n){return t&&!isNaN(t[0])&&!isNaN(t[1])&&!(n.isIgnore&&n.isIgnore(r))&&!(n.clipShape&&!n.clipShape.contain(t[0],t[1]))&&e.getItemVisual(r,"symbol")!=="none"}function pd(e){return e!=null&&!X(e)&&(e={isIgnore:e}),e||{}}function gd(e){var t=e.hostModel,r=t.getModel("emphasis");return{emphasisItemStyle:r.getModel("itemStyle").getItemStyle(),blurItemStyle:t.getModel(["blur","itemStyle"]).getItemStyle(),selectItemStyle:t.getModel(["select","itemStyle"]).getItemStyle(),focus:r.get("focus"),blurScope:r.get("blurScope"),emphasisDisabled:r.get("disabled"),hoverScale:r.get("scale"),labelStatesModels:Gh(t),cursorStyle:t.get("cursor")}}var TC=(function(){function e(t){this.group=new Ft,this._SymbolCtor=t||ov}return e.prototype.updateData=function(t,r){this._progressiveEls=null,r=pd(r);var n=this.group,i=t.hostModel,a=this._data,o=this._SymbolCtor,s=r.disableAnimation,l=gd(t),u={disableAnimation:s},f=r.getSymbolPoint||function(h){return t.getItemLayout(h)};a||n.removeAll(),t.diff(a).add(function(h){var c=f(h);if(su(t,c,h,r)){var v=new o(t,h,l,u);v.setPosition(c),t.setItemGraphicEl(h,v),n.add(v)}}).update(function(h,c){var v=a.getItemGraphicEl(c),d=f(h);if(!su(t,d,h,r)){n.remove(v);return}var p=t.getItemVisual(h,"symbol")||"circle",g=v&&v.getSymbolType&&v.getSymbolType();if(!v||g&&g!==p)n.remove(v),v=new o(t,h,l,u),v.setPosition(d);else{v.updateData(t,h,l,u);var m={x:d[0],y:d[1]};s?v.attr(m):qe(v,m,i)}n.add(v),t.setItemGraphicEl(h,v)}).remove(function(h){var c=a.getItemGraphicEl(h);c&&c.fadeOut(function(){n.remove(c)},i)}).execute(),this._getSymbolPoint=f,this._data=t},e.prototype.updateLayout=function(){var t=this,r=this._data;r&&r.eachItemGraphicEl(function(n,i){var a=t._getSymbolPoint(i);n.setPosition(a),n.markRedraw()})},e.prototype.incrementalPrepareUpdate=function(t){this._seriesScope=gd(t),this._data=null,this.group.removeAll()},e.prototype.incrementalUpdate=function(t,r,n){this._progressiveEls=[],n=pd(n);function i(l){l.isGroup||(l.incremental=!0,l.ensureState("emphasis").hoverLayer=!0)}for(var a=t.start;a<t.end;a++){var o=r.getItemLayout(a);if(su(r,o,a,n)){var s=new this._SymbolCtor(r,a,this._seriesScope);s.traverse(i),s.setPosition(o),this.group.add(s),r.setItemGraphicEl(a,s),this._progressiveEls.push(s)}}},e.prototype.eachRendered=function(t){zh(this._progressiveEls||this.group,t)},e.prototype.remove=function(t){var r=this.group,n=this._data;n&&t?n.eachItemGraphicEl(function(i){i.fadeOut(function(){r.remove(i)},n.hostModel)}):r.removeAll()},e})();function u0(e,t,r){var n=e.getBaseAxis(),i=e.getOtherAxis(n),a=CC(i,r),o=n.dim,s=i.dim,l=t.mapDimension(s),u=t.mapDimension(o),f=s==="x"||s==="radius"?1:0,h=$(e.dimensions,function(d){return t.mapDimension(d)}),c=!1,v=t.getCalculationInfo("stackResultDimension");return Fa(t,h[0])&&(c=!0,h[0]=v),Fa(t,h[1])&&(c=!0,h[1]=v),{dataDimsForPoint:h,valueStart:a,valueAxisDim:s,baseAxisDim:o,stacked:!!c,valueDim:l,baseDim:u,baseDataOffset:f,stackedOverDimension:t.getCalculationInfo("stackedOverDimension")}}function CC(e,t){var r=0,n=e.scale.getExtent();return t==="start"?r=n[0]:t==="end"?r=n[1]:mt(t)&&!isNaN(t)?r=t:n[0]>0?r=n[0]:n[1]<0&&(r=n[1]),r}function f0(e,t,r,n){var i=NaN;e.stacked&&(i=r.get(r.getCalculationInfo("stackedOverDimension"),n)),isNaN(i)&&(i=e.valueStart);var a=e.baseDataOffset,o=[];return o[a]=r.get(e.baseDim,n),o[1-a]=i,t.dataToPoint(o)}var h0=typeof Float32Array<"u",MC=h0?Float32Array:Array;function di(e){return z(e)?h0?new Float32Array(e):e:new MC(e)}function DC(e,t){var r=[];return t.diff(e).add(function(n){r.push({cmd:"+",idx:n})}).update(function(n,i){r.push({cmd:"=",idx:i,idx1:n})}).remove(function(n){r.push({cmd:"-",idx:n})}).execute(),r}function AC(e,t,r,n,i,a,o,s){for(var l=DC(e,t),u=[],f=[],h=[],c=[],v=[],d=[],p=[],g=u0(i,t,o),m=e.getLayout("points")||[],y=t.getLayout("points")||[],_=0;_<l.length;_++){var S=l[_],w=!0,b=void 0,x=void 0;switch(S.cmd){case"=":b=S.idx*2,x=S.idx1*2;var C=m[b],T=m[b+1],D=y[x],A=y[x+1];(isNaN(C)||isNaN(T))&&(C=D,T=A),u.push(C,T),f.push(D,A),h.push(r[b],r[b+1]),c.push(n[x],n[x+1]),p.push(t.getRawIndex(S.idx1));break;case"+":var P=S.idx,L=g.dataDimsForPoint,I=i.dataToPoint([t.get(L[0],P),t.get(L[1],P)]);x=P*2,u.push(I[0],I[1]),f.push(y[x],y[x+1]);var R=f0(g,i,t,P);h.push(R[0],R[1]),c.push(n[x],n[x+1]),p.push(t.getRawIndex(P));break;case"-":w=!1}w&&(v.push(S),d.push(d.length))}d.sort(function(yt,Ht){return p[yt]-p[Ht]});for(var E=u.length,G=di(E),F=di(E),H=di(E),V=di(E),U=[],_=0;_<d.length;_++){var Z=d[_],J=_*2,ot=Z*2;G[J]=u[ot],G[J+1]=u[ot+1],F[J]=f[ot],F[J+1]=f[ot+1],H[J]=h[ot],H[J+1]=h[ot+1],V[J]=c[ot],V[J+1]=c[ot+1],U[_]=v[Z]}return{current:G,next:F,stackedOnCurrent:H,stackedOnNext:V,status:U}}var _r=Math.min,Sr=Math.max;function Pn(e,t){return isNaN(e)||isNaN(t)}function Ff(e,t,r,n,i,a,o,s,l){for(var u,f,h,c,v,d,p=r,g=0;g<n;g++){var m=t[p*2],y=t[p*2+1];if(p>=i||p<0)break;if(Pn(m,y)){if(l){p+=a;continue}break}if(p===r)e[a>0?"moveTo":"lineTo"](m,y),h=m,c=y;else{var _=m-u,S=y-f;if(_*_+S*S<.5){p+=a;continue}if(o>0){for(var w=p+a,b=t[w*2],x=t[w*2+1];b===m&&x===y&&g<n;)g++,w+=a,p+=a,b=t[w*2],x=t[w*2+1],m=t[p*2],y=t[p*2+1],_=m-u,S=y-f;var C=g+1;if(l)for(;Pn(b,x)&&C<n;)C++,w+=a,b=t[w*2],x=t[w*2+1];var T=.5,D=0,A=0,P=void 0,L=void 0;if(C>=n||Pn(b,x))v=m,d=y;else{D=b-u,A=x-f;var I=m-u,R=b-m,E=y-f,G=x-y,F=void 0,H=void 0;if(s==="x"){F=Math.abs(I),H=Math.abs(R);var V=D>0?1:-1;v=m-V*F*o,d=y,P=m+V*H*o,L=y}else if(s==="y"){F=Math.abs(E),H=Math.abs(G);var U=A>0?1:-1;v=m,d=y-U*F*o,P=m,L=y+U*H*o}else F=Math.sqrt(I*I+E*E),H=Math.sqrt(R*R+G*G),T=H/(H+F),v=m-D*o*(1-T),d=y-A*o*(1-T),P=m+D*o*T,L=y+A*o*T,P=_r(P,Sr(b,m)),L=_r(L,Sr(x,y)),P=Sr(P,_r(b,m)),L=Sr(L,_r(x,y)),D=P-m,A=L-y,v=m-D*F/H,d=y-A*F/H,v=_r(v,Sr(u,m)),d=_r(d,Sr(f,y)),v=Sr(v,_r(u,m)),d=Sr(d,_r(f,y)),D=m-v,A=y-d,P=m+D*H/F,L=y+A*H/F}e.bezierCurveTo(h,c,v,d,m,y),h=P,c=L}else e.lineTo(m,y)}u=m,f=y,p+=a}return g}var v0=(function(){function e(){this.smooth=0,this.smoothConstraint=!0}return e})(),LC=(function(e){N(t,e);function t(r){var n=e.call(this,r)||this;return n.type="ec-polyline",n}return t.prototype.getDefaultStyle=function(){return{stroke:Y.color.neutral99,fill:null}},t.prototype.getDefaultShape=function(){return new v0},t.prototype.buildPath=function(r,n){var i=n.points,a=0,o=i.length/2;if(n.connectNulls){for(;o>0&&Pn(i[o*2-2],i[o*2-1]);o--);for(;a<o&&Pn(i[a*2],i[a*2+1]);a++);}for(;a<o;)a+=Ff(r,i,a,o,o,1,n.smooth,n.smoothMonotone,n.connectNulls)+1},t.prototype.getPointOn=function(r,n){this.path||(this.createPathProxy(),this.buildPath(this.path,this.shape));for(var i=this.path,a=i.data,o=hr.CMD,s,l,u=n==="x",f=[],h=0;h<a.length;){var c=a[h++],v=void 0,d=void 0,p=void 0,g=void 0,m=void 0,y=void 0,_=void 0;switch(c){case o.M:s=a[h++],l=a[h++];break;case o.L:if(v=a[h++],d=a[h++],_=u?(r-s)/(v-s):(r-l)/(d-l),_<=1&&_>=0){var S=u?(d-l)*_+l:(v-s)*_+s;return u?[r,S]:[S,r]}s=v,l=d;break;case o.C:v=a[h++],d=a[h++],p=a[h++],g=a[h++],m=a[h++],y=a[h++];var w=u?cs(s,v,p,m,r,f):cs(l,d,g,y,r,f);if(w>0)for(var b=0;b<w;b++){var x=f[b];if(x<=1&&x>=0){var S=u?Lt(l,d,g,y,x):Lt(s,v,p,m,x);return u?[r,S]:[S,r]}}s=m,l=y;break}}},t})(ht),IC=(function(e){N(t,e);function t(){return e!==null&&e.apply(this,arguments)||this}return t})(v0),PC=(function(e){N(t,e);function t(r){var n=e.call(this,r)||this;return n.type="ec-polygon",n}return t.prototype.getDefaultShape=function(){return new IC},t.prototype.buildPath=function(r,n){var i=n.points,a=n.stackedOnPoints,o=0,s=i.length/2,l=n.smoothMonotone;if(n.connectNulls){for(;s>0&&Pn(i[s*2-2],i[s*2-1]);s--);for(;o<s&&Pn(i[o*2],i[o*2+1]);o++);}for(;o<s;){var u=Ff(r,i,o,s,s,1,n.smooth,l,n.connectNulls);Ff(r,a,o+u-1,u,s,-1,n.stackedOnSmooth,l,n.connectNulls),o+=u+1,r.closePath()}},t})(ht);function c0(){var e=gt();return function(t){var r=e(t),n=t.pipelineContext,i=!!r.large,a=!!r.progressiveRender,o=r.large=!!(n&&n.large),s=r.progressiveRender=!!(n&&n.progressiveRender);return(i!==o||a!==s)&&"reset"}}var d0=gt(),RC=c0(),$e=(function(){function e(){this.group=new Ft,this.uid=pl("viewChart"),this.renderTask=Ta({plan:EC,reset:kC}),this.renderTask.context={view:this}}return e.prototype.init=function(t,r){},e.prototype.render=function(t,r,n,i){},e.prototype.highlight=function(t,r,n,i){var a=t.getData(i&&i.dataType);a&&yd(a,i,"emphasis")},e.prototype.downplay=function(t,r,n,i){var a=t.getData(i&&i.dataType);a&&yd(a,i,"normal")},e.prototype.remove=function(t,r){this.group.removeAll()},e.prototype.dispose=function(t,r){},e.prototype.updateView=function(t,r,n,i){this.render(t,r,n,i)},e.prototype.updateLayout=function(t,r,n,i){this.render(t,r,n,i)},e.prototype.updateVisual=function(t,r,n,i){this.render(t,r,n,i)},e.prototype.eachRendered=function(t){zh(this.group,t)},e.markUpdateMethod=function(t,r){d0(t).updateMethod=r},e.protoInitialize=(function(){var t=e.prototype;t.type="chart"})(),e})();function md(e,t,r){e&&wf(e)&&(t==="emphasis"?ws:xs)(e,r)}function yd(e,t,r){var n=En(e,t),i=t&&t.highlightKey!=null?aw(t.highlightKey):null;n!=null?M(Mt(n),function(a){md(e.getItemGraphicEl(a),r,i)}):e.eachItemGraphicEl(function(a){md(a,r,i)})}Sh($e);js($e);function EC(e){return RC(e.model)}function kC(e){var t=e.model,r=e.ecModel,n=e.api,i=e.payload,a=t.pipelineContext.progressiveRender,o=e.view,s=i&&d0(i).updateMethod,l=a?"incrementalPrepareRender":s&&o[s]?s:"render";return l!=="render"&&o[l](t,r,n,i),OC[l]}var OC={incrementalPrepareRender:{progress:function(e,t){t.view.incrementalRender(e,t.model,t.ecModel,t.api,t.payload)}},render:{forceFirstProgress:!0,progress:function(e,t){t.view.render(t.model,t.ecModel,t.api,t.payload)}}};function BC(e,t,r,n,i){var a=e.getArea(),o=a.x,s=a.y,l=a.width,u=a.height,f=r.get(["lineStyle","width"])||0;o-=f/2,s-=f/2,l+=f,u+=f,l=Math.ceil(l),o!==Math.floor(o)&&(o=Math.floor(o),l++);var h=new Tt({shape:{x:o,y:s,width:l,height:u}});if(t){var c=e.getBaseAxis(),v=c.isHorizontal(),d=c.inverse;v?(d&&(h.shape.x+=l),h.shape.width=0):(d||(h.shape.y+=u),h.shape.height=0);var p=et(i)?function(g){i(g,h)}:null;vr(h,{shape:{width:l,height:u,x:o,y:s}},r,null,n,p)}return h}function NC(e,t,r){var n=e.getArea(),i=Nt(n.r0,1),a=Nt(n.r,1),o=new Ci({shape:{cx:Nt(e.cx,1),cy:Nt(e.cy,1),r0:i,r:a,startAngle:n.startAngle,endAngle:n.endAngle,clockwise:n.clockwise}});if(t){var s=e.getBaseAxis().dim==="angle";s?o.shape.endAngle=n.startAngle:o.shape.r=i,vr(o,{shape:{endAngle:n.endAngle,r:a}},r)}return o}function FC(e,t){return e.type===t}function _d(e,t){if(e.length===t.length){for(var r=0;r<e.length;r++)if(e[r]!==t[r])return;return!0}}function Sd(e){for(var t=1/0,r=1/0,n=-1/0,i=-1/0,a=0;a<e.length;){var o=e[a++],s=e[a++];isNaN(o)||(t=Math.min(o,t),n=Math.max(o,n)),isNaN(s)||(r=Math.min(s,r),i=Math.max(s,i))}return[[t,r],[n,i]]}function bd(e,t){var r=Sd(e),n=r[0],i=r[1],a=Sd(t),o=a[0],s=a[1];return Math.max(Math.abs(n[0]-o[0]),Math.abs(n[1]-o[1]),Math.abs(i[0]-s[0]),Math.abs(i[1]-s[1]))}function wd(e){return mt(e)?e:e?.5:0}function zC(e,t,r){if(!r.valueDim)return[];for(var n=t.count(),i=di(n*2),a=0;a<n;a++){var o=f0(r,e,t,a);i[a*2]=o[0],i[a*2+1]=o[1]}return i}function br(e,t,r,n,i){var a=r.getBaseAxis(),o=a.dim==="x"||a.dim==="radius"?0:1,s=[],l=0,u=[],f=[],h=[],c=[];if(i){for(l=0;l<e.length;l+=2){var v=t||e;!isNaN(v[l])&&!isNaN(v[l+1])&&c.push(e[l],e[l+1])}e=c}for(l=0;l<e.length-2;l+=2)switch(h[0]=e[l+2],h[1]=e[l+3],f[0]=e[l],f[1]=e[l+1],s.push(f[0],f[1]),n){case"end":u[o]=h[o],u[1-o]=f[1-o],s.push(u[0],u[1]);break;case"middle":var d=(f[o]+h[o])/2,p=[];u[o]=p[o]=d,u[1-o]=f[1-o],p[1-o]=h[1-o],s.push(u[0],u[1]),s.push(p[0],p[1]);break;default:u[o]=f[o],u[1-o]=h[1-o],s.push(u[0],u[1])}return s.push(e[l++],e[l++]),s}function HC(e,t){var r=[],n=e.length,i,a;function o(f,h,c){var v=f.coord,d=(c-v)/(h.coord-v),p=xS(d,[f.color,h.color]);return{coord:c,color:p}}for(var s=0;s<n;s++){var l=e[s],u=l.coord;if(u<0)i=l;else if(u>t){a?r.push(o(a,l,t)):i&&r.push(o(i,l,0),o(i,l,t));break}else i&&(r.push(o(i,l,0)),i=null),r.push(l),a=l}return r}function VC(e,t,r){var n=e.getVisual("visualMeta");if(!(!n||!n.length||!e.count())&&t.type==="cartesian2d"){for(var i,a,o=n.length-1;o>=0;o--){var s=e.getDimensionInfo(n[o].dimension);if(i=s&&s.coordDim,i==="x"||i==="y"){a=n[o];break}}if(a){var l=t.getAxis(i),u=$(a.stops,function(_){return{coord:l.toGlobalCoord(l.dataToCoord(_.value)),color:_.color}}),f=u.length,h=a.outerColors.slice();f&&u[0].coord>u[f-1].coord&&(u.reverse(),h.reverse());var c=HC(u,i==="x"?r.getWidth():r.getHeight()),v=c.length;if(!v&&f)return u[0].coord<0?h[1]?h[1]:u[f-1].color:h[0]?h[0]:u[0].color;var d=10,p=c[0].coord-d,g=c[v-1].coord+d,m=g-p;if(m<.001)return"transparent";M(c,function(_){_.offset=(_.coord-p)/m}),c.push({offset:v?c[v-1].offset:.5,color:h[1]||"transparent"}),c.unshift({offset:v?c[0].offset:.5,color:h[0]||"transparent"});var y=new jm(0,0,0,0,c,!0);return y[i]=p,y[i+"2"]=g,y}}}function GC(e,t,r){var n=e.get("showAllSymbol"),i=n==="auto";if(!(n&&!i)){var a=r.getAxesByScale("ordinal")[0];if(a&&!(i&&WC(a,t))){var o=t.mapDimension(a.dim),s={};return M(a.getViewLabels(),function(l){var u=a.scale.getRawOrdinalNumber(l.tickValue);s[u]=1}),function(l){return!s.hasOwnProperty(t.get(o,l))}}}}function WC(e,t){var r=e.getExtent(),n=Math.abs(r[1]-r[0])/e.scale.count();isNaN(n)&&(n=0);for(var i=t.count(),a=Math.max(1,Math.round(i/5)),o=0;o<i;o+=a)if(ov.getSymbolSize(t,o)[e.isHorizontal()?1:0]*1.5>n)return!1;return!0}function UC(e,t){return isNaN(e)||isNaN(t)}function YC(e){for(var t=e.length/2;t>0&&UC(e[t*2-2],e[t*2-1]);t--);return t-1}function xd(e,t){return[e[t*2],e[t*2+1]]}function ZC(e,t,r){for(var n=e.length/2,i=r==="x"?0:1,a,o,s=0,l=-1,u=0;u<n;u++)if(o=e[u*2+i],!(isNaN(o)||isNaN(e[u*2+1-i]))){if(u===0){a=o;continue}if(a<=t&&o>=t||a>=t&&o<=t){l=u;break}s=u,a=o}return{range:[s,l],t:(t-a)/(o-a)}}function p0(e){if(e.get(["endLabel","show"]))return!0;for(var t=0;t<xe.length;t++)if(e.get([xe[t],"endLabel","show"]))return!0;return!1}function lu(e,t,r,n){if(FC(t,"cartesian2d")){var i=n.getModel("endLabel"),a=i.get("valueAnimation"),o=n.getData(),s={lastFrameIndex:0},l=p0(n)?function(v,d){e._endLabelOnDuring(v,d,o,s,a,i,t)}:null,u=t.getBaseAxis().isHorizontal(),f=BC(t,r,n,function(){var v=e._endLabel;v&&r&&s.originalX!=null&&v.attr({x:s.originalX,y:s.originalY})},l);if(!n.get("clip",!0)){var h=f.shape,c=Math.max(h.width,h.height);u?(h.y-=c,h.height+=c*2):(h.x-=c,h.width+=c*2)}return l&&l(1,f),f}else return NC(t,r,n)}function XC(e,t){var r=t.getBaseAxis(),n=r.isHorizontal(),i=r.inverse,a=n?i?"right":"left":"center",o=n?"middle":i?"top":"bottom";return{normal:{align:e.get("align")||a,verticalAlign:e.get("verticalAlign")||o}}}var $C=(function(e){N(t,e);function t(){return e!==null&&e.apply(this,arguments)||this}return t.prototype.init=function(){var r=new Ft,n=new TC;this.group.add(n.group),this._symbolDraw=n,this._lineGroup=r,this._changePolyState=Q(this._changePolyState,this)},t.prototype.render=function(r,n,i){var a=r.coordinateSystem,o=this.group,s=r.getData(),l=r.getModel("lineStyle"),u=r.getModel("areaStyle"),f=s.getLayout("points")||[],h=a.type==="polar",c=this._coordSys,v=this._symbolDraw,d=this._polyline,p=this._polygon,g=this._lineGroup,m=!n.ssr&&r.get("animation"),y=!u.isEmpty(),_=u.get("origin"),S=u0(a,s,_),w=y&&zC(a,s,S),b=r.get("showSymbol"),x=r.get("connectNulls"),C=b&&!h&&GC(r,s,a),T=this._data;T&&T.eachItemGraphicEl(function(yt,Ht){yt.__temp&&(o.remove(yt),T.setItemGraphicEl(Ht,null))}),b||v.remove(),o.add(g);var D=h?!1:r.get("step"),A;a&&a.getArea&&r.get("clip",!0)&&(A=a.getArea(),A.width!=null?(A.x-=.1,A.y-=.1,A.width+=.2,A.height+=.2):A.r0&&(A.r0-=.5,A.r+=.5)),this._clipShapeForSymbol=A;var P=VC(s,a,i)||s.getVisual("style")[s.getVisual("drawType")];if(!(d&&c.type===a.type&&D===this._step))b&&v.updateData(s,{isIgnore:C,clipShape:A,disableAnimation:!0,getSymbolPoint:function(yt){return[f[yt*2],f[yt*2+1]]}}),m&&this._initSymbolLabelAnimation(s,a,A),D&&(w&&(w=br(w,f,a,D,x)),f=br(f,null,a,D,x)),d=this._newPolyline(f),y?p=this._newPolygon(f,w):p&&(g.remove(p),p=this._polygon=null),h||this._initOrUpdateEndLabel(r,a,kn(P)),g.setClipPath(lu(this,a,!0,r));else{y&&!p?p=this._newPolygon(f,w):p&&!y&&(g.remove(p),p=this._polygon=null),h||this._initOrUpdateEndLabel(r,a,kn(P));var L=g.getClipPath();if(L){var I=lu(this,a,!1,r);vr(L,{shape:I.shape},r)}else g.setClipPath(lu(this,a,!0,r));b&&v.updateData(s,{isIgnore:C,clipShape:A,disableAnimation:!0,getSymbolPoint:function(yt){return[f[yt*2],f[yt*2+1]]}}),(!_d(this._stackedOnPoints,w)||!_d(this._points,f))&&(m?this._doUpdateAnimation(s,w,a,i,D,_,x):(D&&(w&&(w=br(w,f,a,D,x)),f=br(f,null,a,D,x)),d.setShape({points:f}),p&&p.setShape({points:f,stackedOnPoints:w})))}var R=r.getModel("emphasis"),E=R.get("focus"),G=R.get("blurScope"),F=R.get("disabled");if(d.useStyle(at(l.getLineStyle(),{fill:"none",stroke:P,lineJoin:"bevel"})),Dc(d,r,"lineStyle"),d.style.lineWidth>0&&r.get(["emphasis","lineStyle","width"])==="bolder"){var H=d.getState("emphasis").style;H.lineWidth=+d.style.lineWidth+1}pt(d).seriesIndex=r.seriesIndex,bf(d,E,G,F);var V=wd(r.get("smooth")),U=r.get("smoothMonotone");if(d.setShape({smooth:V,smoothMonotone:U,connectNulls:x}),p){var Z=s.getCalculationInfo("stackedOnSeries"),J=0;p.useStyle(at(u.getAreaStyle(),{fill:P,opacity:.7,lineJoin:"bevel",decal:s.getVisual("style").decal})),Z&&(J=wd(Z.get("smooth"))),p.setShape({smooth:V,stackedOnSmooth:J,smoothMonotone:U,connectNulls:x}),Dc(p,r,"areaStyle"),pt(p).seriesIndex=r.seriesIndex,bf(p,E,G,F)}var ot=this._changePolyState;s.eachItemGraphicEl(function(yt){yt&&(yt.onHoverStateChange=ot)}),this._polyline.onHoverStateChange=ot,this._data=s,this._coordSys=a,this._stackedOnPoints=w,this._points=f,this._step=D,this._valueOrigin=_,r.get("triggerLineEvent")&&(this.packEventData(r,d),p&&this.packEventData(r,p))},t.prototype.packEventData=function(r,n){pt(n).eventData={componentType:"series",componentSubType:"line",componentIndex:r.componentIndex,seriesIndex:r.seriesIndex,seriesName:r.name,seriesType:"line"}},t.prototype.highlight=function(r,n,i,a){var o=r.getData(),s=En(o,a);if(this._changePolyState("emphasis"),!(s instanceof Array)&&s!=null&&s>=0){var l=o.getLayout("points"),u=o.getItemGraphicEl(s);if(!u){var f=l[s*2],h=l[s*2+1];if(isNaN(f)||isNaN(h)||this._clipShapeForSymbol&&!this._clipShapeForSymbol.contain(f,h))return;var c=r.get("zlevel")||0,v=r.get("z")||0;u=new ov(o,s),u.x=f,u.y=h,u.setZ(c,v);var d=u.getSymbolPath().getTextContent();d&&(d.zlevel=c,d.z=v,d.z2=this._polyline.z2+1),u.__temp=!0,o.setItemGraphicEl(s,u),u.stopSymbolAnimation(!0),this.group.add(u)}u.highlight()}else $e.prototype.highlight.call(this,r,n,i,a)},t.prototype.downplay=function(r,n,i,a){var o=r.getData(),s=En(o,a);if(this._changePolyState("normal"),s!=null&&s>=0){var l=o.getItemGraphicEl(s);l&&(l.__temp?(o.setItemGraphicEl(s,null),this.group.remove(l)):l.downplay())}else $e.prototype.downplay.call(this,r,n,i,a)},t.prototype._changePolyState=function(r){var n=this._polygon;wc(this._polyline,r),n&&wc(n,r)},t.prototype._newPolyline=function(r){var n=this._polyline;return n&&this._lineGroup.remove(n),n=new LC({shape:{points:r},segmentIgnoreThreshold:2,z2:10}),this._lineGroup.add(n),this._polyline=n,n},t.prototype._newPolygon=function(r,n){var i=this._polygon;return i&&this._lineGroup.remove(i),i=new PC({shape:{points:r,stackedOnPoints:n},segmentIgnoreThreshold:2}),this._lineGroup.add(i),this._polygon=i,i},t.prototype._initSymbolLabelAnimation=function(r,n,i){var a,o,s=n.getBaseAxis(),l=s.inverse;n.type==="cartesian2d"?(a=s.isHorizontal(),o=!1):n.type==="polar"&&(a=s.dim==="angle",o=!0);var u=r.hostModel,f=u.get("animationDuration");et(f)&&(f=f(null));var h=u.get("animationDelay")||0,c=et(h)?h(null):h;r.eachItemGraphicEl(function(v,d){var p=v;if(p){var g=[v.x,v.y],m=void 0,y=void 0,_=void 0;if(i)if(o){var S=i,w=n.pointToCoord(g);a?(m=S.startAngle,y=S.endAngle,_=-w[1]/180*Math.PI):(m=S.r0,y=S.r,_=w[0])}else{var b=i;a?(m=b.x,y=b.x+b.width,_=v.x):(m=b.y+b.height,y=b.y,_=v.y)}var x=y===m?0:(_-m)/(y-m);l&&(x=1-x);var C=et(h)?h(d):f*x+c,T=p.getSymbolPath(),D=T.getTextContent();p.attr({scaleX:0,scaleY:0}),p.animateTo({scaleX:1,scaleY:1},{duration:200,setToFinal:!0,delay:C}),D&&D.animateFrom({style:{opacity:0}},{duration:300,delay:C}),T.disableLabelAnimation=!0}})},t.prototype._initOrUpdateEndLabel=function(r,n,i){var a=r.getModel("endLabel");if(p0(r)){var o=r.getData(),s=this._polyline,l=o.getLayout("points");if(!l){s.removeTextContent(),this._endLabel=null;return}var u=this._endLabel;u||(u=this._endLabel=new ae({z2:200}),u.ignoreClip=!0,s.setTextContent(this._endLabel),s.disableLabelAnimation=!0);var f=YC(l);f>=0&&(cy(s,Gh(r,"endLabel"),{inheritColor:i,labelFetcher:r,labelDataIndex:f,defaultText:function(h,c,v){return v!=null?wC(o,v):l0(o,h)},enableTextSetter:!0},XC(a,n)),s.textConfig.position=null)}else this._endLabel&&(this._polyline.removeTextContent(),this._endLabel=null)},t.prototype._endLabelOnDuring=function(r,n,i,a,o,s,l){var u=this._endLabel,f=this._polyline;if(u){r<1&&a.originalX==null&&(a.originalX=u.x,a.originalY=u.y);var h=i.getLayout("points"),c=i.hostModel,v=c.get("connectNulls"),d=s.get("precision"),p=s.get("distance")||0,g=l.getBaseAxis(),m=g.isHorizontal(),y=g.inverse,_=n.shape,S=y?m?_.x:_.y+_.height:m?_.x+_.width:_.y,w=(m?p:0)*(y?-1:1),b=(m?0:-p)*(y?-1:1),x=m?"x":"y",C=ZC(h,S,x),T=C.range,D=T[1]-T[0],A=void 0;if(D>=1){if(D>1&&!v){var P=xd(h,T[0]);u.attr({x:P[0]+w,y:P[1]+b}),o&&(A=c.getRawValue(T[0]))}else{var P=f.getPointOn(S,x);P&&u.attr({x:P[0]+w,y:P[1]+b});var L=c.getRawValue(T[0]),I=c.getRawValue(T[1]);o&&(A=km(i,d,L,I,C.t))}a.lastFrameIndex=T[0]}else{var R=r===1||a.lastFrameIndex>0?T[0]:0,P=xd(h,R);o&&(A=c.getRawValue(R)),u.attr({x:P[0]+w,y:P[1]+b})}if(o){var E=vl(u);typeof E.setLabelText=="function"&&E.setLabelText(A)}}},t.prototype._doUpdateAnimation=function(r,n,i,a,o,s,l){var u=this._polyline,f=this._polygon,h=r.hostModel,c=AC(this._data,r,this._stackedOnPoints,n,this._coordSys,i,this._valueOrigin),v=c.current,d=c.stackedOnCurrent,p=c.next,g=c.stackedOnNext;if(o&&(d=br(c.stackedOnCurrent,c.current,i,o,l),v=br(c.current,null,i,o,l),g=br(c.stackedOnNext,c.next,i,o,l),p=br(c.next,null,i,o,l)),bd(v,p)>3e3||f&&bd(d,g)>3e3){u.stopAnimation(),u.setShape({points:p}),f&&(f.stopAnimation(),f.setShape({points:p,stackedOnPoints:g}));return}u.shape.__points=c.current,u.shape.points=v;var m={shape:{points:p}};c.current!==v&&(m.shape.__points=c.next),u.stopAnimation(),qe(u,m,h),f&&(f.setShape({points:v,stackedOnPoints:d}),f.stopAnimation(),qe(f,{shape:{stackedOnPoints:g}},h),u.shape.points!==f.shape.points&&(f.shape.points=u.shape.points));for(var y=[],_=c.status,S=0;S<_.length;S++){var w=_[S].cmd;if(w==="="){var b=r.getItemGraphicEl(_[S].idx1);b&&y.push({el:b,ptIdx:S})}}u.animators&&u.animators.length&&u.animators[0].during(function(){f&&f.dirtyShape();for(var x=u.shape.__points,C=0;C<y.length;C++){var T=y[C].el,D=y[C].ptIdx*2;T.x=x[D],T.y=x[D+1],T.markRedraw()}})},t.prototype.remove=function(r){var n=this.group,i=this._data;this._lineGroup.removeAll(),this._symbolDraw.remove(!0),i&&i.eachItemGraphicEl(function(a,o){a.__temp&&(n.remove(a),i.setItemGraphicEl(o,null))}),this._polyline=this._polygon=this._coordSys=this._points=this._stackedOnPoints=this._endLabel=this._data=null},t.type="line",t})($e);function qC(e,t){return{seriesType:e,plan:c0(),reset:function(r){var n=r.getData(),i=r.coordinateSystem;if(r.pipelineContext,!!i){var a=$(i.dimensions,function(h){return n.mapDimension(h)}).slice(0,2),o=a.length,s=n.getCalculationInfo("stackResultDimension");Fa(n,a[0])&&(a[0]=s),Fa(n,a[1])&&(a[1]=s);var l=n.getStore(),u=n.getDimensionIndex(a[0]),f=n.getDimensionIndex(a[1]);return o&&{progress:function(h,c){for(var v=h.end-h.start,d=di(v*o),p=[],g=[],m=h.start,y=0;m<h.end;m++){var _=void 0;if(o===1){var S=l.get(u,m);_=i.dataToPoint(S,null,g)}else p[0]=l.get(u,m),p[1]=l.get(f,m),_=i.dataToPoint(p,null,g);d[y++]=_[0],d[y++]=_[1]}c.setLayout("points",d)}}}}}}var KC={average:function(e){for(var t=0,r=0,n=0;n<e.length;n++)isNaN(e[n])||(t+=e[n],r++);return r===0?NaN:t/r},sum:function(e){for(var t=0,r=0;r<e.length;r++)t+=e[r]||0;return t},max:function(e){for(var t=-1/0,r=0;r<e.length;r++)e[r]>t&&(t=e[r]);return isFinite(t)?t:NaN},min:function(e){for(var t=1/0,r=0;r<e.length;r++)e[r]<t&&(t=e[r]);return isFinite(t)?t:NaN},nearest:function(e){return e[0]}},QC=function(e){return Math.round(e.length/2)};function JC(e){return{seriesType:e,reset:function(t,r,n){var i=t.getData(),a=t.get("sampling"),o=t.coordinateSystem,s=i.count();if(s>10&&o.type==="cartesian2d"&&a){var l=o.getBaseAxis(),u=o.getOtherAxis(l),f=l.getExtent(),h=n.getDevicePixelRatio(),c=Math.abs(f[1]-f[0])*(h||1),v=Math.round(s/c);if(isFinite(v)&&v>1){a==="lttb"?t.setData(i.lttbDownSample(i.mapDimension(u.dim),1/v)):a==="minmax"&&t.setData(i.minmaxDownSample(i.mapDimension(u.dim),1/v));var d=void 0;W(a)?d=KC[a]:et(a)&&(d=a),d&&t.setData(i.downSample(i.mapDimension(u.dim),1/v,d,QC))}}}}}function jC(e){e.registerChartView($C),e.registerSeriesModel(bC),e.registerLayout(qC("line")),e.registerVisual({seriesType:"line",reset:function(t){var r=t.getData(),n=t.getModel("lineStyle").getLineStyle();n&&!n.stroke&&(n.stroke=r.getVisual("style").fill),r.setVisual("legendLineStyle",n)}}),e.registerProcessor(e.PRIORITY.PROCESSOR.STATISTIC,JC("line"))}var tM="__ec_stack_";function eM(e){return e.get("stack")||tM+e.seriesIndex}function g0(e){return e.dim+e.index}function rM(e,t){var r=[];return t.eachSeriesByType(e,function(n){sM(n)&&r.push(n)}),r}function nM(e){var t={};M(e,function(l){var u=l.coordinateSystem,f=u.getBaseAxis();if(!(f.type!=="time"&&f.type!=="value"))for(var h=l.getData(),c=f.dim+"_"+f.index,v=h.getDimensionIndex(h.mapDimension(f.dim)),d=h.getStore(),p=0,g=d.count();p<g;++p){var m=d.get(v,p);t[c]?t[c].push(m):t[c]=[m]}});var r={};for(var n in t)if(t.hasOwnProperty(n)){var i=t[n];if(i){i.sort(function(l,u){return l-u});for(var a=null,o=1;o<i.length;++o){var s=i[o]-i[o-1];s>0&&(a=a===null?s:Math.min(a,s))}r[n]=a}}return r}function iM(e){var t=nM(e),r=[];return M(e,function(n){var i=n.coordinateSystem,a=i.getBaseAxis(),o=a.getExtent(),s;if(a.type==="category")s=a.getBandWidth();else if(a.type==="value"||a.type==="time"){var l=a.dim+"_"+a.index,u=t[l],f=Math.abs(o[1]-o[0]),h=a.scale.getExtent(),c=Math.abs(h[1]-h[0]);s=u?f/c*u:f}else{var v=n.getData();s=Math.abs(o[1]-o[0])/v.count()}var d=It(n.get("barWidth"),s),p=It(n.get("barMaxWidth"),s),g=It(n.get("barMinWidth")||(lM(n)?.5:1),s),m=n.get("barGap"),y=n.get("barCategoryGap"),_=n.get("defaultBarGap");r.push({bandWidth:s,barWidth:d,barMaxWidth:p,barMinWidth:g,barGap:m,barCategoryGap:y,defaultBarGap:_,axisKey:g0(a),stackId:eM(n)})}),aM(r)}function aM(e){var t={};M(e,function(n,i){var a=n.axisKey,o=n.bandWidth,s=t[a]||{bandWidth:o,remainedWidth:o,autoWidthCount:0,categoryGap:null,gap:n.defaultBarGap||0,stacks:{}},l=s.stacks;t[a]=s;var u=n.stackId;l[u]||s.autoWidthCount++,l[u]=l[u]||{width:0,maxWidth:0};var f=n.barWidth;f&&!l[u].width&&(l[u].width=f,f=Math.min(s.remainedWidth,f),s.remainedWidth-=f);var h=n.barMaxWidth;h&&(l[u].maxWidth=h);var c=n.barMinWidth;c&&(l[u].minWidth=c);var v=n.barGap;v!=null&&(s.gap=v);var d=n.barCategoryGap;d!=null&&(s.categoryGap=d)});var r={};return M(t,function(n,i){r[i]={};var a=n.stacks,o=n.bandWidth,s=n.categoryGap;if(s==null){var l=St(a).length;s=Math.max(35-l*4,15)+"%"}var u=It(s,o),f=It(n.gap,1),h=n.remainedWidth,c=n.autoWidthCount,v=(h-u)/(c+(c-1)*f);v=Math.max(v,0),M(a,function(m){var y=m.maxWidth,_=m.minWidth;if(m.width){var S=m.width;y&&(S=Math.min(S,y)),_&&(S=Math.max(S,_)),m.width=S,h-=S+f*S,c--}else{var S=v;y&&y<S&&(S=Math.min(y,h)),_&&_>S&&(S=_),S!==v&&(m.width=S,h-=S+f*S,c--)}}),v=(h-u)/(c+(c-1)*f),v=Math.max(v,0);var d=0,p;M(a,function(m,y){m.width||(m.width=v),p=m,d+=m.width*(1+f)}),p&&(d-=p.width*f);var g=-d/2;M(a,function(m,y){r[i][y]=r[i][y]||{bandWidth:o,offset:g,width:m.width},g+=m.width*(1+f)})}),r}function oM(e,t,r){if(e&&t){var n=e[g0(t)];return n}}function sM(e){return e.coordinateSystem&&e.coordinateSystem.type==="cartesian2d"}function lM(e){return e.pipelineContext&&e.pipelineContext.large}var Ps="\0__throttleOriginMethod",Td="\0__throttleRate",Cd="\0__throttleType";function m0(e,t,r){var n,i=0,a=0,o=null,s,l,u,f;t=t||0;function h(){a=new Date().getTime(),o=null,e.apply(l,u||[])}var c=function(){for(var v=[],d=0;d<arguments.length;d++)v[d]=arguments[d];n=new Date().getTime(),l=this,u=v;var p=f||t,g=f||r;f=null,s=n-(g?i:a)-p,clearTimeout(o),g?o=setTimeout(h,p):s>=0?h():o=setTimeout(h,-s),i=n};return c.clear=function(){o&&(clearTimeout(o),o=null)},c.debounceNextCall=function(v){f=v},c}function ml(e,t,r,n){var i=e[t];if(i){var a=i[Ps]||i,o=i[Cd],s=i[Td];if(s!==r||o!==n){if(r==null||!n)return e[t]=a;i=e[t]=m0(a,r,n==="debounce"),i[Ps]=a,i[Cd]=n,i[Td]=r}return i}}function Rs(e,t){var r=e[t];r&&r[Ps]&&(r.clear&&r.clear(),e[t]=r[Ps])}function Qn(e,t,r,n,i){var a=e+t;r.isSilent(a)||n.eachComponent({mainType:"series",subType:"pie"},function(o){for(var s=o.seriesIndex,l=o.option.selectedMap,u=i.selected,f=0;f<u.length;f++)if(u[f].seriesIndex===s){var h=o.getData(),c=En(h,i.fromActionPayload);r.trigger(a,{type:a,seriesId:o.id,name:z(c)?h.getName(c[0]):h.getName(c),selected:W(l)?l:k({},l)})}})}function uM(e,t,r){e.on("selectchanged",function(n){var i=r.getModel();n.isFromClick?(Qn("map","selectchanged",t,i,n),Qn("pie","selectchanged",t,i,n)):n.fromAction==="select"?(Qn("map","selected",t,i,n),Qn("pie","selected",t,i,n)):n.fromAction==="unselect"&&(Qn("map","unselected",t,i,n),Qn("pie","unselected",t,i,n))})}var Zi=Math.PI*2,dn=hr.CMD,fM=["top","right","bottom","left"];function hM(e,t,r,n,i){var a=r.width,o=r.height;switch(e){case"top":n.set(r.x+a/2,r.y-t),i.set(0,-1);break;case"bottom":n.set(r.x+a/2,r.y+o+t),i.set(0,1);break;case"left":n.set(r.x-t,r.y+o/2),i.set(-1,0);break;case"right":n.set(r.x+a+t,r.y+o/2),i.set(1,0);break}}function vM(e,t,r,n,i,a,o,s,l){o-=e,s-=t;var u=Math.sqrt(o*o+s*s);o/=u,s/=u;var f=o*r+e,h=s*r+t;if(Math.abs(n-i)%Zi<1e-4)return l[0]=f,l[1]=h,u-r;if(a){var c=n;n=ir(i),i=ir(c)}else n=ir(n),i=ir(i);n>i&&(i+=Zi);var v=Math.atan2(s,o);if(v<0&&(v+=Zi),v>=n&&v<=i||v+Zi>=n&&v+Zi<=i)return l[0]=f,l[1]=h,u-r;var d=r*Math.cos(n)+e,p=r*Math.sin(n)+t,g=r*Math.cos(i)+e,m=r*Math.sin(i)+t,y=(d-o)*(d-o)+(p-s)*(p-s),_=(g-o)*(g-o)+(m-s)*(m-s);return y<_?(l[0]=d,l[1]=p,Math.sqrt(y)):(l[0]=g,l[1]=m,Math.sqrt(_))}function zf(e,t,r,n,i,a,o,s){var l=i-e,u=a-t,f=r-e,h=n-t,c=Math.sqrt(f*f+h*h);f/=c,h/=c;var v=l*f+u*h,d=v/c;s&&(d=Math.min(Math.max(d,0),1)),d*=c;var p=o[0]=e+d*f,g=o[1]=t+d*h;return Math.sqrt((p-i)*(p-i)+(g-a)*(g-a))}function y0(e,t,r,n,i,a,o){r<0&&(e=e+r,r=-r),n<0&&(t=t+n,n=-n);var s=e+r,l=t+n,u=o[0]=Math.min(Math.max(i,e),s),f=o[1]=Math.min(Math.max(a,t),l);return Math.sqrt((u-i)*(u-i)+(f-a)*(f-a))}var Ie=[];function cM(e,t,r){var n=y0(t.x,t.y,t.width,t.height,e.x,e.y,Ie);return r.set(Ie[0],Ie[1]),n}function dM(e,t,r){for(var n=0,i=0,a=0,o=0,s,l,u=1/0,f=t.data,h=e.x,c=e.y,v=0;v<f.length;){var d=f[v++];v===1&&(n=f[v],i=f[v+1],a=n,o=i);var p=u;switch(d){case dn.M:a=f[v++],o=f[v++],n=a,i=o;break;case dn.L:p=zf(n,i,f[v],f[v+1],h,c,Ie,!0),n=f[v++],i=f[v++];break;case dn.C:p=fm(n,i,f[v++],f[v++],f[v++],f[v++],f[v],f[v+1],h,c,Ie),n=f[v++],i=f[v++];break;case dn.Q:p=vm(n,i,f[v++],f[v++],f[v],f[v+1],h,c,Ie),n=f[v++],i=f[v++];break;case dn.A:var g=f[v++],m=f[v++],y=f[v++],_=f[v++],S=f[v++],w=f[v++];v+=1;var b=!!(1-f[v++]);s=Math.cos(S)*y+g,l=Math.sin(S)*_+m,v<=1&&(a=s,o=l);var x=(h-g)*_/y+g;p=vM(g,m,_,S,S+w,b,x,c,Ie),n=Math.cos(S+w)*y+g,i=Math.sin(S+w)*_+m;break;case dn.R:a=n=f[v++],o=i=f[v++];var C=f[v++],T=f[v++];p=y0(a,o,C,T,h,c,Ie);break;case dn.Z:p=zf(n,i,a,o,h,c,Ie,!0),n=a,i=o;break}p<u&&(u=p,r.set(Ie[0],Ie[1]))}return u}var xn=new tt,kt=new tt,se=new tt,pi=new tt,Xi=new tt;function Md(e,t){if(e){var r=e.getTextGuideLine(),n=e.getTextContent();if(n&&r){var i=e.textGuideLineConfig||{},a=[[0,0],[0,0],[0,0]],o=i.candidates||fM,s=n.getBoundingRect().clone();s.applyTransform(n.getComputedTransform());var l=1/0,u=i.anchor,f=e.getComputedTransform(),h=f&&Ei([],f),c=t.get("length2")||0;u&&se.copy(u);for(var v=0;v<o.length;v++){var d=o[v];hM(d,0,s,xn,pi),tt.scaleAndAdd(kt,xn,pi,c),kt.transform(h);var p=e.getBoundingRect(),g=u?u.distance(kt):e instanceof ht?dM(kt,e.path,se):cM(kt,p,se);g<l&&(l=g,kt.transform(f),se.transform(f),se.toArray(a[0]),kt.toArray(a[1]),xn.toArray(a[2]))}pM(a,t.get("minTurnAngle")),r.setShape({points:a})}}}var Dd=[],pn=new tt;function pM(e,t){if(t<=180&&t>0){t=t/180*Math.PI,xn.fromArray(e[0]),kt.fromArray(e[1]),se.fromArray(e[2]),tt.sub(pi,xn,kt),tt.sub(Xi,se,kt);var r=pi.len(),n=Xi.len();if(!(r<.001||n<.001)){pi.scale(1/r),Xi.scale(1/n);var i=pi.dot(Xi),a=Math.cos(t);if(a<i){var o=zf(kt.x,kt.y,se.x,se.y,xn.x,xn.y,Dd,!1);pn.fromArray(Dd),pn.scaleAndAdd(Xi,o/Math.tan(Math.PI-t));var s=se.x!==kt.x?(pn.x-kt.x)/(se.x-kt.x):(pn.y-kt.y)/(se.y-kt.y);if(isNaN(s))return;s<0?tt.copy(pn,kt):s>1&&tt.copy(pn,se),pn.toArray(e[1])}}}}function uu(e,t,r,n){var i=r==="normal",a=i?e:e.ensureState(r);a.ignore=t;var o=n.get("smooth");o&&o===!0&&(o=.3),a.shape=a.shape||{},o>0&&(a.shape.smooth=o);var s=n.getModel("lineStyle").getLineStyle();i?e.useStyle(s):a.style=s}function gM(e,t){var r=t.smooth,n=t.points;if(n)if(e.moveTo(n[0][0],n[0][1]),r>0&&n.length>=3){var i=rf(n[0],n[1]),a=rf(n[1],n[2]);if(!i||!a){e.lineTo(n[1][0],n[1][1]),e.lineTo(n[2][0],n[2][1]);return}var o=Math.min(i,a)*r,s=Zo([],n[1],n[0],o/i),l=Zo([],n[1],n[2],o/a),u=Zo([],s,l,.5);e.bezierCurveTo(s[0],s[1],s[0],s[1],u[0],u[1]),e.bezierCurveTo(l[0],l[1],l[0],l[1],n[2][0],n[2][1])}else for(var f=1;f<n.length;f++)e.lineTo(n[f][0],n[f][1])}function mM(e,t,r){var n=e.getTextGuideLine(),i=e.getTextContent();if(!i){n&&e.removeTextGuideLine();return}for(var a=t.normal,o=a.get("show"),s=i.ignore,l=0;l<_s.length;l++){var u=_s[l],f=t[u],h=u==="normal";if(f){var c=f.get("show"),v=h?s:q(i.states[u]&&i.states[u].ignore,s);if(v||!q(c,o)){var d=h?n:n&&n.states[u];d&&(d.ignore=!0),n&&uu(n,!0,u,f);continue}n||(n=new ja,e.setTextGuideLine(n),!h&&(s||!o)&&uu(n,!0,"normal",t.normal),e.stateProxy&&(n.stateProxy=e.stateProxy)),uu(n,!1,u,f)}}if(n){at(n.style,r),n.style.fill=null;var p=a.get("showAbove"),g=e.textGuideLineConfig=e.textGuideLineConfig||{};g.showAbove=p||!1,n.buildPath=gM}}function yM(e,t){t=t||"labelLine";for(var r={normal:e.getModel(t)},n=0;n<xe.length;n++){var i=xe[n];r[i]=e.getModel([i,t])}return r}var Ad=["label","labelLine","layoutOption","priority","defaultAttr","marginForce","minMarginForce","marginDefault","suggestIgnore"],_M=1,Es=2,_0=_M|Es;function ks(e,t,r){r=r||_0,t?e.dirty|=r:e.dirty&=~r}function S0(e,t){return t=t||_0,e.dirty==null||!!(e.dirty&t)}function Vr(e){if(e)return S0(e)&&SM(e,e.label,e),e}function SM(e,t,r){var n=t.getComputedTransform();e.transform=Vh(e.transform,n);var i=e.localRect=Ba(e.localRect,t.getBoundingRect()),a=t.style,o=a.margin,s=r&&r.marginForce,l=r&&r.minMarginForce,u=r&&r.marginDefault,f=a.__marginType;f==null&&u&&(o=u,f=ci.textMargin);for(var h=0;h<4;h++)fu[h]=f===ci.minMargin&&l&&l[h]!=null?l[h]:s&&s[h]!=null?s[h]:o?o[h]:0;f===ci.textMargin&&Cs(i,fu,!1,!1);var c=e.rect=Ba(e.rect,i);return n&&c.applyTransform(n),f===ci.minMargin&&Cs(c,fu,!1,!1),e.axisAligned=Hh(n),(e.label=e.label||{}).ignore=t.ignore,ks(e,!1),ks(e,!0,Es),e}var fu=[0,0,0,0];function bM(e,t,r){return e.transform=Vh(e.transform,r),e.localRect=Ba(e.localRect,t),e.rect=Ba(e.rect,t),r&&e.rect.applyTransform(r),e.axisAligned=Hh(r),e.obb=void 0,(e.label=e.label||{}).ignore=!1,e}function wM(e,t){if(e){e.label.x+=t.x,e.label.y+=t.y,e.label.markRedraw();var r=e.transform;r&&(r[4]+=t.x,r[5]+=t.y);var n=e.rect;n&&(n.x+=t.x,n.y+=t.y);var i=e.obb;i&&i.fromBoundingRect(e.localRect,r)}}function Hf(e,t){for(var r=0;r<Ad.length;r++){var n=Ad[r];e[n]==null&&(e[n]=t[n])}return Vr(e)}function Ld(e){var t=e.obb;return(!t||S0(e,Es))&&(e.obb=t=t||new ty,t.fromBoundingRect(e.localRect,e.transform),ks(e,!1,Es)),t}function Id(e,t,r,n,i){var a=e.length,o=Mr[t],s=Mi[t];if(a<2)return!1;e.sort(function(x,C){return x.rect[o]-C.rect[o]});for(var l=0,u,f=!1,h=0;h<a;h++){var c=e[h],v=c.rect;u=v[o]-l,u<0&&(v[o]-=u,c.label[o]-=u,f=!0),l=v[o]+v[s]}var d=e[0],p=e[a-1],g,m;y(),g<0&&w(-g,.8),m<0&&w(m,.8),y(),_(g,m,1),_(m,g,-1),y(),g<0&&b(-g),m<0&&b(m);function y(){g=d.rect[o]-r,m=n-p.rect[o]-p.rect[s]}function _(x,C,T){if(x<0){var D=Math.min(C,-x);if(D>0){S(D*T,0,a);var A=D+x;A<0&&w(-A*T,1)}else w(-x*T,1)}}function S(x,C,T){x!==0&&(f=!0);for(var D=C;D<T;D++){var A=e[D],P=A.rect;P[o]+=x,A.label[o]+=x}}function w(x,C){for(var T=[],D=0,A=1;A<a;A++){var P=e[A-1].rect,L=Math.max(e[A].rect[o]-P[o]-P[s],0);T.push(L),D+=L}if(D){var I=Math.min(Math.abs(x)/D,C);if(x>0)for(var A=0;A<a-1;A++){var R=T[A]*I;S(R,0,A+1)}else for(var A=a-1;A>0;A--){var R=T[A-1]*I;S(-R,A,a)}}}function b(x){var C=x<0?-1:1;x=Math.abs(x);for(var T=Math.ceil(x/(a-1)),D=0;D<a-1;D++)if(C>0?S(T,0,D+1):S(-T,a-D-1,a),x-=T,x<=0)return}return f}function xM(e){for(var t=0;t<e.length;t++){var r=e[t],n=r.defaultAttr,i=r.labelLine;r.label.attr("ignore",n.ignore),i&&i.attr("ignore",n.labelGuideIgnore)}}function b0(e){var t=[];e.sort(function(u,f){return(f.suggestIgnore?1:0)-(u.suggestIgnore?1:0)||f.priority-u.priority});function r(u){if(!u.ignore){var f=u.ensureState("emphasis");f.ignore==null&&(f.ignore=!1)}u.ignore=!0}for(var n=0;n<e.length;n++){var i=Vr(e[n]);if(!i.label.ignore){for(var a=i.label,o=i.labelLine,s=!1,l=0;l<t.length;l++)if(sv(i,t[l],null,{touchThreshold:.05})){s=!0;break}s?(r(a),o&&r(o)):t.push(i)}}}function sv(e,t,r,n){return!e||!t||e.label&&e.label.ignore||t.label&&t.label.ignore||!e.rect.intersect(t.rect,r,n)?!1:e.axisAligned&&t.axisAligned?!0:Ld(e).intersect(Ld(t),r,n)}var Jn=(function(){function e(t,r){this.target=t,this.topTarget=r&&r.topTarget}return e})(),TM=(function(){function e(t){this.handler=t,t.on("mousedown",this._dragStart,this),t.on("mousemove",this._drag,this),t.on("mouseup",this._dragEnd,this)}return e.prototype._dragStart=function(t){for(var r=t.target;r&&!r.draggable;)r=r.parent||r.__hostTarget;r&&(this._draggingTarget=r,r.dragging=!0,this._x=t.offsetX,this._y=t.offsetY,this.handler.dispatchToElement(new Jn(r,t),"dragstart",t.event))},e.prototype._drag=function(t){var r=this._draggingTarget;if(r){var n=t.offsetX,i=t.offsetY,a=n-this._x,o=i-this._y;this._x=n,this._y=i,r.drift(a,o,t),this.handler.dispatchToElement(new Jn(r,t),"drag",t.event);var s=this.handler.findHover(n,i,r).target,l=this._dropTarget;this._dropTarget=s,r!==s&&(l&&s!==l&&this.handler.dispatchToElement(new Jn(l,t),"dragleave",t.event),s&&s!==l&&this.handler.dispatchToElement(new Jn(s,t),"dragenter",t.event))}},e.prototype._dragEnd=function(t){var r=this._draggingTarget;r&&(r.dragging=!1),this.handler.dispatchToElement(new Jn(r,t),"dragend",t.event),this._dropTarget&&this.handler.dispatchToElement(new Jn(this._dropTarget,t),"drop",t.event),this._draggingTarget=null,this._dropTarget=null},e})(),CM=/^(?:mouse|pointer|contextmenu|drag|drop)|click/,hu=[],MM=nt.browser.firefox&&+nt.browser.version.split(".")[0]<39;function Vf(e,t,r,n){return r=r||{},n?Pd(e,t,r):MM&&t.layerX!=null&&t.layerX!==t.offsetX?(r.zrX=t.layerX,r.zrY=t.layerY):t.offsetX!=null?(r.zrX=t.offsetX,r.zrY=t.offsetY):Pd(e,t,r),r}function Pd(e,t,r){if(nt.domSupported&&e.getBoundingClientRect){var n=t.clientX,i=t.clientY;if(zy(e)){var a=e.getBoundingClientRect();r.zrX=n-a.left,r.zrY=i-a.top;return}else if(Rf(hu,e,n,i)){r.zrX=hu[0],r.zrY=hu[1];return}}r.zrX=r.zrY=0}function lv(e){return e||window.event}function me(e,t,r){if(t=lv(t),t.zrX!=null)return t;var n=t.type,i=n&&n.indexOf("touch")>=0;if(i){var o=n!=="touchend"?t.targetTouches[0]:t.changedTouches[0];o&&Vf(e,o,t,r)}else{Vf(e,t,t,r);var a=DM(t);t.zrDelta=a?a/120:-(t.detail||0)/3}var s=t.button;return t.which==null&&s!==void 0&&CM.test(t.type)&&(t.which=s&1?1:s&2?3:s&4?2:0),t}function DM(e){var t=e.wheelDelta;if(t)return t;var r=e.deltaX,n=e.deltaY;if(r==null||n==null)return t;var i=Math.abs(n!==0?n:r),a=n>0?-1:n<0?1:r>0?-1:1;return 3*i*a}function AM(e,t,r,n){e.addEventListener(t,r,n)}function LM(e,t,r,n){e.removeEventListener(t,r,n)}var Ai=function(e){e.preventDefault(),e.stopPropagation(),e.cancelBubble=!0};function Rd(e){return e.which===2||e.which===3}var IM=(function(){function e(){this._track=[]}return e.prototype.recognize=function(t,r,n){return this._doTrack(t,r,n),this._recognize(t)},e.prototype.clear=function(){return this._track.length=0,this},e.prototype._doTrack=function(t,r,n){var i=t.touches;if(i){for(var a={points:[],touches:[],target:r,event:t},o=0,s=i.length;o<s;o++){var l=i[o],u=Vf(n,l,{});a.points.push([u.zrX,u.zrY]),a.touches.push(l)}this._track.push(a)}},e.prototype._recognize=function(t){for(var r in vu)if(vu.hasOwnProperty(r)){var n=vu[r](this._track,t);if(n)return n}},e})();function Ed(e){var t=e[1][0]-e[0][0],r=e[1][1]-e[0][1];return Math.sqrt(t*t+r*r)}function PM(e){return[(e[0][0]+e[1][0])/2,(e[0][1]+e[1][1])/2]}var vu={pinch:function(e,t){var r=e.length;if(r){var n=(e[r-1]||{}).points,i=(e[r-2]||{}).points||n;if(i&&i.length>1&&n&&n.length>1){var a=Ed(n)/Ed(i);!isFinite(a)&&(a=1),t.pinchScale=a;var o=PM(n);return t.pinchX=o[0],t.pinchY=o[1],{type:"pinch",target:e[0].target,event:t}}}}},w0="silent";function RM(e,t,r){return{type:e,event:r,target:t.target,topTarget:t.topTarget,cancelBubble:!1,offsetX:r.zrX,offsetY:r.zrY,gestureEvent:r.gestureEvent,pinchX:r.pinchX,pinchY:r.pinchY,pinchScale:r.pinchScale,wheelDelta:r.zrDelta,zrByTouch:r.zrByTouch,which:r.which,stop:EM}}function EM(){Ai(this.event)}var kM=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.handler=null,r}return t.prototype.dispose=function(){},t.prototype.setCursor=function(){},t})(Ee),$i=(function(){function e(t,r){this.x=t,this.y=r}return e})(),OM=["click","dblclick","mousewheel","mouseout","mouseup","mousedown","mousemove","contextmenu"],cu=new it(0,0,0,0),x0=(function(e){N(t,e);function t(r,n,i,a,o){var s=e.call(this)||this;return s._hovered=new $i(0,0),s.storage=r,s.painter=n,s.painterRoot=a,s._pointerSize=o,i=i||new kM,s.proxy=null,s.setHandlerProxy(i),s._draggingMgr=new TM(s),s}return t.prototype.setHandlerProxy=function(r){this.proxy&&this.proxy.dispose(),r&&(M(OM,function(n){r.on&&r.on(n,this[n],this)},this),r.handler=this),this.proxy=r},t.prototype.mousemove=function(r){var n=r.zrX,i=r.zrY,a=T0(this,n,i),o=this._hovered,s=o.target;s&&!s.__zr&&(o=this.findHover(o.x,o.y),s=o.target);var l=this._hovered=a?new $i(n,i):this.findHover(n,i),u=l.target,f=this.proxy;f.setCursor&&f.setCursor(u?u.cursor:"default"),s&&u!==s&&this.dispatchToElement(o,"mouseout",r),this.dispatchToElement(l,"mousemove",r),u&&u!==s&&this.dispatchToElement(l,"mouseover",r)},t.prototype.mouseout=function(r){var n=r.zrEventControl;n!=="only_globalout"&&this.dispatchToElement(this._hovered,"mouseout",r),n!=="no_globalout"&&this.trigger("globalout",{type:"globalout",event:r})},t.prototype.resize=function(){this._hovered=new $i(0,0)},t.prototype.dispatch=function(r,n){var i=this[r];i&&i.call(this,n)},t.prototype.dispose=function(){this.proxy.dispose(),this.storage=null,this.proxy=null,this.painter=null},t.prototype.setCursorStyle=function(r){var n=this.proxy;n.setCursor&&n.setCursor(r)},t.prototype.dispatchToElement=function(r,n,i){r=r||{};var a=r.target;if(!(a&&a.silent)){for(var o="on"+n,s=RM(n,r,i);a&&(a[o]&&(s.cancelBubble=!!a[o].call(a,s)),a.trigger(n,s),a=a.__hostTarget?a.__hostTarget:a.parent,!s.cancelBubble););s.cancelBubble||(this.trigger(n,s),this.painter&&this.painter.eachOtherLayer&&this.painter.eachOtherLayer(function(l){typeof l[o]=="function"&&l[o].call(l,s),l.trigger&&l.trigger(n,s)}))}},t.prototype.findHover=function(r,n,i){var a=this.storage.getDisplayList(),o=new $i(r,n);if(kd(a,o,r,n,i),this._pointerSize&&!o.target){for(var s=[],l=this._pointerSize,u=l/2,f=new it(r-u,n-u,l,l),h=a.length-1;h>=0;h--){var c=a[h];c!==i&&!c.ignore&&!c.ignoreCoarsePointer&&(!c.parent||!c.parent.ignoreCoarsePointer)&&(cu.copy(c.getBoundingRect()),c.transform&&cu.applyTransform(c.transform),cu.intersect(f)&&s.push(c))}if(s.length)for(var v=4,d=Math.PI/12,p=Math.PI*2,g=0;g<u;g+=v)for(var m=0;m<p;m+=d){var y=r+g*Math.cos(m),_=n+g*Math.sin(m);if(kd(s,o,y,_,i),o.target)return o}}return o},t.prototype.processGesture=function(r,n){this._gestureMgr||(this._gestureMgr=new IM);var i=this._gestureMgr;n==="start"&&i.clear();var a=i.recognize(r,this.findHover(r.zrX,r.zrY,null).target,this.proxy.dom);if(n==="end"&&i.clear(),a){var o=a.type;r.gestureEvent=o;var s=new $i;s.target=a.target,this.dispatchToElement(s,o,a.event)}},t})(Ee);M(["click","mousedown","mouseup","mousewheel","dblclick","contextmenu"],function(e){x0.prototype[e]=function(t){var r=t.zrX,n=t.zrY,i=T0(this,r,n),a,o;if((e!=="mouseup"||!i)&&(a=this.findHover(r,n),o=a.target),e==="mousedown")this._downEl=o,this._downPoint=[t.zrX,t.zrY],this._upEl=o;else if(e==="mouseup")this._upEl=o;else if(e==="click"){if(this._downEl!==this._upEl||!this._downPoint||rf(this._downPoint,[t.zrX,t.zrY])>4)return;this._downPoint=null}this.dispatchToElement(a,e,t)}});function BM(e,t,r){if(e[e.rectHover?"rectContain":"contain"](t,r)){for(var n=e,i=void 0,a=!1;n;){if(n.ignoreClip&&(a=!0),!a){var o=n.getClipPath();if(o&&!o.contain(t,r))return!1}n.silent&&(i=!0);var s=n.__hostTarget;n=s?n.ignoreHostSilent?null:s:n.parent}return i?w0:!0}return!1}function kd(e,t,r,n,i){for(var a=e.length-1;a>=0;a--){var o=e[a],s=void 0;if(o!==i&&!o.ignore&&(s=BM(o,r,n))&&(!t.topTarget&&(t.topTarget=o),s!==w0)){t.target=o;break}}}function T0(e,t,r){var n=e.painter;return t<0||t>n.getWidth()||r<0||r>n.getHeight()}var C0=32,qi=7;function NM(e){for(var t=0;e>=C0;)t|=e&1,e>>=1;return e+t}function Od(e,t,r,n){var i=t+1;if(i===r)return 1;if(n(e[i++],e[t])<0){for(;i<r&&n(e[i],e[i-1])<0;)i++;FM(e,t,i)}else for(;i<r&&n(e[i],e[i-1])>=0;)i++;return i-t}function FM(e,t,r){for(r--;t<r;){var n=e[t];e[t++]=e[r],e[r--]=n}}function Bd(e,t,r,n,i){for(n===t&&n++;n<r;n++){for(var a=e[n],o=t,s=n,l;o<s;)l=o+s>>>1,i(a,e[l])<0?s=l:o=l+1;var u=n-o;switch(u){case 3:e[o+3]=e[o+2];case 2:e[o+2]=e[o+1];case 1:e[o+1]=e[o];break;default:for(;u>0;)e[o+u]=e[o+u-1],u--}e[o]=a}}function du(e,t,r,n,i,a){var o=0,s=0,l=1;if(a(e,t[r+i])>0){for(s=n-i;l<s&&a(e,t[r+i+l])>0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s),o+=i,l+=i}else{for(s=i+1;l<s&&a(e,t[r+i-l])<=0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s);var u=o;o=i-l,l=i-u}for(o++;o<l;){var f=o+(l-o>>>1);a(e,t[r+f])>0?o=f+1:l=f}return l}function pu(e,t,r,n,i,a){var o=0,s=0,l=1;if(a(e,t[r+i])<0){for(s=i+1;l<s&&a(e,t[r+i-l])<0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s);var u=o;o=i-l,l=i-u}else{for(s=n-i;l<s&&a(e,t[r+i+l])>=0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s),o+=i,l+=i}for(o++;o<l;){var f=o+(l-o>>>1);a(e,t[r+f])<0?l=f:o=f+1}return l}function zM(e,t){var r=qi,n,i,a=0,o=[];n=[],i=[];function s(v,d){n[a]=v,i[a]=d,a+=1}function l(){for(;a>1;){var v=a-2;if(v>=1&&i[v-1]<=i[v]+i[v+1]||v>=2&&i[v-2]<=i[v]+i[v-1])i[v-1]<i[v+1]&&v--;else if(i[v]>i[v+1])break;f(v)}}function u(){for(;a>1;){var v=a-2;v>0&&i[v-1]<i[v+1]&&v--,f(v)}}function f(v){var d=n[v],p=i[v],g=n[v+1],m=i[v+1];i[v]=p+m,v===a-3&&(n[v+1]=n[v+2],i[v+1]=i[v+2]),a--;var y=pu(e[g],e,d,p,0,t);d+=y,p-=y,p!==0&&(m=du(e[d+p-1],e,g,m,m-1,t),m!==0&&(p<=m?h(d,p,g,m):c(d,p,g,m)))}function h(v,d,p,g){var m=0;for(m=0;m<d;m++)o[m]=e[v+m];var y=0,_=p,S=v;if(e[S++]=e[_++],--g===0){for(m=0;m<d;m++)e[S+m]=o[y+m];return}if(d===1){for(m=0;m<g;m++)e[S+m]=e[_+m];e[S+g]=o[y];return}for(var w=r,b,x,C;;){b=0,x=0,C=!1;do if(t(e[_],o[y])<0){if(e[S++]=e[_++],x++,b=0,--g===0){C=!0;break}}else if(e[S++]=o[y++],b++,x=0,--d===1){C=!0;break}while((b|x)<w);if(C)break;do{if(b=pu(e[_],o,y,d,0,t),b!==0){for(m=0;m<b;m++)e[S+m]=o[y+m];if(S+=b,y+=b,d-=b,d<=1){C=!0;break}}if(e[S++]=e[_++],--g===0){C=!0;break}if(x=du(o[y],e,_,g,0,t),x!==0){for(m=0;m<x;m++)e[S+m]=e[_+m];if(S+=x,_+=x,g-=x,g===0){C=!0;break}}if(e[S++]=o[y++],--d===1){C=!0;break}w--}while(b>=qi||x>=qi);if(C)break;w<0&&(w=0),w+=2}if(r=w,r<1&&(r=1),d===1){for(m=0;m<g;m++)e[S+m]=e[_+m];e[S+g]=o[y]}else{if(d===0)throw new Error;for(m=0;m<d;m++)e[S+m]=o[y+m]}}function c(v,d,p,g){var m=0;for(m=0;m<g;m++)o[m]=e[p+m];var y=v+d-1,_=g-1,S=p+g-1,w=0,b=0;if(e[S--]=e[y--],--d===0){for(w=S-(g-1),m=0;m<g;m++)e[w+m]=o[m];return}if(g===1){for(S-=d,y-=d,b=S+1,w=y+1,m=d-1;m>=0;m--)e[b+m]=e[w+m];e[S]=o[_];return}for(var x=r;;){var C=0,T=0,D=!1;do if(t(o[_],e[y])<0){if(e[S--]=e[y--],C++,T=0,--d===0){D=!0;break}}else if(e[S--]=o[_--],T++,C=0,--g===1){D=!0;break}while((C|T)<x);if(D)break;do{if(C=d-pu(o[_],e,v,d,d-1,t),C!==0){for(S-=C,y-=C,d-=C,b=S+1,w=y+1,m=C-1;m>=0;m--)e[b+m]=e[w+m];if(d===0){D=!0;break}}if(e[S--]=o[_--],--g===1){D=!0;break}if(T=g-du(e[y],o,0,g,g-1,t),T!==0){for(S-=T,_-=T,g-=T,b=S+1,w=_+1,m=0;m<T;m++)e[b+m]=o[w+m];if(g<=1){D=!0;break}}if(e[S--]=e[y--],--d===0){D=!0;break}x--}while(C>=qi||T>=qi);if(D)break;x<0&&(x=0),x+=2}if(r=x,r<1&&(r=1),g===1){for(S-=d,y-=d,b=S+1,w=y+1,m=d-1;m>=0;m--)e[b+m]=e[w+m];e[S]=o[_]}else{if(g===0)throw new Error;for(w=S-(g-1),m=0;m<g;m++)e[w+m]=o[m]}}return{mergeRuns:l,forceMergeRuns:u,pushRun:s}}function is(e,t,r,n){r||(r=0),n||(n=e.length);var i=n-r;if(!(i<2)){var a=0;if(i<C0){a=Od(e,r,n,t),Bd(e,r,n,r+a,t);return}var o=zM(e,t),s=NM(i);do{if(a=Od(e,r,n,t),a<s){var l=i;l>s&&(l=s),Bd(e,r,r+l,r+a,t),a=l}o.pushRun(r,a),o.mergeRuns(),i-=a,r+=a}while(i!==0);o.forceMergeRuns()}}var Nd=!1;function gu(){Nd||(Nd=!0,console.warn("z / z2 / zlevel of displayable is invalid, which may cause unexpected errors"))}function Fd(e,t){return e.zlevel===t.zlevel?e.z===t.z?e.z2-t.z2:e.z-t.z:e.zlevel-t.zlevel}var HM=(function(){function e(){this._roots=[],this._displayList=[],this._displayListLen=0,this.displayableSortFunc=Fd}return e.prototype.traverse=function(t,r){for(var n=0;n<this._roots.length;n++)this._roots[n].traverse(t,r)},e.prototype.getDisplayList=function(t,r){r=r||!1;var n=this._displayList;return(t||!n.length)&&this.updateDisplayList(r),n},e.prototype.updateDisplayList=function(t){this._displayListLen=0;for(var r=this._roots,n=this._displayList,i=0,a=r.length;i<a;i++)this._updateAndAddDisplayable(r[i],null,t);n.length=this._displayListLen,is(n,Fd)},e.prototype._updateAndAddDisplayable=function(t,r,n){if(!(t.ignore&&!n)){t.beforeUpdate(),t.update(),t.afterUpdate();var i=t.getClipPath(),a=r&&r.length,o=0,s=t.__clipPaths;if(!t.ignoreClip&&(a||i)){if(s||(s=t.__clipPaths=[]),a)for(var l=0;l<r.length;l++)s[o++]=r[l];for(var u=i,f=t;u;)u.parent=f,u.updateTransform(),s[o++]=u,f=u,u=u.getClipPath()}if(s&&(s.length=o),t.childrenRef){for(var h=t.childrenRef(),c=0;c<h.length;c++){var v=h[c];t.__dirty&&(v.__dirty|=ue),this._updateAndAddDisplayable(v,s,n)}t.__dirty=0}else{var d=t;isNaN(d.z)&&(gu(),d.z=0),isNaN(d.z2)&&(gu(),d.z2=0),isNaN(d.zlevel)&&(gu(),d.zlevel=0),this._displayList[this._displayListLen++]=d}var p=t.getDecalElement&&t.getDecalElement();p&&this._updateAndAddDisplayable(p,s,n);var g=t.getTextGuideLine();g&&this._updateAndAddDisplayable(g,s,n);var m=t.getTextContent();m&&this._updateAndAddDisplayable(m,s,n)}},e.prototype.addRoot=function(t){t.__zr&&t.__zr.storage===this||this._roots.push(t)},e.prototype.delRoot=function(t){if(t instanceof Array){for(var r=0,n=t.length;r<n;r++)this.delRoot(t[r]);return}var i=ft(this._roots,t);i>=0&&this._roots.splice(i,1)},e.prototype.delAllRoots=function(){this._roots=[],this._displayList=[],this._displayListLen=0},e.prototype.getRoots=function(){return this._roots},e.prototype.dispose=function(){this._displayList=null,this._roots=null},e})(),Os;Os=nt.hasGlobalWindow&&(window.requestAnimationFrame&&window.requestAnimationFrame.bind(window)||window.msRequestAnimationFrame&&window.msRequestAnimationFrame.bind(window)||window.mozRequestAnimationFrame||window.webkitRequestAnimationFrame)||function(e){return setTimeout(e,16)};function gi(){return new Date().getTime()}var VM=(function(e){N(t,e);function t(r){var n=e.call(this)||this;return n._running=!1,n._time=0,n._pausedTime=0,n._pauseStart=0,n._paused=!1,r=r||{},n.stage=r.stage||{},n}return t.prototype.addClip=function(r){r.animation&&this.removeClip(r),this._head?(this._tail.next=r,r.prev=this._tail,r.next=null,this._tail=r):this._head=this._tail=r,r.animation=this},t.prototype.addAnimator=function(r){r.animation=this;var n=r.getClip();n&&this.addClip(n)},t.prototype.removeClip=function(r){if(r.animation){var n=r.prev,i=r.next;n?n.next=i:this._head=i,i?i.prev=n:this._tail=n,r.next=r.prev=r.animation=null}},t.prototype.removeAnimator=function(r){var n=r.getClip();n&&this.removeClip(n),r.animation=null},t.prototype.update=function(r){for(var n=gi()-this._pausedTime,i=n-this._time,a=this._head;a;){var o=a.next,s=a.step(n,i);s&&(a.ondestroy(),this.removeClip(a)),a=o}this._time=n,r||(this.trigger("frame",i),this.stage.update&&this.stage.update())},t.prototype._startLoop=function(){var r=this;this._running=!0;function n(){r._running&&(Os(n),!r._paused&&r.update())}Os(n)},t.prototype.start=function(){this._running||(this._time=gi(),this._pausedTime=0,this._startLoop())},t.prototype.stop=function(){this._running=!1},t.prototype.pause=function(){this._paused||(this._pauseStart=gi(),this._paused=!0)},t.prototype.resume=function(){this._paused&&(this._pausedTime+=gi()-this._pauseStart,this._paused=!1)},t.prototype.clear=function(){for(var r=this._head;r;){var n=r.next;r.prev=r.next=r.animation=null,r=n}this._head=this._tail=null},t.prototype.isFinished=function(){return this._head==null},t.prototype.animate=function(r,n){n=n||{},this.start();var i=new Th(r,n.loop);return this.addAnimator(i),i},t})(Ee),GM=300,mu=nt.domSupported,yu=(function(){var e=["click","dblclick","mousewheel","wheel","mouseout","mouseup","mousedown","mousemove","contextmenu"],t=["touchstart","touchend","touchmove"],r={pointerdown:1,pointerup:1,pointermove:1,pointerout:1},n=$(e,function(i){var a=i.replace("mouse","pointer");return r.hasOwnProperty(a)?a:i});return{mouse:e,touch:t,pointer:n}})(),zd={mouse:["mousemove","mouseup"],pointer:["pointermove","pointerup"]},Hd=!1;function Gf(e){var t=e.pointerType;return t==="pen"||t==="touch"}function WM(e){e.touching=!0,e.touchTimer!=null&&(clearTimeout(e.touchTimer),e.touchTimer=null),e.touchTimer=setTimeout(function(){e.touching=!1,e.touchTimer=null},700)}function _u(e){e&&(e.zrByTouch=!0)}function UM(e,t){return me(e.dom,new YM(e,t),!0)}function M0(e,t){for(var r=t,n=!1;r&&r.nodeType!==9&&!(n=r.domBelongToZr||r!==t&&r===e.painterRoot);)r=r.parentNode;return n}var YM=(function(){function e(t,r){this.stopPropagation=qt,this.stopImmediatePropagation=qt,this.preventDefault=qt,this.type=r.type,this.target=this.currentTarget=t.dom,this.pointerType=r.pointerType,this.clientX=r.clientX,this.clientY=r.clientY}return e})(),Ae={mousedown:function(e){e=me(this.dom,e),this.__mayPointerCapture=[e.zrX,e.zrY],this.trigger("mousedown",e)},mousemove:function(e){e=me(this.dom,e);var t=this.__mayPointerCapture;t&&(e.zrX!==t[0]||e.zrY!==t[1])&&this.__togglePointerCapture(!0),this.trigger("mousemove",e)},mouseup:function(e){e=me(this.dom,e),this.__togglePointerCapture(!1),this.trigger("mouseup",e)},mouseout:function(e){e=me(this.dom,e);var t=e.toElement||e.relatedTarget;M0(this,t)||(this.__pointerCapturing&&(e.zrEventControl="no_globalout"),this.trigger("mouseout",e))},wheel:function(e){Hd=!0,e=me(this.dom,e),this.trigger("mousewheel",e)},mousewheel:function(e){Hd||(e=me(this.dom,e),this.trigger("mousewheel",e))},touchstart:function(e){e=me(this.dom,e),_u(e),this.__lastTouchMoment=new Date,this.handler.processGesture(e,"start"),Ae.mousemove.call(this,e),Ae.mousedown.call(this,e)},touchmove:function(e){e=me(this.dom,e),_u(e),this.handler.processGesture(e,"change"),Ae.mousemove.call(this,e)},touchend:function(e){e=me(this.dom,e),_u(e),this.handler.processGesture(e,"end"),Ae.mouseup.call(this,e),+new Date-+this.__lastTouchMoment<GM&&Ae.click.call(this,e)},pointerdown:function(e){Ae.mousedown.call(this,e)},pointermove:function(e){Gf(e)||Ae.mousemove.call(this,e)},pointerup:function(e){Ae.mouseup.call(this,e)},pointerout:function(e){Gf(e)||Ae.mouseout.call(this,e)}};M(["click","dblclick","contextmenu"],function(e){Ae[e]=function(t){t=me(this.dom,t),this.trigger(e,t)}});var Wf={pointermove:function(e){Gf(e)||Wf.mousemove.call(this,e)},pointerup:function(e){Wf.mouseup.call(this,e)},mousemove:function(e){this.trigger("mousemove",e)},mouseup:function(e){var t=this.__pointerCapturing;this.__togglePointerCapture(!1),this.trigger("mouseup",e),t&&(e.zrEventControl="only_globalout",this.trigger("mouseout",e))}};function ZM(e,t){var r=t.domHandlers;nt.pointerEventsSupported?M(yu.pointer,function(n){as(t,n,function(i){r[n].call(e,i)})}):(nt.touchEventsSupported&&M(yu.touch,function(n){as(t,n,function(i){r[n].call(e,i),WM(t)})}),M(yu.mouse,function(n){as(t,n,function(i){i=lv(i),t.touching||r[n].call(e,i)})}))}function XM(e,t){nt.pointerEventsSupported?M(zd.pointer,r):nt.touchEventsSupported||M(zd.mouse,r);function r(n){function i(a){a=lv(a),M0(e,a.target)||(a=UM(e,a),t.domHandlers[n].call(e,a))}as(t,n,i,{capture:!0})}}function as(e,t,r,n){e.mounted[t]=r,e.listenerOpts[t]=n,AM(e.domTarget,t,r,n)}function Su(e){var t=e.mounted;for(var r in t)t.hasOwnProperty(r)&&LM(e.domTarget,r,t[r],e.listenerOpts[r]);e.mounted={}}var Vd=(function(){function e(t,r){this.mounted={},this.listenerOpts={},this.touching=!1,this.domTarget=t,this.domHandlers=r}return e})(),$M=(function(e){N(t,e);function t(r,n){var i=e.call(this)||this;return i.__pointerCapturing=!1,i.dom=r,i.painterRoot=n,i._localHandlerScope=new Vd(r,Ae),mu&&(i._globalHandlerScope=new Vd(document,Wf)),ZM(i,i._localHandlerScope),i}return t.prototype.dispose=function(){Su(this._localHandlerScope),mu&&Su(this._globalHandlerScope)},t.prototype.setCursor=function(r){this.dom.style&&(this.dom.style.cursor=r||"default")},t.prototype.__togglePointerCapture=function(r){if(this.__mayPointerCapture=null,mu&&+this.__pointerCapturing^+r){this.__pointerCapturing=r;var n=this._globalHandlerScope;r?XM(this,n):Su(n)}},t})(Ee);/*!
* ZRender, a high performance 2d drawing library.
*
* Copyright (c) 2013, Baidu Inc.
* All rights reserved.
*
* LICENSE
* https://github.com/ecomfe/zrender/blob/master/LICENSE.txt
*/var os={},D0={};function qM(e){delete D0[e]}function KM(e){if(!e)return!1;if(typeof e=="string")return ps(e,1)<vf;if(e.colorStops){for(var t=e.colorStops,r=0,n=t.length,i=0;i<n;i++)r+=ps(t[i].color,1);return r/=n,r<vf}return!1}var QM=(function(){function e(t,r,n){var i=this;this._sleepAfterStill=10,this._stillFrameAccum=0,this._needsRefresh=!0,this._needsRefreshHover=!0,this._darkMode=!1,n=n||{},this.dom=r,this.id=t;var a=new HM,o=n.renderer||"canvas";os[o]||(o=St(os)[0]),n.useDirtyRect=n.useDirtyRect==null?!1:n.useDirtyRect;var s=new os[o](r,a,n,t),l=n.ssr||s.ssrOnly;this.storage=a,this.painter=s;var u=!nt.node&&!nt.worker&&!l?new $M(s.getViewportRoot(),s.root):null,f=n.useCoarsePointer,h=f==null||f==="auto"?nt.touchEventsSupported:!!f,c=44,v;h&&(v=q(n.pointerSize,c)),this.handler=new x0(a,s,u,s.root,v),this.animation=new VM({stage:{update:l?null:function(){return i._flush(!0)}}}),l||this.animation.start()}return e.prototype.add=function(t){this._disposed||!t||(this.storage.addRoot(t),t.addSelfToZr(this),this.refresh())},e.prototype.remove=function(t){this._disposed||!t||(this.storage.delRoot(t),t.removeSelfFromZr(this),this.refresh())},e.prototype.configLayer=function(t,r){this._disposed||(this.painter.configLayer&&this.painter.configLayer(t,r),this.refresh())},e.prototype.setBackgroundColor=function(t){this._disposed||(this.painter.setBackgroundColor&&this.painter.setBackgroundColor(t),this.refresh(),this._backgroundColor=t,this._darkMode=KM(t))},e.prototype.getBackgroundColor=function(){return this._backgroundColor},e.prototype.setDarkMode=function(t){this._darkMode=t},e.prototype.isDarkMode=function(){return this._darkMode},e.prototype.refreshImmediately=function(t){this._disposed||(t||this.animation.update(!0),this._needsRefresh=!1,this.painter.refresh(),this._needsRefresh=!1)},e.prototype.refresh=function(){this._disposed||(this._needsRefresh=!0,this.animation.start())},e.prototype.flush=function(){this._disposed||this._flush(!1)},e.prototype._flush=function(t){var r,n=gi();this._needsRefresh&&(r=!0,this.refreshImmediately(t)),this._needsRefreshHover&&(r=!0,this.refreshHoverImmediately());var i=gi();r?(this._stillFrameAccum=0,this.trigger("rendered",{elapsedTime:i-n})):this._sleepAfterStill>0&&(this._stillFrameAccum++,this._stillFrameAccum>this._sleepAfterStill&&this.animation.stop())},e.prototype.setSleepAfterStill=function(t){this._sleepAfterStill=t},e.prototype.wakeUp=function(){this._disposed||(this.animation.start(),this._stillFrameAccum=0)},e.prototype.refreshHover=function(){this._needsRefreshHover=!0},e.prototype.refreshHoverImmediately=function(){this._disposed||(this._needsRefreshHover=!1,this.painter.refreshHover&&this.painter.getType()==="canvas"&&this.painter.refreshHover())},e.prototype.resize=function(t){this._disposed||(t=t||{},this.painter.resize(t.width,t.height),this.handler.resize())},e.prototype.clearAnimation=function(){this._disposed||this.animation.clear()},e.prototype.getWidth=function(){if(!this._disposed)return this.painter.getWidth()},e.prototype.getHeight=function(){if(!this._disposed)return this.painter.getHeight()},e.prototype.setCursorStyle=function(t){this._disposed||this.handler.setCursorStyle(t)},e.prototype.findHover=function(t,r){if(!this._disposed)return this.handler.findHover(t,r)},e.prototype.on=function(t,r,n){return this._disposed||this.handler.on(t,r,n),this},e.prototype.off=function(t,r){this._disposed||this.handler.off(t,r)},e.prototype.trigger=function(t,r){this._disposed||this.handler.trigger(t,r)},e.prototype.clear=function(){if(!this._disposed){for(var t=this.storage.getRoots(),r=0;r<t.length;r++)t[r]instanceof Ft&&t[r].removeSelfFromZr(this);this.storage.delAllRoots(),this.painter.clear()}},e.prototype.dispose=function(){this._disposed||(this.animation.stop(),this.clear(),this.storage.dispose(),this.painter.dispose(),this.handler.dispose(),this.animation=this.storage=this.painter=this.handler=null,this._disposed=!0,qM(this.id))},e})();function Gd(e,t){var r=new QM(Ug(),e,t);return D0[r.id]=r,r}function JM(e,t){os[e]=t}var A0="";typeof navigator<"u"&&(A0=navigator.platform||"");var jn="rgba(0, 0, 0, 0.2)",L0=Y.color.theme[0],jM=lf(L0,null,null,.9);const tD={darkMode:"auto",colorBy:"series",color:Y.color.theme,gradientColor:[jM,L0],aria:{decal:{decals:[{color:jn,dashArrayX:[1,0],dashArrayY:[2,5],symbolSize:1,rotation:Math.PI/6},{color:jn,symbol:"circle",dashArrayX:[[8,8],[0,8,8,0]],dashArrayY:[6,0],symbolSize:.8},{color:jn,dashArrayX:[1,0],dashArrayY:[4,3],rotation:-Math.PI/4},{color:jn,dashArrayX:[[6,6],[0,6,6,0]],dashArrayY:[6,0]},{color:jn,dashArrayX:[[1,0],[1,6]],dashArrayY:[1,0,6,0],rotation:Math.PI/4},{color:jn,symbol:"triangle",dashArrayX:[[9,9],[0,9,9,0]],dashArrayY:[7,2],symbolSize:.75}]}},textStyle:{fontFamily:A0.match(/^Win/)?"Microsoft YaHei":"sans-serif",fontSize:12,fontStyle:"normal",fontWeight:"normal"},blendMode:null,stateAnimation:{duration:300,easing:"cubicOut"},animation:"auto",animationDuration:1e3,animationDurationUpdate:500,animationEasing:"cubicInOut",animationEasingUpdate:"cubicInOut",animationThreshold:2e3,progressiveThreshold:3e3,progressive:400,hoverLayerThreshold:3e3,useUTC:!1};var eD=K();function rD(e,t,r){var n=eD.get(t);if(!n)return r;var i=n(e);return i?r.concat(i):r}var Io,Ki,Wd,Ud="\0_ec_inner",nD=1,uv=(function(e){N(t,e);function t(){return e!==null&&e.apply(this,arguments)||this}return t.prototype.init=function(r,n,i,a,o,s){a=a||{},this.option=null,this._theme=new xt(a),this._locale=new xt(o),this._optionManager=s},t.prototype.setOption=function(r,n,i){var a=Xd(n);this._optionManager.setOption(r,i,a),this._resetOption(null,a)},t.prototype.resetOption=function(r,n){return this._resetOption(r,Xd(n))},t.prototype._resetOption=function(r,n){var i=!1,a=this._optionManager;if(!r||r==="recreate"){var o=a.mountOption(r==="recreate");!this.option||r==="recreate"?Wd(this,o):(this.restoreData(),this._mergeOption(o,n)),i=!0}if((r==="timeline"||r==="media")&&this.restoreData(),!r||r==="recreate"||r==="timeline"){var s=a.getTimelineOption(this);s&&(i=!0,this._mergeOption(s,n))}if(!r||r==="recreate"||r==="media"){var l=a.getMediaOption(this);l.length&&M(l,function(u){i=!0,this._mergeOption(u,n)},this)}return i},t.prototype.mergeOption=function(r){this._mergeOption(r,null)},t.prototype._mergeOption=function(r,n){var i=this.option,a=this._componentsMap,o=this._componentsCount,s=[],l=K(),u=n&&n.replaceMergeMainTypeMap;lx(this),M(r,function(h,c){h!=null&&(dt.hasClass(c)?c&&(s.push(c),l.set(c,!0)):i[c]=i[c]==null?st(h):vt(i[c],h,!0))}),u&&u.each(function(h,c){dt.hasClass(c)&&!l.get(c)&&(s.push(c),l.set(c,!0))}),dt.topologicalTravel(s,dt.getAllClassMainTypes(),f,this);function f(h){var c=rD(this,h,Mt(r[h])),v=a.get(h),d=v?u&&u.get(h)?"replaceMerge":"normalMerge":"replaceAll",p=Db(v,c,d);kb(p,h,dt),i[h]=null,a.set(h,null),o.set(h,0);var g=[],m=[],y=0,_;M(p,function(S,w){var b=S.existing,x=S.newOption;if(!x)b&&(b.mergeOption({},this),b.optionUpdated({},!1));else{var C=h==="series",T=dt.getClass(h,S.keyInfo.subType,!C);if(!T)return;if(h==="tooltip"){if(_)return;_=!0}if(b&&b.constructor===T)b.name=S.keyInfo.name,b.mergeOption(x,this),b.optionUpdated(x,!1);else{var D=k({componentIndex:w},S.keyInfo);b=new T(x,this,this,D),k(b,D),S.brandNew&&(b.__requireNewView=!0),b.init(x,this,this),b.optionUpdated(null,!0)}}b?(g.push(b.option),m.push(b),y++):(g.push(void 0),m.push(void 0))},this),i[h]=g,a.set(h,m),o.set(h,y),h==="series"&&Io(this)}this._seriesIndices||Io(this)},t.prototype.getOption=function(){var r=st(this.option);return M(r,function(n,i){if(dt.hasClass(i)){for(var a=Mt(n),o=a.length,s=!1,l=o-1;l>=0;l--)a[l]&&!Ea(a[l])?s=!0:(a[l]=null,!s&&o--);a.length=o,r[i]=a}}),delete r[Ud],r},t.prototype.setTheme=function(r){this._theme=new xt(r),this._resetOption("recreate",null)},t.prototype.getTheme=function(){return this._theme},t.prototype.getLocaleModel=function(){return this._locale},t.prototype.setUpdatePayload=function(r){this._payload=r},t.prototype.getUpdatePayload=function(){return this._payload},t.prototype.getComponent=function(r,n){var i=this._componentsMap.get(r);if(i){var a=i[n||0];if(a)return a;if(n==null){for(var o=0;o<i.length;o++)if(i[o])return i[o]}}},t.prototype.queryComponents=function(r){var n=r.mainType;if(!n)return[];var i=r.index,a=r.id,o=r.name,s=this._componentsMap.get(n);if(!s||!s.length)return[];var l;return i!=null?(l=[],M(Mt(i),function(u){s[u]&&l.push(s[u])})):a!=null?l=Yd("id",a,s):o!=null?l=Yd("name",o,s):l=wt(s,function(u){return!!u}),Zd(l,r)},t.prototype.findComponents=function(r){var n=r.query,i=r.mainType,a=s(n),o=a?this.queryComponents(a):wt(this._componentsMap.get(i),function(u){return!!u});return l(Zd(o,r));function s(u){var f=i+"Index",h=i+"Id",c=i+"Name";return u&&(u[f]!=null||u[h]!=null||u[c]!=null)?{mainType:i,index:u[f],id:u[h],name:u[c]}:null}function l(u){return r.filter?wt(u,r.filter):u}},t.prototype.eachComponent=function(r,n,i){var a=this._componentsMap;if(et(r)){var o=n,s=r;a.each(function(h,c){for(var v=0;h&&v<h.length;v++){var d=h[v];d&&s.call(o,c,d,d.componentIndex)}})}else for(var l=W(r)?a.get(r):X(r)?this.findComponents(r):null,u=0;l&&u<l.length;u++){var f=l[u];f&&n.call(i,f,f.componentIndex)}},t.prototype.getSeriesByName=function(r){var n=Xe(r,null);return wt(this._componentsMap.get("series"),function(i){return!!i&&n!=null&&i.name===n})},t.prototype.getSeriesByIndex=function(r){return this._componentsMap.get("series")[r]},t.prototype.getSeriesByType=function(r){return wt(this._componentsMap.get("series"),function(n){return!!n&&n.subType===r})},t.prototype.getSeries=function(){return wt(this._componentsMap.get("series"),function(r){return!!r})},t.prototype.getSeriesCount=function(){return this._componentsCount.get("series")},t.prototype.eachSeries=function(r,n){Ki(this),M(this._seriesIndices,function(i){var a=this._componentsMap.get("series")[i];r.call(n,a,i)},this)},t.prototype.eachRawSeries=function(r,n){M(this._componentsMap.get("series"),function(i){i&&r.call(n,i,i.componentIndex)})},t.prototype.eachSeriesByType=function(r,n,i){Ki(this),M(this._seriesIndices,function(a){var o=this._componentsMap.get("series")[a];o.subType===r&&n.call(i,o,a)},this)},t.prototype.eachRawSeriesByType=function(r,n,i){return M(this.getSeriesByType(r),n,i)},t.prototype.isSeriesFiltered=function(r){return Ki(this),this._seriesIndicesMap.get(r.componentIndex)==null},t.prototype.getCurrentSeriesIndices=function(){return(this._seriesIndices||[]).slice()},t.prototype.filterSeries=function(r,n){Ki(this);var i=[];M(this._seriesIndices,function(a){var o=this._componentsMap.get("series")[a];r.call(n,o,a)&&i.push(a)},this),this._seriesIndices=i,this._seriesIndicesMap=K(i)},t.prototype.restoreData=function(r){Io(this);var n=this._componentsMap,i=[];n.each(function(a,o){dt.hasClass(o)&&i.push(o)}),dt.topologicalTravel(i,dt.getAllClassMainTypes(),function(a){M(n.get(a),function(o){o&&(a!=="series"||!iD(o,r))&&o.restoreData()})})},t.internalField=(function(){Io=function(r){var n=r._seriesIndices=[];M(r._componentsMap.get("series"),function(i){i&&n.push(i.componentIndex)}),r._seriesIndicesMap=K(n)},Ki=function(r){},Wd=function(r,n){r.option={},r.option[Ud]=nD,r._componentsMap=K({series:[]}),r._componentsCount=K();var i=n.aria;X(i)&&i.enabled==null&&(i.enabled=!0),aD(n,r._theme.option),vt(n,tD,!1),r._mergeOption(n,null)}})(),t})(xt);function iD(e,t){if(t){var r=t.seriesIndex,n=t.seriesId,i=t.seriesName;return r!=null&&e.componentIndex!==r||n!=null&&e.id!==n||i!=null&&e.name!==i}}function aD(e,t){var r=e.color&&!e.colorLayer;M(t,function(n,i){i==="colorLayer"&&r||i==="color"&&e.color||dt.hasClass(i)||(typeof n=="object"?e[i]=e[i]?vt(e[i],n,!1):st(n):e[i]==null&&(e[i]=n))})}function Yd(e,t,r){if(z(t)){var n=K();return M(t,function(a){if(a!=null){var o=Xe(a,null);o!=null&&n.set(a,!0)}}),wt(r,function(a){return a&&n.get(a[e])})}else{var i=Xe(t,null);return wt(r,function(a){return a&&i!=null&&a[e]===i})}}function Zd(e,t){return t.hasOwnProperty("subType")?wt(e,function(r){return r&&r.subType===t.subType}):e}function Xd(e){var t=K();return e&&M(Mt(e.replaceMerge),function(r){t.set(r,!0)}),{replaceMergeMainTypeMap:t}}Ke(uv,iv);var oD=["getDom","getZr","getWidth","getHeight","getDevicePixelRatio","dispatchAction","isSSR","isDisposed","on","off","getDataURL","getConnectedDataURL","getOption","getId","updateLabelLayout"],I0=(function(){function e(t){M(oD,function(r){this[r]=Q(t[r],t)},this)}return e})(),sD=/^(min|max)?(.+)$/,lD=(function(){function e(t){this._timelineOptions=[],this._mediaList=[],this._currentMediaIndices=[],this._api=t}return e.prototype.setOption=function(t,r,n){t&&(M(Mt(t.series),function(o){o&&o.data&&ie(o.data)&&hs(o.data)}),M(Mt(t.dataset),function(o){o&&o.source&&ie(o.source)&&hs(o.source)})),t=st(t);var i=this._optionBackup,a=uD(t,r,!i);this._newBaseOption=a.baseOption,i?(a.timelineOptions.length&&(i.timelineOptions=a.timelineOptions),a.mediaList.length&&(i.mediaList=a.mediaList),a.mediaDefault&&(i.mediaDefault=a.mediaDefault)):this._optionBackup=a},e.prototype.mountOption=function(t){var r=this._optionBackup;return this._timelineOptions=r.timelineOptions,this._mediaList=r.mediaList,this._mediaDefault=r.mediaDefault,this._currentMediaIndices=[],st(t?r.baseOption:this._newBaseOption)},e.prototype.getTimelineOption=function(t){var r,n=this._timelineOptions;if(n.length){var i=t.getComponent("timeline");i&&(r=st(n[i.getCurrentIndex()]))}return r},e.prototype.getMediaOption=function(t){var r=this._api.getWidth(),n=this._api.getHeight(),i=this._mediaList,a=this._mediaDefault,o=[],s=[];if(!i.length&&!a)return s;for(var l=0,u=i.length;l<u;l++)fD(i[l].query,r,n)&&o.push(l);return!o.length&&a&&(o=[-1]),o.length&&!vD(o,this._currentMediaIndices)&&(s=$(o,function(f){return st(f===-1?a.option:i[f].option)})),this._currentMediaIndices=o,s},e})();function uD(e,t,r){var n=[],i,a,o=e.baseOption,s=e.timeline,l=e.options,u=e.media,f=!!e.media,h=!!(l||s||o&&o.timeline);o?(a=o,a.timeline||(a.timeline=s)):((h||f)&&(e.options=e.media=null),a=e),f&&z(u)&&M(u,function(v){v&&v.option&&(v.query?n.push(v):i||(i=v))}),c(a),M(l,function(v){return c(v)}),M(n,function(v){return c(v.option)});function c(v){M(t,function(d){d(v,r)})}return{baseOption:a,timelineOptions:l||[],mediaDefault:i,mediaList:n}}function fD(e,t,r){var n={width:t,height:r,aspectratio:t/r},i=!0;return M(e,function(a,o){var s=o.match(sD);if(!(!s||!s[1]||!s[2])){var l=s[1],u=s[2].toLowerCase();hD(n[u],a,l)||(i=!1)}}),i}function hD(e,t,r){return r==="min"?e>=t:r==="max"?e<=t:e===t}function vD(e,t){return e.join(",")===t.join(",")}var Me=M,Va=X,$d=["areaStyle","lineStyle","nodeStyle","linkStyle","chordStyle","label","labelLine"];function bu(e){var t=e&&e.itemStyle;if(t)for(var r=0,n=$d.length;r<n;r++){var i=$d[r],a=t.normal,o=t.emphasis;a&&a[i]&&(e[i]=e[i]||{},e[i].normal?vt(e[i].normal,a[i]):e[i].normal=a[i],a[i]=null),o&&o[i]&&(e[i]=e[i]||{},e[i].emphasis?vt(e[i].emphasis,o[i]):e[i].emphasis=o[i],o[i]=null)}}function Ut(e,t,r){if(e&&e[t]&&(e[t].normal||e[t].emphasis)){var n=e[t].normal,i=e[t].emphasis;n&&(r?(e[t].normal=e[t].emphasis=null,at(e[t],n)):e[t]=n),i&&(e.emphasis=e.emphasis||{},e.emphasis[t]=i,i.focus&&(e.emphasis.focus=i.focus),i.blurScope&&(e.emphasis.blurScope=i.blurScope))}}function va(e){Ut(e,"itemStyle"),Ut(e,"lineStyle"),Ut(e,"areaStyle"),Ut(e,"label"),Ut(e,"labelLine"),Ut(e,"upperLabel"),Ut(e,"edgeLabel")}function Ct(e,t){var r=Va(e)&&e[t],n=Va(r)&&r.textStyle;if(n)for(var i=0,a=yc.length;i<a;i++){var o=yc[i];n.hasOwnProperty(o)&&(r[o]=n[o])}}function ye(e){e&&(va(e),Ct(e,"label"),e.emphasis&&Ct(e.emphasis,"label"))}function cD(e){if(Va(e)){bu(e),va(e),Ct(e,"label"),Ct(e,"upperLabel"),Ct(e,"edgeLabel"),e.emphasis&&(Ct(e.emphasis,"label"),Ct(e.emphasis,"upperLabel"),Ct(e.emphasis,"edgeLabel"));var t=e.markPoint;t&&(bu(t),ye(t));var r=e.markLine;r&&(bu(r),ye(r));var n=e.markArea;n&&ye(n);var i=e.data;if(e.type==="graph"){i=i||e.nodes;var a=e.links||e.edges;if(a&&!ie(a))for(var o=0;o<a.length;o++)ye(a[o]);M(e.categories,function(u){va(u)})}if(i&&!ie(i))for(var o=0;o<i.length;o++)ye(i[o]);if(t=e.markPoint,t&&t.data)for(var s=t.data,o=0;o<s.length;o++)ye(s[o]);if(r=e.markLine,r&&r.data)for(var l=r.data,o=0;o<l.length;o++)z(l[o])?(ye(l[o][0]),ye(l[o][1])):ye(l[o]);e.type==="gauge"?(Ct(e,"axisLabel"),Ct(e,"title"),Ct(e,"detail")):e.type==="treemap"?(Ut(e.breadcrumb,"itemStyle"),M(e.levels,function(u){va(u)})):e.type==="tree"&&va(e.leaves)}}function je(e){return z(e)?e:e?[e]:[]}function qd(e){return(z(e)?e[0]:e)||{}}function dD(e,t){Me(je(e.series),function(n){Va(n)&&cD(n)});var r=["xAxis","yAxis","radiusAxis","angleAxis","singleAxis","parallelAxis","radar"];t&&r.push("valueAxis","categoryAxis","logAxis","timeAxis"),Me(r,function(n){Me(je(e[n]),function(i){i&&(Ct(i,"axisLabel"),Ct(i.axisPointer,"label"))})}),Me(je(e.parallel),function(n){var i=n&&n.parallelAxisDefault;Ct(i,"axisLabel"),Ct(i&&i.axisPointer,"label")}),Me(je(e.calendar),function(n){Ut(n,"itemStyle"),Ct(n,"dayLabel"),Ct(n,"monthLabel"),Ct(n,"yearLabel")}),Me(je(e.radar),function(n){Ct(n,"name"),n.name&&n.axisName==null&&(n.axisName=n.name,delete n.name),n.nameGap!=null&&n.axisNameGap==null&&(n.axisNameGap=n.nameGap,delete n.nameGap)}),Me(je(e.geo),function(n){Va(n)&&(ye(n),Me(je(n.regions),function(i){ye(i)}))}),Me(je(e.timeline),function(n){ye(n),Ut(n,"label"),Ut(n,"itemStyle"),Ut(n,"controlStyle",!0);var i=n.data;z(i)&&M(i,function(a){X(a)&&(Ut(a,"label"),Ut(a,"itemStyle"))})}),Me(je(e.toolbox),function(n){Ut(n,"iconStyle"),Me(n.feature,function(i){Ut(i,"iconStyle")})}),Ct(qd(e.axisPointer),"label"),Ct(qd(e.tooltip).axisPointer,"label")}function pD(e,t){for(var r=t.split(","),n=e,i=0;i<r.length&&(n=n&&n[r[i]],n!=null);i++);return n}function gD(e,t,r,n){for(var i=t.split(","),a=e,o,s=0;s<i.length-1;s++)o=i[s],a[o]==null&&(a[o]={}),a=a[o];a[i[s]]==null&&(a[i[s]]=r)}function Kd(e){e&&M(mD,function(t){t[0]in e&&!(t[1]in e)&&(e[t[1]]=e[t[0]])})}var mD=[["x","left"],["y","top"],["x2","right"],["y2","bottom"]],yD=["grid","geo","parallel","legend","toolbox","title","visualMap","dataZoom","timeline"],wu=[["borderRadius","barBorderRadius"],["borderColor","barBorderColor"],["borderWidth","barBorderWidth"]];function Qi(e){var t=e&&e.itemStyle;if(t)for(var r=0;r<wu.length;r++){var n=wu[r][1],i=wu[r][0];t[n]!=null&&(t[i]=t[n])}}function Qd(e){e&&e.alignTo==="edge"&&e.margin!=null&&e.edgeDistance==null&&(e.edgeDistance=e.margin)}function Jd(e){e&&e.downplay&&!e.blur&&(e.blur=e.downplay)}function _D(e){e&&e.focusNodeAdjacency!=null&&(e.emphasis=e.emphasis||{},e.emphasis.focus==null&&(e.emphasis.focus="adjacency"))}function P0(e,t){if(e)for(var r=0;r<e.length;r++)t(e[r]),e[r]&&P0(e[r].children,t)}function R0(e,t){dD(e,t),e.series=Mt(e.series),M(e.series,function(r){if(X(r)){var n=r.type;if(n==="line")r.clipOverflow!=null&&(r.clip=r.clipOverflow);else if(n==="pie"||n==="gauge"){r.clockWise!=null&&(r.clockwise=r.clockWise),Qd(r.label);var i=r.data;if(i&&!ie(i))for(var a=0;a<i.length;a++)Qd(i[a]);r.hoverOffset!=null&&(r.emphasis=r.emphasis||{},(r.emphasis.scaleSize=null)&&(r.emphasis.scaleSize=r.hoverOffset))}else if(n==="gauge"){var o=pD(r,"pointer.color");o!=null&&gD(r,"itemStyle.color",o)}else if(n==="bar"){Qi(r),Qi(r.backgroundStyle),Qi(r.emphasis);var i=r.data;if(i&&!ie(i))for(var a=0;a<i.length;a++)typeof i[a]=="object"&&(Qi(i[a]),Qi(i[a]&&i[a].emphasis))}else if(n==="sunburst"){var s=r.highlightPolicy;s&&(r.emphasis=r.emphasis||{},r.emphasis.focus||(r.emphasis.focus=s)),Jd(r),P0(r.data,Jd)}else n==="graph"||n==="sankey"?_D(r):n==="map"&&(r.mapType&&!r.map&&(r.map=r.mapType),r.mapLocation&&at(r,r.mapLocation));r.hoverAnimation!=null&&(r.emphasis=r.emphasis||{},r.emphasis&&r.emphasis.scale==null&&(r.emphasis.scale=r.hoverAnimation)),Kd(r)}}),e.dataRange&&(e.visualMap=e.dataRange),M(yD,function(r){var n=e[r];n&&(z(n)||(n=[n]),M(n,function(i){Kd(i)}))})}function SD(e){var t=K();e.eachSeries(function(r){var n=r.get("stack");if(n){var i=t.get(n)||t.set(n,[]),a=r.getData(),o={stackResultDimension:a.getCalculationInfo("stackResultDimension"),stackedOverDimension:a.getCalculationInfo("stackedOverDimension"),stackedDimension:a.getCalculationInfo("stackedDimension"),stackedByDimension:a.getCalculationInfo("stackedByDimension"),isStackedByIndex:a.getCalculationInfo("isStackedByIndex"),data:a,seriesModel:r};if(!o.stackedDimension||!(o.isStackedByIndex||o.stackedByDimension))return;i.push(o)}}),t.each(function(r){if(r.length!==0){var n=r[0].seriesModel,i=n.get("stackOrder")||"seriesAsc";i==="seriesDesc"&&r.reverse(),M(r,function(a,o){a.data.setCalculationInfo("stackedOnSeries",o>0?r[o-1].seriesModel:null)}),bD(r)}})}function bD(e){M(e,function(t,r){var n=[],i=[NaN,NaN],a=[t.stackResultDimension,t.stackedOverDimension],o=t.data,s=t.isStackedByIndex,l=t.seriesModel.get("stackStrategy")||"samesign";o.modify(a,function(u,f,h){var c=o.get(t.stackedDimension,h);if(isNaN(c))return i;var v,d;s?d=o.getRawIndex(h):v=o.get(t.stackedByDimension,h);for(var p=NaN,g=r-1;g>=0;g--){var m=e[g];if(s||(d=m.data.rawIndexOf(m.stackedByDimension,v)),d>=0){var y=m.data.getByRawIndex(m.stackResultDimension,d);if(l==="all"||l==="positive"&&y>0||l==="negative"&&y<0||l==="samesign"&&c>=0&&y>0||l==="samesign"&&c<=0&&y<0){c=yb(c,y),p=y;break}}}return n[0]=c,n[1]=p,n})})}var Te=(function(){function e(){this.group=new Ft,this.uid=pl("viewComponent")}return e.prototype.init=function(t,r){},e.prototype.render=function(t,r,n,i){},e.prototype.dispose=function(t,r){},e.prototype.updateView=function(t,r,n,i){},e.prototype.updateLayout=function(t,r,n,i){},e.prototype.updateVisual=function(t,r,n,i){},e.prototype.toggleBlurSeries=function(t,r,n){},e.prototype.eachRendered=function(t){var r=this.group;r&&r.traverse(t)},e})();Sh(Te);js(Te);var jd=gt(),tp={itemStyle:Ia(py,!0),lineStyle:Ia(dy,!0)},wD={lineStyle:"stroke",itemStyle:"fill"};function E0(e,t){var r=e.visualStyleMapper||tp[t];return r||(console.warn("Unknown style type '"+t+"'."),tp.itemStyle)}function k0(e,t){var r=e.visualDrawType||wD[t];return r||(console.warn("Unknown style type '"+t+"'."),"fill")}var xD={createOnAllSeries:!0,performRawSeries:!0,reset:function(e,t){var r=e.getData(),n=e.visualStyleAccessPath||"itemStyle",i=e.getModel(n),a=E0(e,n),o=a(i),s=i.getShallow("decal");s&&(r.setVisual("decal",s),s.dirty=!0);var l=k0(e,n),u=o[l],f=et(u)?u:null,h=o.fill==="auto"||o.stroke==="auto";if(!o[l]||f||h){var c=e.getColorFromPalette(e.name,null,t.getSeriesCount());o[l]||(o[l]=c,r.setVisual("colorFromPalette",!0)),o.fill=o.fill==="auto"||et(o.fill)?c:o.fill,o.stroke=o.stroke==="auto"||et(o.stroke)?c:o.stroke}if(r.setVisual("style",o),r.setVisual("drawType",l),!t.isSeriesFiltered(e)&&f)return r.setVisual("colorFromPalette",!1),{dataEach:function(v,d){var p=e.getDataParams(d),g=k({},o);g[l]=f(p),v.setItemVisual(d,"style",g)}}}},Ji=new xt,TD={createOnAllSeries:!0,performRawSeries:!0,reset:function(e,t){if(!(e.ignoreStyleOnData||t.isSeriesFiltered(e))){var r=e.getData(),n=e.visualStyleAccessPath||"itemStyle",i=E0(e,n),a=r.getVisual("drawType");return{dataEach:r.hasItemOption?function(o,s){var l=o.getRawDataItem(s);if(l&&l[n]){Ji.option=l[n];var u=i(Ji),f=o.ensureUniqueItemVisual(s,"style");k(f,u),Ji.option.decal&&(o.setItemVisual(s,"decal",Ji.option.decal),Ji.option.decal.dirty=!0),a in u&&o.setItemVisual(s,"colorFromPalette",!1)}}:null}}}},CD={performRawSeries:!0,overallReset:function(e){var t=K();e.eachSeries(function(r){var n=r.getColorBy();if(!r.isColorBySeries()){var i=r.type+"-"+n,a=t.get(i);a||(a={},t.set(i,a)),jd(r).scope=a}}),e.eachSeries(function(r){if(!(r.isColorBySeries()||e.isSeriesFiltered(r))){var n=r.getRawData(),i={},a=r.getData(),o=jd(r).scope,s=r.visualStyleAccessPath||"itemStyle",l=k0(r,s);a.each(function(u){var f=a.getRawIndex(u);i[f]=u}),n.each(function(u){var f=i[u],h=a.getItemVisual(f,"colorFromPalette");if(h){var c=a.ensureUniqueItemVisual(f,"style"),v=n.getName(u)||u+"",d=n.count();c[l]=r.getColorFromPalette(v,o,d)}})}})}},Po=Math.PI;function MD(e,t){t=t||{},at(t,{text:"loading",textColor:Y.color.primary,fontSize:12,fontWeight:"normal",fontStyle:"normal",fontFamily:"sans-serif",maskColor:"rgba(255,255,255,0.8)",showSpinner:!0,color:Y.color.theme[0],spinnerRadius:10,lineWidth:5,zlevel:0});var r=new Ft,n=new Tt({style:{fill:t.maskColor},zlevel:t.zlevel,z:1e4});r.add(n);var i=new ae({style:{text:t.text,fill:t.textColor,fontSize:t.fontSize,fontWeight:t.fontWeight,fontStyle:t.fontStyle,fontFamily:t.fontFamily},zlevel:t.zlevel,z:10001}),a=new Tt({style:{fill:"none"},textContent:i,textConfig:{position:"right",distance:10},zlevel:t.zlevel,z:10001});r.add(a);var o;return t.showSpinner&&(o=new ul({shape:{startAngle:-Po/2,endAngle:-Po/2+.1,r:t.spinnerRadius},style:{stroke:t.color,lineCap:"round",lineWidth:t.lineWidth},zlevel:t.zlevel,z:10001}),o.animateShape(!0).when(1e3,{endAngle:Po*3/2}).start("circularInOut"),o.animateShape(!0).when(1e3,{startAngle:Po*3/2}).delay(300).start("circularInOut"),r.add(o)),r.resize=function(){var s=i.getBoundingRect().width,l=t.showSpinner?t.spinnerRadius:0,u=(e.getWidth()-l*2-(t.showSpinner&&s?10:0)-s)/2-(t.showSpinner&&s?0:5+s/2)+(t.showSpinner?0:s/2)+(s?0:l),f=e.getHeight()/2;t.showSpinner&&o.setShape({cx:u,cy:f}),a.setShape({x:u-l,y:f-l,width:l*2,height:l*2}),n.setShape({x:0,y:0,width:e.getWidth(),height:e.getHeight()})},r.resize(),r}var O0=(function(){function e(t,r,n,i){this._stageTaskMap=K(),this.ecInstance=t,this.api=r,n=this._dataProcessorHandlers=n.slice(),i=this._visualHandlers=i.slice(),this._allHandlers=n.concat(i)}return e.prototype.restoreData=function(t,r){t.restoreData(r),this._stageTaskMap.each(function(n){var i=n.overallTask;i&&i.dirty()})},e.prototype.getPerformArgs=function(t,r){if(t.__pipeline){var n=this._pipelineMap.get(t.__pipeline.id),i=n.context,a=!r&&n.progressiveEnabled&&(!i||i.progressiveRender)&&t.__idxInPipeline>n.blockIndex,o=a?n.step:null,s=i&&i.modDataCount,l=s!=null?Math.ceil(s/o):null;return{step:o,modBy:l,modDataCount:s}}},e.prototype.getPipeline=function(t){return this._pipelineMap.get(t)},e.prototype.updateStreamModes=function(t,r){var n=this._pipelineMap.get(t.uid),i=t.getData(),a=i.count(),o=n.progressiveEnabled&&r.incrementalPrepareRender&&a>=n.threshold,s=t.get("large")&&a>=t.get("largeThreshold"),l=t.get("progressiveChunkMode")==="mod"?a:null;t.pipelineContext=n.context={progressiveRender:o,modDataCount:l,large:s}},e.prototype.restorePipelines=function(t){var r=this,n=r._pipelineMap=K();t.eachSeries(function(i){var a=i.getProgressive(),o=i.uid;n.set(o,{id:o,head:null,tail:null,threshold:i.getProgressiveThreshold(),progressiveEnabled:a&&!(i.preventIncremental&&i.preventIncremental()),blockIndex:-1,step:Math.round(a||700),count:0}),r._pipe(i,i.dataTask)})},e.prototype.prepareStageTasks=function(){var t=this._stageTaskMap,r=this.api.getModel(),n=this.api;M(this._allHandlers,function(i){var a=t.get(i.uid)||t.set(i.uid,{}),o="";fr(!(i.reset&&i.overallReset),o),i.reset&&this._createSeriesStageTask(i,a,r,n),i.overallReset&&this._createOverallStageTask(i,a,r,n)},this)},e.prototype.prepareView=function(t,r,n,i){var a=t.renderTask,o=a.context;o.model=r,o.ecModel=n,o.api=i,a.__block=!t.incrementalPrepareRender,this._pipe(r,a)},e.prototype.performDataProcessorTasks=function(t,r){this._performStageTasks(this._dataProcessorHandlers,t,r,{block:!0})},e.prototype.performVisualTasks=function(t,r,n){this._performStageTasks(this._visualHandlers,t,r,n)},e.prototype._performStageTasks=function(t,r,n,i){i=i||{};var a=!1,o=this;M(t,function(l,u){if(!(i.visualType&&i.visualType!==l.visualType)){var f=o._stageTaskMap.get(l.uid),h=f.seriesTaskMap,c=f.overallTask;if(c){var v,d=c.agentStubMap;d.each(function(g){s(i,g)&&(g.dirty(),v=!0)}),v&&c.dirty(),o.updatePayload(c,n);var p=o.getPerformArgs(c,i.block);d.each(function(g){g.perform(p)}),c.perform(p)&&(a=!0)}else h&&h.each(function(g,m){s(i,g)&&g.dirty();var y=o.getPerformArgs(g,i.block);y.skip=!l.performRawSeries&&r.isSeriesFiltered(g.context.model),o.updatePayload(g,n),g.perform(y)&&(a=!0)})}});function s(l,u){return l.setDirty&&(!l.dirtyMap||l.dirtyMap.get(u.__pipeline.id))}this.unfinished=a||this.unfinished},e.prototype.performSeriesTasks=function(t){var r;t.eachSeries(function(n){r=n.dataTask.perform()||r}),this.unfinished=r||this.unfinished},e.prototype.plan=function(){this._pipelineMap.each(function(t){var r=t.tail;do{if(r.__block){t.blockIndex=r.__idxInPipeline;break}r=r.getUpstream()}while(r)})},e.prototype.updatePayload=function(t,r){r!=="remain"&&(t.context.payload=r)},e.prototype._createSeriesStageTask=function(t,r,n,i){var a=this,o=r.seriesTaskMap,s=r.seriesTaskMap=K(),l=t.seriesType,u=t.getTargetSeries;t.createOnAllSeries?n.eachRawSeries(f):l?n.eachRawSeriesByType(l,f):u&&u(n,i).each(f);function f(h){var c=h.uid,v=s.set(c,o&&o.get(c)||Ta({plan:PD,reset:RD,count:kD}));v.context={model:h,ecModel:n,api:i,useClearVisual:t.isVisual&&!t.isLayout,plan:t.plan,reset:t.reset,scheduler:a},a._pipe(h,v)}},e.prototype._createOverallStageTask=function(t,r,n,i){var a=this,o=r.overallTask=r.overallTask||Ta({reset:DD});o.context={ecModel:n,api:i,overallReset:t.overallReset,scheduler:a};var s=o.agentStubMap,l=o.agentStubMap=K(),u=t.seriesType,f=t.getTargetSeries,h=!0,c=!1,v="";fr(!t.createOnAllSeries,v),u?n.eachRawSeriesByType(u,d):f?f(n,i).each(d):(h=!1,M(n.getSeries(),d));function d(p){var g=p.uid,m=l.set(g,s&&s.get(g)||(c=!0,Ta({reset:AD,onDirty:ID})));m.context={model:p,overallProgress:h},m.agent=o,m.__block=h,a._pipe(p,m)}c&&o.dirty()},e.prototype._pipe=function(t,r){var n=t.uid,i=this._pipelineMap.get(n);!i.head&&(i.head=r),i.tail&&i.tail.pipe(r),i.tail=r,r.__idxInPipeline=i.count++,r.__pipeline=i},e.wrapStageHandler=function(t,r){return et(t)&&(t={overallReset:t,seriesType:OD(t)}),t.uid=pl("stageHandler"),r&&(t.visualType=r),t},e})();function DD(e){e.overallReset(e.ecModel,e.api,e.payload)}function AD(e){return e.overallProgress&&LD}function LD(){this.agent.dirty(),this.getDownstream().dirty()}function ID(){this.agent&&this.agent.dirty()}function PD(e){return e.plan?e.plan(e.model,e.ecModel,e.api,e.payload):null}function RD(e){e.useClearVisual&&e.data.clearAllVisual();var t=e.resetDefines=Mt(e.reset(e.model,e.ecModel,e.api,e.payload));return t.length>1?$(t,function(r,n){return B0(n)}):ED}var ED=B0(0);function B0(e){return function(t,r){var n=r.data,i=r.resetDefines[e];if(i&&i.dataEach)for(var a=t.start;a<t.end;a++)i.dataEach(n,a);else i&&i.progress&&i.progress(t,n)}}function kD(e){return e.data.count()}function OD(e){Bs=null;try{e(Ga,N0)}catch{}return Bs}var Ga={},N0={},Bs;F0(Ga,uv);F0(N0,I0);Ga.eachSeriesByType=Ga.eachRawSeriesByType=function(e){Bs=e};Ga.eachComponent=function(e){e.mainType==="series"&&e.subType&&(Bs=e.subType)};function F0(e,t){for(var r in t.prototype)e[r]=qt}var B=Y.darkColor,BD=B.background,ji=function(){return{axisLine:{lineStyle:{color:B.axisLine}},splitLine:{lineStyle:{color:B.axisSplitLine}},splitArea:{areaStyle:{color:[B.backgroundTint,B.backgroundTransparent]}},minorSplitLine:{lineStyle:{color:B.axisMinorSplitLine}},axisLabel:{color:B.axisLabel},axisName:{}}},ep={label:{color:B.secondary},itemStyle:{borderColor:B.borderTint},dividerLineStyle:{color:B.border}},z0={darkMode:!0,color:B.theme,backgroundColor:BD,axisPointer:{lineStyle:{color:B.border},crossStyle:{color:B.borderShade},label:{color:B.tertiary}},legend:{textStyle:{color:B.secondary},pageTextStyle:{color:B.tertiary}},textStyle:{color:B.secondary},title:{textStyle:{color:B.primary},subtextStyle:{color:B.quaternary}},toolbox:{iconStyle:{borderColor:B.accent50}},tooltip:{backgroundColor:B.neutral20,defaultBorderColor:B.border,textStyle:{color:B.tertiary}},dataZoom:{borderColor:B.accent10,textStyle:{color:B.tertiary},brushStyle:{color:B.backgroundTint},handleStyle:{color:B.neutral00,borderColor:B.accent20},moveHandleStyle:{color:B.accent40},emphasis:{handleStyle:{borderColor:B.accent50}},dataBackground:{lineStyle:{color:B.accent30},areaStyle:{color:B.accent20}},selectedDataBackground:{lineStyle:{color:B.accent50},areaStyle:{color:B.accent30}}},visualMap:{textStyle:{color:B.secondary},handleStyle:{borderColor:B.neutral30}},timeline:{lineStyle:{color:B.accent10},label:{color:B.tertiary},controlStyle:{color:B.accent30,borderColor:B.accent30}},calendar:{itemStyle:{color:B.neutral00,borderColor:B.neutral20},dayLabel:{color:B.tertiary},monthLabel:{color:B.secondary},yearLabel:{color:B.secondary}},matrix:{x:ep,y:ep,backgroundColor:{borderColor:B.axisLine},body:{itemStyle:{borderColor:B.borderTint}}},timeAxis:ji(),logAxis:ji(),valueAxis:ji(),categoryAxis:ji(),line:{symbol:"circle"},graph:{color:B.theme},gauge:{title:{color:B.secondary},axisLine:{lineStyle:{color:[[1,B.neutral05]]}},axisLabel:{color:B.axisLabel},detail:{color:B.primary}},candlestick:{itemStyle:{color:"#f64e56",color0:"#54ea92",borderColor:"#f64e56",borderColor0:"#54ea92"}},funnel:{itemStyle:{borderColor:B.background}},radar:(function(){var e=ji();return e.axisName={color:B.axisLabel},e.axisLine.lineStyle.color=B.neutral20,e})(),treemap:{breadcrumb:{itemStyle:{color:B.neutral20,textStyle:{color:B.secondary}},emphasis:{itemStyle:{color:B.neutral30}}}},sunburst:{itemStyle:{borderColor:B.background}},map:{itemStyle:{borderColor:B.border,areaColor:B.neutral10},label:{color:B.tertiary},emphasis:{label:{color:B.primary},itemStyle:{areaColor:B.highlight}},select:{label:{color:B.primary},itemStyle:{areaColor:B.highlight}}},geo:{itemStyle:{borderColor:B.border,areaColor:B.neutral10},emphasis:{label:{color:B.primary},itemStyle:{areaColor:B.highlight}},select:{label:{color:B.primary},itemStyle:{color:B.highlight}}}};z0.categoryAxis.splitLine.show=!1;var ND=(function(){function e(){}return e.prototype.normalizeQuery=function(t){var r={},n={},i={};if(W(t)){var a=We(t);r.mainType=a.main||null,r.subType=a.sub||null}else{var o=["Index","Name","Id"],s={name:1,dataIndex:1,dataType:1};M(t,function(l,u){for(var f=!1,h=0;h<o.length;h++){var c=o[h],v=u.lastIndexOf(c);if(v>0&&v===u.length-c.length){var d=u.slice(0,v);d!=="data"&&(r.mainType=d,r[c.toLowerCase()]=l,f=!0)}}s.hasOwnProperty(u)&&(n[u]=l,f=!0),f||(i[u]=l)})}return{cptQuery:r,dataQuery:n,otherQuery:i}},e.prototype.filter=function(t,r){var n=this.eventInfo;if(!n)return!0;var i=n.targetEl,a=n.packedEvent,o=n.model,s=n.view;if(!o||!s)return!0;var l=r.cptQuery,u=r.dataQuery;return f(l,o,"mainType")&&f(l,o,"subType")&&f(l,o,"index","componentIndex")&&f(l,o,"name")&&f(l,o,"id")&&f(u,a,"name")&&f(u,a,"dataIndex")&&f(u,a,"dataType")&&(!s.filterForExposedEvent||s.filterForExposedEvent(t,r.otherQuery,i,a));function f(h,c,v,d){return h[v]==null||c[d||v]===h[v]}},e.prototype.afterTrigger=function(){this.eventInfo=null},e})(),Uf=["symbol","symbolSize","symbolRotate","symbolOffset"],rp=Uf.concat(["symbolKeepAspect"]),FD={createOnAllSeries:!0,performRawSeries:!0,reset:function(e,t){var r=e.getData();if(e.legendIcon&&r.setVisual("legendIcon",e.legendIcon),!e.hasSymbolVisual)return;for(var n={},i={},a=!1,o=0;o<Uf.length;o++){var s=Uf[o],l=e.get(s);et(l)?(a=!0,i[s]=l):n[s]=l}if(n.symbol=n.symbol||e.defaultSymbol,r.setVisual(k({legendIcon:e.legendIcon||n.symbol,symbolKeepAspect:e.get("symbolKeepAspect")},n)),t.isSeriesFiltered(e))return;var u=St(i);function f(h,c){for(var v=e.getRawValue(c),d=e.getDataParams(c),p=0;p<u.length;p++){var g=u[p];h.setItemVisual(c,g,i[g](v,d))}}return{dataEach:a?f:null}}},zD={createOnAllSeries:!0,performRawSeries:!0,reset:function(e,t){if(!e.hasSymbolVisual||t.isSeriesFiltered(e))return;var r=e.getData();function n(i,a){for(var o=i.getItemModel(a),s=0;s<rp.length;s++){var l=rp[s],u=o.getShallow(l,!0);u!=null&&i.setItemVisual(a,l,u)}}return{dataEach:r.hasItemOption?n:null}}};function HD(e,t,r){switch(r){case"color":var n=e.getItemVisual(t,"style");return n[e.getVisual("drawType")];case"opacity":return e.getItemVisual(t,"style").opacity;case"symbol":case"symbolSize":case"liftZ":return e.getItemVisual(t,r)}}function VD(e,t){switch(t){case"color":var r=e.getVisual("style");return r[e.getVisual("drawType")];case"opacity":return e.getVisual("style").opacity;case"symbol":case"symbolSize":case"liftZ":return e.getVisual(t)}}function ca(e,t,r){for(var n;e&&!(t(e)&&(n=e,r));)e=e.__hostTarget||e.parent;return n}var GD=Math.round(Math.random()*9),WD=typeof Object.defineProperty=="function",UD=(function(){function e(){this._id="__ec_inner_"+GD++}return e.prototype.get=function(t){return this._guard(t)[this._id]},e.prototype.set=function(t,r){var n=this._guard(t);return WD?Object.defineProperty(n,this._id,{value:r,enumerable:!1,configurable:!0}):n[this._id]=r,this},e.prototype.delete=function(t){return this.has(t)?(delete this._guard(t)[this._id],!0):!1},e.prototype.has=function(t){return!!this._guard(t)[this._id]},e.prototype._guard=function(t){if(t!==Object(t))throw TypeError("Value of WeakMap is not a non-null object.");return t},e})();function Tn(e){return isFinite(e)}function YD(e,t,r){var n=t.x==null?0:t.x,i=t.x2==null?1:t.x2,a=t.y==null?0:t.y,o=t.y2==null?0:t.y2;t.global||(n=n*r.width+r.x,i=i*r.width+r.x,a=a*r.height+r.y,o=o*r.height+r.y),n=Tn(n)?n:0,i=Tn(i)?i:1,a=Tn(a)?a:0,o=Tn(o)?o:0;var s=e.createLinearGradient(n,a,i,o);return s}function ZD(e,t,r){var n=r.width,i=r.height,a=Math.min(n,i),o=t.x==null?.5:t.x,s=t.y==null?.5:t.y,l=t.r==null?.5:t.r;t.global||(o=o*n+r.x,s=s*i+r.y,l=l*a),o=Tn(o)?o:.5,s=Tn(s)?s:.5,l=l>=0&&Tn(l)?l:.5;var u=e.createRadialGradient(o,s,0,o,s,l);return u}function Yf(e,t,r){for(var n=t.type==="radial"?ZD(e,t,r):YD(e,t,r),i=t.colorStops,a=0;a<i.length;a++)n.addColorStop(i[a].offset,i[a].color);return n}function XD(e,t){if(e===t||!e&&!t)return!1;if(!e||!t||e.length!==t.length)return!0;for(var r=0;r<e.length;r++)if(e[r]!==t[r])return!0;return!1}function Ro(e){return parseInt(e,10)}function Eo(e,t,r){var n=["width","height"][t],i=["clientWidth","clientHeight"][t],a=["paddingLeft","paddingTop"][t],o=["paddingRight","paddingBottom"][t];if(r[n]!=null&&r[n]!=="auto")return parseFloat(r[n]);var s=document.defaultView.getComputedStyle(e);return(e[i]||Ro(s[n])||Ro(e.style[n]))-(Ro(s[a])||0)-(Ro(s[o])||0)|0}function $D(e,t){return!e||e==="solid"||!(t>0)?null:e==="dashed"?[4*t,2*t]:e==="dotted"?[t]:mt(e)?[e]:z(e)?e:null}function H0(e){var t=e.style,r=t.lineDash&&t.lineWidth>0&&$D(t.lineDash,t.lineWidth),n=t.lineDashOffset;if(r){var i=t.strokeNoScale&&e.getLineScale?e.getLineScale():1;i&&i!==1&&(r=$(r,function(a){return a/i}),n/=i)}return[r,n]}var qD=new hr(!0);function Ns(e){var t=e.stroke;return!(t==null||t==="none"||!(e.lineWidth>0))}function np(e){return typeof e=="string"&&e!=="none"}function Fs(e){var t=e.fill;return t!=null&&t!=="none"}function ip(e,t){if(t.fillOpacity!=null&&t.fillOpacity!==1){var r=e.globalAlpha;e.globalAlpha=t.fillOpacity*t.opacity,e.fill(),e.globalAlpha=r}else e.fill()}function ap(e,t){if(t.strokeOpacity!=null&&t.strokeOpacity!==1){var r=e.globalAlpha;e.globalAlpha=t.strokeOpacity*t.opacity,e.stroke(),e.globalAlpha=r}else e.stroke()}function Zf(e,t,r){var n=Qg(t.image,t.__image,r);if(tl(n)){var i=e.createPattern(n,t.repeat||"repeat");if(typeof DOMMatrix=="function"&&i&&i.setTransform){var a=new DOMMatrix;a.translateSelf(t.x||0,t.y||0),a.rotateSelf(0,0,(t.rotation||0)*E1),a.scaleSelf(t.scaleX||1,t.scaleY||1),i.setTransform(a)}return i}}function KD(e,t,r,n){var i,a=Ns(r),o=Fs(r),s=r.strokePercent,l=s<1,u=!t.path;(!t.silent||l)&&u&&t.createPathProxy();var f=t.path||qD,h=t.__dirty;if(!n){var c=r.fill,v=r.stroke,d=o&&!!c.colorStops,p=a&&!!v.colorStops,g=o&&!!c.image,m=a&&!!v.image,y=void 0,_=void 0,S=void 0,w=void 0,b=void 0;(d||p)&&(b=t.getBoundingRect()),d&&(y=h?Yf(e,c,b):t.__canvasFillGradient,t.__canvasFillGradient=y),p&&(_=h?Yf(e,v,b):t.__canvasStrokeGradient,t.__canvasStrokeGradient=_),g&&(S=h||!t.__canvasFillPattern?Zf(e,c,t):t.__canvasFillPattern,t.__canvasFillPattern=S),m&&(w=h||!t.__canvasStrokePattern?Zf(e,v,t):t.__canvasStrokePattern,t.__canvasStrokePattern=w),d?e.fillStyle=y:g&&(S?e.fillStyle=S:o=!1),p?e.strokeStyle=_:m&&(w?e.strokeStyle=w:a=!1)}var x=t.getGlobalScale();f.setScale(x[0],x[1],t.segmentIgnoreThreshold);var C,T;e.setLineDash&&r.lineDash&&(i=H0(t),C=i[0],T=i[1]);var D=!0;(u||h&si)&&(f.setDPR(e.dpr),l?f.setContext(null):(f.setContext(e),D=!1),f.reset(),t.buildPath(f,t.shape,n),f.toStatic(),t.pathUpdated()),D&&f.rebuildPath(e,l?s:1),C&&(e.setLineDash(C),e.lineDashOffset=T),n||(r.strokeFirst?(a&&ap(e,r),o&&ip(e,r)):(o&&ip(e,r),a&&ap(e,r))),C&&e.setLineDash([])}function QD(e,t,r){var n=t.__image=Qg(r.image,t.__image,t,t.onload);if(!(!n||!tl(n))){var i=r.x||0,a=r.y||0,o=t.getWidth(),s=t.getHeight(),l=n.width/n.height;if(o==null&&s!=null?o=s*l:s==null&&o!=null?s=o/l:o==null&&s==null&&(o=n.width,s=n.height),r.sWidth&&r.sHeight){var u=r.sx||0,f=r.sy||0;e.drawImage(n,u,f,r.sWidth,r.sHeight,i,a,o,s)}else if(r.sx&&r.sy){var u=r.sx,f=r.sy,h=o-u,c=s-f;e.drawImage(n,u,f,h,c,i,a,o,s)}else e.drawImage(n,i,a,o,s)}}function JD(e,t,r){var n,i=r.text;if(i!=null&&(i+=""),i){e.font=r.font||Or,e.textAlign=r.textAlign,e.textBaseline=r.textBaseline;var a=void 0,o=void 0;e.setLineDash&&r.lineDash&&(n=H0(t),a=n[0],o=n[1]),a&&(e.setLineDash(a),e.lineDashOffset=o),r.strokeFirst?(Ns(r)&&e.strokeText(i,r.x,r.y),Fs(r)&&e.fillText(i,r.x,r.y)):(Fs(r)&&e.fillText(i,r.x,r.y),Ns(r)&&e.strokeText(i,r.x,r.y)),a&&e.setLineDash([])}}var op=["shadowBlur","shadowOffsetX","shadowOffsetY"],sp=[["lineCap","butt"],["lineJoin","miter"],["miterLimit",10]];function V0(e,t,r,n,i){var a=!1;if(!n&&(r=r||{},t===r))return!1;if(n||t.opacity!==r.opacity){re(e,i),a=!0;var o=Math.max(Math.min(t.opacity,1),0);e.globalAlpha=isNaN(o)?An.opacity:o}(n||t.blend!==r.blend)&&(a||(re(e,i),a=!0),e.globalCompositeOperation=t.blend||An.blend);for(var s=0;s<op.length;s++){var l=op[s];(n||t[l]!==r[l])&&(a||(re(e,i),a=!0),e[l]=e.dpr*(t[l]||0))}return(n||t.shadowColor!==r.shadowColor)&&(a||(re(e,i),a=!0),e.shadowColor=t.shadowColor||An.shadowColor),a}function lp(e,t,r,n,i){var a=Wa(t,i.inHover),o=n?null:r&&Wa(r,i.inHover)||{};if(a===o)return!1;var s=V0(e,a,o,n,i);if((n||a.fill!==o.fill)&&(s||(re(e,i),s=!0),np(a.fill)&&(e.fillStyle=a.fill)),(n||a.stroke!==o.stroke)&&(s||(re(e,i),s=!0),np(a.stroke)&&(e.strokeStyle=a.stroke)),(n||a.opacity!==o.opacity)&&(s||(re(e,i),s=!0),e.globalAlpha=a.opacity==null?1:a.opacity),t.hasStroke()){var l=a.lineWidth,u=l/(a.strokeNoScale&&t.getLineScale?t.getLineScale():1);e.lineWidth!==u&&(s||(re(e,i),s=!0),e.lineWidth=u)}for(var f=0;f<sp.length;f++){var h=sp[f],c=h[0];(n||a[c]!==o[c])&&(s||(re(e,i),s=!0),e[c]=a[c]||h[1])}return s}function jD(e,t,r,n,i){return V0(e,Wa(t,i.inHover),r&&Wa(r,i.inHover),n,i)}function G0(e,t){var r=t.transform,n=e.dpr||1;r?e.setTransform(n*r[0],n*r[1],n*r[2],n*r[3],n*r[4],n*r[5]):e.setTransform(n,0,0,n,0,0)}function tA(e,t,r){for(var n=!1,i=0;i<e.length;i++){var a=e[i];n=n||a.isZeroArea(),G0(t,a),t.beginPath(),a.buildPath(t,a.shape),t.clip()}r.allClipped=n}function eA(e,t){return e&&t?e[0]!==t[0]||e[1]!==t[1]||e[2]!==t[2]||e[3]!==t[3]||e[4]!==t[4]||e[5]!==t[5]:!(!e&&!t)}var up=1,fp=2,hp=3,vp=4;function rA(e){var t=Fs(e),r=Ns(e);return!(e.lineDash||!(+t^+r)||t&&typeof e.fill!="string"||r&&typeof e.stroke!="string"||e.strokePercent<1||e.strokeOpacity<1||e.fillOpacity<1)}function re(e,t){t.batchFill&&e.fill(),t.batchStroke&&e.stroke(),t.batchFill="",t.batchStroke=""}function Wa(e,t){return t&&e.__hoverStyle||e.style}function W0(e,t){Cn(e,t,{inHover:!1,viewWidth:0,viewHeight:0},!0)}function Cn(e,t,r,n){var i=t.transform;if(!t.shouldBePainted(r.viewWidth,r.viewHeight,!1,!1)){t.__dirty&=~ue,t.__isRendered=!1;return}var a=t.__clipPaths,o=r.prevElClipPaths,s=!1,l=!1;if((!o||XD(a,o))&&(o&&o.length&&(re(e,r),e.restore(),l=s=!0,r.prevElClipPaths=null,r.allClipped=!1,r.prevEl=null),a&&a.length&&(re(e,r),e.save(),tA(a,e,r),s=!0),r.prevElClipPaths=a),r.allClipped){t.__isRendered=!1;return}t.beforeBrush&&t.beforeBrush(),t.innerBeforeBrush();var u=r.prevEl;u||(l=s=!0);var f=t instanceof ht&&t.autoBatch&&rA(t.style);s||eA(i,u.transform)?(re(e,r),G0(e,t)):f||re(e,r);var h=Wa(t,r.inHover);t instanceof ht?(r.lastDrawType!==up&&(l=!0,r.lastDrawType=up),lp(e,t,u,l,r),(!f||!r.batchFill&&!r.batchStroke)&&e.beginPath(),KD(e,t,h,f),f&&(r.batchFill=h.fill||"",r.batchStroke=h.stroke||"")):t instanceof ms?(r.lastDrawType!==hp&&(l=!0,r.lastDrawType=hp),lp(e,t,u,l,r),JD(e,t,h)):t instanceof Gr?(r.lastDrawType!==fp&&(l=!0,r.lastDrawType=fp),jD(e,t,u,l,r),QD(e,t,h)):t.getTemporalDisplayables&&(r.lastDrawType!==vp&&(l=!0,r.lastDrawType=vp),nA(e,t,r)),f&&n&&re(e,r),t.innerAfterBrush(),t.afterBrush&&t.afterBrush(),r.prevEl=t,t.__dirty=0,t.__isRendered=!0}function nA(e,t,r){var n=t.getDisplayables(),i=t.getTemporalDisplayables();e.save();var a={prevElClipPaths:null,prevEl:null,allClipped:!1,viewWidth:r.viewWidth,viewHeight:r.viewHeight,inHover:r.inHover},o,s;for(o=t.getCursor(),s=n.length;o<s;o++){var l=n[o];l.beforeBrush&&l.beforeBrush(),l.innerBeforeBrush(),Cn(e,l,a,o===s-1),l.innerAfterBrush(),l.afterBrush&&l.afterBrush(),a.prevEl=l}for(var u=0,f=i.length;u<f;u++){var l=i[u];l.beforeBrush&&l.beforeBrush(),l.innerBeforeBrush(),Cn(e,l,a,u===f-1),l.innerAfterBrush(),l.afterBrush&&l.afterBrush(),a.prevEl=l}t.clearTemporalDisplayables(),t.notClear=!0,e.restore()}var xu=new UD,cp=new xi(100),dp=["symbol","symbolSize","symbolKeepAspect","color","backgroundColor","dashArrayX","dashArrayY","maxTileWidth","maxTileHeight"];function pp(e,t){if(e==="none")return null;var r=t.getDevicePixelRatio(),n=t.getZr(),i=n.painter.type==="svg";e.dirty&&xu.delete(e);var a=xu.get(e);if(a)return a;var o=at(e,{symbol:"rect",symbolSize:1,symbolKeepAspect:!0,color:"rgba(0, 0, 0, 0.2)",backgroundColor:null,dashArrayX:5,dashArrayY:5,rotation:0,maxTileWidth:512,maxTileHeight:512});o.backgroundColor==="none"&&(o.backgroundColor=null);var s={repeat:"repeat"};return l(s),s.rotation=o.rotation,s.scaleX=s.scaleY=i?1:1/r,xu.set(e,s),e.dirty=!1,s;function l(u){for(var f=[r],h=!0,c=0;c<dp.length;++c){var v=o[dp[c]];if(v!=null&&!z(v)&&!W(v)&&!mt(v)&&typeof v!="boolean"){h=!1;break}f.push(v)}var d;if(h){d=f.join(",")+(i?"-svg":"");var p=cp.get(d);p&&(i?u.svgElement=p:u.image=p)}var g=Y0(o.dashArrayX),m=iA(o.dashArrayY),y=U0(o.symbol),_=aA(g),S=Z0(m),w=!i&&ur.createCanvas(),b=i&&{tag:"g",attrs:{},key:"dcl",children:[]},x=T(),C;w&&(w.width=x.width*r,w.height=x.height*r,C=w.getContext("2d")),D(),h&&cp.put(d,w||b),u.image=w,u.svgElement=b,u.svgWidth=x.width,u.svgHeight=x.height;function T(){for(var A=1,P=0,L=_.length;P<L;++P)A=pc(A,_[P]);for(var I=1,P=0,L=y.length;P<L;++P)I=pc(I,y[P].length);A*=I;var R=S*_.length*y.length;return{width:Math.max(1,Math.min(A,o.maxTileWidth)),height:Math.max(1,Math.min(R,o.maxTileHeight))}}function D(){C&&(C.clearRect(0,0,w.width,w.height),o.backgroundColor&&(C.fillStyle=o.backgroundColor,C.fillRect(0,0,w.width,w.height)));for(var A=0,P=0;P<m.length;++P)A+=m[P];if(A<=0)return;for(var L=-S,I=0,R=0,E=0;L<x.height;){if(I%2===0){for(var G=R/2%y.length,F=0,H=0,V=0;F<x.width*2;){for(var U=0,P=0;P<g[E].length;++P)U+=g[E][P];if(U<=0)break;if(H%2===0){var Z=(1-o.symbolSize)*.5,J=F+g[E][H]*Z,ot=L+m[I]*Z,yt=g[E][H]*o.symbolSize,Ht=m[I]*o.symbolSize,ce=V/2%y[G].length;de(J,ot,yt,Ht,y[G][ce])}F+=g[E][H],++V,++H,H===g[E].length&&(H=0)}++E,E===g.length&&(E=0)}L+=m[I],++R,++I,I===m.length&&(I=0)}function de(Vt,Dt,rt,lt,Ur){var Yt=i?1:r,Cv=Bn(Ur,Vt*Yt,Dt*Yt,rt*Yt,lt*Yt,o.color,o.symbolKeepAspect);if(i){var Mv=n.painter.renderOneToVNode(Cv);Mv&&b.children.push(Mv)}else W0(C,Cv)}}}}function U0(e){if(!e||e.length===0)return[["rect"]];if(W(e))return[[e]];for(var t=!0,r=0;r<e.length;++r)if(!W(e[r])){t=!1;break}if(t)return U0([e]);for(var n=[],r=0;r<e.length;++r)W(e[r])?n.push([e[r]]):n.push(e[r]);return n}function Y0(e){if(!e||e.length===0)return[[0,0]];if(mt(e)){var t=Math.ceil(e);return[[t,t]]}for(var r=!0,n=0;n<e.length;++n)if(!mt(e[n])){r=!1;break}if(r)return Y0([e]);for(var i=[],n=0;n<e.length;++n)if(mt(e[n])){var t=Math.ceil(e[n]);i.push([t,t])}else{var t=$(e[n],function(s){return Math.ceil(s)});t.length%2===1?i.push(t.concat(t)):i.push(t)}return i}function iA(e){if(!e||typeof e=="object"&&e.length===0)return[0,0];if(mt(e)){var t=Math.ceil(e);return[t,t]}var r=$(e,function(n){return Math.ceil(n)});return e.length%2?r.concat(r):r}function aA(e){return $(e,function(t){return Z0(t)})}function Z0(e){for(var t=0,r=0;r<e.length;++r)t+=e[r];return e.length%2===1?t*2:t}function oA(e,t){e.eachRawSeries(function(r){if(!e.isSeriesFiltered(r)){var n=r.getData();n.hasItemVisual()&&n.each(function(o){var s=n.getItemVisual(o,"decal");if(s){var l=n.ensureUniqueItemVisual(o,"style");l.decal=pp(s,t)}});var i=n.getVisual("decal");if(i){var a=n.getVisual("style");a.decal=pp(i,t)}}})}var Le=new Ee,X0={};function sA(e,t){X0[e]=t}function lA(e){return X0[e]}var uA=1,fA=800,hA=900,vA=1e3,cA=2e3,dA=5e3,$0=1e3,pA=1100,fv=2e3,q0=3e3,gA=4e3,yl=4500,mA=4600,yA=5e3,_A=6e3,K0=7e3,SA={PROCESSOR:{FILTER:vA,SERIES_FILTER:fA,STATISTIC:dA},VISUAL:{LAYOUT:$0,PROGRESSIVE_LAYOUT:pA,GLOBAL:fv,CHART:q0,POST_CHART_LAYOUT:mA,COMPONENT:gA,BRUSH:yA,CHART_ITEM:yl,ARIA:_A,DECAL:K0}},At="__flagInMainProcess",ko="__mainProcessVersion",Pt="__pendingUpdate",Tu="__needsUpdateStatus",gp=/^[a-zA-Z0-9_]+$/,Cu="__connectUpdateStatus",mp=0,bA=1,wA=2;function Q0(e){return function(){for(var t=[],r=0;r<arguments.length;r++)t[r]=arguments[r];if(this.isDisposed()){this.id;return}return j0(this,e,t)}}function J0(e){return function(){for(var t=[],r=0;r<arguments.length;r++)t[r]=arguments[r];return j0(this,e,t)}}function j0(e,t,r){return r[0]=r[0]&&r[0].toLowerCase(),Ee.prototype[t].apply(e,r)}var t_=(function(e){N(t,e);function t(){return e!==null&&e.apply(this,arguments)||this}return t})(Ee),e_=t_.prototype;e_.on=J0("on");e_.off=J0("off");var gn,Mu,Oo,tr,Bo,Du,Au,ti,ei,yp,_p,Lu,Sp,No,bp,r_,pe,wp,ri,n_=(function(e){N(t,e);function t(r,n,i){var a=e.call(this,new ND)||this;a._chartsViews=[],a._chartsMap={},a._componentsViews=[],a._componentsMap={},a._pendingActions=[],i=i||{},a._dom=r;var o="canvas",s="auto",l=!1;a[ko]=1,i.ssr;var u=a._zr=Gd(r,{renderer:i.renderer||o,devicePixelRatio:i.devicePixelRatio,width:i.width,height:i.height,ssr:i.ssr,useDirtyRect:q(i.useDirtyRect,l),useCoarsePointer:q(i.useCoarsePointer,s),pointerSize:i.pointerSize});a._ssr=i.ssr,a._throttledZrFlush=m0(Q(u.flush,u),17),a._updateTheme(n),a._locale=pT(i.locale||Hy),a._coordSysMgr=new Yh;var f=a._api=bp(a);function h(c,v){return c.__prio-v.__prio}return is(Hs,h),is(qf,h),a._scheduler=new O0(a,f,qf,Hs),a._messageCenter=new t_,a._initEvents(),a.resize=Q(a.resize,a),u.animation.on("frame",a._onframe,a),yp(u,a),_p(u,a),hs(a),a}return t.prototype._onframe=function(){if(!this._disposed){wp(this);var r=this._scheduler;if(this[Pt]){var n=this[Pt].silent;this[At]=!0,ri(this);try{gn(this),tr.update.call(this,null,this[Pt].updateParams)}catch(l){throw this[At]=!1,this[Pt]=null,l}this._zr.flush(),this[At]=!1,this[Pt]=null,ti.call(this,n),ei.call(this,n)}else if(r.unfinished){var i=uA,a=this._model,o=this._api;r.unfinished=!1;do{var s=+new Date;r.performSeriesTasks(a),r.performDataProcessorTasks(a),Du(this,a),r.performVisualTasks(a),No(this,this._model,o,"remain",{}),i-=+new Date-s}while(i>0&&r.unfinished);r.unfinished||this._zr.flush()}}},t.prototype.getDom=function(){return this._dom},t.prototype.getId=function(){return this.id},t.prototype.getZr=function(){return this._zr},t.prototype.isSSR=function(){return this._ssr},t.prototype.setOption=function(r,n,i){if(!this[At]){if(this._disposed){this.id;return}var a,o,s;if(X(n)&&(i=n.lazyUpdate,a=n.silent,o=n.replaceMerge,s=n.transition,n=n.notMerge),this[At]=!0,ri(this),!this._model||n){var l=new lD(this._api),u=this._theme,f=this._model=new uv;f.scheduler=this._scheduler,f.ssr=this._ssr,f.init(null,null,null,u,this._locale,l)}this._model.setOption(r,{replaceMerge:o},Kf);var h={seriesTransition:s,optionChanged:!0};if(i)this[Pt]={silent:a,updateParams:h},this[At]=!1,this.getZr().wakeUp();else{try{gn(this),tr.update.call(this,null,h)}catch(c){throw this[Pt]=null,this[At]=!1,c}this._ssr||this._zr.flush(),this[Pt]=null,this[At]=!1,ti.call(this,a),ei.call(this,a)}}},t.prototype.setTheme=function(r,n){if(!this[At]){if(this._disposed){this.id;return}var i=this._model;if(i){var a=n&&n.silent,o=null;this[Pt]&&(a==null&&(a=this[Pt].silent),o=this[Pt].updateParams,this[Pt]=null),this[At]=!0,ri(this);try{this._updateTheme(r),i.setTheme(this._theme),gn(this),tr.update.call(this,{type:"setTheme"},o)}catch(s){throw this[At]=!1,s}this[At]=!1,ti.call(this,a),ei.call(this,a)}}},t.prototype._updateTheme=function(r){W(r)&&(r=i_[r]),r&&(r=st(r),r&&R0(r,!0),this._theme=r)},t.prototype.getModel=function(){return this._model},t.prototype.getOption=function(){return this._model&&this._model.getOption()},t.prototype.getWidth=function(){return this._zr.getWidth()},t.prototype.getHeight=function(){return this._zr.getHeight()},t.prototype.getDevicePixelRatio=function(){return this._zr.painter.dpr||nt.hasGlobalWindow&&window.devicePixelRatio||1},t.prototype.getRenderedCanvas=function(r){return this.renderToCanvas(r)},t.prototype.renderToCanvas=function(r){r=r||{};var n=this._zr.painter;return n.getRenderedCanvas({backgroundColor:r.backgroundColor||this._model.get("backgroundColor"),pixelRatio:r.pixelRatio||this.getDevicePixelRatio()})},t.prototype.renderToSVGString=function(r){r=r||{};var n=this._zr.painter;return n.renderToString({useViewBox:r.useViewBox})},t.prototype.getSvgDataURL=function(){var r=this._zr,n=r.storage.getDisplayList();return M(n,function(i){i.stopAnimation(null,!0)}),r.painter.toDataURL()},t.prototype.getDataURL=function(r){if(this._disposed){this.id;return}r=r||{};var n=r.excludeComponents,i=this._model,a=[],o=this;M(n,function(l){i.eachComponent({mainType:l},function(u){var f=o._componentsMap[u.__viewId];f.group.ignore||(a.push(f),f.group.ignore=!0)})});var s=this._zr.painter.getType()==="svg"?this.getSvgDataURL():this.renderToCanvas(r).toDataURL("image/"+(r&&r.type||"png"));return M(a,function(l){l.group.ignore=!1}),s},t.prototype.getConnectedDataURL=function(r){if(this._disposed){this.id;return}var n=r.type==="svg",i=this.group,a=Math.min,o=Math.max,s=1/0;if(xp[i]){var l=s,u=s,f=-s,h=-s,c=[],v=r&&r.pixelRatio||this.getDevicePixelRatio();M(Ca,function(_,S){if(_.group===i){var w=n?_.getZr().painter.getSvgDom().innerHTML:_.renderToCanvas(st(r)),b=_.getDom().getBoundingClientRect();l=a(b.left,l),u=a(b.top,u),f=o(b.right,f),h=o(b.bottom,h),c.push({dom:w,left:b.left,top:b.top})}}),l*=v,u*=v,f*=v,h*=v;var d=f-l,p=h-u,g=ur.createCanvas(),m=Gd(g,{renderer:n?"svg":"canvas"});if(m.resize({width:d,height:p}),n){var y="";return M(c,function(_){var S=_.left-l,w=_.top-u;y+='<g transform="translate('+S+","+w+')">'+_.dom+"</g>"}),m.painter.getSvgRoot().innerHTML=y,r.connectedBackgroundColor&&m.painter.setBackgroundColor(r.connectedBackgroundColor),m.refreshImmediately(),m.painter.toDataURL()}else return r.connectedBackgroundColor&&m.add(new Tt({shape:{x:0,y:0,width:d,height:p},style:{fill:r.connectedBackgroundColor}})),M(c,function(_){var S=new Gr({style:{x:_.left*v-l,y:_.top*v-u,image:_.dom}});m.add(S)}),m.refreshImmediately(),g.toDataURL("image/"+(r&&r.type||"png"))}else return this.getDataURL(r)},t.prototype.convertToPixel=function(r,n,i){return Bo(this,"convertToPixel",r,n,i)},t.prototype.convertToLayout=function(r,n,i){return Bo(this,"convertToLayout",r,n,i)},t.prototype.convertFromPixel=function(r,n,i){return Bo(this,"convertFromPixel",r,n,i)},t.prototype.containPixel=function(r,n){if(this._disposed){this.id;return}var i=this._model,a,o=Wl(i,r);return M(o,function(s,l){l.indexOf("Models")>=0&&M(s,function(u){var f=u.coordinateSystem;if(f&&f.containPoint)a=a||!!f.containPoint(n);else if(l==="seriesModels"){var h=this._chartsMap[u.__viewId];h&&h.containPoint&&(a=a||h.containPoint(n,u))}},this)},this),!!a},t.prototype.getVisual=function(r,n){var i=this._model,a=Wl(i,r,{defaultMainType:"series"}),o=a.seriesModel,s=o.getData(),l=a.hasOwnProperty("dataIndexInside")?a.dataIndexInside:a.hasOwnProperty("dataIndex")?s.indexOfRawIndex(a.dataIndex):null;return l!=null?HD(s,l,n):VD(s,n)},t.prototype.getViewOfComponentModel=function(r){return this._componentsMap[r.__viewId]},t.prototype.getViewOfSeriesModel=function(r){return this._chartsMap[r.__viewId]},t.prototype._initEvents=function(){var r=this;M(xA,function(i){var a=function(o){var s=r.getModel(),l=o.target,u,f=i==="globalout";if(f?u={}:l&&ca(l,function(p){var g=pt(p);if(g&&g.dataIndex!=null){var m=g.dataModel||s.getSeriesByIndex(g.seriesIndex);return u=m&&m.getDataParams(g.dataIndex,g.dataType,l)||{},!0}else if(g.eventData)return u=k({},g.eventData),!0},!0),u){var h=u.componentType,c=u.componentIndex;(h==="markLine"||h==="markPoint"||h==="markArea")&&(h="series",c=u.seriesIndex);var v=h&&c!=null&&s.getComponent(h,c),d=v&&r[v.mainType==="series"?"_chartsMap":"_componentsMap"][v.__viewId];u.event=o,u.type=i,r._$eventProcessor.eventInfo={targetEl:l,packedEvent:u,model:v,view:d},r.trigger(i,u)}};a.zrEventfulCallAtLast=!0,r._zr.on(i,a,r)});var n=this._messageCenter;M($f,function(i,a){n.on(a,function(o){r.trigger(a,o)})}),uM(n,this,this._api)},t.prototype.isDisposed=function(){return this._disposed},t.prototype.clear=function(){if(this._disposed){this.id;return}this.setOption({series:[]},!0)},t.prototype.dispose=function(){if(this._disposed){this.id;return}this._disposed=!0;var r=this.getDom();r&&Em(this.getDom(),vv,"");var n=this,i=n._api,a=n._model;M(n._componentsViews,function(o){o.dispose(a,i)}),M(n._chartsViews,function(o){o.dispose(a,i)}),n._zr.dispose(),n._dom=n._model=n._chartsMap=n._componentsMap=n._chartsViews=n._componentsViews=n._scheduler=n._api=n._zr=n._throttledZrFlush=n._theme=n._coordSysMgr=n._messageCenter=null,delete Ca[n.id]},t.prototype.resize=function(r){if(!this[At]){if(this._disposed){this.id;return}this._zr.resize(r);var n=this._model;if(this._loadingFX&&this._loadingFX.resize(),!!n){var i=n.resetOption("media"),a=r&&r.silent;this[Pt]&&(a==null&&(a=this[Pt].silent),i=!0,this[Pt]=null),this[At]=!0,ri(this);try{i&&gn(this),tr.update.call(this,{type:"resize",animation:k({duration:0},r&&r.animation)})}catch(o){throw this[At]=!1,o}this[At]=!1,ti.call(this,a),ei.call(this,a)}}},t.prototype.showLoading=function(r,n){if(this._disposed){this.id;return}if(X(r)&&(n=r,r=""),r=r||"default",this.hideLoading(),!!Qf[r]){var i=Qf[r](this._api,n),a=this._zr;this._loadingFX=i,a.add(i)}},t.prototype.hideLoading=function(){if(this._disposed){this.id;return}this._loadingFX&&this._zr.remove(this._loadingFX),this._loadingFX=null},t.prototype.makeActionFromEvent=function(r){var n=k({},r);return n.type=Xf[r.type],n},t.prototype.dispatchAction=function(r,n){if(this._disposed){this.id;return}if(X(n)||(n={silent:!!n}),!!zs[r.type]&&this._model){if(this[At]){this._pendingActions.push(r);return}var i=n.silent;Au.call(this,r,i);var a=n.flush;a?this._zr.flush():a!==!1&&nt.browser.weChat&&this._throttledZrFlush(),ti.call(this,i),ei.call(this,i)}},t.prototype.updateLabelLayout=function(){Le.trigger("series:layoutlabels",this._model,this._api,{updatedSeries:[]})},t.prototype.appendData=function(r){if(this._disposed){this.id;return}var n=r.seriesIndex,i=this.getModel(),a=i.getSeriesByIndex(n);a.appendData(r),this._scheduler.unfinished=!0,this.getZr().wakeUp()},t.internalField=(function(){gn=function(h){var c=h._scheduler;c.restorePipelines(h._model),c.prepareStageTasks(),Mu(h,!0),Mu(h,!1),c.plan()},Mu=function(h,c){for(var v=h._model,d=h._scheduler,p=c?h._componentsViews:h._chartsViews,g=c?h._componentsMap:h._chartsMap,m=h._zr,y=h._api,_=0;_<p.length;_++)p[_].__alive=!1;c?v.eachComponent(function(b,x){b!=="series"&&S(x)}):v.eachSeries(S);function S(b){var x=b.__requireNewView;b.__requireNewView=!1;var C="_ec_"+b.id+"_"+b.type,T=!x&&g[C];if(!T){var D=We(b.type),A=c?Te.getClass(D.main,D.sub):$e.getClass(D.sub);T=new A,T.init(v,y),g[C]=T,p.push(T),m.add(T.group)}b.__viewId=T.__id=C,T.__alive=!0,T.__model=b,T.group.__ecComponentInfo={mainType:b.mainType,index:b.componentIndex},!c&&d.prepareView(T,b,v,y)}for(var _=0;_<p.length;){var w=p[_];w.__alive?_++:(!c&&w.renderTask.dispose(),m.remove(w.group),w.dispose(v,y),p.splice(_,1),g[w.__id]===w&&delete g[w.__id],w.__id=w.group.__ecComponentInfo=null)}},Oo=function(h,c,v,d,p){var g=h._model;if(g.setUpdatePayload(v),!d){M([].concat(h._componentsViews).concat(h._chartsViews),w);return}var m={};m[d+"Id"]=v[d+"Id"],m[d+"Index"]=v[d+"Index"],m[d+"Name"]=v[d+"Name"];var y={mainType:d,query:m};p&&(y.subType=p);var _=v.excludeSeriesId,S;_!=null&&(S=K(),M(Mt(_),function(b){var x=Xe(b,null);x!=null&&S.set(x,!0)})),g&&g.eachComponent(y,function(b){var x=S&&S.get(b.id)!=null;if(!x)if(Ac(v))if(b instanceof Hr)v.type===Ln&&!v.notBlur&&!b.get(["emphasis","disabled"])&&Qb(b,v,h._api);else{var C=Ph(b.mainType,b.componentIndex,v.name,h._api),T=C.focusSelf,D=C.dispatchers;v.type===Ln&&T&&!v.notBlur&&Sf(b.mainType,b.componentIndex,h._api),D&&M(D,function(A){v.type===Ln?ws(A):xs(A)})}else xf(v)&&b instanceof Hr&&(tw(b,v,h._api),Cc(b),pe(h))},h),g&&g.eachComponent(y,function(b){var x=S&&S.get(b.id)!=null;x||w(h[d==="series"?"_chartsMap":"_componentsMap"][b.__viewId])},h);function w(b){b&&b.__alive&&b[c]&&b[c](b.__model,g,h._api,v)}},tr={prepareAndUpdate:function(h){gn(this),tr.update.call(this,h,h&&{optionChanged:h.newOption!=null})},update:function(h,c){var v=this._model,d=this._api,p=this._zr,g=this._coordSysMgr,m=this._scheduler;if(v){v.setUpdatePayload(h),m.restoreData(v,h),m.performSeriesTasks(v),g.create(v,d),m.performDataProcessorTasks(v,h),Du(this,v),g.update(v,d),n(v),m.performVisualTasks(v,h);var y=v.get("backgroundColor")||"transparent";p.setBackgroundColor(y);var _=v.get("darkMode");_!=null&&_!=="auto"&&p.setDarkMode(_),Lu(this,v,d,h,c),Le.trigger("afterupdate",v,d)}},updateTransform:function(h){var c=this,v=this._model,d=this._api;if(v){v.setUpdatePayload(h);var p=[];v.eachComponent(function(m,y){if(m!=="series"){var _=c.getViewOfComponentModel(y);if(_&&_.__alive)if(_.updateTransform){var S=_.updateTransform(y,v,d,h);S&&S.update&&p.push(_)}else p.push(_)}});var g=K();v.eachSeries(function(m){var y=c._chartsMap[m.__viewId];if(y.updateTransform){var _=y.updateTransform(m,v,d,h);_&&_.update&&g.set(m.uid,1)}else g.set(m.uid,1)}),n(v),this._scheduler.performVisualTasks(v,h,{setDirty:!0,dirtyMap:g}),No(this,v,d,h,{},g),Le.trigger("afterupdate",v,d)}},updateView:function(h){var c=this._model;c&&(c.setUpdatePayload(h),$e.markUpdateMethod(h,"updateView"),n(c),this._scheduler.performVisualTasks(c,h,{setDirty:!0}),Lu(this,c,this._api,h,{}),Le.trigger("afterupdate",c,this._api))},updateVisual:function(h){var c=this,v=this._model;v&&(v.setUpdatePayload(h),v.eachSeries(function(d){d.getData().clearAllVisual()}),$e.markUpdateMethod(h,"updateVisual"),n(v),this._scheduler.performVisualTasks(v,h,{visualType:"visual",setDirty:!0}),v.eachComponent(function(d,p){if(d!=="series"){var g=c.getViewOfComponentModel(p);g&&g.__alive&&g.updateVisual(p,v,c._api,h)}}),v.eachSeries(function(d){var p=c._chartsMap[d.__viewId];p.updateVisual(d,v,c._api,h)}),Le.trigger("afterupdate",v,this._api))},updateLayout:function(h){tr.update.call(this,h)}};function r(h,c,v,d,p){if(h._disposed){h.id;return}for(var g=h._model,m=h._coordSysMgr.getCoordinateSystems(),y,_=Wl(g,v),S=0;S<m.length;S++){var w=m[S];if(w[c]&&(y=w[c](g,_,d,p))!=null)return y}}Bo=r,Du=function(h,c){var v=h._chartsMap,d=h._scheduler;c.eachSeries(function(p){d.updateStreamModes(p,v[p.__viewId])})},Au=function(h,c){var v=this,d=this.getModel(),p=h.type,g=h.escapeConnect,m=zs[p],y=(m.update||"update").split(":"),_=y.pop(),S=y[0]!=null&&We(y[0]);this[At]=!0,ri(this);var w=[h],b=!1;h.batch&&(b=!0,w=$(h.batch,function(E){return E=at(k({},E),h),E.batch=null,E}));var x=[],C,T=[],D=m.nonRefinedEventType,A=xf(h),P=Ac(h);if(P&&Wm(this._api),M(w,function(E){var G=m.action(E,d,v._api);if(m.refineEvent?T.push(G):C=G,C=C||k({},E),C.type=D,x.push(C),P){var F=Mh(h),H=F.queryOptionMap,V=F.mainTypeSpecified,U=V?H.keys()[0]:"series";Oo(v,_,E,U),pe(v)}else A?(Oo(v,_,E,"series"),pe(v)):S&&Oo(v,_,E,S.main,S.sub)}),_!=="none"&&!P&&!A&&!S)try{this[Pt]?(gn(this),tr.update.call(this,h),this[Pt]=null):tr[_].call(this,h)}catch(E){throw this[At]=!1,E}if(b?C={type:D,escapeConnect:g,batch:x}:C=x[0],this[At]=!1,!c){var L=void 0;if(m.refineEvent){var I=m.refineEvent(T,h,d,this._api).eventContent;fr(X(I)),L=at({type:m.refinedEventType},I),L.fromAction=h.type,L.fromActionPayload=h,L.escapeConnect=!0}var R=this._messageCenter;R.trigger(C.type,C),L&&R.trigger(L.type,L)}},ti=function(h){for(var c=this._pendingActions;c.length;){var v=c.shift();Au.call(this,v,h)}},ei=function(h){!h&&this.trigger("updated")},yp=function(h,c){h.on("rendered",function(v){c.trigger("rendered",v),h.animation.isFinished()&&!c[Pt]&&!c._scheduler.unfinished&&!c._pendingActions.length&&c.trigger("finished")})},_p=function(h,c){h.on("mouseover",function(v){var d=v.target,p=ca(d,wf);p&&(Jb(p,v,c._api),pe(c))}).on("mouseout",function(v){var d=v.target,p=ca(d,wf);p&&(jb(p,v,c._api),pe(c))}).on("click",function(v){var d=v.target,p=ca(d,function(y){return pt(y).dataIndex!=null},!0);if(p){var g=p.selected?"unselect":"select",m=pt(p);c._api.dispatchAction({type:g,dataType:m.dataType,dataIndexInside:m.dataIndex,seriesIndex:m.seriesIndex,isFromClick:!0})}})};function n(h){h.clearColorPalette(),h.eachSeries(function(c){c.clearColorPalette()})}function i(h){var c=[],v=[],d=!1;if(h.eachComponent(function(y,_){var S=_.get("zlevel")||0,w=_.get("z")||0,b=_.getZLevelKey();d=d||!!b,(y==="series"?v:c).push({zlevel:S,z:w,idx:_.componentIndex,type:y,key:b})}),d){var p=c.concat(v),g,m;is(p,function(y,_){return y.zlevel===_.zlevel?y.z-_.z:y.zlevel-_.zlevel}),M(p,function(y){var _=h.getComponent(y.type,y.idx),S=y.zlevel,w=y.key;g!=null&&(S=Math.max(g,S)),w?(S===g&&w!==m&&S++,m=w):m&&(S===g&&S++,m=""),g=S,_.setZLevel(S)})}}Lu=function(h,c,v,d,p){i(c),Sp(h,c,v,d,p),M(h._chartsViews,function(g){g.__alive=!1}),No(h,c,v,d,p),M(h._chartsViews,function(g){g.__alive||g.remove(c,v)})},Sp=function(h,c,v,d,p,g){M(g||h._componentsViews,function(m){var y=m.__model;u(y,m),m.render(y,c,v,d),l(y,m),f(y,m)})},No=function(h,c,v,d,p,g){var m=h._scheduler;p=k(p||{},{updatedSeries:c.getSeries()}),Le.trigger("series:beforeupdate",c,v,p);var y=!1;c.eachSeries(function(_){var S=h._chartsMap[_.__viewId];S.__alive=!0;var w=S.renderTask;m.updatePayload(w,d),u(_,S),g&&g.get(_.uid)&&w.dirty(),w.perform(m.getPerformArgs(w))&&(y=!0),S.group.silent=!!_.get("silent"),s(_,S),Cc(_)}),m.unfinished=y||m.unfinished,Le.trigger("series:layoutlabels",c,v,p),Le.trigger("series:transition",c,v,p),c.eachSeries(function(_){var S=h._chartsMap[_.__viewId];l(_,S),f(_,S)}),o(h,c),Le.trigger("series:afterupdate",c,v,p)},pe=function(h){h[Tu]=!0,h.getZr().wakeUp()},ri=function(h){h[ko]=(h[ko]+1)%1e3},wp=function(h){h[Tu]&&(h.getZr().storage.traverse(function(c){bi(c)||a(c)}),h[Tu]=!1)};function a(h){for(var c=[],v=h.currentStates,d=0;d<v.length;d++){var p=v[d];p==="emphasis"||p==="blur"||p==="select"||c.push(p)}h.selected&&h.states.select&&c.push("select"),h.hoverState===ol&&h.states.emphasis?c.push("emphasis"):h.hoverState===al&&h.states.blur&&c.push("blur"),h.useStates(c)}function o(h,c){var v=h._zr,d=v.storage,p=0;d.traverse(function(g){g.isGroup||p++}),p>c.get("hoverLayerThreshold")&&!nt.node&&!nt.worker&&c.eachSeries(function(g){if(!g.preventUsingHoverLayer){var m=h._chartsMap[g.__viewId];m.__alive&&m.eachRendered(function(y){y.states.emphasis&&(y.states.emphasis.hoverLayer=!0)})}})}function s(h,c){var v=h.get("blendMode")||null;c.eachRendered(function(d){d.isGroup||(d.style.blend=v)})}function l(h,c){if(!h.preventAutoZ){var v=Na(h);c.eachRendered(function(d){return fy(d,v.z,v.zlevel),!0})}}function u(h,c){c.eachRendered(function(v){if(!bi(v)){var d=v.getTextContent(),p=v.getTextGuideLine();v.stateTransition&&(v.stateTransition=null),d&&d.stateTransition&&(d.stateTransition=null),p&&p.stateTransition&&(p.stateTransition=null),v.hasState()?(v.prevStates=v.currentStates,v.clearStates()):v.prevStates&&(v.prevStates=null)}})}function f(h,c){var v=h.getModel("stateAnimation"),d=h.isAnimationEnabled(),p=v.get("duration"),g=p>0?{duration:p,delay:v.get("delay"),easing:v.get("easing")}:null;c.eachRendered(function(m){if(m.states&&m.states.emphasis){if(bi(m))return;if(m instanceof ht&&ow(m),m.__dirty){var y=m.prevStates;y&&m.useStates(y)}if(d){m.stateTransition=g;var _=m.getTextContent(),S=m.getTextGuideLine();_&&(_.stateTransition=g),S&&(S.stateTransition=g)}m.__dirty&&a(m)}})}bp=function(h){return new((function(c){N(v,c);function v(){return c!==null&&c.apply(this,arguments)||this}return v.prototype.getCoordinateSystems=function(){return h._coordSysMgr.getCoordinateSystems()},v.prototype.getComponentByElement=function(d){for(;d;){var p=d.__ecComponentInfo;if(p!=null)return h._model.getComponent(p.mainType,p.index);d=d.parent}},v.prototype.enterEmphasis=function(d,p){ws(d,p),pe(h)},v.prototype.leaveEmphasis=function(d,p){xs(d,p),pe(h)},v.prototype.enterBlur=function(d){Kb(d),pe(h)},v.prototype.leaveBlur=function(d){zm(d),pe(h)},v.prototype.enterSelect=function(d){Hm(d),pe(h)},v.prototype.leaveSelect=function(d){Vm(d),pe(h)},v.prototype.getModel=function(){return h.getModel()},v.prototype.getViewOfComponentModel=function(d){return h.getViewOfComponentModel(d)},v.prototype.getViewOfSeriesModel=function(d){return h.getViewOfSeriesModel(d)},v.prototype.getMainProcessVersion=function(){return h[ko]},v})(I0))(h)},r_=function(h){function c(v,d){for(var p=0;p<v.length;p++){var g=v[p];g[Cu]=d}}M(Xf,function(v,d){h._messageCenter.on(d,function(p){if(xp[h.group]&&h[Cu]!==mp){if(p&&p.escapeConnect)return;var g=h.makeActionFromEvent(p),m=[];M(Ca,function(y){y!==h&&y.group===h.group&&m.push(y)}),c(m,mp),M(m,function(y){y[Cu]!==bA&&y.dispatchAction(g)}),c(m,wA)}})})}})(),t})(Ee),hv=n_.prototype;hv.on=Q0("on");hv.off=Q0("off");hv.one=function(e,t,r){var n=this;function i(){for(var a=[],o=0;o<arguments.length;o++)a[o]=arguments[o];t&&t.apply&&t.apply(this,a),n.off(e,i)}this.on.call(this,e,i,r)};var xA=["click","dblclick","mouseover","mouseout","mousemove","mousedown","mouseup","globalout","contextmenu"];var zs={},Xf={},$f={},qf=[],Kf=[],Hs=[],i_={},Qf={},Ca={},xp={},TA=+new Date-0,vv="_echarts_instance_";function CA(e,t,r){{var n=MA(e);if(n)return n}var i=new n_(e,t,r);return i.id="ec_"+TA++,Ca[i.id]=i,Em(e,vv,i.id),r_(i),Le.trigger("afterinit",i),i}function MA(e){return Ca[Fb(e,vv)]}function a_(e,t){i_[e]=t}function o_(e){ft(Kf,e)<0&&Kf.push(e)}function s_(e,t){dv(qf,e,t,cA)}function DA(e){cv("afterinit",e)}function AA(e){cv("afterupdate",e)}function cv(e,t){Le.on(e,t)}function zn(e,t,r){var n,i,a,o,s;et(t)&&(r=t,t=""),X(e)?(n=e.type,i=e.event,o=e.update,s=e.publishNonRefinedEvent,r||(r=e.action),a=e.refineEvent):(n=e,i=t);function l(f){return f.toLowerCase()}i=l(i||n);var u=a?l(n):i;zs[n]||(fr(gp.test(n)&&gp.test(i)),a&&fr(i!==n),zs[n]={actionType:n,refinedEventType:i,nonRefinedEventType:u,update:o,action:r,refineEvent:a},$f[i]=1,a&&s&&($f[u]=1),Xf[u]=n)}function LA(e,t){Yh.register(e,t)}function IA(e,t){dv(Hs,e,t,$0,"layout")}function Hn(e,t){dv(Hs,e,t,q0,"visual")}var Tp=[];function dv(e,t,r,n,i){if((et(t)||X(t))&&(r=t,t=n),!(ft(Tp,r)>=0)){Tp.push(r);var a=O0.wrapStageHandler(r,i);a.__prio=t,a.__raw=r,e.push(a)}}function l_(e,t){Qf[e]=t}function PA(e,t,r){var n=lA("registerMap");n&&n(e,t,r)}var RA=ZT;Hn(fv,xD);Hn(yl,TD);Hn(yl,CD);Hn(fv,FD);Hn(yl,zD);Hn(K0,oA);o_(R0);s_(hA,SD);l_("default",MD);zn({type:Ln,event:Ln,update:Ln},qt);zn({type:Ko,event:Ko,update:Ko},qt);zn({type:Ss,event:Lh,update:Ss,action:qt,refineEvent:pv,publishNonRefinedEvent:!0});zn({type:yf,event:Lh,update:yf,action:qt,refineEvent:pv,publishNonRefinedEvent:!0});zn({type:bs,event:Lh,update:bs,action:qt,refineEvent:pv,publishNonRefinedEvent:!0});function pv(e,t,r,n){return{eventContent:{selected:ew(r),isFromClick:t.isFromClick||!1}}}a_("default",{});a_("dark",z0);var Cp=[],EA={registerPreprocessor:o_,registerProcessor:s_,registerPostInit:DA,registerPostUpdate:AA,registerUpdateLifecycle:cv,registerAction:zn,registerCoordinateSystem:LA,registerLayout:IA,registerVisual:Hn,registerTransform:RA,registerLoading:l_,registerMap:PA,registerImpl:sA,PRIORITY:SA,ComponentModel:dt,ComponentView:Te,SeriesModel:Hr,ChartView:$e,registerComponentModel:function(e){dt.registerClass(e)},registerComponentView:function(e){Te.registerClass(e)},registerSeriesModel:function(e){Hr.registerClass(e)},registerChartView:function(e){$e.registerClass(e)},registerCustomSeries:function(e,t){},registerSubTypeDefaulter:function(e,t){dt.registerSubTypeDefaulter(e,t)},registerPainter:function(e,t){JM(e,t)}};function Nn(e){if(z(e)){M(e,function(t){Nn(t)});return}ft(Cp,e)>=0||(Cp.push(e),et(e)&&(e={install:e}),e.install(EA))}var u_={left:0,right:0,top:0,bottom:0},Vs=["25%","25%"],kA=(function(e){N(t,e);function t(){return e!==null&&e.apply(this,arguments)||this}return t.prototype.mergeDefaultAndTheme=function(r,n){var i=eo(r.outerBounds);e.prototype.mergeDefaultAndTheme.apply(this,arguments),i&&r.outerBounds&&On(r.outerBounds,i)},t.prototype.mergeOption=function(r,n){e.prototype.mergeOption.apply(this,arguments),this.option.outerBounds&&r.outerBounds&&On(this.option.outerBounds,r.outerBounds)},t.type="grid",t.dependencies=["xAxis","yAxis"],t.layoutMode="box",t.defaultOption={show:!1,z:0,left:"15%",top:65,right:"10%",bottom:80,containLabel:!1,outerBoundsMode:"auto",outerBounds:u_,outerBoundsContain:"all",outerBoundsClampWidth:Vs[0],outerBoundsClampHeight:Vs[1],backgroundColor:Y.color.transparent,borderWidth:1,borderColor:Y.color.neutral30},t})(dt),OA=(function(){function e(){}return e.prototype.getNeedCrossZero=function(){var t=this.option;return!t.scale},e.prototype.getCoordSysModel=function(){},e})(),Jf=(function(e){N(t,e);function t(){return e!==null&&e.apply(this,arguments)||this}return t.prototype.getCoordSysModel=function(){return this.getReferringComponents("grid",$t).models[0]},t.type="cartesian2dAxis",t})(dt);Ke(Jf,OA);var f_={show:!0,z:0,inverse:!1,name:"",nameLocation:"end",nameRotate:null,nameTruncate:{maxWidth:null,ellipsis:"...",placeholder:"."},nameTextStyle:{},nameGap:15,silent:!1,triggerEvent:!1,tooltip:{show:!1},axisPointer:{},axisLine:{show:!0,onZero:!0,onZeroAxisIndex:null,lineStyle:{color:Y.color.axisLine,width:1,type:"solid"},symbol:["none","none"],symbolSize:[10,15],breakLine:!0},axisTick:{show:!0,inside:!1,length:5,lineStyle:{width:1}},axisLabel:{show:!0,inside:!1,rotate:0,showMinLabel:null,showMaxLabel:null,margin:8,fontSize:12,color:Y.color.axisLabel,textMargin:[0,3]},splitLine:{show:!0,showMinLine:!0,showMaxLine:!0,lineStyle:{color:Y.color.axisSplitLine,width:1,type:"solid"}},splitArea:{show:!1,areaStyle:{color:[Y.color.backgroundTint,Y.color.backgroundTransparent]}},breakArea:{show:!0,itemStyle:{color:Y.color.neutral00,borderColor:Y.color.border,borderWidth:1,borderType:[3,3],opacity:.6},zigzagAmplitude:4,zigzagMinSpan:4,zigzagMaxSpan:20,zigzagZ:100,expandOnClick:!0},breakLabelLayout:{moveOverlap:"auto"}},BA=vt({boundaryGap:!0,deduplication:null,jitter:0,jitterOverlap:!0,jitterMargin:2,splitLine:{show:!1},axisTick:{alignWithLabel:!1,interval:"auto",show:"auto"},axisLabel:{interval:"auto"}},f_),gv=vt({boundaryGap:[0,0],axisLine:{show:"auto"},axisTick:{show:"auto"},splitNumber:5,minorTick:{show:!1,splitNumber:5,length:3,lineStyle:{}},minorSplitLine:{show:!1,lineStyle:{color:Y.color.axisMinorSplitLine,width:1}}},f_),NA=vt({splitNumber:6,axisLabel:{showMinLabel:!1,showMaxLabel:!1,rich:{primary:{fontWeight:"bold"}}},splitLine:{show:!1}},gv),FA=at({logBase:10},gv);const zA={category:BA,value:gv,time:NA,log:FA};var HA=0,jf=(function(){function e(t){this.categories=t.categories||[],this._needCollect=t.needCollect,this._deduplication=t.deduplication,this.uid=++HA,this._onCollect=t.onCollect}return e.createByAxisModel=function(t){var r=t.option,n=r.data,i=n&&$(n,VA);return new e({categories:i,needCollect:!i,deduplication:r.dedplication!==!1})},e.prototype.getOrdinal=function(t){return this._getOrCreateMap().get(t)},e.prototype.parseAndCollect=function(t){var r,n=this._needCollect;if(!W(t)&&!n)return t;if(n&&!this._deduplication)return r=this.categories.length,this.categories[r]=t,this._onCollect&&this._onCollect(t,r),r;var i=this._getOrCreateMap();return r=i.get(t),r==null&&(n?(r=this.categories.length,this.categories[r]=t,i.set(t,r),this._onCollect&&this._onCollect(t,r)):r=NaN),r},e.prototype._getOrCreateMap=function(){return this._map||(this._map=K(this.categories))},e})();function VA(e){return X(e)&&e.value!=null?e.value:e+""}var GA={value:1,category:1,time:1,log:1},WA=null;function UA(){return WA}function Mp(e,t,r,n){M(GA,function(i,a){var o=vt(vt({},zA[a],!0),n,!0),s=(function(l){N(u,l);function u(){var f=l!==null&&l.apply(this,arguments)||this;return f.type=t+"Axis."+a,f}return u.prototype.mergeDefaultAndTheme=function(f,h){var c=za(this),v=c?eo(f):{},d=h.getTheme();vt(f,d.get(a+"Axis")),vt(f,this.getDefaultOption()),f.type=Dp(f),c&&On(f,v,c)},u.prototype.optionUpdated=function(){var f=this.option;f.type==="category"&&(this.__ordinalMeta=jf.createByAxisModel(this))},u.prototype.getCategories=function(f){var h=this.option;if(h.type==="category")return f?h.data:this.__ordinalMeta.categories},u.prototype.getOrdinalMeta=function(){return this.__ordinalMeta},u.prototype.updateAxisBreaks=function(f){return{breaks:[]}},u.type=t+"Axis."+a,u.defaultOption=o,u})(r);e.registerComponentModel(s)}),e.registerSubTypeDefaulter(t+"Axis",Dp)}function Dp(e){return e.type||(e.data?"category":"value")}function th(e){return e.type==="interval"||e.type==="log"}function YA(e,t,r,n,i){var a={},o=a.interval=Mm(t/r);n!=null&&o<n&&(o=a.interval=n),i!=null&&o>i&&(o=a.interval=i);var s=a.intervalPrecision=Ua(o),l=a.niceTickExtent=[Nt(Math.ceil(e[0]/o)*o,s),Nt(Math.floor(e[1]/o)*o,s)];return ZA(l,e),a}function Iu(e){var t=Math.pow(10,Ch(e)),r=e/t;return r?r===2?r=3:r===3?r=5:r*=2:r=1,Nt(r*t)}function Ua(e){return ar(e)+2}function Ap(e,t,r){e[t]=Math.max(Math.min(e[t],r[1]),r[0])}function ZA(e,t){!isFinite(e[0])&&(e[0]=t[0]),!isFinite(e[1])&&(e[1]=t[1]),Ap(e,0,t),Ap(e,1,t),e[0]>e[1]&&(e[0]=e[1])}function mv(e,t){return e>=t[0]&&e<=t[1]}var XA=(function(){function e(){this.normalize=Lp,this.scale=Ip}return e.prototype.updateMethods=function(t){t.hasBreaks()?(this.normalize=Q(t.normalize,t),this.scale=Q(t.scale,t)):(this.normalize=Lp,this.scale=Ip)},e})();function Lp(e,t){return t[1]===t[0]?.5:(e-t[0])/(t[1]-t[0])}function Ip(e,t){return e*(t[1]-t[0])+t[0]}function eh(e,t,r){var n=Math.log(e);return[Math.log(r?t[0]:Math.max(0,t[0]))/n,Math.log(r?t[1]:Math.max(0,t[1]))/n]}var Wr=(function(){function e(t){this._calculator=new XA,this._setting=t||{},this._extent=[1/0,-1/0]}return e.prototype.getSetting=function(t){return this._setting[t]},e.prototype._innerUnionExtent=function(t){var r=this._extent;this._innerSetExtent(t[0]<r[0]?t[0]:r[0],t[1]>r[1]?t[1]:r[1])},e.prototype.unionExtentFromData=function(t,r){this._innerUnionExtent(t.getApproximateExtent(r))},e.prototype.getExtent=function(){return this._extent.slice()},e.prototype.setExtent=function(t,r){this._innerSetExtent(t,r)},e.prototype._innerSetExtent=function(t,r){var n=this._extent;isNaN(t)||(n[0]=t),isNaN(r)||(n[1]=r),this._brkCtx&&this._brkCtx.update(n)},e.prototype.setBreaksFromOption=function(t){},e.prototype._innerSetBreak=function(t){this._brkCtx&&(this._brkCtx.setBreaks(t),this._calculator.updateMethods(this._brkCtx),this._brkCtx.update(this._extent))},e.prototype._innerGetBreaks=function(){return this._brkCtx?this._brkCtx.breaks:[]},e.prototype.hasBreaks=function(){return this._brkCtx?this._brkCtx.hasBreaks():!1},e.prototype._getExtentSpanWithBreaks=function(){return this._brkCtx&&this._brkCtx.hasBreaks()?this._brkCtx.getExtentSpan():this._extent[1]-this._extent[0]},e.prototype.isInExtentRange=function(t){return this._extent[0]<=t&&this._extent[1]>=t},e.prototype.isBlank=function(){return this._isBlank},e.prototype.setBlank=function(t){this._isBlank=t},e})();js(Wr);var h_=(function(e){N(t,e);function t(r){var n=e.call(this,r)||this;n.type="ordinal";var i=n.getSetting("ordinalMeta");return i||(i=new jf({})),z(i)&&(i=new jf({categories:$(i,function(a){return X(a)?a.value:a})})),n._ordinalMeta=i,n._extent=n.getSetting("extent")||[0,i.categories.length-1],n}return t.prototype.parse=function(r){return r==null?NaN:W(r)?this._ordinalMeta.getOrdinal(r):Math.round(r)},t.prototype.contain=function(r){return mv(r,this._extent)&&r>=0&&r<this._ordinalMeta.categories.length},t.prototype.normalize=function(r){return r=this._getTickNumber(r),this._calculator.normalize(r,this._extent)},t.prototype.scale=function(r){return r=Math.round(this._calculator.scale(r,this._extent)),this.getRawOrdinalNumber(r)},t.prototype.getTicks=function(){for(var r=[],n=this._extent,i=n[0];i<=n[1];)r.push({value:i}),i++;return r},t.prototype.getMinorTicks=function(r){},t.prototype.setSortInfo=function(r){if(r==null){this._ordinalNumbersByTick=this._ticksByOrdinalNumber=null;return}for(var n=r.ordinalNumbers,i=this._ordinalNumbersByTick=[],a=this._ticksByOrdinalNumber=[],o=0,s=this._ordinalMeta.categories.length,l=Math.min(s,n.length);o<l;++o){var u=n[o];i[o]=u,a[u]=o}for(var f=0;o<s;++o){for(;a[f]!=null;)f++;i.push(f),a[f]=o}},t.prototype._getTickNumber=function(r){var n=this._ticksByOrdinalNumber;return n&&r>=0&&r<n.length?n[r]:r},t.prototype.getRawOrdinalNumber=function(r){var n=this._ordinalNumbersByTick;return n&&r>=0&&r<n.length?n[r]:r},t.prototype.getLabel=function(r){if(!this.isBlank()){var n=this.getRawOrdinalNumber(r.value),i=this._ordinalMeta.categories[n];return i==null?"":i+""}},t.prototype.count=function(){return this._extent[1]-this._extent[0]+1},t.prototype.isInExtentRange=function(r){return r=this._getTickNumber(r),this._extent[0]<=r&&this._extent[1]>=r},t.prototype.getOrdinalMeta=function(){return this._ordinalMeta},t.prototype.calcNiceTicks=function(){},t.prototype.calcNiceExtent=function(){},t.type="ordinal",t})(Wr);Wr.registerClass(h_);var wr=Nt,Li=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type="interval",r._interval=0,r._intervalPrecision=2,r}return t.prototype.parse=function(r){return r==null||r===""?NaN:Number(r)},t.prototype.contain=function(r){return mv(r,this._extent)},t.prototype.normalize=function(r){return this._calculator.normalize(r,this._extent)},t.prototype.scale=function(r){return this._calculator.scale(r,this._extent)},t.prototype.getInterval=function(){return this._interval},t.prototype.setInterval=function(r){this._interval=r,this._niceExtent=this._extent.slice(),this._intervalPrecision=Ua(r)},t.prototype.getTicks=function(r){r=r||{};var n=this._interval,i=this._extent,a=this._niceExtent,o=this._intervalPrecision,s=As(),l=[];if(!n)return l;r.breakTicks;var u=1e4;i[0]<a[0]&&(r.expandToNicedExtent?l.push({value:wr(a[0]-n,o)}):l.push({value:i[0]}));for(var f=function(d,p){return Math.round((p-d)/n)},h=a[0];h<=a[1];){if(l.push({value:h}),h=wr(h+n,o),this._brkCtx){var c=this._brkCtx.calcNiceTickMultiple(h,f);c>=0&&(h=wr(h+c*n,o))}if(l.length>0&&h===l[l.length-1].value)break;if(l.length>u)return[]}var v=l.length?l[l.length-1].value:a[1];return i[1]>v&&(r.expandToNicedExtent?l.push({value:wr(v+n,o)}):l.push({value:i[1]})),r.breakTicks,l},t.prototype.getMinorTicks=function(r){for(var n=this.getTicks({expandToNicedExtent:!0}),i=[],a=this.getExtent(),o=1;o<n.length;o++){var s=n[o],l=n[o-1];if(!(l.break||s.break)){for(var u=0,f=[],h=s.value-l.value,c=h/r,v=Ua(c);u<r-1;){var d=wr(l.value+(u+1)*c,v);d>a[0]&&d<a[1]&&f.push(d),u++}var p=As();p&&p.pruneTicksByBreak("auto",f,this._getNonTransBreaks(),function(g){return g},this._interval,a),i.push(f)}}return i},t.prototype._getNonTransBreaks=function(){return this._brkCtx?this._brkCtx.breaks:[]},t.prototype.getLabel=function(r,n){if(r==null)return"";var i=n&&n.precision;i==null?i=ar(r.value)||0:i==="auto"&&(i=this._intervalPrecision);var a=wr(r.value,i,!0);return qy(a)},t.prototype.calcNiceTicks=function(r,n,i){r=r||5;var a=this._extent.slice(),o=this._getExtentSpanWithBreaks();if(isFinite(o)){o<0&&(o=-o,a.reverse(),this._innerSetExtent(a[0],a[1]),a=this._extent.slice());var s=YA(a,o,r,n,i);this._intervalPrecision=s.intervalPrecision,this._interval=s.interval,this._niceExtent=s.niceTickExtent}},t.prototype.calcNiceExtent=function(r){var n=this._extent.slice();if(n[0]===n[1])if(n[0]!==0){var i=Math.abs(n[0]);r.fixMax||(n[1]+=i/2),n[0]-=i/2}else n[1]=1;var a=n[1]-n[0];isFinite(a)||(n[0]=0,n[1]=1),this._innerSetExtent(n[0],n[1]),n=this._extent.slice(),this.calcNiceTicks(r.splitNumber,r.minInterval,r.maxInterval);var o=this._interval,s=this._intervalPrecision;r.fixMin||(n[0]=wr(Math.floor(n[0]/o)*o,s)),r.fixMax||(n[1]=wr(Math.ceil(n[1]/o)*o,s)),this._innerSetExtent(n[0],n[1])},t.prototype.setNiceExtent=function(r,n){this._niceExtent=[r,n]},t.type="interval",t})(Wr);Wr.registerClass(Li);var $A=function(e,t,r,n){for(;r<n;){var i=r+n>>>1;e[i][1]<t?r=i+1:n=i}return r},v_=(function(e){N(t,e);function t(r){var n=e.call(this,r)||this;return n.type="time",n}return t.prototype.getLabel=function(r){var n=this.getSetting("useUTC");return gl(r.value,nd[CT(xa(this._minLevelUnit))]||nd.second,n,this.getSetting("locale"))},t.prototype.getFormattedLabel=function(r,n,i){var a=this.getSetting("useUTC"),o=this.getSetting("locale");return MT(r,n,i,o,a)},t.prototype.getTicks=function(r){var n=this._interval,i=this._extent,a=[];if(!n)return a;var o=this.getSetting("useUTC"),s=Ls(i[1],o);a.push({value:i[0],time:{level:0,upperTimeUnit:s,lowerTimeUnit:s}});var l=rL(this._minLevelUnit,this._approxInterval,o,i,this._getExtentSpanWithBreaks(),this._brkCtx);a=a.concat(l);var u=Ls(i[1],o);a.push({value:i[1],time:{level:0,upperTimeUnit:u,lowerTimeUnit:u}}),this.getSetting("useUTC");var f=In.length-1,h=0;return M(a,function(c){f=Math.min(f,ft(In,c.time.upperTimeUnit)),h=Math.max(h,c.time.level)}),a},t.prototype.calcNiceExtent=function(r){var n=this.getExtent();if(n[0]===n[1]&&(n[0]-=be,n[1]+=be),n[1]===-1/0&&n[0]===1/0){var i=new Date;n[1]=+new Date(i.getFullYear(),i.getMonth(),i.getDate()),n[0]=n[1]-be}this._innerSetExtent(n[0],n[1]),this.calcNiceTicks(r.splitNumber,r.minInterval,r.maxInterval)},t.prototype.calcNiceTicks=function(r,n,i){r=r||10;var a=this._getExtentSpanWithBreaks();this._approxInterval=a/r,n!=null&&this._approxInterval<n&&(this._approxInterval=n),i!=null&&this._approxInterval>i&&(this._approxInterval=i);var o=Fo.length,s=Math.min($A(Fo,this._approxInterval,0,o),o-1);this._interval=Fo[s][1],this._intervalPrecision=Ua(this._interval),this._minLevelUnit=Fo[Math.max(s-1,0)][0]},t.prototype.parse=function(r){return mt(r)?r:+Bi(r)},t.prototype.contain=function(r){return mv(r,this._extent)},t.prototype.normalize=function(r){return this._calculator.normalize(r,this._extent)},t.prototype.scale=function(r){return this._calculator.scale(r,this._extent)},t.type="time",t})(Li),Fo=[["second",$h],["minute",qh],["hour",wa],["quarter-day",wa*6],["half-day",wa*12],["day",be*1.2],["half-week",be*3.5],["week",be*7],["month",be*31],["quarter",be*95],["half-year",rd/2],["year",rd]];function qA(e,t,r,n){return Ef(new Date(t),e,n).getTime()===Ef(new Date(r),e,n).getTime()}function KA(e,t){return e/=be,e>16?16:e>7.5?7:e>3.5?4:e>1.5?2:1}function QA(e){var t=30*be;return e/=t,e>6?6:e>3?3:e>2?2:1}function JA(e){return e/=wa,e>12?12:e>6?6:e>3.5?4:e>2?2:1}function Pp(e,t){return e/=t?qh:$h,e>30?30:e>20?20:e>15?15:e>10?10:e>5?5:e>2?2:1}function jA(e){return Mm(e)}function tL(e,t,r){var n=Math.max(0,ft(In,t)-1);return Ef(new Date(e),In[n],r).getTime()}function eL(e,t){var r=new Date(0);r[e](1);var n=r.getTime();r[e](1+t);var i=r.getTime()-n;return function(a,o){return Math.max(0,Math.round((o-a)/i))}}function rL(e,t,r,n,i,a){var o=1e4,s=bT,l=0;function u(L,I,R,E,G,F,H){for(var V=eL(G,L),U=I,Z=new Date(U);U<R&&U<=n[1]&&(H.push({value:U}),!(l++>o));)if(Z[G](Z[E]()+L),U=Z.getTime(),a){var J=a.calcNiceTickMultiple(U,V);J>0&&(Z[G](Z[E]()+J*L),U=Z.getTime())}H.push({value:U,notAdd:!0})}function f(L,I,R){var E=[],G=!I.length;if(!qA(xa(L),n[0],n[1],r)){G&&(I=[{value:tL(n[0],L,r)},{value:n[1]}]);for(var F=0;F<I.length-1;F++){var H=I[F].value,V=I[F+1].value;if(H!==V){var U=void 0,Z=void 0,J=void 0,ot=!1;switch(L){case"year":U=Math.max(1,Math.round(t/be/365)),Z=Gy(r),J=DT(r);break;case"half-year":case"quarter":case"month":U=QA(t),Z=Kh(r),J=Wy(r);break;case"week":case"half-week":case"day":U=KA(t),Z=Qh(r),J=Uy(r),ot=!0;break;case"half-day":case"quarter-day":case"hour":U=JA(t),Z=Jh(r),J=Yy(r);break;case"minute":U=Pp(t,!0),Z=jh(r),J=Zy(r);break;case"second":U=Pp(t,!1),Z=tv(r),J=Xy(r);break;case"millisecond":U=jA(t),Z=ev(r),J=$y(r);break}V>=n[0]&&H<=n[1]&&u(U,H,V,Z,J,ot,E),L==="year"&&R.length>1&&F===0&&R.unshift({value:R[0].value-U})}}for(var F=0;F<E.length;F++)R.push(E[F])}}for(var h=[],c=[],v=0,d=0,p=0;p<s.length;++p){var g=xa(s[p]);if(TT(s[p])){f(s[p],h[h.length-1]||[],c);var m=s[p+1]?xa(s[p+1]):null;if(g!==m){if(c.length){d=v,c.sort(function(L,I){return L.value-I.value});for(var y=[],_=0;_<c.length;++_){var S=c[_].value;(_===0||c[_-1].value!==S)&&(y.push(c[_]),S>=n[0]&&S<=n[1]&&v++)}var w=i/t;if(v>w*1.5&&d>w/1.5||(h.push(y),v>w||e===s[p]))break}c=[]}}}for(var b=wt($(h,function(L){return wt(L,function(I){return I.value>=n[0]&&I.value<=n[1]&&!I.notAdd})}),function(L){return L.length>0}),x=[],C=b.length-1,p=0;p<b.length;++p)for(var T=b[p],D=0;D<T.length;++D){var A=Ls(T[D].value,r);x.push({value:T[D].value,time:{level:C-p,upperTimeUnit:A,lowerTimeUnit:A}})}x.sort(function(L,I){return L.value-I.value});for(var P=[],p=0;p<x.length;++p)(p===0||x[p].value!==x[p-1].value)&&P.push(x[p]);return P}Wr.registerClass(v_);var rh=Nt,nL=Math.floor,iL=Math.ceil,zo=Math.pow,Ho=Math.log,c_=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type="log",r.base=10,r._originalScale=new Li,r}return t.prototype.getTicks=function(r){r=r||{};var n=this._extent.slice(),i=this._originalScale.getExtent(),a=e.prototype.getTicks.call(this,r),o=this.base;return this._originalScale._innerGetBreaks(),$(a,function(s){var l=s.value,u=null,f=zo(o,l);l===n[0]&&this._fixMin?u=i[0]:l===n[1]&&this._fixMax&&(u=i[1]);var h;return u!=null&&(f=Pu(f,u)),{value:f,break:h}},this)},t.prototype._getNonTransBreaks=function(){return this._originalScale._innerGetBreaks()},t.prototype.setExtent=function(r,n){this._originalScale.setExtent(r,n);var i=eh(this.base,[r,n]);e.prototype.setExtent.call(this,i[0],i[1])},t.prototype.getExtent=function(){var r=this.base,n=e.prototype.getExtent.call(this);n[0]=zo(r,n[0]),n[1]=zo(r,n[1]);var i=this._originalScale.getExtent();return this._fixMin&&(n[0]=Pu(n[0],i[0])),this._fixMax&&(n[1]=Pu(n[1],i[1])),n},t.prototype.unionExtentFromData=function(r,n){this._originalScale.unionExtentFromData(r,n);var i=eh(this.base,r.getApproximateExtent(n),!0);this._innerUnionExtent(i)},t.prototype.calcNiceTicks=function(r){r=r||10;var n=this._extent.slice(),i=this._getExtentSpanWithBreaks();if(!(!isFinite(i)||i<=0)){var a=Sb(i),o=r/i*a;for(o<=.5&&(a*=10);!isNaN(a)&&Math.abs(a)<1&&Math.abs(a)>0;)a*=10;var s=[rh(iL(n[0]/a)*a),rh(nL(n[1]/a)*a)];this._interval=a,this._intervalPrecision=Ua(a),this._niceExtent=s}},t.prototype.calcNiceExtent=function(r){e.prototype.calcNiceExtent.call(this,r),this._fixMin=r.fixMin,this._fixMax=r.fixMax},t.prototype.contain=function(r){return r=Ho(r)/Ho(this.base),e.prototype.contain.call(this,r)},t.prototype.normalize=function(r){return r=Ho(r)/Ho(this.base),e.prototype.normalize.call(this,r)},t.prototype.scale=function(r){return r=e.prototype.scale.call(this,r),zo(this.base,r)},t.prototype.setBreaksFromOption=function(r){},t.type="log",t})(Li);function Pu(e,t){return rh(e,ar(t))}Wr.registerClass(c_);var aL=(function(){function e(t,r,n){this._prepareParams(t,r,n)}return e.prototype._prepareParams=function(t,r,n){n[1]<n[0]&&(n=[NaN,NaN]),this._dataMin=n[0],this._dataMax=n[1];var i=this._isOrdinal=t.type==="ordinal";this._needCrossZero=t.type==="interval"&&r.getNeedCrossZero&&r.getNeedCrossZero();var a=r.get("min",!0);a==null&&(a=r.get("startValue",!0));var o=this._modelMinRaw=a;et(o)?this._modelMinNum=Vo(t,o({min:n[0],max:n[1]})):o!=="dataMin"&&(this._modelMinNum=Vo(t,o));var s=this._modelMaxRaw=r.get("max",!0);if(et(s)?this._modelMaxNum=Vo(t,s({min:n[0],max:n[1]})):s!=="dataMax"&&(this._modelMaxNum=Vo(t,s)),i)this._axisDataLen=r.getCategories().length;else{var l=r.get("boundaryGap"),u=z(l)?l:[l||0,l||0];typeof u[0]=="boolean"||typeof u[1]=="boolean"?this._boundaryGapInner=[0,0]:this._boundaryGapInner=[Rn(u[0],1),Rn(u[1],1)]}},e.prototype.calculate=function(){var t=this._isOrdinal,r=this._dataMin,n=this._dataMax,i=this._axisDataLen,a=this._boundaryGapInner,o=t?null:n-r||Math.abs(r),s=this._modelMinRaw==="dataMin"?r:this._modelMinNum,l=this._modelMaxRaw==="dataMax"?n:this._modelMaxNum,u=s!=null,f=l!=null;s==null&&(s=t?i?0:NaN:r-a[0]*o),l==null&&(l=t?i?i-1:NaN:n+a[1]*o),(s==null||!isFinite(s))&&(s=NaN),(l==null||!isFinite(l))&&(l=NaN);var h=La(s)||La(l)||t&&!i;this._needCrossZero&&(s>0&&l>0&&!u&&(s=0),s<0&&l<0&&!f&&(l=0));var c=this._determinedMin,v=this._determinedMax;return c!=null&&(s=c,u=!0),v!=null&&(l=v,f=!0),{min:s,max:l,minFixed:u,maxFixed:f,isBlank:h}},e.prototype.modifyDataMinMax=function(t,r){this[sL[t]]=r},e.prototype.setDeterminedMinMax=function(t,r){var n=oL[t];this[n]=r},e.prototype.freeze=function(){this.frozen=!0},e})(),oL={min:"_determinedMin",max:"_determinedMax"},sL={min:"_dataMin",max:"_dataMax"};function d_(e,t,r){var n=e.rawExtentInfo;return n||(n=new aL(e,t,r),e.rawExtentInfo=n,n)}function Vo(e,t){return t==null?null:La(t)?NaN:e.parse(t)}function p_(e,t){var r=e.type,n=d_(e,t,e.getExtent()).calculate();e.setBlank(n.isBlank);var i=n.min,a=n.max,o=t.ecModel;if(o&&r==="time"){var s=rM("bar",o),l=!1;if(M(s,function(h){l=l||h.getBaseAxis()===t.axis}),l){var u=iM(s),f=lL(i,a,t,u);i=f.min,a=f.max}}return{extent:[i,a],fixMin:n.minFixed,fixMax:n.maxFixed}}function lL(e,t,r,n){var i=r.axis.getExtent(),a=Math.abs(i[1]-i[0]),o=oM(n,r.axis);if(o===void 0)return{min:e,max:t};var s=1/0;M(o,function(v){s=Math.min(v.offset,s)});var l=-1/0;M(o,function(v){l=Math.max(v.offset+v.width,l)}),s=Math.abs(s),l=Math.abs(l);var u=s+l,f=t-e,h=1-(s+l)/a,c=f/h-f;return t+=c*(l/u),e-=c*(s/u),{min:e,max:t}}function Rp(e,t){var r=t,n=p_(e,r),i=n.extent,a=r.get("splitNumber");e instanceof c_&&(e.base=r.get("logBase"));var o=e.type,s=r.get("interval"),l=o==="interval"||o==="time";e.setBreaksFromOption(y_(r)),e.setExtent(i[0],i[1]),e.calcNiceExtent({splitNumber:a,fixMin:n.fixMin,fixMax:n.fixMax,minInterval:l?r.get("minInterval"):null,maxInterval:l?r.get("maxInterval"):null}),s!=null&&e.setInterval&&e.setInterval(s)}function uL(e,t){if(t=t||e.get("type"),t)switch(t){case"category":return new h_({ordinalMeta:e.getOrdinalMeta?e.getOrdinalMeta():e.getCategories(),extent:[1/0,-1/0]});case"time":return new v_({locale:e.ecModel.getLocaleModel(),useUTC:e.ecModel.get("useUTC")});default:return new(Wr.getClass(t)||Li)}}function fL(e){var t=e.scale.getExtent(),r=t[0],n=t[1];return!(r>0&&n>0||r<0&&n<0)}function ro(e){var t=e.getLabelModel().get("formatter");if(e.type==="time"){var r=wT(t);return function(i,a){return e.scale.getFormattedLabel(i,a,r)}}else{if(W(t))return function(i){var a=e.scale.getLabel(i),o=t.replace("{value}",a??"");return o};if(et(t)){if(e.type==="category")return function(i,a){return t(Gs(e,i),i.value-e.scale.getExtent()[0],null)};var n=As();return function(i,a){var o=null;return n&&(o=n.makeAxisLabelFormatterParamBreak(o,i.break)),t(Gs(e,i),a,o)}}else return function(i){return e.scale.getLabel(i)}}}function Gs(e,t){return e.type==="category"?e.scale.getLabel(t):t.value}function yv(e){var t=e.get("interval");return t??"auto"}function g_(e){return e.type==="category"&&yv(e.getLabelModel())===0}function m_(e,t){var r={};return M(e.mapDimensionsAll(t),function(n){r[Qx(e,n)]=!0}),St(r)}function hL(e,t,r){t&&M(m_(t,r),function(n){var i=t.getApproximateExtent(n);i[0]<e[0]&&(e[0]=i[0]),i[1]>e[1]&&(e[1]=i[1])})}function Ii(e){return e==="middle"||e==="center"}function Ya(e){return e.getShallow("show")}function y_(e){var t=e.get("breaks",!0);t==null}var vL=(function(){function e(t){this.type="cartesian",this._dimList=[],this._axes={},this.name=t||""}return e.prototype.getAxis=function(t){return this._axes[t]},e.prototype.getAxes=function(){return $(this._dimList,function(t){return this._axes[t]},this)},e.prototype.getAxesByScale=function(t){return t=t.toLowerCase(),wt(this.getAxes(),function(r){return r.scale.type===t})},e.prototype.addAxis=function(t){var r=t.dim;this._axes[r]=t,this._dimList.push(r)},e})(),nh=["x","y"];function Ep(e){return(e.type==="interval"||e.type==="time")&&!e.hasBreaks()}var cL=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type="cartesian2d",r.dimensions=nh,r}return t.prototype.calcAffineTransform=function(){this._transform=this._invTransform=null;var r=this.getAxis("x").scale,n=this.getAxis("y").scale;if(!(!Ep(r)||!Ep(n))){var i=r.getExtent(),a=n.getExtent(),o=this.dataToPoint([i[0],a[0]]),s=this.dataToPoint([i[1],a[1]]),l=i[1]-i[0],u=a[1]-a[0];if(!(!l||!u)){var f=(s[0]-o[0])/l,h=(s[1]-o[1])/u,c=o[0]-i[0]*f,v=o[1]-a[0]*h,d=this._transform=[f,0,0,h,c,v];this._invTransform=Ei([],d)}}},t.prototype.getBaseAxis=function(){return this.getAxesByScale("ordinal")[0]||this.getAxesByScale("time")[0]||this.getAxis("x")},t.prototype.containPoint=function(r){var n=this.getAxis("x"),i=this.getAxis("y");return n.contain(n.toLocalCoord(r[0]))&&i.contain(i.toLocalCoord(r[1]))},t.prototype.containData=function(r){return this.getAxis("x").containData(r[0])&&this.getAxis("y").containData(r[1])},t.prototype.containZone=function(r,n){var i=this.dataToPoint(r),a=this.dataToPoint(n),o=this.getArea(),s=new it(i[0],i[1],a[0]-i[0],a[1]-i[1]);return o.intersect(s)},t.prototype.dataToPoint=function(r,n,i){i=i||[];var a=r[0],o=r[1];if(this._transform&&a!=null&&isFinite(a)&&o!=null&&isFinite(o))return we(i,r,this._transform);var s=this.getAxis("x"),l=this.getAxis("y");return i[0]=s.toGlobalCoord(s.dataToCoord(a,n)),i[1]=l.toGlobalCoord(l.dataToCoord(o,n)),i},t.prototype.clampData=function(r,n){var i=this.getAxis("x").scale,a=this.getAxis("y").scale,o=i.getExtent(),s=a.getExtent(),l=i.parse(r[0]),u=a.parse(r[1]);return n=n||[],n[0]=Math.min(Math.max(Math.min(o[0],o[1]),l),Math.max(o[0],o[1])),n[1]=Math.min(Math.max(Math.min(s[0],s[1]),u),Math.max(s[0],s[1])),n},t.prototype.pointToData=function(r,n,i){if(i=i||[],this._invTransform)return we(i,r,this._invTransform);var a=this.getAxis("x"),o=this.getAxis("y");return i[0]=a.coordToData(a.toLocalCoord(r[0]),n),i[1]=o.coordToData(o.toLocalCoord(r[1]),n),i},t.prototype.getOtherAxis=function(r){return this.getAxis(r.dim==="x"?"y":"x")},t.prototype.getArea=function(r){r=r||0;var n=this.getAxis("x").getGlobalExtent(),i=this.getAxis("y").getGlobalExtent(),a=Math.min(n[0],n[1])-r,o=Math.min(i[0],i[1])-r,s=Math.max(n[0],n[1])-a+r,l=Math.max(i[0],i[1])-o+r;return new it(a,o,s,l)},t})(vL),dL=gt(),Ma=gt(),Re={estimate:1,determine:2};function Ws(e){return{out:{noPxChangeTryDetermine:[]},kind:e}}function __(e,t){var r=$(t,function(n){return e.scale.parse(n)});return e.type==="time"&&r.length>0&&(r.sort(),r.unshift(r[0]),r.push(r[r.length-1])),r}function pL(e,t){var r=e.getLabelModel().get("customValues");if(r){var n=ro(e),i=e.scale.getExtent(),a=__(e,r),o=wt(a,function(s){return s>=i[0]&&s<=i[1]});return{labels:$(o,function(s){var l={value:s};return{formattedLabel:n(l),rawLabel:e.scale.getLabel(l),tickValue:s,time:void 0,break:void 0}})}}return e.type==="category"?mL(e,t):_L(e)}function gL(e,t,r){var n=e.getTickModel().get("customValues");if(n){var i=e.scale.getExtent(),a=__(e,n);return{ticks:wt(a,function(o){return o>=i[0]&&o<=i[1]})}}return e.type==="category"?yL(e,t):{ticks:$(e.scale.getTicks(r),function(o){return o.value})}}function mL(e,t){var r=e.getLabelModel(),n=S_(e,r,t);return!r.get("show")||e.scale.isBlank()?{labels:[]}:n}function S_(e,t,r){var n=bL(e),i=yv(t),a=r.kind===Re.estimate;if(!a){var o=w_(n,i);if(o)return o}var s,l;et(i)?s=C_(e,i):(l=i==="auto"?wL(e,r):i,s=T_(e,l));var u={labels:s,labelCategoryInterval:l};return a?r.out.noPxChangeTryDetermine.push(function(){return ih(n,i,u),!0}):ih(n,i,u),u}function yL(e,t){var r=SL(e),n=yv(t),i=w_(r,n);if(i)return i;var a,o;if((!t.get("show")||e.scale.isBlank())&&(a=[]),et(n))a=C_(e,n,!0);else if(n==="auto"){var s=S_(e,e.getLabelModel(),Ws(Re.determine));o=s.labelCategoryInterval,a=$(s.labels,function(l){return l.tickValue})}else o=n,a=T_(e,o,!0);return ih(r,n,{ticks:a,tickCategoryInterval:o})}function _L(e){var t=e.scale.getTicks(),r=ro(e);return{labels:$(t,function(n,i){return{formattedLabel:r(n,i),rawLabel:e.scale.getLabel(n),tickValue:n.value,time:n.time,break:n.break}})}}var SL=b_("axisTick"),bL=b_("axisLabel");function b_(e){return function(r){return Ma(r)[e]||(Ma(r)[e]={list:[]})}}function w_(e,t){for(var r=0;r<e.list.length;r++)if(e.list[r].key===t)return e.list[r].value}function ih(e,t,r){return e.list.push({key:t,value:r}),r}function wL(e,t){if(t.kind===Re.estimate){var r=e.calculateCategoryInterval(t);return t.out.noPxChangeTryDetermine.push(function(){return Ma(e).autoInterval=r,!0}),r}var n=Ma(e).autoInterval;return n??(Ma(e).autoInterval=e.calculateCategoryInterval(t))}function xL(e,t){var r=t.kind,n=CL(e),i=ro(e),a=(n.axisRotate-n.labelRotate)/180*Math.PI,o=e.scale,s=o.getExtent(),l=o.count();if(s[1]-s[0]<1)return 0;var u=1,f=40;l>f&&(u=Math.max(1,Math.floor(l/f)));for(var h=s[0],c=e.dataToCoord(h+1)-e.dataToCoord(h),v=Math.abs(c*Math.cos(a)),d=Math.abs(c*Math.sin(a)),p=0,g=0;h<=s[1];h+=u){var m=0,y=0,_=em(i({value:h}),n.font,"center","top");m=_.width*1.3,y=_.height*1.3,p=Math.max(p,m,7),g=Math.max(g,y,7)}var S=p/v,w=g/d;isNaN(S)&&(S=1/0),isNaN(w)&&(w=1/0);var b=Math.max(0,Math.floor(Math.min(S,w)));if(r===Re.estimate)return t.out.noPxChangeTryDetermine.push(Q(TL,null,e,b,l)),b;var x=x_(e,b,l);return x??b}function TL(e,t,r){return x_(e,t,r)==null}function x_(e,t,r){var n=dL(e.model),i=e.getExtent(),a=n.lastAutoInterval,o=n.lastTickCount;if(a!=null&&o!=null&&Math.abs(a-t)<=1&&Math.abs(o-r)<=1&&a>t&&n.axisExtent0===i[0]&&n.axisExtent1===i[1])return a;n.lastTickCount=r,n.lastAutoInterval=t,n.axisExtent0=i[0],n.axisExtent1=i[1]}function CL(e){var t=e.getLabelModel();return{axisRotate:e.getRotate?e.getRotate():e.isHorizontal&&!e.isHorizontal()?90:0,labelRotate:t.get("rotate")||0,font:t.getFont()}}function T_(e,t,r){var n=ro(e),i=e.scale,a=i.getExtent(),o=e.getLabelModel(),s=[],l=Math.max((t||0)+1,1),u=a[0],f=i.count();u!==0&&l>1&&f/l>2&&(u=Math.round(Math.ceil(u/l)*l));var h=g_(e),c=o.get("showMinLabel")||h,v=o.get("showMaxLabel")||h;c&&u!==a[0]&&p(a[0]);for(var d=u;d<=a[1];d+=l)p(d);v&&d-l!==a[1]&&p(a[1]);function p(g){var m={value:g};s.push(r?g:{formattedLabel:n(m),rawLabel:i.getLabel(m),tickValue:g,time:void 0,break:void 0})}return s}function C_(e,t,r){var n=e.scale,i=ro(e),a=[];return M(n.getTicks(),function(o){var s=n.getLabel(o),l=o.value;t(o.value,s)&&a.push(r?l:{formattedLabel:i(o),rawLabel:s,tickValue:l,time:void 0,break:void 0})}),a}var kp=[0,1],ML=(function(){function e(t,r,n){this.onBand=!1,this.inverse=!1,this.dim=t,this.scale=r,this._extent=n||[0,0]}return e.prototype.contain=function(t){var r=this._extent,n=Math.min(r[0],r[1]),i=Math.max(r[0],r[1]);return t>=n&&t<=i},e.prototype.containData=function(t){return this.scale.contain(this.scale.parse(t))},e.prototype.getExtent=function(){return this._extent.slice()},e.prototype.getPixelPrecision=function(t){return Tm(t||this.scale.getExtent(),this._extent)},e.prototype.setExtent=function(t,r){var n=this._extent;n[0]=t,n[1]=r},e.prototype.dataToCoord=function(t,r){var n=this._extent,i=this.scale;return t=i.normalize(i.parse(t)),this.onBand&&i.type==="ordinal"&&(n=n.slice(),Op(n,i.count())),Et(t,kp,n,r)},e.prototype.coordToData=function(t,r){var n=this._extent,i=this.scale;this.onBand&&i.type==="ordinal"&&(n=n.slice(),Op(n,i.count()));var a=Et(t,n,kp,r);return this.scale.scale(a)},e.prototype.pointToData=function(t,r){},e.prototype.getTicksCoords=function(t){t=t||{};var r=t.tickModel||this.getTickModel(),n=gL(this,r,{breakTicks:t.breakTicks,pruneByBreak:t.pruneByBreak}),i=n.ticks,a=$(i,function(s){return{coord:this.dataToCoord(this.scale.type==="ordinal"?this.scale.getRawOrdinalNumber(s):s),tickValue:s}},this),o=r.get("alignWithLabel");return DL(this,a,o,t.clamp),a},e.prototype.getMinorTicksCoords=function(){if(this.scale.type==="ordinal")return[];var t=this.model.getModel("minorTick"),r=t.get("splitNumber");r>0&&r<100||(r=5);var n=this.scale.getMinorTicks(r),i=$(n,function(a){return $(a,function(o){return{coord:this.dataToCoord(o),tickValue:o}},this)},this);return i},e.prototype.getViewLabels=function(t){return t=t||Ws(Re.determine),pL(this,t).labels},e.prototype.getLabelModel=function(){return this.model.getModel("axisLabel")},e.prototype.getTickModel=function(){return this.model.getModel("axisTick")},e.prototype.getBandWidth=function(){var t=this._extent,r=this.scale.getExtent(),n=r[1]-r[0]+(this.onBand?1:0);n===0&&(n=1);var i=Math.abs(t[1]-t[0]);return Math.abs(i)/n},e.prototype.calculateCategoryInterval=function(t){return t=t||Ws(Re.determine),xL(this,t)},e})();function Op(e,t){var r=e[1]-e[0],n=t,i=r/n/2;e[0]+=i,e[1]-=i}function DL(e,t,r,n){var i=t.length;if(!e.onBand||r||!i)return;var a=e.getExtent(),o,s;if(i===1)t[0].coord=a[0],t[0].onBand=!0,o=t[1]={coord:a[1],tickValue:t[0].tickValue,onBand:!0};else{var l=t[i-1].tickValue-t[0].tickValue,u=(t[i-1].coord-t[0].coord)/l;M(t,function(v){v.coord-=u/2,v.onBand=!0});var f=e.scale.getExtent();s=1+f[1]-t[i-1].tickValue,o={coord:t[i-1].coord+u*s,tickValue:f[1]+1,onBand:!0},t.push(o)}var h=a[0]>a[1];c(t[0].coord,a[0])&&(n?t[0].coord=a[0]:t.shift()),n&&c(a[0],t[0].coord)&&t.unshift({coord:a[0],onBand:!0}),c(a[1],o.coord)&&(n?o.coord=a[1]:t.pop()),n&&c(o.coord,a[1])&&t.push({coord:a[1],onBand:!0});function c(v,d){return v=Nt(v),d=Nt(d),h?v>d:v<d}}var AL=(function(e){N(t,e);function t(r,n,i,a,o){var s=e.call(this,r,n,i)||this;return s.index=0,s.type=a||"value",s.position=o||"bottom",s}return t.prototype.isHorizontal=function(){var r=this.position;return r==="top"||r==="bottom"},t.prototype.getGlobalExtent=function(r){var n=this.getExtent();return n[0]=this.toGlobalCoord(n[0]),n[1]=this.toGlobalCoord(n[1]),r&&n[0]>n[1]&&n.reverse(),n},t.prototype.pointToData=function(r,n){return this.coordToData(this.toLocalCoord(r[this.dim==="x"?0:1]),n)},t.prototype.setCategorySortInfo=function(r){if(this.type!=="category")return!1;this.model.option.categorySortInfo=r,this.scale.setSortInfo(r)},t})(ML),LL="expandAxisBreak",Lr=Math.PI,IL=[[1,2,1,2],[5,3,5,3],[8,3,8,3]],PL=[[0,1,0,1],[0,3,0,3],[0,3,0,3]],Za=gt(),M_=gt(),D_=(function(){function e(t){this.recordMap={},this.resolveAxisNameOverlap=t}return e.prototype.ensureRecord=function(t){var r=t.axis.dim,n=t.componentIndex,i=this.recordMap,a=i[r]||(i[r]=[]);return a[n]||(a[n]={ready:{}})},e})();function RL(e,t,r,n){var i=r.axis,a=t.ensureRecord(r),o=[],s,l=_v(e.axisName)&&Ii(e.nameLocation);M(n,function(d){var p=Vr(d);if(!(!p||p.label.ignore)){o.push(p);var g=a.transGroup;l&&(g.transform?Ei(ta,g.transform):bh(ta),p.transform&&ma(ta,ta,p.transform),it.copy(Go,p.localRect),Go.applyTransform(ta),s?s.union(Go):it.copy(s=new it(0,0,0,0),Go))}});var u=Math.abs(a.dirVec.x)>.1?"x":"y",f=a.transGroup[u];if(o.sort(function(d,p){return Math.abs(d.label[u]-f)-Math.abs(p.label[u]-f)}),l&&s){var h=i.getExtent(),c=Math.min(h[0],h[1]),v=Math.max(h[0],h[1])-c;s.union(new it(c,0,v,1))}a.stOccupiedRect=s,a.labelInfoList=o}var ta=sr(),Go=new it(0,0,0,0),A_=function(e,t,r,n,i,a){if(Ii(e.nameLocation)){var o=a.stOccupiedRect;o&&L_(bM({},o,a.transGroup.transform),n,i)}else I_(a.labelInfoList,a.dirVec,n,i)};function L_(e,t,r){var n=new tt;sv(e,t,n,{direction:Math.atan2(r.y,r.x),bidirectional:!1,touchThreshold:.05})&&wM(t,n)}function I_(e,t,r,n){for(var i=tt.dot(n,t)>=0,a=0,o=e.length;a<o;a++){var s=e[i?a:o-1-a];s.label.ignore||L_(s,r,n)}}var kr=(function(){function e(t,r,n,i){this.group=new Ft,this._axisModel=t,this._api=r,this._local={},this._shared=i||new D_(A_),this._resetCfgDetermined(n)}return e.prototype.updateCfg=function(t){var r=this._cfg.raw;r.position=t.position,r.labelOffset=t.labelOffset,this._resetCfgDetermined(r)},e.prototype.__getRawCfg=function(){return this._cfg.raw},e.prototype._resetCfgDetermined=function(t){var r=this._axisModel,n=r.getDefaultOption?r.getDefaultOption():{},i=q(t.axisName,r.get("name")),a=r.get("nameMoveOverlap");(a==null||a==="auto")&&(a=q(t.defaultNameMoveOverlap,!0));var o={raw:t,position:t.position,rotation:t.rotation,nameDirection:q(t.nameDirection,1),tickDirection:q(t.tickDirection,1),labelDirection:q(t.labelDirection,1),labelOffset:q(t.labelOffset,0),silent:q(t.silent,!0),axisName:i,nameLocation:yi(r.get("nameLocation"),n.nameLocation,"end"),shouldNameMoveOverlap:_v(i)&&a,optionHideOverlap:r.get(["axisLabel","hideOverlap"]),showMinorTicks:r.get(["minorTick","show"])};this._cfg=o;var s=new Ft({x:o.position[0],y:o.position[1],rotation:o.rotation});s.updateTransform(),this._transformGroup=s;var l=this._shared.ensureRecord(r);l.transGroup=this._transformGroup,l.dirVec=new tt(Math.cos(-o.rotation),Math.sin(-o.rotation))},e.prototype.build=function(t,r){var n=this;return t||(t={axisLine:!0,axisTickLabelEstimate:!1,axisTickLabelDetermine:!0,axisName:!0}),M(EL,function(i){t[i]&&kL[i](n._cfg,n._local,n._shared,n._axisModel,n.group,n._transformGroup,n._api,r||{})}),this},e.innerTextLayout=function(t,r,n){var i=Cm(r-t),a,o;return ys(i)?(o=n>0?"top":"bottom",a="center"):ys(i-Lr)?(o=n>0?"bottom":"top",a="center"):(o="middle",i>0&&i<Lr?a=n>0?"right":"left":a=n>0?"left":"right"),{rotation:i,textAlign:a,textVerticalAlign:o}},e.makeAxisEventDataBase=function(t){var r={componentType:t.mainType,componentIndex:t.componentIndex};return r[t.mainType+"Index"]=t.componentIndex,r},e.isLabelSilent=function(t){var r=t.get("tooltip");return t.get("silent")||!(t.get("triggerEvent")||r&&r.show)},e})(),EL=["axisLine","axisTickLabelEstimate","axisTickLabelDetermine","axisName"],kL={axisLine:function(e,t,r,n,i,a,o){var s=n.get(["axisLine","show"]);if(s==="auto"&&(s=!0,e.raw.axisLineAutoShow!=null&&(s=!!e.raw.axisLineAutoShow)),!!s){var l=n.axis.getExtent(),u=a.transform,f=[l[0],0],h=[l[1],0],c=f[0]>h[0];u&&(we(f,f,u),we(h,h,u));var v=k({lineCap:"round"},n.getModel(["axisLine","lineStyle"]).getLineStyle()),d={strokeContainThreshold:e.raw.strokeContainThreshold||5,silent:!0,z2:1,style:v};if(n.get(["axisLine","breakLine"])&&n.axis.scale.hasBreaks())UA().buildAxisBreakLine(n,i,a,d);else{var p=new Fr(k({shape:{x1:f[0],y1:f[1],x2:h[0],y2:h[1]}},d));ka(p.shape,p.style.lineWidth),p.anid="line",i.add(p)}var g=n.get(["axisLine","symbol"]);if(g!=null){var m=n.get(["axisLine","symbolSize"]);W(g)&&(g=[g,g]),(W(m)||mt(m))&&(m=[m,m]);var y=s0(n.get(["axisLine","symbolOffset"])||0,m),_=m[0],S=m[1];M([{rotate:e.rotation+Math.PI/2,offset:y[0],r:0},{rotate:e.rotation-Math.PI/2,offset:y[1],r:Math.sqrt((f[0]-h[0])*(f[0]-h[0])+(f[1]-h[1])*(f[1]-h[1]))}],function(w,b){if(g[b]!=="none"&&g[b]!=null){var x=Bn(g[b],-_/2,-S/2,_,S,v.stroke,!0),C=w.r+w.offset,T=c?h:f;x.attr({rotation:w.rotate,x:T[0]+C*Math.cos(e.rotation),y:T[1]-C*Math.sin(e.rotation),silent:!0,z2:11}),i.add(x)}})}}},axisTickLabelEstimate:function(e,t,r,n,i,a,o,s){var l=Np(t,i,s);l&&Bp(e,t,r,n,i,a,o,Re.estimate)},axisTickLabelDetermine:function(e,t,r,n,i,a,o,s){var l=Np(t,i,s);l&&Bp(e,t,r,n,i,a,o,Re.determine);var u=FL(e,i,a,n);NL(e,t.labelLayoutList,u),zL(e,i,a,n,e.tickDirection)},axisName:function(e,t,r,n,i,a,o,s){var l=r.ensureRecord(n);t.nameEl&&(i.remove(t.nameEl),t.nameEl=l.nameLayout=l.nameLocation=null);var u=e.axisName;if(_v(u)){var f=e.nameLocation,h=e.nameDirection,c=n.getModel("nameTextStyle"),v=n.get("nameGap")||0,d=n.axis.getExtent(),p=n.axis.inverse?-1:1,g=new tt(0,0),m=new tt(0,0);f==="start"?(g.x=d[0]-p*v,m.x=-p):f==="end"?(g.x=d[1]+p*v,m.x=p):(g.x=(d[0]+d[1])/2,g.y=e.labelOffset+h*v,m.y=h);var y=sr();m.transform(wh(y,y,e.rotation));var _=n.get("nameRotate");_!=null&&(_=_*Lr/180);var S,w;Ii(f)?S=kr.innerTextLayout(e.rotation,_??e.rotation,h):(S=OL(e.rotation,f,_||0,d),w=e.raw.axisNameAvailableWidth,w!=null&&(w=Math.abs(w/Math.sin(S.rotation)),!isFinite(w)&&(w=null)));var b=c.getFont(),x=n.get("nameTruncate",!0)||{},C=x.ellipsis,T=fs(e.raw.nameTruncateMaxWidth,x.maxWidth,w),D=s.nameMarginLevel||0,A=new ae({x:g.x,y:g.y,rotation:S.rotation,silent:kr.isLabelSilent(n),style:zr(c,{text:u,font:b,overflow:"truncate",width:T,ellipsis:C,fill:c.getTextColor()||n.get(["axisLine","lineStyle","color"]),align:c.get("align")||S.textAlign,verticalAlign:c.get("verticalAlign")||S.textVerticalAlign}),z2:1});if(Fh({el:A,componentModel:n,itemName:u}),A.__fullText=u,A.anid="name",n.get("triggerEvent")){var P=kr.makeAxisEventDataBase(n);P.targetType="axisName",P.name=u,pt(A).eventData=P}a.add(A),A.updateTransform(),t.nameEl=A;var L=l.nameLayout=Vr({label:A,priority:A.z2,defaultAttr:{ignore:A.ignore},marginDefault:Ii(f)?IL[D]:PL[D]});if(l.nameLocation=f,i.add(A),A.decomposeTransform(),e.shouldNameMoveOverlap&&L){var I=r.ensureRecord(n);r.resolveAxisNameOverlap(e,r,n,L,m,I)}}}};function Bp(e,t,r,n,i,a,o,s){R_(t)||HL(e,t,i,s,n,o);var l=t.labelLayoutList;VL(e,n,l,a),e.rotation;var u=e.optionHideOverlap;BL(n,l,u),u&&b0(wt(l,function(f){return f&&!f.label.ignore})),RL(e,r,n,l)}function OL(e,t,r,n){var i=Cm(r-e),a,o,s=n[0]>n[1],l=t==="start"&&!s||t!=="start"&&s;return ys(i-Lr/2)?(o=l?"bottom":"top",a="center"):ys(i-Lr*1.5)?(o=l?"top":"bottom",a="center"):(o="middle",i<Lr*1.5&&i>Lr/2?a=l?"left":"right":a=l?"right":"left"),{rotation:i,textAlign:a,textVerticalAlign:o}}function BL(e,t,r){if(g_(e.axis))return;function n(s,l,u){var f=Vr(t[l]),h=Vr(t[u]);if(!(!f||!h)){if(s===!1||f.suggestIgnore){da(f.label);return}if(h.suggestIgnore){da(h.label);return}var c=.1;if(!r){var v=[0,0,0,0];f=Hf({marginForce:v},f),h=Hf({marginForce:v},h)}sv(f,h,null,{touchThreshold:c})&&da(s?h.label:f.label)}}var i=e.get(["axisLabel","showMinLabel"]),a=e.get(["axisLabel","showMaxLabel"]),o=t.length;n(i,0,1),n(a,o-1,o-2)}function NL(e,t,r){e.showMinorTicks||M(t,function(n){if(n&&n.label.ignore)for(var i=0;i<r.length;i++){var a=r[i],o=M_(a),s=Za(n.label);if(o.tickValue!=null&&!o.onBand&&o.tickValue===s.tickValue){da(a);return}}})}function da(e){e&&(e.ignore=!0)}function P_(e,t,r,n,i){for(var a=[],o=[],s=[],l=0;l<e.length;l++){var u=e[l].coord;o[0]=u,o[1]=0,s[0]=u,s[1]=r,t&&(we(o,o,t),we(s,s,t));var f=new Fr({shape:{x1:o[0],y1:o[1],x2:s[0],y2:s[1]},style:n,z2:2,autoBatch:!0,silent:!0});ka(f.shape,f.style.lineWidth),f.anid=i+"_"+e[l].tickValue,a.push(f);var h=M_(f);h.onBand=!!e[l].onBand,h.tickValue=e[l].tickValue}return a}function FL(e,t,r,n){var i=n.axis,a=n.getModel("axisTick"),o=a.get("show");if(o==="auto"&&(o=!0,e.raw.axisTickAutoShow!=null&&(o=!!e.raw.axisTickAutoShow)),!o||i.scale.isBlank())return[];for(var s=a.getModel("lineStyle"),l=e.tickDirection*a.get("length"),u=i.getTicksCoords(),f=P_(u,r.transform,l,at(s.getLineStyle(),{stroke:n.get(["axisLine","lineStyle","color"])}),"ticks"),h=0;h<f.length;h++)t.add(f[h]);return f}function zL(e,t,r,n,i){var a=n.axis,o=n.getModel("minorTick");if(!(!e.showMinorTicks||a.scale.isBlank())){var s=a.getMinorTicksCoords();if(s.length)for(var l=o.getModel("lineStyle"),u=i*o.get("length"),f=at(l.getLineStyle(),at(n.getModel("axisTick").getLineStyle(),{stroke:n.get(["axisLine","lineStyle","color"])})),h=0;h<s.length;h++)for(var c=P_(s[h],r.transform,u,f,"minorticks_"+h),v=0;v<c.length;v++)t.add(c[v])}}function Np(e,t,r){if(R_(e)){var n=e.axisLabelsCreationContext,i=n.out.noPxChangeTryDetermine;if(r.noPxChange){for(var a=!0,o=0;o<i.length;o++)a=a&&i[o]();if(a)return!1}i.length&&(t.remove(e.labelGroup),ah(e,null,null,null))}return!0}function HL(e,t,r,n,i,a){var o=i.axis,s=fs(e.raw.axisLabelShow,i.get(["axisLabel","show"])),l=new Ft;r.add(l);var u=Ws(n);if(!s||o.scale.isBlank()){ah(t,[],l,u);return}var f=i.getModel("axisLabel"),h=o.getViewLabels(u),c=(fs(e.raw.labelRotate,f.get("rotate"))||0)*Lr/180,v=kr.innerTextLayout(e.rotation,c,e.labelDirection),d=i.getCategories&&i.getCategories(!0),p=[],g=i.get("triggerEvent"),m=1/0,y=-1/0;M(h,function(S,w){var b,x=o.scale.type==="ordinal"?o.scale.getRawOrdinalNumber(S.tickValue):S.tickValue,C=S.formattedLabel,T=S.rawLabel,D=f;if(d&&d[x]){var A=d[x];X(A)&&A.textStyle&&(D=new xt(A.textStyle,f,i.ecModel))}var P=D.getTextColor()||i.get(["axisLine","lineStyle","color"]),L=D.getShallow("align",!0)||v.textAlign,I=q(D.getShallow("alignMinLabel",!0),L),R=q(D.getShallow("alignMaxLabel",!0),L),E=D.getShallow("verticalAlign",!0)||D.getShallow("baseline",!0)||v.textVerticalAlign,G=q(D.getShallow("verticalAlignMinLabel",!0),E),F=q(D.getShallow("verticalAlignMaxLabel",!0),E),H=10+(((b=S.time)===null||b===void 0?void 0:b.level)||0);m=Math.min(m,H),y=Math.max(y,H);var V=new ae({x:0,y:0,rotation:0,silent:kr.isLabelSilent(i),z2:H,style:zr(D,{text:C,align:w===0?I:w===h.length-1?R:L,verticalAlign:w===0?G:w===h.length-1?F:E,fill:et(P)?P(o.type==="category"?T:o.type==="value"?x+"":x,w):P})});V.anid="label_"+x;var U=Za(V);if(U.break=S.break,U.tickValue=x,U.layoutRotation=v.rotation,Fh({el:V,componentModel:i,itemName:C,formatterParamsExtra:{isTruncated:function(){return V.isTruncated},value:T,tickIndex:w}}),g){var Z=kr.makeAxisEventDataBase(i);Z.targetType="axisLabel",Z.value=T,Z.tickIndex=w,S.break&&(Z.break={start:S.break.parsedBreak.vmin,end:S.break.parsedBreak.vmax}),o.type==="category"&&(Z.dataIndex=x),pt(V).eventData=Z,S.break&&WL(i,a,V,S.break)}p.push(V),l.add(V)});var _=$(p,function(S){return{label:S,priority:Za(S).break?S.z2+(y-m+1):S.z2,defaultAttr:{ignore:S.ignore}}});ah(t,_,l,u)}function R_(e){return!!e.labelLayoutList}function ah(e,t,r,n){e.labelLayoutList=t,e.labelGroup=r,e.axisLabelsCreationContext=n}function VL(e,t,r,n){var i=t.get(["axisLabel","margin"]);M(r,function(a,o){var s=Vr(a);if(s){var l=s.label,u=Za(l);s.suggestIgnore=l.ignore,l.ignore=!1,nf(er,GL),er.x=t.axis.dataToCoord(u.tickValue),er.y=e.labelOffset+e.labelDirection*i,er.rotation=u.layoutRotation,n.add(er),er.updateTransform(),n.remove(er),er.decomposeTransform(),nf(l,er),l.markRedraw(),ks(s,!0),Vr(s)}})}var er=new Tt,GL=new Tt;function _v(e){return!!e}function WL(e,t,r,n){r.on("click",function(i){var a={type:LL,breaks:[{start:n.parsedBreak.breakOption.start,end:n.parsedBreak.breakOption.end}]};a[e.axis.dim+"AxisIndex"]=e.componentIndex,t.dispatchAction(a)})}function Us(e,t,r){r=r||{};var n=t.axis,i={},a=n.getAxesOnZeroOf()[0],o=n.position,s=a?"onZero":o,l=n.dim,u=[e.x,e.x+e.width,e.y,e.y+e.height],f={left:0,right:1,top:0,bottom:1,onZero:2},h=t.get("offset")||0,c=l==="x"?[u[2]-h,u[3]+h]:[u[0]-h,u[1]+h];if(a){var v=a.toGlobalCoord(a.dataToCoord(0));c[f.onZero]=Math.max(Math.min(v,c[1]),c[0])}i.position=[l==="y"?c[f[s]]:u[0],l==="x"?c[f[s]]:u[3]],i.rotation=Math.PI/2*(l==="x"?0:1);var d={top:-1,bottom:1,left:-1,right:1};i.labelDirection=i.tickDirection=i.nameDirection=d[o],i.labelOffset=a?c[f[o]]-c[f.onZero]:0,t.get(["axisTick","inside"])&&(i.tickDirection=-i.tickDirection),fs(r.labelInside,t.get(["axisLabel","inside"]))&&(i.labelDirection=-i.labelDirection);var p=t.get(["axisLabel","rotate"]);return i.labelRotate=s==="top"?-p:p,i.z2=1,i}function UL(e){return e.coordinateSystem&&e.coordinateSystem.type==="cartesian2d"}function Fp(e){var t={xAxisModel:null,yAxisModel:null};return M(t,function(r,n){var i=n.replace(/Model$/,""),a=e.getReferringComponents(i,$t).models[0];t[n]=a}),t}function YL(e,t,r,n,i,a){for(var o=Us(e,r),s=!1,l=!1,u=0;u<t.length;u++)th(t[u].getOtherAxis(r.axis).scale)&&(s=l=!0,r.axis.type==="category"&&r.axis.onBand&&(l=!1));return o.axisLineAutoShow=s,o.axisTickAutoShow=l,o.defaultNameMoveOverlap=a,new kr(r,n,o,i)}function ZL(e,t,r){var n=Us(t,r);e.updateCfg(n)}function XL(e,t,r){var n=Li.prototype,i=n.getTicks.call(r),a=n.getTicks.call(r,{expandToNicedExtent:!0}),o=i.length-1,s=n.getInterval.call(r),l=p_(e,t),u=l.extent,f=l.fixMin,h=l.fixMax;e.type==="log"&&(u=eh(e.base,u,!0)),e.setBreaksFromOption(y_(t)),e.setExtent(u[0],u[1]),e.calcNiceExtent({splitNumber:o,fixMin:f,fixMax:h});var c=n.getExtent.call(e);f&&(u[0]=c[0]),h&&(u[1]=c[1]);var v=n.getInterval.call(e),d=u[0],p=u[1];if(f&&h)v=(p-d)/o;else if(f)for(p=u[0]+v*o;p<u[1]&&isFinite(p)&&isFinite(u[1]);)v=Iu(v),p=u[0]+v*o;else if(h)for(d=u[1]-v*o;d>u[0]&&isFinite(d)&&isFinite(u[0]);)v=Iu(v),d=u[1]-v*o;else{var g=e.getTicks().length-1;g>o&&(v=Iu(v));var m=v*o;p=Math.ceil(u[1]/v)*v,d=Nt(p-m),d<0&&u[0]>=0?(d=0,p=Nt(m)):p>0&&u[1]<=0&&(p=0,d=-Nt(m))}var y=(i[0].value-a[0].value)/s,_=(i[o].value-a[o].value)/s;n.setExtent.call(e,d+v*y,p+v*_),n.setInterval.call(e,v),(y||_)&&n.setNiceExtent.call(e,d+v,p-v)}var zp=[[3,1],[0,2]],$L=(function(){function e(t,r,n){this.type="grid",this._coordsMap={},this._coordsList=[],this._axesMap={},this._axesList=[],this.axisPointerEnabled=!0,this.dimensions=nh,this._initCartesian(t,r,n),this.model=t}return e.prototype.getRect=function(){return this._rect},e.prototype.update=function(t,r){var n=this._axesMap;this._updateScale(t,this.model);function i(o){var s,l=St(o),u=l.length;if(u){for(var f=[],h=u-1;h>=0;h--){var c=+l[h],v=o[c],d=v.model,p=v.scale;th(p)&&d.get("alignTicks")&&d.get("interval")==null?f.push(v):(Rp(p,d),th(p)&&(s=v))}f.length&&(s||(s=f.pop(),Rp(s.scale,s.model)),M(f,function(g){XL(g.scale,g.model,s.scale)}))}}i(n.x),i(n.y);var a={};M(n.x,function(o){Hp(n,"y",o,a)}),M(n.y,function(o){Hp(n,"x",o,a)}),this.resize(this.model,r)},e.prototype.resize=function(t,r,n){var i=nv(t,r),a=this._rect=to(t.getBoxLayoutParams(),i.refContainer),o=this._axesMap,s=this._coordsList,l=t.get("containLabel");if(E_(o,a),!n){var u=KL(a,s,o,l,r),f=void 0;if(l)f=Wp(a.clone(),"axisLabel",null,a,o,u,i);else{var h=QL(t,a,i),c=h.outerBoundsRect,v=h.parsedOuterBoundsContain,d=h.outerBoundsClamp;c&&(f=Wp(c,v,d,a,o,u,i))}k_(a,o,Re.determine,null,f,i)}M(this._coordsList,function(p){p.calcAffineTransform()})},e.prototype.getAxis=function(t,r){var n=this._axesMap[t];if(n!=null)return n[r||0]},e.prototype.getAxes=function(){return this._axesList.slice()},e.prototype.getCartesian=function(t,r){if(t!=null&&r!=null){var n="x"+t+"y"+r;return this._coordsMap[n]}X(t)&&(r=t.yAxisIndex,t=t.xAxisIndex);for(var i=0,a=this._coordsList;i<a.length;i++)if(a[i].getAxis("x").index===t||a[i].getAxis("y").index===r)return a[i]},e.prototype.getCartesians=function(){return this._coordsList.slice()},e.prototype.convertToPixel=function(t,r,n){var i=this._findConvertTarget(r);return i.cartesian?i.cartesian.dataToPoint(n):i.axis?i.axis.toGlobalCoord(i.axis.dataToCoord(n)):null},e.prototype.convertFromPixel=function(t,r,n){var i=this._findConvertTarget(r);return i.cartesian?i.cartesian.pointToData(n):i.axis?i.axis.coordToData(i.axis.toLocalCoord(n)):null},e.prototype._findConvertTarget=function(t){var r=t.seriesModel,n=t.xAxisModel||r&&r.getReferringComponents("xAxis",$t).models[0],i=t.yAxisModel||r&&r.getReferringComponents("yAxis",$t).models[0],a=t.gridModel,o=this._coordsList,s,l;if(r)s=r.coordinateSystem,ft(o,s)<0&&(s=null);else if(n&&i)s=this.getCartesian(n.componentIndex,i.componentIndex);else if(n)l=this.getAxis("x",n.componentIndex);else if(i)l=this.getAxis("y",i.componentIndex);else if(a){var u=a.coordinateSystem;u===this&&(s=this._coordsList[0])}return{cartesian:s,axis:l}},e.prototype.containPoint=function(t){var r=this._coordsList[0];if(r)return r.containPoint(t)},e.prototype._initCartesian=function(t,r,n){var i=this,a=this,o={left:!1,right:!1,top:!1,bottom:!1},s={x:{},y:{}},l={x:0,y:0};if(r.eachComponent("xAxis",u("x"),this),r.eachComponent("yAxis",u("y"),this),!l.x||!l.y){this._axesMap={},this._axesList=[];return}this._axesMap=s,M(s.x,function(f,h){M(s.y,function(c,v){var d="x"+h+"y"+v,p=new cL(d);p.master=i,p.model=t,i._coordsMap[d]=p,i._coordsList.push(p),p.addAxis(f),p.addAxis(c)})});function u(f){return function(h,c){if(Ru(h,t)){var v=h.get("position");f==="x"?v!=="top"&&v!=="bottom"&&(v=o.bottom?"top":"bottom"):v!=="left"&&v!=="right"&&(v=o.left?"right":"left"),o[v]=!0;var d=new AL(f,uL(h),[0,0],h.get("type"),v),p=d.type==="category";d.onBand=p&&h.get("boundaryGap"),d.inverse=h.get("inverse"),h.axis=d,d.model=h,d.grid=a,d.index=c,a._axesList.push(d),s[f][c]=d,l[f]++}}}},e.prototype._updateScale=function(t,r){M(this._axesList,function(i){if(i.scale.setExtent(1/0,-1/0),i.type==="category"){var a=i.model.get("categorySortInfo");i.scale.setSortInfo(a)}}),t.eachSeries(function(i){if(UL(i)){var a=Fp(i),o=a.xAxisModel,s=a.yAxisModel;if(!Ru(o,r)||!Ru(s,r))return;var l=this.getCartesian(o.componentIndex,s.componentIndex),u=i.getData(),f=l.getAxis("x"),h=l.getAxis("y");n(u,f),n(u,h)}},this);function n(i,a){M(m_(i,a.dim),function(o){a.scale.unionExtentFromData(i,o)})}},e.prototype.getTooltipAxes=function(t){var r=[],n=[];return M(this.getCartesians(),function(i){var a=t!=null&&t!=="auto"?i.getAxis(t):i.getBaseAxis(),o=i.getOtherAxis(a);ft(r,a)<0&&r.push(a),ft(n,o)<0&&n.push(o)}),{baseAxes:r,otherAxes:n}},e.create=function(t,r){var n=[];return t.eachComponent("grid",function(i,a){var o=new e(i,t,r);o.name="grid_"+a,o.resize(i,r,!0),i.coordinateSystem=o,n.push(o)}),t.eachSeries(function(i){Yx({targetModel:i,coordSysType:"cartesian2d",coordSysProvider:a});function a(){var o=Fp(i),s=o.xAxisModel,l=o.yAxisModel,u=s.getCoordSysModel(),f=u.coordinateSystem;return f.getCartesian(s.componentIndex,l.componentIndex)}}),n},e.dimensions=nh,e})();function Ru(e,t){return e.getCoordSysModel()===t}function Hp(e,t,r,n){r.getAxesOnZeroOf=function(){return a?[a]:[]};var i=e[t],a,o=r.model,s=o.get(["axisLine","onZero"]),l=o.get(["axisLine","onZeroAxisIndex"]);if(!s)return;if(l!=null)Vp(i[l])&&(a=i[l]);else for(var u in i)if(i.hasOwnProperty(u)&&Vp(i[u])&&!n[f(i[u])]){a=i[u];break}a&&(n[f(a)]=!0);function f(h){return h.dim+"_"+h.index}}function Vp(e){return e&&e.type!=="category"&&e.type!=="time"&&fL(e)}function qL(e,t){var r=e.getExtent(),n=r[0]+r[1];e.toGlobalCoord=e.dim==="x"?function(i){return i+t}:function(i){return n-i+t},e.toLocalCoord=e.dim==="x"?function(i){return i-t}:function(i){return n-i+t}}function E_(e,t){M(e.x,function(r){return Gp(r,t.x,t.width)}),M(e.y,function(r){return Gp(r,t.y,t.height)})}function Gp(e,t,r){var n=[0,r],i=e.inverse?1:0;e.setExtent(n[i],n[1-i]),qL(e,t)}function Wp(e,t,r,n,i,a,o){k_(n,i,Re.estimate,t,!1,o);var s=[0,0,0,0];u(0),u(1),f(n,0,NaN),f(n,1,NaN);var l=C1(s,function(c){return c>0})==null;return Cs(n,s,!0,!0,r),E_(i,n),l;function u(c){M(i[Mr[c]],function(v){if(Ya(v.model)){var d=a.ensureRecord(v.model),p=d.labelInfoList;if(p)for(var g=0;g<p.length;g++){var m=p[g],y=v.scale.normalize(Za(m.label).tickValue);y=c===1?1-y:y,f(m.rect,c,y),f(m.rect,1-c,NaN)}var _=d.nameLayout;if(_){var y=Ii(d.nameLocation)?.5:NaN;f(_.rect,c,y),f(_.rect,1-c,NaN)}}})}function f(c,v,d){var p=e[Mr[v]]-c[Mr[v]],g=c[Mi[v]]+c[Mr[v]]-(e[Mi[v]]+e[Mr[v]]);p=h(p,1-d),g=h(g,d);var m=zp[v][0],y=zp[v][1];s[m]=fe(s[m],p),s[y]=fe(s[y],g)}function h(c,v){return c>0&&!La(v)&&v>1e-4&&(c/=v),c}}function KL(e,t,r,n,i){var a=new D_(JL);return M(r,function(o){return M(o,function(s){if(Ya(s.model)){var l=!n;s.axisBuilder=YL(e,t,s.model,i,a,l)}})}),a}function k_(e,t,r,n,i,a){var o=r===Re.determine;M(t,function(u){return M(u,function(f){Ya(f.model)&&(ZL(f.axisBuilder,e,f.model),f.axisBuilder.build(o?{axisTickLabelDetermine:!0}:{axisTickLabelEstimate:!0},{noPxChange:i}))})});var s={x:0,y:0};l(0),l(1);function l(u){s[Mr[1-u]]=e[Mi[u]]<=a.refContainer[Mi[u]]*.5?0:1-u===1?2:1}M(t,function(u,f){return M(u,function(h){Ya(h.model)&&((n==="all"||o)&&h.axisBuilder.build({axisName:!0},{nameMarginLevel:s[f]}),o&&h.axisBuilder.build({axisLine:!0}))})})}function QL(e,t,r){var n,i=e.get("outerBoundsMode",!0);i==="same"?n=t.clone():(i==null||i==="auto")&&(n=to(e.get("outerBounds",!0)||u_,r.refContainer));var a=e.get("outerBoundsContain",!0),o;a==null||a==="auto"||ft(["all","axisLabel"],a)<0?o="all":o=a;var s=[mf(q(e.get("outerBoundsClampWidth",!0),Vs[0]),t.width),mf(q(e.get("outerBoundsClampHeight",!0),Vs[1]),t.height)];return{outerBoundsRect:n,parsedOuterBoundsContain:o,outerBoundsClamp:s}}var JL=function(e,t,r,n,i,a){var o=r.axis.dim==="x"?"y":"x";A_(e,t,r,n,i,a),Ii(e.nameLocation)||M(t.recordMap[o],function(s){s&&s.labelInfoList&&s.dirVec&&I_(s.labelInfoList,s.dirVec,n,i)})};function jL(e,t){var r={axesInfo:{},seriesInvolved:!1,coordSysAxesInfo:{},coordSysMap:{}};return t2(r,e,t),r.seriesInvolved&&r2(r,e),r}function t2(e,t,r){var n=t.getComponent("tooltip"),i=t.getComponent("axisPointer"),a=i.get("link",!0)||[],o=[];M(r.getCoordinateSystems(),function(s){if(!s.axisPointerEnabled)return;var l=Xa(s.model),u=e.coordSysAxesInfo[l]={};e.coordSysMap[l]=s;var f=s.model,h=f.getModel("tooltip",n);if(M(s.getAxes(),ne(p,!1,null)),s.getTooltipAxes&&n&&h.get("show")){var c=h.get("trigger")==="axis",v=h.get(["axisPointer","type"])==="cross",d=s.getTooltipAxes(h.get(["axisPointer","axis"]));(c||v)&&M(d.baseAxes,ne(p,v?"cross":!0,c)),v&&M(d.otherAxes,ne(p,"cross",!1))}function p(g,m,y){var _=y.model.getModel("axisPointer",i),S=_.get("show");if(!(!S||S==="auto"&&!g&&!oh(_))){m==null&&(m=_.get("triggerTooltip")),_=g?e2(y,h,i,t,g,m):_;var w=_.get("snap"),b=_.get("triggerEmphasis"),x=Xa(y.model),C=m||w||y.type==="category",T=e.axesInfo[x]={key:x,axis:y,coordSys:s,axisPointerModel:_,triggerTooltip:m,triggerEmphasis:b,involveSeries:C,snap:w,useHandle:oh(_),seriesModels:[],linkGroup:null};u[x]=T,e.seriesInvolved=e.seriesInvolved||C;var D=n2(a,y);if(D!=null){var A=o[D]||(o[D]={axesInfo:{}});A.axesInfo[x]=T,A.mapper=a[D].mapper,T.linkGroup=A}}}})}function e2(e,t,r,n,i,a){var o=t.getModel("axisPointer"),s=["type","snap","lineStyle","shadowStyle","label","animation","animationDurationUpdate","animationEasingUpdate","z"],l={};M(s,function(c){l[c]=st(o.get(c))}),l.snap=e.type!=="category"&&!!a,o.get("type")==="cross"&&(l.type="line");var u=l.label||(l.label={});if(u.show==null&&(u.show=!1),i==="cross"){var f=o.get(["label","show"]);if(u.show=f??!0,!a){var h=l.lineStyle=o.get("crossStyle");h&&at(u,h.textStyle)}}return e.model.getModel("axisPointer",new xt(l,r,n))}function r2(e,t){t.eachSeries(function(r){var n=r.coordinateSystem,i=r.get(["tooltip","trigger"],!0),a=r.get(["tooltip","show"],!0);!n||!n.model||i==="none"||i===!1||i==="item"||a===!1||r.get(["axisPointer","show"],!0)===!1||M(e.coordSysAxesInfo[Xa(n.model)],function(o){var s=o.axis;n.getAxis(s.dim)===s&&(o.seriesModels.push(r),o.seriesDataCount==null&&(o.seriesDataCount=0),o.seriesDataCount+=r.getData().count())})})}function n2(e,t){for(var r=t.model,n=t.dim,i=0;i<e.length;i++){var a=e[i]||{};if(Eu(a[n+"AxisId"],r.id)||Eu(a[n+"AxisIndex"],r.componentIndex)||Eu(a[n+"AxisName"],r.name))return i}}function Eu(e,t){return e==="all"||z(e)&&ft(e,t)>=0||e===t}function i2(e){var t=Sv(e);if(t){var r=t.axisPointerModel,n=t.axis.scale,i=r.option,a=r.get("status"),o=r.get("value");o!=null&&(o=n.parse(o));var s=oh(r);a==null&&(i.status=s?"show":"hide");var l=n.getExtent().slice();l[0]>l[1]&&l.reverse(),(o==null||o>l[1])&&(o=l[1]),o<l[0]&&(o=l[0]),i.value=o,s&&(i.status=t.axis.scale.isBlank()?"hide":"show")}}function Sv(e){var t=(e.ecModel.getComponent("axisPointer")||{}).coordSysAxesInfo;return t&&t.axesInfo[Xa(e)]}function a2(e){var t=Sv(e);return t&&t.axisPointerModel}function oh(e){return!!e.get(["handle","show"])}function Xa(e){return e.type+"||"+e.id}var Up={},O_=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type=t.type,r}return t.prototype.render=function(r,n,i,a){this.axisPointerClass&&i2(r),e.prototype.render.apply(this,arguments),this._doUpdateAxisPointerClass(r,i,!0)},t.prototype.updateAxisPointer=function(r,n,i,a){this._doUpdateAxisPointerClass(r,i,!1)},t.prototype.remove=function(r,n){var i=this._axisPointer;i&&i.remove(n)},t.prototype.dispose=function(r,n){this._disposeAxisPointer(n),e.prototype.dispose.apply(this,arguments)},t.prototype._doUpdateAxisPointerClass=function(r,n,i){var a=t.getAxisPointerClass(this.axisPointerClass);if(a){var o=a2(r);o?(this._axisPointer||(this._axisPointer=new a)).render(r,o,n,i):this._disposeAxisPointer(n)}},t.prototype._disposeAxisPointer=function(r){this._axisPointer&&this._axisPointer.dispose(r),this._axisPointer=null},t.registerAxisPointerClass=function(r,n){Up[r]=n},t.getAxisPointerClass=function(r){return r&&Up[r]},t.type="axis",t})(Te),sh=gt();function o2(e,t,r,n){var i=r.axis;if(!i.scale.isBlank()){var a=r.getModel("splitArea"),o=a.getModel("areaStyle"),s=o.get("color"),l=n.coordinateSystem.getRect(),u=i.getTicksCoords({tickModel:a,clamp:!0,breakTicks:"none",pruneByBreak:"preserve_extent_bound"});if(u.length){var f=s.length,h=sh(e).splitAreaColors,c=K(),v=0;if(h)for(var d=0;d<u.length;d++){var p=h.get(u[d].tickValue);if(p!=null){v=(p+(f-1)*d)%f;break}}var g=i.toGlobalCoord(u[0].coord),m=o.getAreaStyle();s=z(s)?s:[s];for(var d=1;d<u.length;d++){var y=i.toGlobalCoord(u[d].coord),_=void 0,S=void 0,w=void 0,b=void 0;i.isHorizontal()?(_=g,S=l.y,w=y-_,b=l.height,g=_+w):(_=l.x,S=g,w=l.width,b=y-S,g=S+b);var x=u[d-1].tickValue;x!=null&&c.set(x,v),t.add(new Tt({anid:x!=null?"area_"+x:null,shape:{x:_,y:S,width:w,height:b},style:at({fill:s[v]},m),autoBatch:!0,silent:!0})),v=(v+1)%f}sh(e).splitAreaColors=c}}}function s2(e){sh(e).splitAreaColors=null}var l2=["splitArea","splitLine","minorSplitLine","breakArea"],B_=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type=t.type,r.axisPointerClass="CartesianAxisPointer",r}return t.prototype.render=function(r,n,i,a){this.group.removeAll();var o=this._axisGroup;if(this._axisGroup=new Ft,this.group.add(this._axisGroup),!!Ya(r)){this._axisGroup.add(r.axis.axisBuilder.group),M(l2,function(l){r.get([l,"show"])&&u2[l](this,this._axisGroup,r,r.getCoordSysModel(),i)},this);var s=a&&a.type==="changeAxisOrder"&&a.isInitSort;s||sy(o,this._axisGroup,r),e.prototype.render.call(this,r,n,i,a)}},t.prototype.remove=function(){s2(this)},t.type="cartesianAxis",t})(O_),u2={splitLine:function(e,t,r,n,i){var a=r.axis;if(!a.scale.isBlank()){var o=r.getModel("splitLine"),s=o.getModel("lineStyle"),l=s.get("color"),u=o.get("showMinLine")!==!1,f=o.get("showMaxLine")!==!1;l=z(l)?l:[l];for(var h=n.coordinateSystem.getRect(),c=a.isHorizontal(),v=0,d=a.getTicksCoords({tickModel:o,breakTicks:"none",pruneByBreak:"preserve_extent_bound"}),p=[],g=[],m=s.getLineStyle(),y=0;y<d.length;y++){var _=a.toGlobalCoord(d[y].coord);if(!(y===0&&!u||y===d.length-1&&!f)){var S=d[y].tickValue;c?(p[0]=_,p[1]=h.y,g[0]=_,g[1]=h.y+h.height):(p[0]=h.x,p[1]=_,g[0]=h.x+h.width,g[1]=_);var w=v++%l.length,b=new Fr({anid:S!=null?"line_"+S:null,autoBatch:!0,shape:{x1:p[0],y1:p[1],x2:g[0],y2:g[1]},style:at({stroke:l[w]},m),silent:!0});ka(b.shape,m.lineWidth),t.add(b)}}}},minorSplitLine:function(e,t,r,n,i){var a=r.axis,o=r.getModel("minorSplitLine"),s=o.getModel("lineStyle"),l=n.coordinateSystem.getRect(),u=a.isHorizontal(),f=a.getMinorTicksCoords();if(f.length)for(var h=[],c=[],v=s.getLineStyle(),d=0;d<f.length;d++)for(var p=0;p<f[d].length;p++){var g=a.toGlobalCoord(f[d][p].coord);u?(h[0]=g,h[1]=l.y,c[0]=g,c[1]=l.y+l.height):(h[0]=l.x,h[1]=g,c[0]=l.x+l.width,c[1]=g);var m=new Fr({anid:"minor_line_"+f[d][p].tickValue,autoBatch:!0,shape:{x1:h[0],y1:h[1],x2:c[0],y2:c[1]},style:v,silent:!0});ka(m.shape,v.lineWidth),t.add(m)}},splitArea:function(e,t,r,n,i){o2(e,t,r,n)},breakArea:function(e,t,r,n,i){r.axis.scale}},N_=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type=t.type,r}return t.type="xAxis",t})(B_),f2=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type=N_.type,r}return t.type="yAxis",t})(B_),h2=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type="grid",r}return t.prototype.render=function(r,n){this.group.removeAll(),r.get("show")&&this.group.add(new Tt({shape:r.coordinateSystem.getRect(),style:at({fill:r.get("backgroundColor")},r.getItemStyle()),silent:!0,z2:-1}))},t.type="grid",t})(Te),Yp={offset:0};function v2(e){e.registerComponentView(h2),e.registerComponentModel(kA),e.registerCoordinateSystem("cartesian2d",$L),Mp(e,"x",Jf,Yp),Mp(e,"y",Jf,Yp),e.registerComponentView(N_),e.registerComponentView(f2),e.registerPreprocessor(function(t){t.xAxis&&t.yAxis&&!t.grid&&(t.grid={})})}var c2=gt();function Zp(e,t){return!!c2(e)[t]}zn({type:"takeGlobalCursor",event:"globalCursorTaken",update:"update"},qt);var d2={axisPointer:1,tooltip:1,brush:1};function p2(e,t,r){var n=t.getComponentByElement(e.topTarget);if(!n||n===r||d2.hasOwnProperty(n.mainType))return!1;var i=n.coordinateSystem;if(!i||i.model===r)return!1;var a=Na(n),o=Na(r);return!((a.zlevel-o.zlevel||a.z-o.z)<=0)}var g2=(function(e){N(t,e);function t(r){var n=e.call(this)||this;n._zr=r;var i=Q(n._mousedownHandler,n),a=Q(n._mousemoveHandler,n),o=Q(n._mouseupHandler,n),s=Q(n._mousewheelHandler,n),l=Q(n._pinchHandler,n);return n.enable=function(u,f){var h=f.zInfo,c=Na(h.component),v=c.z,d=c.zlevel,p={component:h.component,z:v,zlevel:d,z2:q(h.z2,-1/0)},g=k({},f.triggerInfo);this._opt=at(k({},f),{zoomOnMouseWheel:!0,moveOnMouseMove:!0,moveOnMouseWheel:!1,preventDefaultMouseMove:!0,zInfoParsed:p,triggerInfo:g}),u==null&&(u=!0),(!this._enabled||this._controlType!==u)&&(this._enabled=!0,this.disable(),(u===!0||u==="move"||u==="pan")&&(ra(r,"mousedown",i,p),ra(r,"mousemove",a,p),ra(r,"mouseup",o,p)),(u===!0||u==="scale"||u==="zoom")&&(ra(r,"mousewheel",s,p),ra(r,"pinch",l,p)))},n.disable=function(){this._enabled=!1,na(r,"mousedown",i),na(r,"mousemove",a),na(r,"mouseup",o),na(r,"mousewheel",s),na(r,"pinch",l)},n}return t.prototype.isDragging=function(){return this._dragging},t.prototype.isPinching=function(){return this._pinching},t.prototype._checkPointer=function(r,n,i){var a=this._opt,o=a.zInfoParsed;if(p2(r,a.api,o.component))return!1;var s=a.triggerInfo,l=s.roamTrigger,u=!1;return l==="global"&&(u=!0),u||(u=s.isInSelf(r,n,i)),u&&s.isInClip&&!s.isInClip(r,n,i)&&(u=!1),u},t.prototype._decideCursorStyle=function(r,n,i,a){var o=r.target;if(!o&&this._checkPointer(r,n,i))return"grab";if(a)return o&&o.cursor||"default"},t.prototype.dispose=function(){this.disable()},t.prototype._mousedownHandler=function(r){if(!(Rd(r)||ea(r))){for(var n=r.target;n;){if(n.draggable)return;n=n.__hostTarget||n.parent}var i=r.offsetX,a=r.offsetY;this._checkPointer(r,i,a)&&(this._x=i,this._y=a,this._dragging=!0)}},t.prototype._mousemoveHandler=function(r){var n=this._zr;if(!(r.gestureEvent==="pinch"||Zp(n,"globalPan")||ea(r))){var i=r.offsetX,a=r.offsetY;if(!this._dragging||!ss("moveOnMouseMove",r,this._opt)){var o=this._decideCursorStyle(r,i,a,!1);o&&n.setCursorStyle(o);return}n.setCursorStyle("grabbing");var s=this._x,l=this._y,u=i-s,f=a-l;this._x=i,this._y=a,this._opt.preventDefaultMouseMove&&Ai(r.event),r.__ecRoamConsumed=!0,Xp(this,"pan","moveOnMouseMove",r,{dx:u,dy:f,oldX:s,oldY:l,newX:i,newY:a,isAvailableBehavior:null})}},t.prototype._mouseupHandler=function(r){if(!ea(r)){var n=this._zr;if(!Rd(r)){this._dragging=!1;var i=this._decideCursorStyle(r,r.offsetX,r.offsetY,!0);i&&n.setCursorStyle(i)}}},t.prototype._mousewheelHandler=function(r){if(!ea(r)){var n=ss("zoomOnMouseWheel",r,this._opt),i=ss("moveOnMouseWheel",r,this._opt),a=r.wheelDelta,o=Math.abs(a),s=r.offsetX,l=r.offsetY;if(!(a===0||!n&&!i)){if(n){var u=o>3?1.4:o>1?1.2:1.1,f=a>0?u:1/u;this._checkTriggerMoveZoom(this,"zoom","zoomOnMouseWheel",r,{scale:f,originX:s,originY:l,isAvailableBehavior:null})}if(i){var h=Math.abs(a),c=(a>0?1:-1)*(h>3?.4:h>1?.15:.05);this._checkTriggerMoveZoom(this,"scrollMove","moveOnMouseWheel",r,{scrollDelta:c,originX:s,originY:l,isAvailableBehavior:null})}}}},t.prototype._pinchHandler=function(r){if(!(Zp(this._zr,"globalPan")||ea(r))){var n=r.pinchScale>1?1.1:1/1.1;this._checkTriggerMoveZoom(this,"zoom",null,r,{scale:n,originX:r.pinchX,originY:r.pinchY,isAvailableBehavior:null})}},t.prototype._checkTriggerMoveZoom=function(r,n,i,a,o){r._checkPointer(a,o.originX,o.originY)&&(Ai(a.event),a.__ecRoamConsumed=!0,Xp(r,n,i,a,o))},t})(Ee);function ea(e){return e.__ecRoamConsumed}var m2=gt();function _l(e){var t=m2(e);return t.roam=t.roam||{},t.uniform=t.uniform||{},t}function ra(e,t,r,n){for(var i=_l(e),a=i.roam,o=a[t]=a[t]||[],s=0;s<o.length;s++){var l=o[s].zInfoParsed;if((l.zlevel-n.zlevel||l.z-n.z||l.z2-n.z2)<=0)break}o.splice(s,0,{listener:r,zInfoParsed:n}),y2(e,t)}function na(e,t,r){for(var n=_l(e),i=n.roam[t]||[],a=0;a<i.length;a++)if(i[a].listener===r){i.splice(a,1),i.length||_2(e,t);return}}function y2(e,t){var r=_l(e);r.uniform[t]||e.on(t,r.uniform[t]=function(n){var i=r.roam[t];if(i)for(var a=0;a<i.length;a++)i[a].listener(n)})}function _2(e,t){var r=_l(e),n=r.uniform;n[t]&&(e.off(t,n[t]),n[t]=null)}function Xp(e,t,r,n,i){i.isAvailableBehavior=Q(ss,null,r,n),e.trigger(t,i)}function ss(e,t,r){var n=r[e];return!e||n&&(!W(n)||t.event[n+"Key"])}function $a(e,t,r,n,i,a){e=e||0;var o=r[1]-r[0];if(i!=null&&(i=ni(i,[0,o])),a!=null&&(a=Math.max(a,i??0)),n==="all"){var s=Math.abs(t[1]-t[0]);s=ni(s,[0,o]),i=a=ni(s,[i,a]),n=0}t[0]=ni(t[0],r),t[1]=ni(t[1],r);var l=ku(t,n);t[n]+=e;var u=i||0,f=r.slice();l.sign<0?f[0]+=u:f[1]-=u,t[n]=ni(t[n],f);var h;return h=ku(t,n),i!=null&&(h.sign!==l.sign||h.span<i)&&(t[1-n]=t[n]+l.sign*i),h=ku(t,n),a!=null&&h.span>a&&(t[1-n]=t[n]+h.sign*a),t}function ku(e,t){var r=e[t]-e[1-t];return{span:Math.abs(r),sign:r>0?-1:r<0?1:t?-1:1}}function ni(e,t){return Math.min(t[1]!=null?t[1]:1/0,Math.max(t[0]!=null?t[0]:-1/0,e))}var Sn=gt(),$p=st,Ou=Q,S2=(function(){function e(){this._dragging=!1,this.animationThreshold=15}return e.prototype.render=function(t,r,n,i){var a=r.get("value"),o=r.get("status");if(this._axisModel=t,this._axisPointerModel=r,this._api=n,!(!i&&this._lastValue===a&&this._lastStatus===o)){this._lastValue=a,this._lastStatus=o;var s=this._group,l=this._handle;if(!o||o==="hide"){s&&s.hide(),l&&l.hide();return}s&&s.show(),l&&l.show();var u={};this.makeElOption(u,a,t,r,n);var f=u.graphicKey;f!==this._lastGraphicKey&&this.clear(n),this._lastGraphicKey=f;var h=this._moveAnimation=this.determineAnimation(t,r);if(!s)s=this._group=new Ft,this.createPointerEl(s,u,t,r),this.createLabelEl(s,u,t,r),n.getZr().add(s);else{var c=ne(qp,r,h);this.updatePointerEl(s,u,c),this.updateLabelEl(s,u,c,r)}Qp(s,r,!0),this._renderHandle(a)}},e.prototype.remove=function(t){this.clear(t)},e.prototype.dispose=function(t){this.clear(t)},e.prototype.determineAnimation=function(t,r){var n=r.get("animation"),i=t.axis,a=i.type==="category",o=r.get("snap");if(!o&&!a)return!1;if(n==="auto"||n==null){var s=this.animationThreshold;if(a&&i.getBandWidth()>s)return!0;if(o){var l=Sv(t).seriesDataCount,u=i.getExtent();return Math.abs(u[0]-u[1])/l>s}return!1}return n===!0},e.prototype.makeElOption=function(t,r,n,i,a){},e.prototype.createPointerEl=function(t,r,n,i){var a=r.pointer;if(a){var o=Sn(t).pointerEl=new Qw[a.type]($p(r.pointer));t.add(o)}},e.prototype.createLabelEl=function(t,r,n,i){if(r.label){var a=Sn(t).labelEl=new ae($p(r.label));t.add(a),Kp(a,i)}},e.prototype.updatePointerEl=function(t,r,n){var i=Sn(t).pointerEl;i&&r.pointer&&(i.setStyle(r.pointer.style),n(i,{shape:r.pointer.shape}))},e.prototype.updateLabelEl=function(t,r,n,i){var a=Sn(t).labelEl;a&&(a.setStyle(r.label.style),n(a,{x:r.label.x,y:r.label.y}),Kp(a,i))},e.prototype._renderHandle=function(t){if(!(this._dragging||!this.updateHandleTransform)){var r=this._axisPointerModel,n=this._api.getZr(),i=this._handle,a=r.getModel("handle"),o=r.get("status");if(!a.get("show")||!o||o==="hide"){i&&n.remove(i),this._handle=null;return}var s;this._handle||(s=!0,i=this._handle=ly(a.get("icon"),{cursor:"move",draggable:!0,onmousemove:function(u){Ai(u.event)},onmousedown:Ou(this._onHandleDragMove,this,0,0),drift:Ou(this._onHandleDragMove,this),ondragend:Ou(this._onHandleDragEnd,this)}),n.add(i)),Qp(i,r,!1),i.setStyle(a.getItemStyle(null,["color","borderColor","borderWidth","opacity","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"]));var l=a.get("size");z(l)||(l=[l,l]),i.scaleX=l[0]/2,i.scaleY=l[1]/2,ml(this,"_doDispatchAxisPointer",a.get("throttle")||0,"fixRate"),this._moveHandleToValue(t,s)}},e.prototype._moveHandleToValue=function(t,r){qp(this._axisPointerModel,!r&&this._moveAnimation,this._handle,Bu(this.getHandleTransform(t,this._axisModel,this._axisPointerModel)))},e.prototype._onHandleDragMove=function(t,r){var n=this._handle;if(n){this._dragging=!0;var i=this.updateHandleTransform(Bu(n),[t,r],this._axisModel,this._axisPointerModel);this._payloadInfo=i,n.stopAnimation(),n.attr(Bu(i)),Sn(n).lastProp=null,this._doDispatchAxisPointer()}},e.prototype._doDispatchAxisPointer=function(){var t=this._handle;if(t){var r=this._payloadInfo,n=this._axisModel;this._api.dispatchAction({type:"updateAxisPointer",x:r.cursorPoint[0],y:r.cursorPoint[1],tooltipOption:r.tooltipOption,axesInfo:[{axisDim:n.axis.dim,axisIndex:n.componentIndex}]})}},e.prototype._onHandleDragEnd=function(){this._dragging=!1;var t=this._handle;if(t){var r=this._axisPointerModel.get("value");this._moveHandleToValue(r),this._api.dispatchAction({type:"hideTip"})}},e.prototype.clear=function(t){this._lastValue=null,this._lastStatus=null;var r=t.getZr(),n=this._group,i=this._handle;r&&n&&(this._lastGraphicKey=null,n&&r.remove(n),i&&r.remove(i),this._group=null,this._handle=null,this._payloadInfo=null),Rs(this,"_doDispatchAxisPointer")},e.prototype.doClear=function(){},e.prototype.buildLabel=function(t,r,n){return n=n||0,{x:t[n],y:t[1-n],width:r[n],height:r[1-n]}},e})();function qp(e,t,r,n){F_(Sn(r).lastProp,n)||(Sn(r).lastProp=n,t?qe(r,n,e):(r.stopAnimation(),r.attr(n)))}function F_(e,t){if(X(e)&&X(t)){var r=!0;return M(t,function(n,i){r=r&&F_(e[i],n)}),!!r}else return e===t}function Kp(e,t){e[t.get(["label","show"])?"show":"hide"]()}function Bu(e){return{x:e.x||0,y:e.y||0,rotation:e.rotation||0}}function Qp(e,t,r){var n=t.get("z"),i=t.get("zlevel");e&&e.traverse(function(a){a.type!=="group"&&(n!=null&&(a.z=n),i!=null&&(a.zlevel=i),a.silent=r)})}function b2(e){var t=e.get("type"),r=e.getModel(t+"Style"),n;return t==="line"?(n=r.getLineStyle(),n.fill=null):t==="shadow"&&(n=r.getAreaStyle(),n.stroke=null),n}function w2(e,t,r,n,i){var a=r.get("value"),o=z_(a,t.axis,t.ecModel,r.get("seriesDataIndices"),{precision:r.get(["label","precision"]),formatter:r.get(["label","formatter"])}),s=r.getModel("label"),l=rv(s.get("padding")||0),u=s.getFont(),f=em(o,u),h=i.position,c=f.width+l[1]+l[3],v=f.height+l[0]+l[2],d=i.align;d==="right"&&(h[0]-=c),d==="center"&&(h[0]-=c/2);var p=i.verticalAlign;p==="bottom"&&(h[1]-=v),p==="middle"&&(h[1]-=v/2),x2(h,c,v,n);var g=s.get("backgroundColor");(!g||g==="auto")&&(g=t.get(["axisLine","lineStyle","color"])),e.label={x:h[0],y:h[1],style:zr(s,{text:o,font:u,fill:s.getTextColor(),padding:l,backgroundColor:g}),z2:10}}function x2(e,t,r,n){var i=n.getWidth(),a=n.getHeight();e[0]=Math.min(e[0]+t,i)-t,e[1]=Math.min(e[1]+r,a)-r,e[0]=Math.max(e[0],0),e[1]=Math.max(e[1],0)}function z_(e,t,r,n,i){e=t.scale.parse(e);var a=t.scale.getLabel({value:e},{precision:i.precision}),o=i.formatter;if(o){var s={value:Gs(t,{value:e}),axisDimension:t.dim,axisIndex:t.index,seriesData:[]};M(n,function(l){var u=r.getSeriesByIndex(l.seriesIndex),f=l.dataIndexInside,h=u&&u.getDataParams(f);h&&s.seriesData.push(h)}),W(o)?a=o.replace("{value}",a):et(o)&&(a=o(s))}return a}function H_(e,t,r){var n=sr();return wh(n,n,r.rotation),Qu(n,n,r.position),Oa([e.dataToCoord(t),(r.labelOffset||0)+(r.labelDirection||1)*(r.labelMargin||0)],n)}function T2(e,t,r,n,i,a){var o=kr.innerTextLayout(r.rotation,0,r.labelDirection);r.labelMargin=i.get(["label","margin"]),w2(t,n,i,a,{position:H_(n.axis,e,r),align:o.textAlign,verticalAlign:o.textVerticalAlign})}function C2(e,t,r){return r=r||0,{x1:e[r],y1:e[1-r],x2:t[r],y2:t[1-r]}}function M2(e,t,r){return r=r||0,{x:e[r],y:e[1-r],width:t[r],height:t[1-r]}}var D2=(function(e){N(t,e);function t(){return e!==null&&e.apply(this,arguments)||this}return t.prototype.makeElOption=function(r,n,i,a,o){var s=i.axis,l=s.grid,u=a.get("type"),f=Jp(l,s).getOtherAxis(s).getGlobalExtent(),h=s.toGlobalCoord(s.dataToCoord(n,!0));if(u&&u!=="none"){var c=b2(a),v=A2[u](s,h,f);v.style=c,r.graphicKey=v.type,r.pointer=v}var d=Us(l.getRect(),i);T2(n,r,d,i,a,o)},t.prototype.getHandleTransform=function(r,n,i){var a=Us(n.axis.grid.getRect(),n,{labelInside:!1});a.labelMargin=i.get(["handle","margin"]);var o=H_(n.axis,r,a);return{x:o[0],y:o[1],rotation:a.rotation+(a.labelDirection<0?Math.PI:0)}},t.prototype.updateHandleTransform=function(r,n,i,a){var o=i.axis,s=o.grid,l=o.getGlobalExtent(!0),u=Jp(s,o).getOtherAxis(o).getGlobalExtent(),f=o.dim==="x"?0:1,h=[r.x,r.y];h[f]+=n[f],h[f]=Math.min(l[1],h[f]),h[f]=Math.max(l[0],h[f]);var c=(u[1]+u[0])/2,v=[c,c];v[f]=h[f];var d=[{verticalAlign:"middle"},{align:"center"}];return{x:h[0],y:h[1],rotation:r.rotation,cursorPoint:v,tooltipOption:d[f]}},t})(S2);function Jp(e,t){var r={};return r[t.dim+"AxisIndex"]=t.index,e.getCartesian(r)}var A2={line:function(e,t,r){var n=C2([t,r[0]],[t,r[1]],jp(e));return{type:"Line",subPixelOptimize:!0,shape:n}},shadow:function(e,t,r){var n=Math.max(1,e.getBandWidth()),i=r[1]-r[0];return{type:"Rect",shape:M2([t-n/2,r[0]],[n,i],jp(e))}}};function jp(e){return e.dim==="x"?0:1}var L2=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type=t.type,r}return t.type="axisPointer",t.defaultOption={show:"auto",z:50,type:"line",snap:!1,triggerTooltip:!0,triggerEmphasis:!0,value:null,status:null,link:[],animation:null,animationDurationUpdate:200,lineStyle:{color:Y.color.border,width:1,type:"dashed"},shadowStyle:{color:Y.color.shadowTint},label:{show:!0,formatter:null,precision:"auto",margin:3,color:Y.color.neutral00,padding:[5,7,5,7],backgroundColor:Y.color.accent60,borderColor:null,borderWidth:0,borderRadius:3},handle:{show:!1,icon:"M10.7,11.9v-1.3H9.3v1.3c-4.9,0.3-8.8,4.4-8.8,9.4c0,5,3.9,9.1,8.8,9.4h1.3c4.9-0.3,8.8-4.4,8.8-9.4C19.5,16.3,15.6,12.2,10.7,11.9z M13.3,24.4H6.7v-1.2h6.6z M13.3,22H6.7v-1.2h6.6z M13.3,19.6H6.7v-1.2h6.6z",size:45,margin:50,color:Y.color.accent40,throttle:40}},t})(dt),or=gt(),I2=M;function V_(e,t,r){if(!nt.node){var n=t.getZr();or(n).records||(or(n).records={}),P2(n,t);var i=or(n).records[e]||(or(n).records[e]={});i.handler=r}}function P2(e,t){if(or(e).initialized)return;or(e).initialized=!0,r("click",ne(tg,"click")),r("mousemove",ne(tg,"mousemove")),r("globalout",E2);function r(n,i){e.on(n,function(a){var o=k2(t);I2(or(e).records,function(s){s&&i(s,a,o.dispatchAction)}),R2(o.pendings,t)})}}function R2(e,t){var r=e.showTip.length,n=e.hideTip.length,i;r?i=e.showTip[r-1]:n&&(i=e.hideTip[n-1]),i&&(i.dispatchAction=null,t.dispatchAction(i))}function E2(e,t,r){e.handler("leave",null,r)}function tg(e,t,r,n){t.handler(e,r,n)}function k2(e){var t={showTip:[],hideTip:[]},r=function(n){var i=t[n.type];i?i.push(n):(n.dispatchAction=r,e.dispatchAction(n))};return{dispatchAction:r,pendings:t}}function lh(e,t){if(!nt.node){var r=t.getZr(),n=(or(r).records||{})[e];n&&(or(r).records[e]=null)}}var O2=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type=t.type,r}return t.prototype.render=function(r,n,i){var a=n.getComponent("tooltip"),o=r.get("triggerOn")||a&&a.get("triggerOn")||"mousemove|click";V_("axisPointer",i,function(s,l,u){o!=="none"&&(s==="leave"||o.indexOf(s)>=0)&&u({type:"updateAxisPointer",currTrigger:s,x:l&&l.offsetX,y:l&&l.offsetY})})},t.prototype.remove=function(r,n){lh("axisPointer",n)},t.prototype.dispose=function(r,n){lh("axisPointer",n)},t.type="axisPointer",t})(Te);function G_(e,t){var r=[],n=e.seriesIndex,i;if(n==null||!(i=t.getSeriesByIndex(n)))return{point:[]};var a=i.getData(),o=En(a,e);if(o==null||o<0||z(o))return{point:[]};var s=a.getItemGraphicEl(o),l=i.coordinateSystem;if(i.getTooltipPosition)r=i.getTooltipPosition(o)||[];else if(l&&l.dataToPoint)if(e.isStacked){var u=l.getBaseAxis(),f=l.getOtherAxis(u),h=f.dim,c=u.dim,v=h==="x"||h==="radius"?1:0,d=a.mapDimension(c),p=[];p[v]=a.get(d,o),p[1-v]=a.get(a.getCalculationInfo("stackResultDimension"),o),r=l.dataToPoint(p)||[]}else r=l.dataToPoint(a.getValues($(l.dimensions,function(m){return a.mapDimension(m)}),o))||[];else if(s){var g=s.getBoundingRect().clone();g.applyTransform(s.transform),r=[g.x+g.width/2,g.y+g.height/2]}return{point:r,el:s}}var eg=gt();function B2(e,t,r){var n=e.currTrigger,i=[e.x,e.y],a=e,o=e.dispatchAction||Q(r.dispatchAction,r),s=t.getComponent("axisPointer").coordSysAxesInfo;if(s){ls(i)&&(i=G_({seriesIndex:a.seriesIndex,dataIndex:a.dataIndex},t).point);var l=ls(i),u=a.axesInfo,f=s.axesInfo,h=n==="leave"||ls(i),c={},v={},d={list:[],map:{}},p={showPointer:ne(F2,v),showTooltip:ne(z2,d)};M(s.coordSysMap,function(m,y){var _=l||m.containPoint(i);M(s.coordSysAxesInfo[y],function(S,w){var b=S.axis,x=W2(u,S);if(!h&&_&&(!u||x)){var C=x&&x.value;C==null&&!l&&(C=b.pointToData(i)),C!=null&&rg(S,C,p,!1,c)}})});var g={};return M(f,function(m,y){var _=m.linkGroup;_&&!v[y]&&M(_.axesInfo,function(S,w){var b=v[w];if(S!==m&&b){var x=b.value;_.mapper&&(x=m.axis.scale.parse(_.mapper(x,ng(S),ng(m)))),g[m.key]=x}})}),M(g,function(m,y){rg(f[y],m,p,!0,c)}),H2(v,f,c),V2(d,i,e,o),G2(f,o,r),c}}function rg(e,t,r,n,i){var a=e.axis;if(!(a.scale.isBlank()||!a.containData(t))){if(!e.involveSeries){r.showPointer(e,t);return}var o=N2(t,e),s=o.payloadBatch,l=o.snapToValue;s[0]&&i.seriesIndex==null&&k(i,s[0]),!n&&e.snap&&a.containData(l)&&l!=null&&(t=l),r.showPointer(e,t,s),r.showTooltip(e,o,l)}}function N2(e,t){var r=t.axis,n=r.dim,i=e,a=[],o=Number.MAX_VALUE,s=-1;return M(t.seriesModels,function(l,u){var f=l.getData().mapDimensionsAll(n),h,c;if(l.getAxisTooltipData){var v=l.getAxisTooltipData(f,e,r);c=v.dataIndices,h=v.nestestValue}else{if(c=l.indicesOfNearest(n,f[0],e,r.type==="category"?.5:null),!c.length)return;h=l.getData().get(f[0],c[0])}if(!(h==null||!isFinite(h))){var d=e-h,p=Math.abs(d);p<=o&&((p<o||d>=0&&s<0)&&(o=p,s=d,i=h,a.length=0),M(c,function(g){a.push({seriesIndex:l.seriesIndex,dataIndexInside:g,dataIndex:l.getData().getRawIndex(g)})}))}}),{payloadBatch:a,snapToValue:i}}function F2(e,t,r,n){e[t.key]={value:r,payloadBatch:n}}function z2(e,t,r,n){var i=r.payloadBatch,a=t.axis,o=a.model,s=t.axisPointerModel;if(!(!t.triggerTooltip||!i.length)){var l=t.coordSys.model,u=Xa(l),f=e.map[u];f||(f=e.map[u]={coordSysId:l.id,coordSysIndex:l.componentIndex,coordSysType:l.type,coordSysMainType:l.mainType,dataByAxis:[]},e.list.push(f)),f.dataByAxis.push({axisDim:a.dim,axisIndex:o.componentIndex,axisType:o.type,axisId:o.id,value:n,valueLabelOpt:{precision:s.get(["label","precision"]),formatter:s.get(["label","formatter"])},seriesDataIndices:i.slice()})}}function H2(e,t,r){var n=r.axesInfo=[];M(t,function(i,a){var o=i.axisPointerModel.option,s=e[a];s?(!i.useHandle&&(o.status="show"),o.value=s.value,o.seriesDataIndices=(s.payloadBatch||[]).slice()):!i.useHandle&&(o.status="hide"),o.status==="show"&&n.push({axisDim:i.axis.dim,axisIndex:i.axis.model.componentIndex,value:o.value})})}function V2(e,t,r,n){if(ls(t)||!e.list.length){n({type:"hideTip"});return}var i=((e.list[0].dataByAxis[0]||{}).seriesDataIndices||[])[0]||{};n({type:"showTip",escapeConnect:!0,x:t[0],y:t[1],tooltipOption:r.tooltipOption,position:r.position,dataIndexInside:i.dataIndexInside,dataIndex:i.dataIndex,seriesIndex:i.seriesIndex,dataByCoordSys:e.list})}function G2(e,t,r){var n=r.getZr(),i="axisPointerLastHighlights",a=eg(n)[i]||{},o=eg(n)[i]={};M(e,function(u,f){var h=u.axisPointerModel.option;h.status==="show"&&u.triggerEmphasis&&M(h.seriesDataIndices,function(c){var v=c.seriesIndex+" | "+c.dataIndex;o[v]=c})});var s=[],l=[];M(a,function(u,f){!o[f]&&l.push(u)}),M(o,function(u,f){!a[f]&&s.push(u)}),l.length&&r.dispatchAction({type:"downplay",escapeConnect:!0,notBlur:!0,batch:l}),s.length&&r.dispatchAction({type:"highlight",escapeConnect:!0,notBlur:!0,batch:s})}function W2(e,t){for(var r=0;r<(e||[]).length;r++){var n=e[r];if(t.axis.dim===n.axisDim&&t.axis.model.componentIndex===n.axisIndex)return n}}function ng(e){var t=e.axis.model,r={},n=r.axisDim=e.axis.dim;return r.axisIndex=r[n+"AxisIndex"]=t.componentIndex,r.axisName=r[n+"AxisName"]=t.name,r.axisId=r[n+"AxisId"]=t.id,r}function ls(e){return!e||e[0]==null||isNaN(e[0])||e[1]==null||isNaN(e[1])}function W_(e){O_.registerAxisPointerClass("CartesianAxisPointer",D2),e.registerComponentModel(L2),e.registerComponentView(O2),e.registerPreprocessor(function(t){if(t){(!t.axisPointer||t.axisPointer.length===0)&&(t.axisPointer={});var r=t.axisPointer.link;r&&!z(r)&&(t.axisPointer.link=[r])}}),e.registerProcessor(e.PRIORITY.PROCESSOR.STATISTIC,function(t,r){t.getComponent("axisPointer").coordSysAxesInfo=jL(t,r)}),e.registerAction({type:"updateAxisPointer",event:"updateAxisPointer",update:":updateAxisPointer"},B2)}function U2(e){Nn(v2),Nn(W_)}var ig=["x","y","radius","angle","single"],Y2=["cartesian2d","polar","singleAxis"];function Z2(e){var t=e.get("coordinateSystem");return ft(Y2,t)>=0}function Ir(e){return e+"Axis"}function X2(e,t){var r=K(),n=[],i=K();e.eachComponent({mainType:"dataZoom",query:t},function(f){i.get(f.uid)||s(f)});var a;do a=!1,e.eachComponent("dataZoom",o);while(a);function o(f){!i.get(f.uid)&&l(f)&&(s(f),a=!0)}function s(f){i.set(f.uid,!0),n.push(f),u(f)}function l(f){var h=!1;return f.eachTargetAxis(function(c,v){var d=r.get(c);d&&d[v]&&(h=!0)}),h}function u(f){f.eachTargetAxis(function(h,c){(r.get(h)||r.set(h,[]))[c]=!0})}return n}function U_(e){var t=e.ecModel,r={infoList:[],infoMap:K()};return e.eachTargetAxis(function(n,i){var a=t.getComponent(Ir(n),i);if(a){var o=a.getCoordSysModel();if(o){var s=o.uid,l=r.infoMap.get(s);l||(l={model:o,axisModels:[]},r.infoList.push(l),r.infoMap.set(s,l)),l.axisModels.push(a)}}}),r}var Nu=(function(){function e(){this.indexList=[],this.indexMap=[]}return e.prototype.add=function(t){this.indexMap[t]||(this.indexList.push(t),this.indexMap[t]=!0)},e})(),Ys=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type=t.type,r._autoThrottle=!0,r._noTarget=!0,r._rangePropMode=["percent","percent"],r}return t.prototype.init=function(r,n,i){var a=ag(r);this.settledOption=a,this.mergeDefaultAndTheme(r,i),this._doInit(a)},t.prototype.mergeOption=function(r){var n=ag(r);vt(this.option,r,!0),vt(this.settledOption,n,!0),this._doInit(n)},t.prototype._doInit=function(r){var n=this.option;this._setDefaultThrottle(r),this._updateRangeUse(r);var i=this.settledOption;M([["start","startValue"],["end","endValue"]],function(a,o){this._rangePropMode[o]==="value"&&(n[a[0]]=i[a[0]]=null)},this),this._resetTarget()},t.prototype._resetTarget=function(){var r=this.get("orient",!0),n=this._targetAxisInfoMap=K(),i=this._fillSpecifiedTargetAxis(n);i?this._orient=r||this._makeAutoOrientByTargetAxis():(this._orient=r||"horizontal",this._fillAutoTargetAxisByOrient(n,this._orient)),this._noTarget=!0,n.each(function(a){a.indexList.length&&(this._noTarget=!1)},this)},t.prototype._fillSpecifiedTargetAxis=function(r){var n=!1;return M(ig,function(i){var a=this.getReferringComponents(Ir(i),Nb);if(a.specified){n=!0;var o=new Nu;M(a.models,function(s){o.add(s.componentIndex)}),r.set(i,o)}},this),n},t.prototype._fillAutoTargetAxisByOrient=function(r,n){var i=this.ecModel,a=!0;if(a){var o=n==="vertical"?"y":"x",s=i.findComponents({mainType:o+"Axis"});l(s,o)}if(a){var s=i.findComponents({mainType:"singleAxis",filter:function(f){return f.get("orient",!0)===n}});l(s,"single")}function l(u,f){var h=u[0];if(h){var c=new Nu;if(c.add(h.componentIndex),r.set(f,c),a=!1,f==="x"||f==="y"){var v=h.getReferringComponents("grid",$t).models[0];v&&M(u,function(d){h.componentIndex!==d.componentIndex&&v===d.getReferringComponents("grid",$t).models[0]&&c.add(d.componentIndex)})}}}a&&M(ig,function(u){if(a){var f=i.findComponents({mainType:Ir(u),filter:function(c){return c.get("type",!0)==="category"}});if(f[0]){var h=new Nu;h.add(f[0].componentIndex),r.set(u,h),a=!1}}},this)},t.prototype._makeAutoOrientByTargetAxis=function(){var r;return this.eachTargetAxis(function(n){!r&&(r=n)},this),r==="y"?"vertical":"horizontal"},t.prototype._setDefaultThrottle=function(r){if(r.hasOwnProperty("throttle")&&(this._autoThrottle=!1),this._autoThrottle){var n=this.ecModel.option;this.option.throttle=n.animation&&n.animationDurationUpdate>0?100:20}},t.prototype._updateRangeUse=function(r){var n=this._rangePropMode,i=this.get("rangeMode");M([["start","startValue"],["end","endValue"]],function(a,o){var s=r[a[0]]!=null,l=r[a[1]]!=null;s&&!l?n[o]="percent":!s&&l?n[o]="value":i?n[o]=i[o]:s&&(n[o]="percent")})},t.prototype.noTarget=function(){return this._noTarget},t.prototype.getFirstTargetAxisModel=function(){var r;return this.eachTargetAxis(function(n,i){r==null&&(r=this.ecModel.getComponent(Ir(n),i))},this),r},t.prototype.eachTargetAxis=function(r,n){this._targetAxisInfoMap.each(function(i,a){M(i.indexList,function(o){r.call(n,a,o)})})},t.prototype.getAxisProxy=function(r,n){var i=this.getAxisModel(r,n);if(i)return i.__dzAxisProxy},t.prototype.getAxisModel=function(r,n){var i=this._targetAxisInfoMap.get(r);if(i&&i.indexMap[n])return this.ecModel.getComponent(Ir(r),n)},t.prototype.setRawRange=function(r){var n=this.option,i=this.settledOption;M([["start","startValue"],["end","endValue"]],function(a){(r[a[0]]!=null||r[a[1]]!=null)&&(n[a[0]]=i[a[0]]=r[a[0]],n[a[1]]=i[a[1]]=r[a[1]])},this),this._updateRangeUse(r)},t.prototype.setCalculatedRange=function(r){var n=this.option;M(["start","startValue","end","endValue"],function(i){n[i]=r[i]})},t.prototype.getPercentRange=function(){var r=this.findRepresentativeAxisProxy();if(r)return r.getDataPercentWindow()},t.prototype.getValueRange=function(r,n){if(r==null&&n==null){var i=this.findRepresentativeAxisProxy();if(i)return i.getDataValueWindow()}else return this.getAxisProxy(r,n).getDataValueWindow()},t.prototype.findRepresentativeAxisProxy=function(r){if(r)return r.__dzAxisProxy;for(var n,i=this._targetAxisInfoMap.keys(),a=0;a<i.length;a++)for(var o=i[a],s=this._targetAxisInfoMap.get(o),l=0;l<s.indexList.length;l++){var u=this.getAxisProxy(o,s.indexList[l]);if(u.hostedBy(this))return u;n||(n=u)}return n},t.prototype.getRangePropMode=function(){return this._rangePropMode.slice()},t.prototype.getOrient=function(){return this._orient},t.type="dataZoom",t.dependencies=["xAxis","yAxis","radiusAxis","angleAxis","singleAxis","series","toolbox"],t.defaultOption={z:4,filterMode:"filter",start:0,end:100},t})(dt);function ag(e){var t={};return M(["start","end","startValue","endValue","throttle"],function(r){e.hasOwnProperty(r)&&(t[r]=e[r])}),t}var Y_=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type=t.type,r}return t.prototype.render=function(r,n,i,a){this.dataZoomModel=r,this.ecModel=n,this.api=i},t.type="dataZoom",t})(Te),li=M,og=fa,$2=(function(){function e(t,r,n,i){this._dimName=t,this._axisIndex=r,this.ecModel=i,this._dataZoomModel=n}return e.prototype.hostedBy=function(t){return this._dataZoomModel===t},e.prototype.getDataValueWindow=function(){return this._valueWindow.slice()},e.prototype.getDataPercentWindow=function(){return this._percentWindow.slice()},e.prototype.getTargetSeriesModels=function(){var t=[];return this.ecModel.eachSeries(function(r){if(Z2(r)){var n=Ir(this._dimName),i=r.getReferringComponents(n,$t).models[0];i&&this._axisIndex===i.componentIndex&&t.push(r)}},this),t},e.prototype.getAxisModel=function(){return this.ecModel.getComponent(this._dimName+"Axis",this._axisIndex)},e.prototype.getMinMaxSpan=function(){return st(this._minMaxSpan)},e.prototype.calculateDataWindow=function(t){var r=this._dataExtent,n=this.getAxisModel(),i=n.axis.scale,a=this._dataZoomModel.getRangePropMode(),o=[0,100],s=[],l=[],u;li(["start","end"],function(c,v){var d=t[c],p=t[c+"Value"];a[v]==="percent"?(d==null&&(d=o[v]),p=i.parse(Et(d,o,r))):(u=!0,p=p==null?r[v]:i.parse(p),d=Et(p,r,o)),l[v]=p==null||isNaN(p)?r[v]:p,s[v]=d==null||isNaN(d)?o[v]:d}),og(l),og(s);var f=this._minMaxSpan;u?h(l,s,r,o,!1):h(s,l,o,r,!0);function h(c,v,d,p,g){var m=g?"Span":"ValueSpan";$a(0,c,d,"all",f["min"+m],f["max"+m]);for(var y=0;y<2;y++)v[y]=Et(c[y],d,p,!0),g&&(v[y]=i.parse(v[y]))}return{valueWindow:l,percentWindow:s}},e.prototype.reset=function(t){if(t===this._dataZoomModel){var r=this.getTargetSeriesModels();this._dataExtent=q2(this,this._dimName,r),this._updateMinMaxSpan();var n=this.calculateDataWindow(t.settledOption);this._valueWindow=n.valueWindow,this._percentWindow=n.percentWindow,this._setAxisModel()}},e.prototype.filterData=function(t,r){if(t!==this._dataZoomModel)return;var n=this._dimName,i=this.getTargetSeriesModels(),a=t.get("filterMode"),o=this._valueWindow;if(a==="none")return;li(i,function(l){var u=l.getData(),f=u.mapDimensionsAll(n);if(f.length){if(a==="weakFilter"){var h=u.getStore(),c=$(f,function(v){return u.getDimensionIndex(v)},u);u.filterSelf(function(v){for(var d,p,g,m=0;m<f.length;m++){var y=h.get(c[m],v),_=!isNaN(y),S=y<o[0],w=y>o[1];if(_&&!S&&!w)return!0;_&&(g=!0),S&&(d=!0),w&&(p=!0)}return g&&d&&p})}else li(f,function(v){if(a==="empty")l.setData(u=u.map(v,function(p){return s(p)?p:NaN}));else{var d={};d[v]=o,u.selectRange(d)}});li(f,function(v){u.setApproximateExtent(o,v)})}});function s(l){return l>=o[0]&&l<=o[1]}},e.prototype._updateMinMaxSpan=function(){var t=this._minMaxSpan={},r=this._dataZoomModel,n=this._dataExtent;li(["min","max"],function(i){var a=r.get(i+"Span"),o=r.get(i+"ValueSpan");o!=null&&(o=this.getAxisModel().axis.scale.parse(o)),o!=null?a=Et(n[0]+o,n,[0,100],!0):a!=null&&(o=Et(a,[0,100],n,!0)-n[0]),t[i+"Span"]=a,t[i+"ValueSpan"]=o},this)},e.prototype._setAxisModel=function(){var t=this.getAxisModel(),r=this._percentWindow,n=this._valueWindow;if(r){var i=Tm(n,[0,500]);i=Math.min(i,20);var a=t.axis.scale.rawExtentInfo;r[0]!==0&&a.setDeterminedMinMax("min",+n[0].toFixed(i)),r[1]!==100&&a.setDeterminedMinMax("max",+n[1].toFixed(i)),a.freeze()}},e})();function q2(e,t,r){var n=[1/0,-1/0];li(r,function(o){hL(n,o.getData(),t)});var i=e.getAxisModel(),a=d_(i.axis.scale,i,n).calculate();return[a.min,a.max]}var K2={getTargetSeries:function(e){function t(i){e.eachComponent("dataZoom",function(a){a.eachTargetAxis(function(o,s){var l=e.getComponent(Ir(o),s);i(o,s,l,a)})})}t(function(i,a,o,s){o.__dzAxisProxy=null});var r=[];t(function(i,a,o,s){o.__dzAxisProxy||(o.__dzAxisProxy=new $2(i,a,s,e),r.push(o.__dzAxisProxy))});var n=K();return M(r,function(i){M(i.getTargetSeriesModels(),function(a){n.set(a.uid,a)})}),n},overallReset:function(e,t){e.eachComponent("dataZoom",function(r){r.eachTargetAxis(function(n,i){r.getAxisProxy(n,i).reset(r)}),r.eachTargetAxis(function(n,i){r.getAxisProxy(n,i).filterData(r,t)})}),e.eachComponent("dataZoom",function(r){var n=r.findRepresentativeAxisProxy();if(n){var i=n.getDataPercentWindow(),a=n.getDataValueWindow();r.setCalculatedRange({start:i[0],end:i[1],startValue:a[0],endValue:a[1]})}})}};function Q2(e){e.registerAction("dataZoom",function(t,r){var n=X2(r,t);M(n,function(i){i.setRawRange({start:t.start,end:t.end,startValue:t.startValue,endValue:t.endValue})})})}var sg=!1;function Z_(e){sg||(sg=!0,e.registerProcessor(e.PRIORITY.PROCESSOR.FILTER,K2),Q2(e),e.registerSubTypeDefaulter("dataZoom",function(){return"slider"}))}var J2=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type=t.type,r}return t.type="tooltip",t.dependencies=["axisPointer"],t.defaultOption={z:60,show:!0,showContent:!0,trigger:"item",triggerOn:"mousemove|click",alwaysShowContent:!1,renderMode:"auto",confine:null,showDelay:0,hideDelay:100,transitionDuration:.4,displayTransition:!0,enterable:!1,backgroundColor:Y.color.neutral00,shadowBlur:10,shadowColor:"rgba(0, 0, 0, .2)",shadowOffsetX:1,shadowOffsetY:2,borderRadius:4,borderWidth:1,defaultBorderColor:Y.color.border,padding:null,extraCssText:"",axisPointer:{type:"line",axis:"auto",animation:"auto",animationDurationUpdate:200,animationEasingUpdate:"exponentialOut",crossStyle:{color:Y.color.borderShade,width:1,type:"dashed",textStyle:{}}},textStyle:{color:Y.color.tertiary,fontSize:14}},t})(dt);function X_(e){var t=e.get("confine");return t!=null?!!t:e.get("renderMode")==="richText"}function $_(e){if(nt.domSupported){for(var t=document.documentElement.style,r=0,n=e.length;r<n;r++)if(e[r]in t)return e[r]}}var q_=$_(["transform","webkitTransform","OTransform","MozTransform","msTransform"]),j2=$_(["webkitTransition","transition","OTransition","MozTransition","msTransition"]);function K_(e,t){if(!e)return t;t=Ky(t,!0);var r=e.indexOf(t);return e=r===-1?t:"-"+e.slice(0,r)+"-"+t,e.toLowerCase()}function tI(e,t){var r=e.currentStyle||document.defaultView&&document.defaultView.getComputedStyle(e);return r?r[t]:null}var eI=K_(j2,"transition"),bv=K_(q_,"transform"),rI="position:absolute;display:block;border-style:solid;white-space:nowrap;z-index:9999999;"+(nt.transform3dSupported?"will-change:transform;":"");function nI(e){return e=e==="left"?"right":e==="right"?"left":e==="top"?"bottom":"top",e}function iI(e,t,r){if(!W(r)||r==="inside")return"";var n=e.get("backgroundColor"),i=e.get("borderWidth");t=kn(t);var a=nI(r),o=Math.max(Math.round(i)*1.5,6),s="",l=bv+":",u;ft(["left","right"],a)>-1?(s+="top:50%",l+="translateY(-50%) rotate("+(u=a==="left"?-225:-45)+"deg)"):(s+="left:50%",l+="translateX(-50%) rotate("+(u=a==="top"?225:45)+"deg)");var f=u*Math.PI/180,h=o+i,c=h*Math.abs(Math.cos(f))+h*Math.abs(Math.sin(f)),v=Math.round(((c-Math.SQRT2*i)/2+Math.SQRT2*i-(c-h)/2)*100)/100;s+=";"+a+":-"+v+"px";var d=t+" solid "+i+"px;",p=["position:absolute;width:"+o+"px;height:"+o+"px;z-index:-1;",s+";"+l+";","border-bottom:"+d,"border-right:"+d,"background-color:"+n+";"];return'<div style="'+p.join("")+'"></div>'}function aI(e,t,r){var n="cubic-bezier(0.23,1,0.32,1)",i="",a="";return r&&(i=" "+e/2+"s "+n,a="opacity"+i+",visibility"+i),t||(i=" "+e+"s "+n,a+=(a.length?",":"")+(nt.transformSupported?""+bv+i:",left"+i+",top"+i)),eI+":"+a}function lg(e,t,r){var n=e.toFixed(0)+"px",i=t.toFixed(0)+"px";if(!nt.transformSupported)return r?"top:"+i+";left:"+n+";":[["top",i],["left",n]];var a=nt.transform3dSupported,o="translate"+(a?"3d":"")+"("+n+","+i+(a?",0":"")+")";return r?"top:0;left:0;"+bv+":"+o+";":[["top",0],["left",0],[q_,o]]}function oI(e){var t=[],r=e.get("fontSize"),n=e.getTextColor();n&&t.push("color:"+n),t.push("font:"+e.getFont());var i=q(e.get("lineHeight"),Math.round(r*3/2));r&&t.push("line-height:"+i+"px");var a=e.get("textShadowColor"),o=e.get("textShadowBlur")||0,s=e.get("textShadowOffsetX")||0,l=e.get("textShadowOffsetY")||0;return a&&o&&t.push("text-shadow:"+s+"px "+l+"px "+o+"px "+a),M(["decoration","align"],function(u){var f=e.get(u);f&&t.push("text-"+u+":"+f)}),t.join(";")}function sI(e,t,r,n){var i=[],a=e.get("transitionDuration"),o=e.get("backgroundColor"),s=e.get("shadowBlur"),l=e.get("shadowColor"),u=e.get("shadowOffsetX"),f=e.get("shadowOffsetY"),h=e.getModel("textStyle"),c=o0(e,"html"),v=u+"px "+f+"px "+s+"px "+l;return i.push("box-shadow:"+v),t&&a>0&&i.push(aI(a,r,n)),o&&i.push("background-color:"+o),M(["width","color","radius"],function(d){var p="border-"+d,g=Ky(p),m=e.get(g);m!=null&&i.push(p+":"+m+(d==="color"?"":"px"))}),i.push(oI(h)),c!=null&&i.push("padding:"+rv(c).join("px ")+"px"),i.join(";")+";"}function ug(e,t,r,n,i){var a=t&&t.painter;if(r){var o=a&&a.getViewportRoot();o&&sT(e,o,r,n,i)}else{e[0]=n,e[1]=i;var s=a&&a.getViewportRootOffset();s&&(e[0]+=s.offsetLeft,e[1]+=s.offsetTop)}e[2]=e[0]/t.getWidth(),e[3]=e[1]/t.getHeight()}var lI=(function(){function e(t,r){if(this._show=!1,this._styleCoord=[0,0,0,0],this._enterable=!0,this._alwaysShowContent=!1,this._firstShow=!0,this._longHide=!0,nt.wxa)return null;var n=document.createElement("div");n.domBelongToZr=!0,this.el=n;var i=this._zr=t.getZr(),a=r.appendTo,o=a&&(W(a)?document.querySelector(a):Aa(a)?a:et(a)&&a(t.getDom()));ug(this._styleCoord,i,o,t.getWidth()/2,t.getHeight()/2),(o||t.getDom()).appendChild(n),this._api=t,this._container=o;var s=this;n.onmouseenter=function(){s._enterable&&(clearTimeout(s._hideTimeout),s._show=!0),s._inContent=!0},n.onmousemove=function(l){if(l=l||window.event,!s._enterable){var u=i.handler,f=i.painter.getViewportRoot();me(f,l,!0),u.dispatch("mousemove",l)}},n.onmouseleave=function(){s._inContent=!1,s._enterable&&s._show&&s.hideLater(s._hideDelay)}}return e.prototype.update=function(t){if(!this._container){var r=this._api.getDom(),n=tI(r,"position"),i=r.style;i.position!=="absolute"&&n!=="absolute"&&(i.position="relative")}var a=t.get("alwaysShowContent");a&&this._moveIfResized(),this._alwaysShowContent=a,this._enableDisplayTransition=t.get("displayTransition")&&t.get("transitionDuration")>0,this.el.className=t.get("className")||""},e.prototype.show=function(t,r){clearTimeout(this._hideTimeout),clearTimeout(this._longHideTimeout);var n=this.el,i=n.style,a=this._styleCoord;n.innerHTML?i.cssText=rI+sI(t,!this._firstShow,this._longHide,this._enableDisplayTransition)+lg(a[0],a[1],!0)+("border-color:"+kn(r)+";")+(t.get("extraCssText")||"")+(";pointer-events:"+(this._enterable?"auto":"none")):i.display="none",this._show=!0,this._firstShow=!1,this._longHide=!1},e.prototype.setContent=function(t,r,n,i,a){var o=this.el;if(t==null){o.innerHTML="";return}var s="";if(W(a)&&n.get("trigger")==="item"&&!X_(n)&&(s=iI(n,i,a)),W(t))o.innerHTML=t+s;else if(t){o.innerHTML="",z(t)||(t=[t]);for(var l=0;l<t.length;l++)Aa(t[l])&&t[l].parentNode!==o&&o.appendChild(t[l]);if(s&&o.childNodes.length){var u=document.createElement("div");u.innerHTML=s,o.appendChild(u)}}},e.prototype.setEnterable=function(t){this._enterable=t},e.prototype.getSize=function(){var t=this.el;return t?[t.offsetWidth,t.offsetHeight]:[0,0]},e.prototype.moveTo=function(t,r){if(this.el){var n=this._styleCoord;if(ug(n,this._zr,this._container,t,r),n[0]!=null&&n[1]!=null){var i=this.el.style,a=lg(n[0],n[1]);M(a,function(o){i[o[0]]=o[1]})}}},e.prototype._moveIfResized=function(){var t=this._styleCoord[2],r=this._styleCoord[3];this.moveTo(t*this._zr.getWidth(),r*this._zr.getHeight())},e.prototype.hide=function(){var t=this,r=this.el.style;this._enableDisplayTransition?(r.visibility="hidden",r.opacity="0"):r.display="none",nt.transform3dSupported&&(r.willChange=""),this._show=!1,this._longHideTimeout=setTimeout(function(){return t._longHide=!0},500)},e.prototype.hideLater=function(t){this._show&&!(this._inContent&&this._enterable)&&!this._alwaysShowContent&&(t?(this._hideDelay=t,this._show=!1,this._hideTimeout=setTimeout(Q(this.hide,this),t)):this.hide())},e.prototype.isShow=function(){return this._show},e.prototype.dispose=function(){clearTimeout(this._hideTimeout),clearTimeout(this._longHideTimeout);var t=this._zr;lT(t&&t.painter&&t.painter.getViewportRoot(),this._container);var r=this.el;if(r){r.onmouseenter=r.onmousemove=r.onmouseleave=null;var n=r.parentNode;n&&n.removeChild(r)}this.el=this._container=null},e})(),uI=(function(){function e(t){this._show=!1,this._styleCoord=[0,0,0,0],this._alwaysShowContent=!1,this._enterable=!0,this._zr=t.getZr(),hg(this._styleCoord,this._zr,t.getWidth()/2,t.getHeight()/2)}return e.prototype.update=function(t){var r=t.get("alwaysShowContent");r&&this._moveIfResized(),this._alwaysShowContent=r},e.prototype.show=function(){this._hideTimeout&&clearTimeout(this._hideTimeout),this.el.show(),this._show=!0},e.prototype.setContent=function(t,r,n,i,a){var o=this;X(t)&&ut(""),this.el&&this._zr.remove(this.el);var s=n.getModel("textStyle");this.el=new ae({style:{rich:r.richTextStyles,text:t,lineHeight:22,borderWidth:1,borderColor:i,textShadowColor:s.get("textShadowColor"),fill:n.get(["textStyle","color"]),padding:o0(n,"richText"),verticalAlign:"top",align:"left"},z:n.get("z")}),M(["backgroundColor","borderRadius","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"],function(u){o.el.style[u]=n.get(u)}),M(["textShadowBlur","textShadowOffsetX","textShadowOffsetY"],function(u){o.el.style[u]=s.get(u)||0}),this._zr.add(this.el);var l=this;this.el.on("mouseover",function(){l._enterable&&(clearTimeout(l._hideTimeout),l._show=!0),l._inContent=!0}),this.el.on("mouseout",function(){l._enterable&&l._show&&l.hideLater(l._hideDelay),l._inContent=!1})},e.prototype.setEnterable=function(t){this._enterable=t},e.prototype.getSize=function(){var t=this.el,r=this.el.getBoundingRect(),n=fg(t.style);return[r.width+n.left+n.right,r.height+n.top+n.bottom]},e.prototype.moveTo=function(t,r){var n=this.el;if(n){var i=this._styleCoord;hg(i,this._zr,t,r),t=i[0],r=i[1];var a=n.style,o=Tr(a.borderWidth||0),s=fg(a);n.x=t+o+s.left,n.y=r+o+s.top,n.markRedraw()}},e.prototype._moveIfResized=function(){var t=this._styleCoord[2],r=this._styleCoord[3];this.moveTo(t*this._zr.getWidth(),r*this._zr.getHeight())},e.prototype.hide=function(){this.el&&this.el.hide(),this._show=!1},e.prototype.hideLater=function(t){this._show&&!(this._inContent&&this._enterable)&&!this._alwaysShowContent&&(t?(this._hideDelay=t,this._show=!1,this._hideTimeout=setTimeout(Q(this.hide,this),t)):this.hide())},e.prototype.isShow=function(){return this._show},e.prototype.dispose=function(){this._zr.remove(this.el)},e})();function Tr(e){return Math.max(0,e)}function fg(e){var t=Tr(e.shadowBlur||0),r=Tr(e.shadowOffsetX||0),n=Tr(e.shadowOffsetY||0);return{left:Tr(t-r),right:Tr(t+r),top:Tr(t-n),bottom:Tr(t+n)}}function hg(e,t,r,n){e[0]=r,e[1]=n,e[2]=e[0]/t.getWidth(),e[3]=e[1]/t.getHeight()}var fI=new Tt({shape:{x:-1,y:-1,width:2,height:2}}),hI=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type=t.type,r}return t.prototype.init=function(r,n){if(!(nt.node||!n.getDom())){var i=r.getComponent("tooltip"),a=this._renderMode=zb(i.get("renderMode"));this._tooltipContent=a==="richText"?new uI(n):new lI(n,{appendTo:i.get("appendToBody",!0)?"body":i.get("appendTo",!0)})}},t.prototype.render=function(r,n,i){if(!(nt.node||!i.getDom())){this.group.removeAll(),this._tooltipModel=r,this._ecModel=n,this._api=i;var a=this._tooltipContent;a.update(r),a.setEnterable(r.get("enterable")),this._initGlobalListener(),this._keepShow(),this._renderMode!=="richText"&&r.get("transitionDuration")?ml(this,"_updatePosition",50,"fixRate"):Rs(this,"_updatePosition")}},t.prototype._initGlobalListener=function(){var r=this._tooltipModel,n=r.get("triggerOn");V_("itemTooltip",this._api,Q(function(i,a,o){n!=="none"&&(n.indexOf(i)>=0?this._tryShow(a,o):i==="leave"&&this._hide(o))},this))},t.prototype._keepShow=function(){var r=this._tooltipModel,n=this._ecModel,i=this._api,a=r.get("triggerOn");if(this._lastX!=null&&this._lastY!=null&&a!=="none"&&a!=="click"){var o=this;clearTimeout(this._refreshUpdateTimeout),this._refreshUpdateTimeout=setTimeout(function(){!i.isDisposed()&&o.manuallyShowTip(r,n,i,{x:o._lastX,y:o._lastY,dataByCoordSys:o._lastDataByCoordSys})})}},t.prototype.manuallyShowTip=function(r,n,i,a){if(!(a.from===this.uid||nt.node||!i.getDom())){var o=vg(a,i);this._ticket="";var s=a.dataByCoordSys,l=pI(a,n,i);if(l){var u=l.el.getBoundingRect().clone();u.applyTransform(l.el.transform),this._tryShow({offsetX:u.x+u.width/2,offsetY:u.y+u.height/2,target:l.el,position:a.position,positionDefault:"bottom"},o)}else if(a.tooltip&&a.x!=null&&a.y!=null){var f=fI;f.x=a.x,f.y=a.y,f.update(),pt(f).tooltipConfig={name:null,option:a.tooltip},this._tryShow({offsetX:a.x,offsetY:a.y,target:f},o)}else if(s)this._tryShow({offsetX:a.x,offsetY:a.y,position:a.position,dataByCoordSys:s,tooltipOption:a.tooltipOption},o);else if(a.seriesIndex!=null){if(this._manuallyAxisShowTip(r,n,i,a))return;var h=G_(a,n),c=h.point[0],v=h.point[1];c!=null&&v!=null&&this._tryShow({offsetX:c,offsetY:v,target:h.el,position:a.position,positionDefault:"bottom"},o)}else a.x!=null&&a.y!=null&&(i.dispatchAction({type:"updateAxisPointer",x:a.x,y:a.y}),this._tryShow({offsetX:a.x,offsetY:a.y,position:a.position,target:i.getZr().findHover(a.x,a.y).target},o))}},t.prototype.manuallyHideTip=function(r,n,i,a){var o=this._tooltipContent;this._tooltipModel&&o.hideLater(this._tooltipModel.get("hideDelay")),this._lastX=this._lastY=this._lastDataByCoordSys=null,a.from!==this.uid&&this._hide(vg(a,i))},t.prototype._manuallyAxisShowTip=function(r,n,i,a){var o=a.seriesIndex,s=a.dataIndex,l=n.getComponent("axisPointer").coordSysAxesInfo;if(!(o==null||s==null||l==null)){var u=n.getSeriesByIndex(o);if(u){var f=u.getData(),h=ia([f.getItemModel(s),u,(u.coordinateSystem||{}).model],this._tooltipModel);if(h.get("trigger")==="axis")return i.dispatchAction({type:"updateAxisPointer",seriesIndex:o,dataIndex:s,position:a.position}),!0}}},t.prototype._tryShow=function(r,n){var i=r.target,a=this._tooltipModel;if(a){this._lastX=r.offsetX,this._lastY=r.offsetY;var o=r.dataByCoordSys;if(o&&o.length)this._showAxisTooltip(o,r);else if(i){var s=pt(i);if(s.ssrType==="legend")return;this._lastDataByCoordSys=null;var l,u;ca(i,function(f){if(f.tooltipDisabled)return l=u=null,!0;l||u||(pt(f).dataIndex!=null?l=f:pt(f).tooltipConfig!=null&&(u=f))},!0),l?this._showSeriesItemTooltip(r,l,n):u?this._showComponentItemTooltip(r,u,n):this._hide(n)}else this._lastDataByCoordSys=null,this._hide(n)}},t.prototype._showOrMove=function(r,n){var i=r.get("showDelay");n=Q(n,this),clearTimeout(this._showTimout),i>0?this._showTimout=setTimeout(n,i):n()},t.prototype._showAxisTooltip=function(r,n){var i=this._ecModel,a=this._tooltipModel,o=[n.offsetX,n.offsetY],s=ia([n.tooltipOption],a),l=this._renderMode,u=[],f=Ha("section",{blocks:[],noHeader:!0}),h=[],c=new ou;M(r,function(y){M(y.dataByAxis,function(_){var S=i.getComponent(_.axisDim+"Axis",_.axisIndex),w=_.value;if(!(!S||w==null)){var b=z_(w,S.axis,i,_.seriesDataIndices,_.valueLabelOpt),x=Ha("section",{header:b,noHeader:!Ge(b),sortBlocks:!0,blocks:[]});f.blocks.push(x),M(_.seriesDataIndices,function(C){var T=i.getSeriesByIndex(C.seriesIndex),D=C.dataIndexInside,A=T.getDataParams(D);if(!(A.dataIndex<0)){A.axisDim=_.axisDim,A.axisIndex=_.axisIndex,A.axisType=_.axisType,A.axisId=_.axisId,A.axisValue=Gs(S.axis,{value:w}),A.axisValueLabel=b,A.marker=c.makeTooltipMarker("item",kn(A.color),l);var P=sd(T.formatTooltip(D,!0,null)),L=P.frag;if(L){var I=ia([T],a).get("valueFormatter");x.blocks.push(I?k({valueFormatter:I},L):L)}P.text&&h.push(P.text),u.push(A)}})}})}),f.blocks.reverse(),h.reverse();var v=n.position,d=s.get("order"),p=vd(f,c,l,d,i.get("useUTC"),s.get("textStyle"));p&&h.unshift(p);var g=l==="richText"?`

`:"<br/>",m=h.join(g);this._showOrMove(s,function(){this._updateContentNotChangedOnAxis(r,u)?this._updatePosition(s,v,o[0],o[1],this._tooltipContent,u):this._showTooltipContent(s,m,u,Math.random()+"",o[0],o[1],v,null,c)})},t.prototype._showSeriesItemTooltip=function(r,n,i){var a=this._ecModel,o=pt(n),s=o.seriesIndex,l=a.getSeriesByIndex(s),u=o.dataModel||l,f=o.dataIndex,h=o.dataType,c=u.getData(h),v=this._renderMode,d=r.positionDefault,p=ia([c.getItemModel(f),u,l&&(l.coordinateSystem||{}).model],this._tooltipModel,d?{position:d}:null),g=p.get("trigger");if(!(g!=null&&g!=="item")){var m=u.getDataParams(f,h),y=new ou;m.marker=y.makeTooltipMarker("item",kn(m.color),v);var _=sd(u.formatTooltip(f,!1,h)),S=p.get("order"),w=p.get("valueFormatter"),b=_.frag,x=b?vd(w?k({valueFormatter:w},b):b,y,v,S,a.get("useUTC"),p.get("textStyle")):_.text,C="item_"+u.name+"_"+f;this._showOrMove(p,function(){this._showTooltipContent(p,x,m,C,r.offsetX,r.offsetY,r.position,r.target,y)}),i({type:"showTip",dataIndexInside:f,dataIndex:c.getRawIndex(f),seriesIndex:s,from:this.uid})}},t.prototype._showComponentItemTooltip=function(r,n,i){var a=this._renderMode==="html",o=pt(n),s=o.tooltipConfig,l=s.option||{},u=l.encodeHTMLContent;if(W(l)){var f=l;l={content:f,formatter:f},u=!0}u&&a&&l.content&&(l=st(l),l.content=ee(l.content));var h=[l],c=this._ecModel.getComponent(o.componentMainType,o.componentIndex);c&&h.push(c),h.push({formatter:l.content});var v=r.positionDefault,d=ia(h,this._tooltipModel,v?{position:v}:null),p=d.get("content"),g=Math.random()+"",m=new ou;this._showOrMove(d,function(){var y=st(d.get("formatterParams")||{});this._showTooltipContent(d,p,y,g,r.offsetX,r.offsetY,r.position,n,m)}),i({type:"showTip",from:this.uid})},t.prototype._showTooltipContent=function(r,n,i,a,o,s,l,u,f){if(this._ticket="",!(!r.get("showContent")||!r.get("show"))){var h=this._tooltipContent;h.setEnterable(r.get("enterable"));var c=r.get("formatter");l=l||r.get("position");var v=n,d=this._getNearestPoint([o,s],i,r.get("trigger"),r.get("borderColor"),r.get("defaultBorderColor",!0)),p=d.color;if(c)if(W(c)){var g=r.ecModel.get("useUTC"),m=z(i)?i[0]:i,y=m&&m.axisType&&m.axisType.indexOf("time")>=0;v=c,y&&(v=gl(m.axisValue,v,g)),v=Qy(v,i,!0)}else if(et(c)){var _=Q(function(S,w){S===this._ticket&&(h.setContent(w,f,r,p,l),this._updatePosition(r,l,o,s,h,i,u))},this);this._ticket=a,v=c(i,a,_)}else v=c;h.setContent(v,f,r,p,l),h.show(r,p),this._updatePosition(r,l,o,s,h,i,u)}},t.prototype._getNearestPoint=function(r,n,i,a,o){if(i==="axis"||z(n))return{color:a||o};if(!z(n))return{color:a||n.color||n.borderColor}},t.prototype._updatePosition=function(r,n,i,a,o,s,l){var u=this._api.getWidth(),f=this._api.getHeight();n=n||r.get("position");var h=o.getSize(),c=r.get("align"),v=r.get("verticalAlign"),d=l&&l.getBoundingRect().clone();if(l&&d.applyTransform(l.transform),et(n)&&(n=n([i,a],s,o.el,d,{viewSize:[u,f],contentSize:h.slice()})),z(n))i=It(n[0],u),a=It(n[1],f);else if(X(n)){var p=n;p.width=h[0],p.height=h[1];var g=to(p,{width:u,height:f});i=g.x,a=g.y,c=null,v=null}else if(W(n)&&l){var m=dI(n,d,h,r.get("borderWidth"));i=m[0],a=m[1]}else{var m=vI(i,a,o,u,f,c?null:20,v?null:20);i=m[0],a=m[1]}if(c&&(i-=cg(c)?h[0]/2:c==="right"?h[0]:0),v&&(a-=cg(v)?h[1]/2:v==="bottom"?h[1]:0),X_(r)){var m=cI(i,a,o,u,f);i=m[0],a=m[1]}o.moveTo(i,a)},t.prototype._updateContentNotChangedOnAxis=function(r,n){var i=this._lastDataByCoordSys,a=this._cbParamsList,o=!!i&&i.length===r.length;return o&&M(i,function(s,l){var u=s.dataByAxis||[],f=r[l]||{},h=f.dataByAxis||[];o=o&&u.length===h.length,o&&M(u,function(c,v){var d=h[v]||{},p=c.seriesDataIndices||[],g=d.seriesDataIndices||[];o=o&&c.value===d.value&&c.axisType===d.axisType&&c.axisId===d.axisId&&p.length===g.length,o&&M(p,function(m,y){var _=g[y];o=o&&m.seriesIndex===_.seriesIndex&&m.dataIndex===_.dataIndex}),a&&M(c.seriesDataIndices,function(m){var y=m.seriesIndex,_=n[y],S=a[y];_&&S&&S.data!==_.data&&(o=!1)})})}),this._lastDataByCoordSys=r,this._cbParamsList=n,!!o},t.prototype._hide=function(r){this._lastDataByCoordSys=null,r({type:"hideTip",from:this.uid})},t.prototype.dispose=function(r,n){nt.node||!n.getDom()||(Rs(this,"_updatePosition"),this._tooltipContent.dispose(),lh("itemTooltip",n))},t.type="tooltip",t})(Te);function ia(e,t,r){var n=t.ecModel,i;r?(i=new xt(r,n,n),i=new xt(t.option,i,n)):i=t;for(var a=e.length-1;a>=0;a--){var o=e[a];o&&(o instanceof xt&&(o=o.get("tooltip",!0)),W(o)&&(o={formatter:o}),o&&(i=new xt(o,i,n)))}return i}function vg(e,t){return e.dispatchAction||Q(t.dispatchAction,t)}function vI(e,t,r,n,i,a,o){var s=r.getSize(),l=s[0],u=s[1];return a!=null&&(e+l+a+2>n?e-=l+a:e+=a),o!=null&&(t+u+o>i?t-=u+o:t+=o),[e,t]}function cI(e,t,r,n,i){var a=r.getSize(),o=a[0],s=a[1];return e=Math.min(e+o,n)-o,t=Math.min(t+s,i)-s,e=Math.max(e,0),t=Math.max(t,0),[e,t]}function dI(e,t,r,n){var i=r[0],a=r[1],o=Math.ceil(Math.SQRT2*n)+8,s=0,l=0,u=t.width,f=t.height;switch(e){case"inside":s=t.x+u/2-i/2,l=t.y+f/2-a/2;break;case"top":s=t.x+u/2-i/2,l=t.y-a-o;break;case"bottom":s=t.x+u/2-i/2,l=t.y+f+o;break;case"left":s=t.x-i-o,l=t.y+f/2-a/2;break;case"right":s=t.x+u+o,l=t.y+f/2-a/2}return[s,l]}function cg(e){return e==="center"||e==="middle"}function pI(e,t,r){var n=Mh(e).queryOptionMap,i=n.keys()[0];if(!(!i||i==="series")){var a=Qa(t,i,n.get(i),{useDefault:!1,enableAll:!1,enableNone:!1}),o=a.models[0];if(o){var s=r.getViewOfComponentModel(o),l;if(s.group.traverse(function(u){var f=pt(u).tooltipConfig;if(f&&f.name===e.name)return l=u,!0}),l)return{componentMainType:i,componentIndex:o.componentIndex,el:l}}}}function gI(e){Nn(W_),e.registerComponentModel(J2),e.registerComponentView(hI),e.registerAction({type:"showTip",event:"showTip",update:"tooltip:manuallyShowTip"},qt),e.registerAction({type:"hideTip",event:"hideTip",update:"tooltip:manuallyHideTip"},qt)}var mI=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type=t.type,r.layoutMode={type:"box",ignoreSize:!0},r}return t.type="title",t.defaultOption={z:6,show:!0,text:"",target:"blank",subtext:"",subtarget:"blank",left:"center",top:Y.size.m,backgroundColor:Y.color.transparent,borderColor:Y.color.primary,borderWidth:0,padding:5,itemGap:10,textStyle:{fontSize:18,fontWeight:"bold",color:Y.color.primary},subtextStyle:{fontSize:12,color:Y.color.quaternary}},t})(dt),yI=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type=t.type,r}return t.prototype.render=function(r,n,i){if(this.group.removeAll(),!!r.get("show")){var a=this.group,o=r.getModel("textStyle"),s=r.getModel("subtextStyle"),l=r.get("textAlign"),u=q(r.get("textBaseline"),r.get("textVerticalAlign")),f=new ae({style:zr(o,{text:r.get("text"),fill:o.getTextColor()},{disableBox:!0}),z2:10}),h=f.getBoundingRect(),c=r.get("subtext"),v=new ae({style:zr(s,{text:c,fill:s.getTextColor(),y:h.height+r.get("itemGap"),verticalAlign:"top"},{disableBox:!0}),z2:10}),d=r.get("link"),p=r.get("sublink"),g=r.get("triggerEvent",!0);f.silent=!d&&!g,v.silent=!p&&!g,d&&f.on("click",function(){ad(d,"_"+r.get("target"))}),p&&v.on("click",function(){ad(p,"_"+r.get("subtarget"))}),pt(f).eventData=pt(v).eventData=g?{componentType:"title",componentIndex:r.componentIndex}:null,a.add(f),c&&a.add(v);var m=a.getBoundingRect(),y=r.getBoxLayoutParams();y.width=m.width,y.height=m.height;var _=nv(r,i),S=to(y,_.refContainer,r.get("padding"));l||(l=r.get("left")||r.get("right"),l==="middle"&&(l="center"),l==="right"?S.x+=S.width:l==="center"&&(S.x+=S.width/2)),u||(u=r.get("top")||r.get("bottom"),u==="center"&&(u="middle"),u==="bottom"?S.y+=S.height:u==="middle"&&(S.y+=S.height/2),u=u||"top"),a.x=S.x,a.y=S.y,a.markRedraw();var w={align:l,verticalAlign:u};f.setStyle(w),v.setStyle(w),m=a.getBoundingRect();var b=S.margin,x=r.getItemStyle(["color","opacity"]);x.fill=r.get("backgroundColor");var C=new Tt({shape:{x:m.x-b[3],y:m.y-b[0],width:m.width+b[1]+b[3],height:m.height+b[0]+b[2],r:r.get("borderRadius")},style:x,subPixelOptimize:!0,silent:!0});a.add(C)}},t.type="title",t})(Te);function _I(e){e.registerComponentModel(mI),e.registerComponentView(yI)}var SI=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type=t.type,r}return t.type="dataZoom.inside",t.defaultOption=Fy(Ys.defaultOption,{disabled:!1,zoomLock:!1,zoomOnMouseWheel:!0,moveOnMouseMove:!0,moveOnMouseWheel:!1,preventDefaultMouseMove:!0}),t})(Ys),wv=gt();function bI(e,t,r){wv(e).coordSysRecordMap.each(function(n){var i=n.dataZoomInfoMap.get(t.uid);i&&(i.getRange=r)})}function wI(e,t){for(var r=wv(e).coordSysRecordMap,n=r.keys(),i=0;i<n.length;i++){var a=n[i],o=r.get(a),s=o.dataZoomInfoMap;if(s){var l=t.uid,u=s.get(l);u&&(s.removeKey(l),s.keys().length||Q_(r,o))}}}function Q_(e,t){if(t){e.removeKey(t.model.uid);var r=t.controller;r&&r.dispose()}}function xI(e,t){var r={model:t,containsPoint:ne(CI,t),dispatchAction:ne(TI,e),dataZoomInfoMap:null,controller:null},n=r.controller=new g2(e.getZr());return M(["pan","zoom","scrollMove"],function(i){n.on(i,function(a){var o=[];r.dataZoomInfoMap.each(function(s){if(a.isAvailableBehavior(s.model.option)){var l=(s.getRange||{})[i],u=l&&l(s.dzReferCoordSysInfo,r.model.mainType,r.controller,a);!s.model.get("disabled",!0)&&u&&o.push({dataZoomId:s.model.id,start:u[0],end:u[1]})}}),o.length&&r.dispatchAction(o)})}),r}function TI(e,t){e.isDisposed()||e.dispatchAction({type:"dataZoom",animation:{easing:"cubicOut",duration:100},batch:t})}function CI(e,t,r,n){return e.coordinateSystem.containPoint([r,n])}function MI(e,t,r){var n,i="type_",a={type_true:2,type_move:1,type_false:0,type_undefined:-1},o=!0;return e.each(function(s){var l=s.model,u=l.get("disabled",!0)?!1:l.get("zoomLock",!0)?"move":!0;a[i+u]>a[i+n]&&(n=u),o=o&&l.get("preventDefaultMouseMove",!0)}),{controlType:n,opt:{zoomOnMouseWheel:!0,moveOnMouseMove:!0,moveOnMouseWheel:!0,preventDefaultMouseMove:!!o,api:r,zInfo:{component:t.model},triggerInfo:{roamTrigger:null,isInSelf:t.containsPoint}}}}function DI(e){e.registerProcessor(e.PRIORITY.PROCESSOR.FILTER,function(t,r){var n=wv(r),i=n.coordSysRecordMap||(n.coordSysRecordMap=K());i.each(function(a){a.dataZoomInfoMap=null}),t.eachComponent({mainType:"dataZoom",subType:"inside"},function(a){var o=U_(a);M(o.infoList,function(s){var l=s.model.uid,u=i.get(l)||i.set(l,xI(r,s.model)),f=u.dataZoomInfoMap||(u.dataZoomInfoMap=K());f.set(a.uid,{dzReferCoordSysInfo:s,model:a,getRange:null})})}),i.each(function(a){var o=a.controller,s,l=a.dataZoomInfoMap;if(l){var u=l.keys()[0];u!=null&&(s=l.get(u))}if(!s){Q_(i,a);return}var f=MI(l,a,r);o.enable(f.controlType,f.opt),ml(a,"dispatchAction",s.model.get("throttle",!0),"fixRate")})})}var AI=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type="dataZoom.inside",r}return t.prototype.render=function(r,n,i){if(e.prototype.render.apply(this,arguments),r.noTarget()){this._clear();return}this.range=r.getPercentRange(),bI(i,r,{pan:Q(Fu.pan,this),zoom:Q(Fu.zoom,this),scrollMove:Q(Fu.scrollMove,this)})},t.prototype.dispose=function(){this._clear(),e.prototype.dispose.apply(this,arguments)},t.prototype._clear=function(){wI(this.api,this.dataZoomModel),this.range=null},t.type="dataZoom.inside",t})(Y_),Fu={zoom:function(e,t,r,n){var i=this.range,a=i.slice(),o=e.axisModels[0];if(o){var s=zu[t](null,[n.originX,n.originY],o,r,e),l=(s.signal>0?s.pixelStart+s.pixelLength-s.pixel:s.pixel-s.pixelStart)/s.pixelLength*(a[1]-a[0])+a[0],u=Math.max(1/n.scale,0);a[0]=(a[0]-l)*u+l,a[1]=(a[1]-l)*u+l;var f=this.dataZoomModel.findRepresentativeAxisProxy().getMinMaxSpan();if($a(0,a,[0,100],0,f.minSpan,f.maxSpan),this.range=a,i[0]!==a[0]||i[1]!==a[1])return a}},pan:dg(function(e,t,r,n,i,a){var o=zu[n]([a.oldX,a.oldY],[a.newX,a.newY],t,i,r);return o.signal*(e[1]-e[0])*o.pixel/o.pixelLength}),scrollMove:dg(function(e,t,r,n,i,a){var o=zu[n]([0,0],[a.scrollDelta,a.scrollDelta],t,i,r);return o.signal*(e[1]-e[0])*a.scrollDelta})};function dg(e){return function(t,r,n,i){var a=this.range,o=a.slice(),s=t.axisModels[0];if(s){var l=e(o,s,t,r,n,i);if($a(l,o,[0,100],"all"),this.range=o,a[0]!==o[0]||a[1]!==o[1])return o}}}var zu={grid:function(e,t,r,n,i){var a=r.axis,o={},s=i.model.coordinateSystem.getRect();return e=e||[0,0],a.dim==="x"?(o.pixel=t[0]-e[0],o.pixelLength=s.width,o.pixelStart=s.x,o.signal=a.inverse?1:-1):(o.pixel=t[1]-e[1],o.pixelLength=s.height,o.pixelStart=s.y,o.signal=a.inverse?-1:1),o},polar:function(e,t,r,n,i){var a=r.axis,o={},s=i.model.coordinateSystem,l=s.getRadiusAxis().getExtent(),u=s.getAngleAxis().getExtent();return e=e?s.pointToCoord(e):[0,0],t=s.pointToCoord(t),r.mainType==="radiusAxis"?(o.pixel=t[0]-e[0],o.pixelLength=l[1]-l[0],o.pixelStart=l[0],o.signal=a.inverse?1:-1):(o.pixel=t[1]-e[1],o.pixelLength=u[1]-u[0],o.pixelStart=u[0],o.signal=a.inverse?-1:1),o},singleAxis:function(e,t,r,n,i){var a=r.axis,o=i.model.coordinateSystem.getRect(),s={};return e=e||[0,0],a.orient==="horizontal"?(s.pixel=t[0]-e[0],s.pixelLength=o.width,s.pixelStart=o.x,s.signal=a.inverse?1:-1):(s.pixel=t[1]-e[1],s.pixelLength=o.height,s.pixelStart=o.y,s.signal=a.inverse?-1:1),s}};function LI(e){Z_(e),e.registerComponentModel(SI),e.registerComponentView(AI),DI(e)}var II=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type=t.type,r}return t.type="dataZoom.slider",t.layoutMode="box",t.defaultOption=Fy(Ys.defaultOption,{show:!0,right:"ph",top:"ph",width:"ph",height:"ph",left:null,bottom:null,borderColor:Y.color.accent10,borderRadius:0,backgroundColor:Y.color.transparent,dataBackground:{lineStyle:{color:Y.color.accent30,width:.5},areaStyle:{color:Y.color.accent20,opacity:.2}},selectedDataBackground:{lineStyle:{color:Y.color.accent40,width:.5},areaStyle:{color:Y.color.accent20,opacity:.3}},fillerColor:"rgba(135,175,274,0.2)",handleIcon:"path://M-9.35,34.56V42m0-40V9.5m-2,0h4a2,2,0,0,1,2,2v21a2,2,0,0,1-2,2h-4a2,2,0,0,1-2-2v-21A2,2,0,0,1-11.35,9.5Z",handleSize:"100%",handleStyle:{color:Y.color.neutral00,borderColor:Y.color.accent20},moveHandleSize:7,moveHandleIcon:"path://M-320.9-50L-320.9-50c18.1,0,27.1,9,27.1,27.1V85.7c0,18.1-9,27.1-27.1,27.1l0,0c-18.1,0-27.1-9-27.1-27.1V-22.9C-348-41-339-50-320.9-50z M-212.3-50L-212.3-50c18.1,0,27.1,9,27.1,27.1V85.7c0,18.1-9,27.1-27.1,27.1l0,0c-18.1,0-27.1-9-27.1-27.1V-22.9C-239.4-41-230.4-50-212.3-50z M-103.7-50L-103.7-50c18.1,0,27.1,9,27.1,27.1V85.7c0,18.1-9,27.1-27.1,27.1l0,0c-18.1,0-27.1-9-27.1-27.1V-22.9C-130.9-41-121.8-50-103.7-50z",moveHandleStyle:{color:Y.color.accent40,opacity:.5},showDetail:!0,showDataShadow:"auto",realtime:!0,zoomLock:!1,textStyle:{color:Y.color.tertiary},brushSelect:!0,brushStyle:{color:Y.color.accent30,opacity:.3},emphasis:{handleLabel:{show:!0},handleStyle:{borderColor:Y.color.accent40},moveHandleStyle:{opacity:.8}},defaultLocationEdgeGap:15}),t})(Ys),aa=Tt,PI=1,Hu=30,RI=7,oa="horizontal",pg="vertical",EI=5,kI=["line","bar","candlestick","scatter"],OI={easing:"cubicOut",duration:100,delay:0},BI=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type=t.type,r._displayables={},r}return t.prototype.init=function(r,n){this.api=n,this._onBrush=Q(this._onBrush,this),this._onBrushEnd=Q(this._onBrushEnd,this)},t.prototype.render=function(r,n,i,a){if(e.prototype.render.apply(this,arguments),ml(this,"_dispatchZoomAction",r.get("throttle"),"fixRate"),this._orient=r.getOrient(),r.get("show")===!1){this.group.removeAll();return}if(r.noTarget()){this._clear(),this.group.removeAll();return}(!a||a.type!=="dataZoom"||a.from!==this.uid)&&this._buildView(),this._updateView()},t.prototype.dispose=function(){this._clear(),e.prototype.dispose.apply(this,arguments)},t.prototype._clear=function(){Rs(this,"_dispatchZoomAction");var r=this.api.getZr();r.off("mousemove",this._onBrush),r.off("mouseup",this._onBrushEnd)},t.prototype._buildView=function(){var r=this.group;r.removeAll(),this._brushing=!1,this._displayables.brushRect=null,this._resetLocation(),this._resetInterval();var n=this._displayables.sliderGroup=new Ft;this._renderBackground(),this._renderHandle(),this._renderDataShadow(),r.add(n),this._positionGroup()},t.prototype._resetLocation=function(){var r=this.dataZoomModel,n=this.api,i=r.get("brushSelect"),a=i?RI:0,o=nv(r,n).refContainer,s=this._findCoordRect(),l=r.get("defaultLocationEdgeGap",!0)||0,u=this._orient===oa?{right:o.width-s.x-s.width,top:o.height-Hu-l-a,width:s.width,height:Hu}:{right:l,top:s.y,width:Hu,height:s.height},f=eo(r.option);M(["right","top","width","height"],function(c){f[c]==="ph"&&(f[c]=u[c])});var h=to(f,o);this._location={x:h.x,y:h.y},this._size=[h.width,h.height],this._orient===pg&&this._size.reverse()},t.prototype._positionGroup=function(){var r=this.group,n=this._location,i=this._orient,a=this.dataZoomModel.getFirstTargetAxisModel(),o=a&&a.get("inverse"),s=this._displayables.sliderGroup,l=(this._dataShadowInfo||{}).otherAxisInverse;s.attr(i===oa&&!o?{scaleY:l?1:-1,scaleX:1}:i===oa&&o?{scaleY:l?1:-1,scaleX:-1}:i===pg&&!o?{scaleY:l?-1:1,scaleX:1,rotation:Math.PI/2}:{scaleY:l?-1:1,scaleX:-1,rotation:Math.PI/2});var u=r.getBoundingRect([s]);r.x=n.x-u.x,r.y=n.y-u.y,r.markRedraw()},t.prototype._getViewExtent=function(){return[0,this._size[0]]},t.prototype._renderBackground=function(){var r=this.dataZoomModel,n=this._size,i=this._displayables.sliderGroup,a=r.get("brushSelect");i.add(new aa({silent:!0,shape:{x:0,y:0,width:n[0],height:n[1]},style:{fill:r.get("backgroundColor")},z2:-40}));var o=new aa({shape:{x:0,y:0,width:n[0],height:n[1]},style:{fill:"transparent"},z2:0,onclick:Q(this._onClickPanel,this)}),s=this.api.getZr();a?(o.on("mousedown",this._onBrushStart,this),o.cursor="crosshair",s.on("mousemove",this._onBrush),s.on("mouseup",this._onBrushEnd)):(s.off("mousemove",this._onBrush),s.off("mouseup",this._onBrushEnd)),i.add(o)},t.prototype._renderDataShadow=function(){var r=this._dataShadowInfo=this._prepareDataShadowInfo();if(this._displayables.dataShadowSegs=[],!r)return;var n=this._size,i=this._shadowSize||[],a=r.series,o=a.getRawData(),s=a.getShadowDim&&a.getShadowDim(),l=s&&o.getDimensionInfo(s)?a.getShadowDim():r.otherDim;if(l==null)return;var u=this._shadowPolygonPts,f=this._shadowPolylinePts;if(o!==this._shadowData||l!==this._shadowDim||n[0]!==i[0]||n[1]!==i[1]){var h=o.getDataExtent(r.thisDim),c=o.getDataExtent(l),v=(c[1]-c[0])*.3;c=[c[0]-v,c[1]+v];var d=[0,n[1]],p=[0,n[0]],g=[[n[0],0],[0,0]],m=[],y=p[1]/Math.max(1,o.count()-1),_=n[0]/(h[1]-h[0]),S=r.thisAxis.type==="time",w=-y,b=Math.round(o.count()/n[0]),x;o.each([r.thisDim,l],function(P,L,I){if(b>0&&I%b){S||(w+=y);return}w=S?(+P-h[0])*_:w+y;var R=L==null||isNaN(L)||L==="",E=R?0:Et(L,c,d,!0);R&&!x&&I?(g.push([g[g.length-1][0],0]),m.push([m[m.length-1][0],0])):!R&&x&&(g.push([w,0]),m.push([w,0])),R||(g.push([w,E]),m.push([w,E])),x=R}),u=this._shadowPolygonPts=g,f=this._shadowPolylinePts=m}this._shadowData=o,this._shadowDim=l,this._shadowSize=[n[0],n[1]];var C=this.dataZoomModel;function T(P){var L=C.getModel(P?"selectedDataBackground":"dataBackground"),I=new Ft,R=new Ja({shape:{points:u},segmentIgnoreThreshold:1,style:L.getModel("areaStyle").getAreaStyle(),silent:!0,z2:-20}),E=new ja({shape:{points:f},segmentIgnoreThreshold:1,style:L.getModel("lineStyle").getLineStyle(),silent:!0,z2:-19});return I.add(R),I.add(E),I}for(var D=0;D<3;D++){var A=T(D===1);this._displayables.sliderGroup.add(A),this._displayables.dataShadowSegs.push(A)}},t.prototype._prepareDataShadowInfo=function(){var r=this.dataZoomModel,n=r.get("showDataShadow");if(n!==!1){var i,a=this.ecModel;return r.eachTargetAxis(function(o,s){var l=r.getAxisProxy(o,s).getTargetSeriesModels();M(l,function(u){if(!i&&!(n!==!0&&ft(kI,u.get("type"))<0)){var f=a.getComponent(Ir(o),s).axis,h=NI(o),c,v=u.coordinateSystem;h!=null&&v.getOtherAxis&&(c=v.getOtherAxis(f).inverse),h=u.getData().mapDimension(h);var d=u.getData().mapDimension(o);i={thisAxis:f,series:u,thisDim:d,otherDim:h,otherAxisInverse:c}}},this)},this),i}},t.prototype._renderHandle=function(){var r=this.group,n=this._displayables,i=n.handles=[null,null],a=n.handleLabels=[null,null],o=this._displayables.sliderGroup,s=this._size,l=this.dataZoomModel,u=this.api,f=l.get("borderRadius")||0,h=l.get("brushSelect"),c=n.filler=new aa({silent:h,style:{fill:l.get("fillerColor")},textConfig:{position:"inside"}});o.add(c),o.add(new aa({silent:!0,subPixelOptimize:!0,shape:{x:0,y:0,width:s[0],height:s[1],r:f},style:{stroke:l.get("dataBackgroundColor")||l.get("borderColor"),lineWidth:PI,fill:Y.color.transparent}})),M([0,1],function(_){var S=l.get("handleIcon");!Is[S]&&S.indexOf("path://")<0&&S.indexOf("image://")<0&&(S="path://"+S);var w=Bn(S,-1,0,2,2,null,!0);w.attr({cursor:FI(this._orient),draggable:!0,drift:Q(this._onDragMove,this,_),ondragend:Q(this._onDragEnd,this),onmouseover:Q(this._showDataInfo,this,!0),onmouseout:Q(this._showDataInfo,this,!1),z2:5});var b=w.getBoundingRect(),x=l.get("handleSize");this._handleHeight=It(x,this._size[1]),this._handleWidth=b.width/b.height*this._handleHeight,w.setStyle(l.getModel("handleStyle").getItemStyle()),w.style.strokeNoScale=!0,w.rectHover=!0,w.ensureState("emphasis").style=l.getModel(["emphasis","handleStyle"]).getItemStyle(),Um(w);var C=l.get("handleColor");C!=null&&(w.style.fill=C),o.add(i[_]=w);var T=l.getModel("textStyle"),D=l.get("handleLabel")||{},A=D.show||!1;r.add(a[_]=new ae({silent:!0,invisible:!A,style:zr(T,{x:0,y:0,text:"",verticalAlign:"middle",align:"center",fill:T.getTextColor(),font:T.getFont()}),z2:10}))},this);var v=c;if(h){var d=It(l.get("moveHandleSize"),s[1]),p=n.moveHandle=new Tt({style:l.getModel("moveHandleStyle").getItemStyle(),silent:!0,shape:{r:[0,0,2,2],y:s[1]-.5,height:d}}),g=d*.8,m=n.moveHandleIcon=Bn(l.get("moveHandleIcon"),-g/2,-g/2,g,g,Y.color.neutral00,!0);m.silent=!0,m.y=s[1]+d/2-.5,p.ensureState("emphasis").style=l.getModel(["emphasis","moveHandleStyle"]).getItemStyle();var y=Math.min(s[1]/2,Math.max(d,10));v=n.moveZone=new Tt({invisible:!0,shape:{y:s[1]-y,height:d+y}}),v.on("mouseover",function(){u.enterEmphasis(p)}).on("mouseout",function(){u.leaveEmphasis(p)}),o.add(p),o.add(m),o.add(v)}v.attr({draggable:!0,cursor:"default",drift:Q(this._onDragMove,this,"all"),ondragstart:Q(this._showDataInfo,this,!0),ondragend:Q(this._onDragEnd,this),onmouseover:Q(this._showDataInfo,this,!0),onmouseout:Q(this._showDataInfo,this,!1)})},t.prototype._resetInterval=function(){var r=this._range=this.dataZoomModel.getPercentRange(),n=this._getViewExtent();this._handleEnds=[Et(r[0],[0,100],n,!0),Et(r[1],[0,100],n,!0)]},t.prototype._updateInterval=function(r,n){var i=this.dataZoomModel,a=this._handleEnds,o=this._getViewExtent(),s=i.findRepresentativeAxisProxy().getMinMaxSpan(),l=[0,100];$a(n,a,o,i.get("zoomLock")?"all":r,s.minSpan!=null?Et(s.minSpan,l,o,!0):null,s.maxSpan!=null?Et(s.maxSpan,l,o,!0):null);var u=this._range,f=this._range=fa([Et(a[0],o,l,!0),Et(a[1],o,l,!0)]);return!u||u[0]!==f[0]||u[1]!==f[1]},t.prototype._updateView=function(r){var n=this._displayables,i=this._handleEnds,a=fa(i.slice()),o=this._size;M([0,1],function(v){var d=n.handles[v],p=this._handleHeight;d.attr({scaleX:p/2,scaleY:p/2,x:i[v]+(v?-1:1),y:o[1]/2-p/2})},this),n.filler.setShape({x:a[0],y:0,width:a[1]-a[0],height:o[1]});var s={x:a[0],width:a[1]-a[0]};n.moveHandle&&(n.moveHandle.setShape(s),n.moveZone.setShape(s),n.moveZone.getBoundingRect(),n.moveHandleIcon&&n.moveHandleIcon.attr("x",s.x+s.width/2));for(var l=n.dataShadowSegs,u=[0,a[0],a[1],o[0]],f=0;f<l.length;f++){var h=l[f],c=h.getClipPath();c||(c=new Tt,h.setClipPath(c)),c.setShape({x:u[f],y:0,width:u[f+1]-u[f],height:o[1]})}this._updateDataInfo(r)},t.prototype._updateDataInfo=function(r){var n=this.dataZoomModel,i=this._displayables,a=i.handleLabels,o=this._orient,s=["",""];if(n.get("showDetail")){var l=n.findRepresentativeAxisProxy();if(l){var u=l.getAxisModel().axis,f=this._range,h=r?l.calculateDataWindow({start:f[0],end:f[1]}).valueWindow:l.getDataValueWindow();s=[this._formatLabel(h[0],u),this._formatLabel(h[1],u)]}}var c=fa(this._handleEnds.slice());v.call(this,0),v.call(this,1);function v(d){var p=ay(i.handles[d].parent,this.group),g=oy(d===0?"right":"left",p),m=this._handleWidth/2+EI,y=Oa([c[d]+(d===0?-m:m),this._size[1]/2],p);a[d].setStyle({x:y[0],y:y[1],verticalAlign:o===oa?"middle":g,align:o===oa?g:"center",text:s[d]})}},t.prototype._formatLabel=function(r,n){var i=this.dataZoomModel,a=i.get("labelFormatter"),o=i.get("labelPrecision");(o==null||o==="auto")&&(o=n.getPixelPrecision());var s=r==null||isNaN(r)?"":n.type==="category"||n.type==="time"?n.scale.getLabel({value:Math.round(r)}):r.toFixed(Math.min(o,20));return et(a)?a(r,s):W(a)?a.replace("{value}",s):s},t.prototype._showDataInfo=function(r){var n=this.dataZoomModel.get("handleLabel")||{},i=n.show||!1,a=this.dataZoomModel.getModel(["emphasis","handleLabel"]),o=a.get("show")||!1,s=r||this._dragging?o:i,l=this._displayables,u=l.handleLabels;u[0].attr("invisible",!s),u[1].attr("invisible",!s),l.moveHandle&&this.api[s?"enterEmphasis":"leaveEmphasis"](l.moveHandle,1)},t.prototype._onDragMove=function(r,n,i,a){this._dragging=!0,Ai(a.event);var o=this._displayables.sliderGroup.getLocalTransform(),s=Oa([n,i],o,!0),l=this._updateInterval(r,s[0]),u=this.dataZoomModel.get("realtime");this._updateView(!u),l&&u&&this._dispatchZoomAction(!0)},t.prototype._onDragEnd=function(){this._dragging=!1,this._showDataInfo(!1);var r=this.dataZoomModel.get("realtime");!r&&this._dispatchZoomAction(!1)},t.prototype._onClickPanel=function(r){var n=this._size,i=this._displayables.sliderGroup.transformCoordToLocal(r.offsetX,r.offsetY);if(!(i[0]<0||i[0]>n[0]||i[1]<0||i[1]>n[1])){var a=this._handleEnds,o=(a[0]+a[1])/2,s=this._updateInterval("all",i[0]-o);this._updateView(),s&&this._dispatchZoomAction(!1)}},t.prototype._onBrushStart=function(r){var n=r.offsetX,i=r.offsetY;this._brushStart=new tt(n,i),this._brushing=!0,this._brushStartTime=+new Date},t.prototype._onBrushEnd=function(r){if(this._brushing){var n=this._displayables.brushRect;if(this._brushing=!1,!!n){n.attr("ignore",!0);var i=n.shape,a=+new Date;if(!(a-this._brushStartTime<200&&Math.abs(i.width)<5)){var o=this._getViewExtent(),s=[0,100],l=this._handleEnds=[i.x,i.x+i.width],u=this.dataZoomModel.findRepresentativeAxisProxy().getMinMaxSpan();$a(0,l,o,0,u.minSpan!=null?Et(u.minSpan,s,o,!0):null,u.maxSpan!=null?Et(u.maxSpan,s,o,!0):null),this._range=fa([Et(l[0],o,s,!0),Et(l[1],o,s,!0)]),this._updateView(),this._dispatchZoomAction(!1)}}}},t.prototype._onBrush=function(r){this._brushing&&(Ai(r.event),this._updateBrushRect(r.offsetX,r.offsetY))},t.prototype._updateBrushRect=function(r,n){var i=this._displayables,a=this.dataZoomModel,o=i.brushRect;o||(o=i.brushRect=new aa({silent:!0,style:a.getModel("brushStyle").getItemStyle()}),i.sliderGroup.add(o)),o.attr("ignore",!1);var s=this._brushStart,l=this._displayables.sliderGroup,u=l.transformCoordToLocal(r,n),f=l.transformCoordToLocal(s.x,s.y),h=this._size;u[0]=Math.max(Math.min(h[0],u[0]),0),o.setShape({x:f[0],y:0,width:u[0]-f[0],height:h[1]})},t.prototype._dispatchZoomAction=function(r){var n=this._range;this.api.dispatchAction({type:"dataZoom",from:this.uid,dataZoomId:this.dataZoomModel.id,animation:r?OI:null,start:n[0],end:n[1]})},t.prototype._findCoordRect=function(){var r,n=U_(this.dataZoomModel).infoList;if(!r&&n.length){var i=n[0].model.coordinateSystem;r=i.getRect&&i.getRect()}if(!r){var a=this.api.getWidth(),o=this.api.getHeight();r={x:a*.2,y:o*.2,width:a*.6,height:o*.6}}return r},t.type="dataZoom.slider",t})(Y_);function NI(e){var t={x:"y",y:"x",radius:"angle",angle:"radius"};return t[e]}function FI(e){return e==="vertical"?"ns-resize":"ew-resize"}function zI(e){e.registerComponentModel(II),e.registerComponentView(BI),Z_(e)}function HI(e){Nn(LI),Nn(zI)}var gg={value:"eq","<":"lt","<=":"lte",">":"gt",">=":"gte","=":"eq","!=":"ne","<>":"ne"},VI=(function(){function e(t){var r=this._condVal=W(t)?new RegExp(t):A1(t)?t:null;if(r==null){var n="";ut(n)}}return e.prototype.evaluate=function(t){var r=typeof t;return W(r)?this._condVal.test(t):mt(r)?this._condVal.test(t+""):!1},e})(),GI=(function(){function e(){}return e.prototype.evaluate=function(){return this.value},e})(),WI=(function(){function e(){}return e.prototype.evaluate=function(){for(var t=this.children,r=0;r<t.length;r++)if(!t[r].evaluate())return!1;return!0},e})(),UI=(function(){function e(){}return e.prototype.evaluate=function(){for(var t=this.children,r=0;r<t.length;r++)if(t[r].evaluate())return!0;return!1},e})(),YI=(function(){function e(){}return e.prototype.evaluate=function(){return!this.child.evaluate()},e})(),ZI=(function(){function e(){}return e.prototype.evaluate=function(){for(var t=!!this.valueParser,r=this.getValue,n=r(this.valueGetterParam),i=t?this.valueParser(n):null,a=0;a<this.subCondList.length;a++)if(!this.subCondList[a].evaluate(t?i:n))return!1;return!0},e})();function xv(e,t){if(e===!0||e===!1){var r=new GI;return r.value=e,r}var n="";return J_(e)||ut(n),e.and?mg("and",e,t):e.or?mg("or",e,t):e.not?XI(e,t):$I(e,t)}function mg(e,t,r){var n=t[e],i="";z(n)||ut(i),n.length||ut(i);var a=e==="and"?new WI:new UI;return a.children=$(n,function(o){return xv(o,r)}),a.children.length||ut(i),a}function XI(e,t){var r=e.not,n="";J_(r)||ut(n);var i=new YI;return i.child=xv(r,t),i.child||ut(n),i}function $I(e,t){for(var r="",n=t.prepareGetValue(e),i=[],a=St(e),o=e.parser,s=o?Ay(o):null,l=0;l<a.length;l++){var u=a[l];if(!(u==="parser"||t.valueGetterAttrMap.get(u))){var f=he(gg,u)?gg[u]:u,h=e[u],c=s?s(h):h,v=Mx(f,c)||f==="reg"&&new VI(c);v||ut(r),i.push(v)}}i.length||ut(r);var d=new ZI;return d.valueGetterParam=n,d.valueParser=s,d.getValue=t.getValue,d.subCondList=i,d}function J_(e){return X(e)&&!Kt(e)}var qI=(function(){function e(t,r){this._cond=xv(t,r)}return e.prototype.evaluate=function(){return this._cond.evaluate()},e})();function KI(e,t){return new qI(e,t)}var QI={type:"echarts:filter",transform:function(e){for(var t=e.upstream,r,n=KI(e.config,{valueGetterAttrMap:K({dimension:!0}),prepareGetValue:function(s){var l="",u=s.dimension;he(s,"dimension")||ut(l);var f=t.getDimensionInfo(u);return f||ut(l),{dimIdx:f.index}},getValue:function(s){return t.retrieveValueFromItem(r,s.dimIdx)}}),i=[],a=0,o=t.count();a<o;a++)r=t.getRawDataItem(a),n.evaluate()&&i.push(r);return{data:i}}},JI={type:"echarts:sort",transform:function(e){var t=e.upstream,r=e.config,n="",i=Mt(r);i.length||ut(n);var a=[];M(i,function(f){var h=f.dimension,c=f.order,v=f.parser,d=f.incomparable;if(h==null&&ut(n),c!=="asc"&&c!=="desc"&&ut(n),d&&d!=="min"&&d!=="max"){var p="";ut(p)}if(c!=="asc"&&c!=="desc"){var g="";ut(g)}var m=t.getDimensionInfo(h);m||ut(n);var y=v?Ay(v):null;v&&!y&&ut(n),a.push({dimIdx:m.index,parser:y,comparator:new Iy(c,d)})});var o=t.sourceFormat;o!==zt&&o!==Ce&&ut(n);for(var s=[],l=0,u=t.count();l<u;l++)s.push(t.getRawDataItem(l));return s.sort(function(f,h){for(var c=0;c<a.length;c++){var v=a[c],d=t.retrieveValueFromItem(f,v.dimIdx),p=t.retrieveValueFromItem(h,v.dimIdx);v.parser&&(d=v.parser(d),p=v.parser(p));var g=v.comparator.evaluate(d,p);if(g!==0)return g}return 0}),{data:s}}};function jI(e){e.registerTransform(QI),e.registerTransform(JI)}var tP=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type="dataset",r}return t.prototype.init=function(r,n,i){e.prototype.init.call(this,r,n,i),this._sourceManager=new t0(this),ud(this)},t.prototype.mergeOption=function(r,n){e.prototype.mergeOption.call(this,r,n),ud(this)},t.prototype.optionUpdated=function(){this._sourceManager.dirty()},t.prototype.getSourceManager=function(){return this._sourceManager},t.type="dataset",t.defaultOption={seriesLayoutBy:Pe},t})(dt),eP=(function(e){N(t,e);function t(){var r=e!==null&&e.apply(this,arguments)||this;return r.type="dataset",r}return t.type="dataset",t})(Te);function rP(e){e.registerComponentModel(tP),e.registerComponentView(eP)}function nP(e){if(e){for(var t=[],r=0;r<e.length;r++)t.push(e[r].slice());return t}}function iP(e,t){var r=e.label,n=t&&t.getTextGuideLine();return{dataIndex:e.dataIndex,dataType:e.dataType,seriesIndex:e.seriesModel.seriesIndex,text:e.label.style.text,rect:e.hostRect,labelRect:e.rect,align:r.style.align,verticalAlign:r.style.verticalAlign,labelLinePoints:nP(n&&n.shape.points)}}var yg=["align","verticalAlign","width","height","fontSize"],Zt=new qa,Vu=gt(),aP=gt();function Wo(e,t,r){for(var n=0;n<r.length;n++){var i=r[n];t[i]!=null&&(e[i]=t[i])}}var Uo=["x","y","rotation"],oP=(function(){function e(){this._labelList=[],this._chartViewList=[]}return e.prototype.clearLabels=function(){this._labelList=[],this._chartViewList=[]},e.prototype._addLabel=function(t,r,n,i,a){var o=i.style,s=i.__hostTarget,l=s.textConfig||{},u=i.getComputedTransform(),f=i.getBoundingRect().plain();it.applyTransform(f,f,u),u?Zt.setLocalTransform(u):(Zt.x=Zt.y=Zt.rotation=Zt.originX=Zt.originY=0,Zt.scaleX=Zt.scaleY=1),Zt.rotation=ir(Zt.rotation);var h=i.__hostTarget,c;if(h){c=h.getBoundingRect().plain();var v=h.getComputedTransform();it.applyTransform(c,c,v)}var d=c&&h.getTextGuideLine();this._labelList.push({label:i,labelLine:d,seriesModel:n,dataIndex:t,dataType:r,layoutOptionOrCb:a,layoutOption:null,rect:f,hostRect:c,priority:c?c.width*c.height:0,defaultAttr:{ignore:i.ignore,labelGuideIgnore:d&&d.ignore,x:Zt.x,y:Zt.y,scaleX:Zt.scaleX,scaleY:Zt.scaleY,rotation:Zt.rotation,style:{x:o.x,y:o.y,align:o.align,verticalAlign:o.verticalAlign,width:o.width,height:o.height,fontSize:o.fontSize},cursor:i.cursor,attachedPos:l.position,attachedRot:l.rotation}})},e.prototype.addLabelsOfSeries=function(t){var r=this;this._chartViewList.push(t);var n=t.__model,i=n.get("labelLayout");(et(i)||St(i).length)&&t.group.traverse(function(a){if(a.ignore)return!0;var o=a.getTextContent(),s=pt(a);o&&!o.disableLabelLayout&&r._addLabel(s.dataIndex,s.dataType,n,o,i)})},e.prototype.updateLayoutConfig=function(t){var r=t.getWidth(),n=t.getHeight();function i(_,S){return function(){Md(_,S)}}for(var a=0;a<this._labelList.length;a++){var o=this._labelList[a],s=o.label,l=s.__hostTarget,u=o.defaultAttr,f=void 0;et(o.layoutOptionOrCb)?f=o.layoutOptionOrCb(iP(o,l)):f=o.layoutOptionOrCb,f=f||{},o.layoutOption=f;var h=Math.PI/180;l&&l.setTextConfig({local:!1,position:f.x!=null||f.y!=null?null:u.attachedPos,rotation:f.rotate!=null?f.rotate*h:u.attachedRot,offset:[f.dx||0,f.dy||0]});var c=!1;if(f.x!=null?(s.x=It(f.x,r),s.setStyle("x",0),c=!0):(s.x=u.x,s.setStyle("x",u.style.x)),f.y!=null?(s.y=It(f.y,n),s.setStyle("y",0),c=!0):(s.y=u.y,s.setStyle("y",u.style.y)),f.labelLinePoints){var v=l.getTextGuideLine();v&&(v.setShape({points:f.labelLinePoints}),c=!1)}var d=Vu(s);d.needsUpdateLabelLine=c,s.rotation=f.rotate!=null?f.rotate*h:u.rotation,s.scaleX=u.scaleX,s.scaleY=u.scaleY;for(var p=0;p<yg.length;p++){var g=yg[p];s.setStyle(g,f[g]!=null?f[g]:u.style[g])}if(f.draggable){if(s.draggable=!0,s.cursor="move",l){var m=o.seriesModel;if(o.dataIndex!=null){var y=o.seriesModel.getData(o.dataType);m=y.getItemModel(o.dataIndex)}s.on("drag",i(l,m.getModel("labelLine")))}}else s.off("drag"),s.cursor=u.cursor}},e.prototype.layout=function(t){var r=t.getWidth(),n=t.getHeight(),i=[];M(this._labelList,function(l){l.defaultAttr.ignore||i.push(Hf({},l))});var a=wt(i,function(l){return l.layoutOption.moveOverlap==="shiftX"}),o=wt(i,function(l){return l.layoutOption.moveOverlap==="shiftY"});Id(a,0,0,r),Id(o,1,0,n);var s=wt(i,function(l){return l.layoutOption.hideOverlap});xM(s),b0(s)},e.prototype.processLabelsOverall=function(){var t=this;M(this._chartViewList,function(r){var n=r.__model,i=r.ignoreLabelLineUpdate,a=n.isAnimationEnabled();r.group.traverse(function(o){if(o.ignore&&!o.forceLabelAnimation)return!0;var s=!i,l=o.getTextContent();!s&&l&&(s=Vu(l).needsUpdateLabelLine),s&&t._updateLabelLine(o,n),a&&t._animateLabels(o,n)})})},e.prototype._updateLabelLine=function(t,r){var n=t.getTextContent(),i=pt(t),a=i.dataIndex;if(n&&a!=null){var o=r.getData(i.dataType),s=o.getItemModel(a),l={},u=o.getItemVisual(a,"style");if(u){var f=o.getVisual("drawType");l.stroke=u[f]}var h=s.getModel("labelLine");mM(t,yM(s),l),Md(t,h)}},e.prototype._animateLabels=function(t,r){var n=t.getTextContent(),i=t.getTextGuideLine();if(n&&(t.forceLabelAnimation||!n.ignore&&!n.invisible&&!t.disableLabelAnimation&&!bi(t))){var a=Vu(n),o=a.oldLayout,s=pt(t),l=s.dataIndex,u={x:n.x,y:n.y,rotation:n.rotation},f=r.getData(s.dataType);if(o){n.attr(o);var c=t.prevStates;c&&(ft(c,"select")>=0&&n.attr(a.oldLayoutSelect),ft(c,"emphasis")>=0&&n.attr(a.oldLayoutEmphasis)),qe(n,u,r,l)}else if(n.attr(u),!vl(n).valueAnimation){var h=q(n.style.opacity,1);n.style.opacity=0,vr(n,{style:{opacity:h}},r,l)}if(a.oldLayout=u,n.states.select){var v=a.oldLayoutSelect={};Wo(v,u,Uo),Wo(v,n.states.select,Uo)}if(n.states.emphasis){var d=a.oldLayoutEmphasis={};Wo(d,u,Uo),Wo(d,n.states.emphasis,Uo)}ex(n,l,f,r,r)}if(i&&!i.ignore&&!i.invisible){var a=aP(i),o=a.oldLayout,p={points:i.shape.points};o?(i.attr({shape:o}),qe(i,{shape:p},r)):(i.setShape(p),i.style.strokePercent=0,vr(i,{style:{strokePercent:1}},r)),a.oldLayout=p}},e})(),Gu=gt();function sP(e){e.registerUpdateLifecycle("series:beforeupdate",function(t,r,n){var i=Gu(r).labelManager;i||(i=Gu(r).labelManager=new oP),i.clearLabels()}),e.registerUpdateLifecycle("series:layoutlabels",function(t,r,n){var i=Gu(r).labelManager;n.updatedSeries.forEach(function(a){i.addLabelsOfSeries(r.getViewOfSeriesModel(a))}),i.updateLayoutConfig(r),i.layout(r),i.processLabelsOverall()})}var He=hr.CMD;function mi(e,t){return Math.abs(e-t)<1e-5}function uh(e){var t=e.data,r=e.len(),n=[],i,a=0,o=0,s=0,l=0;function u(L,I){i&&i.length>2&&n.push(i),i=[L,I]}function f(L,I,R,E){mi(L,R)&&mi(I,E)||i.push(L,I,R,E,R,E)}function h(L,I,R,E,G,F){var H=Math.abs(I-L),V=Math.tan(H/4)*4/3,U=I<L?-1:1,Z=Math.cos(L),J=Math.sin(L),ot=Math.cos(I),yt=Math.sin(I),Ht=Z*G+R,ce=J*F+E,de=ot*G+R,Vt=yt*F+E,Dt=G*V*U,rt=F*V*U;i.push(Ht-Dt*J,ce+rt*Z,de+Dt*yt,Vt-rt*ot,de,Vt)}for(var c,v,d,p,g=0;g<r;){var m=t[g++],y=g===1;switch(y&&(a=t[g],o=t[g+1],s=a,l=o,(m===He.L||m===He.C||m===He.Q)&&(i=[s,l])),m){case He.M:a=s=t[g++],o=l=t[g++],u(s,l);break;case He.L:c=t[g++],v=t[g++],f(a,o,c,v),a=c,o=v;break;case He.C:i.push(t[g++],t[g++],t[g++],t[g++],a=t[g++],o=t[g++]);break;case He.Q:c=t[g++],v=t[g++],d=t[g++],p=t[g++],i.push(a+2/3*(c-a),o+2/3*(v-o),d+2/3*(c-d),p+2/3*(v-p),d,p),a=d,o=p;break;case He.A:var _=t[g++],S=t[g++],w=t[g++],b=t[g++],x=t[g++],C=t[g++]+x;g+=1;var T=!t[g++];c=Math.cos(x)*w+_,v=Math.sin(x)*b+S,y?(s=c,l=v,u(s,l)):f(a,o,c,v),a=Math.cos(C)*w+_,o=Math.sin(C)*b+S;for(var D=(T?-1:1)*Math.PI/2,A=x;T?A>C:A<C;A+=D){var P=T?Math.max(A+D,C):Math.min(A+D,C);h(A,P,_,S,w,b)}break;case He.R:s=a=t[g++],l=o=t[g++],c=s+t[g++],v=l+t[g++],u(c,l),f(c,l,c,v),f(c,v,s,v),f(s,v,s,l),f(s,l,c,l);break;case He.Z:i&&f(a,o,s,l),a=s,o=l;break}}return i&&i.length>2&&n.push(i),n}function fh(e,t,r,n,i,a,o,s,l,u){if(mi(e,r)&&mi(t,n)&&mi(i,o)&&mi(a,s)){l.push(o,s);return}var f=2/u,h=f*f,c=o-e,v=s-t,d=Math.sqrt(c*c+v*v);c/=d,v/=d;var p=r-e,g=n-t,m=i-o,y=a-s,_=p*p+g*g,S=m*m+y*y;if(_<h&&S<h){l.push(o,s);return}var w=c*p+v*g,b=-c*m-v*y,x=_-w*w,C=S-b*b;if(x<h&&w>=0&&C<h&&b>=0){l.push(o,s);return}var T=[],D=[];Br(e,r,i,o,.5,T),Br(t,n,a,s,.5,D),fh(T[0],D[0],T[1],D[1],T[2],D[2],T[3],D[3],l,u),fh(T[4],D[4],T[5],D[5],T[6],D[6],T[7],D[7],l,u)}function lP(e,t){var r=uh(e),n=[];t=t||1;for(var i=0;i<r.length;i++){var a=r[i],o=[],s=a[0],l=a[1];o.push(s,l);for(var u=2;u<a.length;){var f=a[u++],h=a[u++],c=a[u++],v=a[u++],d=a[u++],p=a[u++];fh(s,l,f,h,c,v,d,p,o,t),s=d,l=p}n.push(o)}return n}function j_(e,t,r){var n=e[t],i=e[1-t],a=Math.abs(n/i),o=Math.ceil(Math.sqrt(a*r)),s=Math.floor(r/o);s===0&&(s=1,o=r);for(var l=[],u=0;u<o;u++)l.push(s);var f=o*s,h=r-f;if(h>0)for(var u=0;u<h;u++)l[u%o]+=1;return l}function _g(e,t,r){for(var n=e.r0,i=e.r,a=e.startAngle,o=e.endAngle,s=Math.abs(o-a),l=s*i,u=i-n,f=l>Math.abs(u),h=j_([l,u],f?0:1,t),c=(f?s:u)/h.length,v=0;v<h.length;v++)for(var d=(f?u:s)/h[v],p=0;p<h[v];p++){var g={};f?(g.startAngle=a+c*v,g.endAngle=a+c*(v+1),g.r0=n+d*p,g.r=n+d*(p+1)):(g.startAngle=a+d*p,g.endAngle=a+d*(p+1),g.r0=n+c*v,g.r=n+c*(v+1)),g.clockwise=e.clockwise,g.cx=e.cx,g.cy=e.cy,r.push(g)}}function uP(e,t,r){for(var n=e.width,i=e.height,a=n>i,o=j_([n,i],a?0:1,t),s=a?"width":"height",l=a?"height":"width",u=a?"x":"y",f=a?"y":"x",h=e[s]/o.length,c=0;c<o.length;c++)for(var v=e[l]/o[c],d=0;d<o[c];d++){var p={};p[u]=c*h,p[f]=d*v,p[s]=h,p[l]=v,p.x+=e.x,p.y+=e.y,r.push(p)}}function Sg(e,t,r,n){return e*n-r*t}function fP(e,t,r,n,i,a,o,s){var l=r-e,u=n-t,f=o-i,h=s-a,c=Sg(f,h,l,u);if(Math.abs(c)<1e-6)return null;var v=e-i,d=t-a,p=Sg(v,d,f,h)/c;return p<0||p>1?null:new tt(p*l+e,p*u+t)}function hP(e,t,r){var n=new tt;tt.sub(n,r,t),n.normalize();var i=new tt;tt.sub(i,e,t);var a=i.dot(n);return a}function ii(e,t){var r=e[e.length-1];r&&r[0]===t[0]&&r[1]===t[1]||e.push(t)}function vP(e,t,r){for(var n=e.length,i=[],a=0;a<n;a++){var o=e[a],s=e[(a+1)%n],l=fP(o[0],o[1],s[0],s[1],t.x,t.y,r.x,r.y);l&&i.push({projPt:hP(l,t,r),pt:l,idx:a})}if(i.length<2)return[{points:e},{points:e}];i.sort(function(g,m){return g.projPt-m.projPt});var u=i[0],f=i[i.length-1];if(f.idx<u.idx){var h=u;u=f,f=h}for(var c=[u.pt.x,u.pt.y],v=[f.pt.x,f.pt.y],d=[c],p=[v],a=u.idx+1;a<=f.idx;a++)ii(d,e[a].slice());ii(d,v),ii(d,c);for(var a=f.idx+1;a<=u.idx+n;a++)ii(p,e[a%n].slice());return ii(p,c),ii(p,v),[{points:d},{points:p}]}function bg(e){var t=e.points,r=[],n=[];ym(t,r,n);var i=new it(r[0],r[1],n[0]-r[0],n[1]-r[1]),a=i.width,o=i.height,s=i.x,l=i.y,u=new tt,f=new tt;return a>o?(u.x=f.x=s+a/2,u.y=l,f.y=l+o):(u.y=f.y=l+o/2,u.x=s,f.x=s+a),vP(t,u,f)}function Zs(e,t,r,n){if(r===1)n.push(t);else{var i=Math.floor(r/2),a=e(t);Zs(e,a[0],i,n),Zs(e,a[1],r-i,n)}return n}function cP(e,t){for(var r=[],n=0;n<t;n++)r.push(Rh(e));return r}function dP(e,t){t.setStyle(e.style),t.z=e.z,t.z2=e.z2,t.zlevel=e.zlevel}function pP(e){for(var t=[],r=0;r<e.length;)t.push([e[r++],e[r++]]);return t}function gP(e,t){var r=[],n=e.shape,i;switch(e.type){case"rect":uP(n,t,r),i=Tt;break;case"sector":_g(n,t,r),i=Ci;break;case"circle":_g({r0:0,r:n.r,startAngle:0,endAngle:Math.PI*2,cx:n.cx,cy:n.cy},t,r),i=Ci;break;default:var a=e.getComputedTransform(),o=a?Math.sqrt(Math.max(a[0]*a[0]+a[1]*a[1],a[2]*a[2]+a[3]*a[3])):1,s=$(lP(e.getUpdatedPathProxy(),o),function(m){return pP(m)}),l=s.length;if(l===0)Zs(bg,{points:s[0]},t,r);else if(l===t)for(var u=0;u<l;u++)r.push({points:s[u]});else{var f=0,h=$(s,function(m){var y=[],_=[];ym(m,y,_);var S=(_[1]-y[1])*(_[0]-y[0]);return f+=S,{poly:m,area:S}});h.sort(function(m,y){return y.area-m.area});for(var c=t,u=0;u<l;u++){var v=h[u];if(c<=0)break;var d=u===l-1?c:Math.ceil(v.area/f*t);d<0||(Zs(bg,{points:v.poly},d,r),c-=d)}}i=Ja;break}if(!i)return cP(e,t);for(var p=[],u=0;u<r.length;u++){var g=new i;g.setShape(r[u]),dP(e,g),p.push(g)}return p}function mP(e,t){var r=e.length,n=t.length;if(r===n)return[e,t];for(var i=[],a=[],o=r<n?e:t,s=Math.min(r,n),l=Math.abs(n-r)/6,u=(s-2)/6,f=Math.ceil(l/u)+1,h=[o[0],o[1]],c=l,v=2;v<s;){var d=o[v-2],p=o[v-1],g=o[v++],m=o[v++],y=o[v++],_=o[v++],S=o[v++],w=o[v++];if(c<=0){h.push(g,m,y,_,S,w);continue}for(var b=Math.min(c,f-1)+1,x=1;x<=b;x++){var C=x/b;Br(d,g,y,S,C,i),Br(p,m,_,w,C,a),d=i[3],p=a[3],h.push(i[1],a[1],i[2],a[2],d,p),g=i[5],m=a[5],y=i[6],_=a[6]}c-=b-1}return o===e?[h,t]:[e,h]}function wg(e,t){for(var r=e.length,n=e[r-2],i=e[r-1],a=[],o=0;o<t.length;)a[o++]=n,a[o++]=i;return a}function yP(e,t){for(var r,n,i,a=[],o=[],s=0;s<Math.max(e.length,t.length);s++){var l=e[s],u=t[s],f=void 0,h=void 0;l?u?(r=mP(l,u),f=r[0],h=r[1],n=f,i=h):(h=wg(i||l,l),f=l):(f=wg(n||u,u),h=u),a.push(f),o.push(h)}return[a,o]}function xg(e){for(var t=0,r=0,n=0,i=e.length,a=0,o=i-2;a<i;o=a,a+=2){var s=e[o],l=e[o+1],u=e[a],f=e[a+1],h=s*f-u*l;t+=h,r+=(s+u)*h,n+=(l+f)*h}return t===0?[e[0]||0,e[1]||0]:[r/t/3,n/t/3,t]}function _P(e,t,r,n){for(var i=(e.length-2)/6,a=1/0,o=0,s=e.length,l=s-2,u=0;u<i;u++){for(var f=u*6,h=0,c=0;c<s;c+=2){var v=c===0?f:(f+c-2)%l+2,d=e[v]-r[0],p=e[v+1]-r[1],g=t[c]-n[0],m=t[c+1]-n[1],y=g-d,_=m-p;h+=y*y+_*_}h<a&&(a=h,o=u)}return o}function SP(e){for(var t=[],r=e.length,n=0;n<r;n+=2)t[n]=e[r-n-2],t[n+1]=e[r-n-1];return t}function bP(e,t,r,n){for(var i=[],a,o=0;o<e.length;o++){var s=e[o],l=t[o],u=xg(s),f=xg(l);a==null&&(a=u[2]<0!=f[2]<0);var h=[],c=[],v=0,d=1/0,p=[],g=s.length;a&&(s=SP(s));for(var m=_P(s,l,u,f)*6,y=g-2,_=0;_<y;_+=2){var S=(m+_)%y+2;h[_+2]=s[S]-u[0],h[_+3]=s[S+1]-u[1]}h[0]=s[m]-u[0],h[1]=s[m+1]-u[1];for(var w=n/r,b=-n/2;b<=n/2;b+=w){for(var x=Math.sin(b),C=Math.cos(b),T=0,_=0;_<s.length;_+=2){var D=h[_],A=h[_+1],P=l[_]-f[0],L=l[_+1]-f[1],I=P*C-L*x,R=P*x+L*C;p[_]=I,p[_+1]=R;var E=I-D,G=R-A;T+=E*E+G*G}if(T<d){d=T,v=b;for(var F=0;F<p.length;F++)c[F]=p[F]}}i.push({from:h,to:c,fromCp:u,toCp:f,rotation:-v})}return i}function Xs(e){return e.__isCombineMorphing}var t1="__mOriginal_";function $s(e,t,r){var n=t1+t,i=e[n]||e[t];e[n]||(e[n]=e[t]);var a=r.replace,o=r.after,s=r.before;e[t]=function(){var l=arguments,u;return s&&s.apply(this,l),a?u=a.apply(this,l):u=i.apply(this,l),o&&o.apply(this,l),u}}function Da(e,t){var r=t1+t;e[r]&&(e[t]=e[r],e[r]=null)}function Tg(e,t){for(var r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;){var a=n[i],o=n[i+1];n[i++]=t[0]*a+t[2]*o+t[4],n[i++]=t[1]*a+t[3]*o+t[5]}}function e1(e,t){var r=e.getUpdatedPathProxy(),n=t.getUpdatedPathProxy(),i=yP(uh(r),uh(n)),a=i[0],o=i[1],s=e.getComputedTransform(),l=t.getComputedTransform();function u(){this.transform=null}s&&Tg(a,s),l&&Tg(o,l),$s(t,"updateTransform",{replace:u}),t.transform=null;var f=bP(a,o,10,Math.PI),h=[];$s(t,"buildPath",{replace:function(c){for(var v=t.__morphT,d=1-v,p=[],g=0;g<f.length;g++){var m=f[g],y=m.from,_=m.to,S=m.rotation*v,w=m.fromCp,b=m.toCp,x=Math.sin(S),C=Math.cos(S);Zo(p,w,b,v);for(var T=0;T<y.length;T+=2){var D=y[T],A=y[T+1],P=_[T],L=_[T+1],I=D*d+P*v,R=A*d+L*v;h[T]=I*C-R*x+p[0],h[T+1]=I*x+R*C+p[1]}var E=h[0],G=h[1];c.moveTo(E,G);for(var T=2;T<y.length;){var P=h[T++],L=h[T++],F=h[T++],H=h[T++],V=h[T++],U=h[T++];E===P&&G===L&&F===V&&H===U?c.lineTo(V,U):c.bezierCurveTo(P,L,F,H,V,U),E=V,G=U}}}})}function Tv(e,t,r){if(!e||!t)return t;var n=r.done,i=r.during;e1(e,t),t.__morphT=0;function a(){Da(t,"buildPath"),Da(t,"updateTransform"),t.__morphT=-1,t.createPathProxy(),t.dirtyShape()}return t.animateTo({__morphT:1},at({during:function(o){t.dirtyShape(),i&&i(o)},done:function(){a(),n&&n()}},r)),t}function wP(e,t,r,n,i,a){var o=16;e=i===r?0:Math.round(32767*(e-r)/(i-r)),t=a===n?0:Math.round(32767*(t-n)/(a-n));for(var s=0,l,u=(1<<o)/2;u>0;u/=2){var f=0,h=0;(e&u)>0&&(f=1),(t&u)>0&&(h=1),s+=u*u*(3*f^h),h===0&&(f===1&&(e=u-1-e,t=u-1-t),l=e,e=t,t=l)}return s}function qs(e){var t=1/0,r=1/0,n=-1/0,i=-1/0,a=$(e,function(s){var l=s.getBoundingRect(),u=s.getComputedTransform(),f=l.x+l.width/2+(u?u[4]:0),h=l.y+l.height/2+(u?u[5]:0);return t=Math.min(f,t),r=Math.min(h,r),n=Math.max(f,n),i=Math.max(h,i),[f,h]}),o=$(a,function(s,l){return{cp:s,z:wP(s[0],s[1],t,r,n,i),path:e[l]}});return o.sort(function(s,l){return s.z-l.z}).map(function(s){return s.path})}function r1(e){return gP(e.path,e.count)}function hh(){return{fromIndividuals:[],toIndividuals:[],count:0}}function xP(e,t,r){var n=[];function i(w){for(var b=0;b<w.length;b++){var x=w[b];Xs(x)?i(x.childrenRef()):x instanceof ht&&n.push(x)}}i(e);var a=n.length;if(!a)return hh();var o=r.dividePath||r1,s=o({path:t,count:a});if(s.length!==a)return console.error("Invalid morphing: unmatched splitted path"),hh();n=qs(n),s=qs(s);for(var l=r.done,u=r.during,f=r.individualDelay,h=new qa,c=0;c<a;c++){var v=n[c],d=s[c];d.parent=t,d.copyTransform(h),f||e1(v,d)}t.__isCombineMorphing=!0,t.childrenRef=function(){return s};function p(w){for(var b=0;b<s.length;b++)s[b].addSelfToZr(w)}$s(t,"addSelfToZr",{after:function(w){p(w)}}),$s(t,"removeSelfFromZr",{after:function(w){for(var b=0;b<s.length;b++)s[b].removeSelfFromZr(w)}});function g(){t.__isCombineMorphing=!1,t.__morphT=-1,t.childrenRef=null,Da(t,"addSelfToZr"),Da(t,"removeSelfFromZr")}var m=s.length;if(f)for(var y=m,_=function(){y--,y===0&&(g(),l&&l())},c=0;c<m;c++){var S=f?at({delay:(r.delay||0)+f(c,m,n[c],s[c]),done:_},r):r;Tv(n[c],s[c],S)}else t.__morphT=0,t.animateTo({__morphT:1},at({during:function(w){for(var b=0;b<m;b++){var x=s[b];x.__morphT=t.__morphT,x.dirtyShape()}u&&u(w)},done:function(){g();for(var w=0;w<e.length;w++)Da(e[w],"updateTransform");l&&l()}},r));return t.__zr&&p(t.__zr),{fromIndividuals:n,toIndividuals:s,count:m}}function TP(e,t,r){var n=t.length,i=[],a=r.dividePath||r1;function o(v){for(var d=0;d<v.length;d++){var p=v[d];Xs(p)?o(p.childrenRef()):p instanceof ht&&i.push(p)}}if(Xs(e)){o(e.childrenRef());var s=i.length;if(s<n)for(var l=0,u=s;u<n;u++)i.push(Rh(i[l++%s]));i.length=n}else{i=a({path:e,count:n});for(var f=e.getComputedTransform(),u=0;u<i.length;u++)i[u].setLocalTransform(f);if(i.length!==n)return console.error("Invalid morphing: unmatched splitted path"),hh()}i=qs(i),t=qs(t);for(var h=r.individualDelay,u=0;u<n;u++){var c=h?at({delay:(r.delay||0)+h(u,n,i[u],t[u])},r):r;Tv(i[u],t[u],c)}return{fromIndividuals:i,toIndividuals:t,count:t.length}}function Cg(e){return z(e[0])}function Mg(e,t){for(var r=[],n=e.length,i=0;i<n;i++)r.push({one:e[i],many:[]});for(var i=0;i<t.length;i++){var a=t[i].length,o=void 0;for(o=0;o<a;o++)r[o%n].many.push(t[i][o])}for(var s=0,i=n-1;i>=0;i--)if(!r[i].many.length){var l=r[s].many;if(l.length<=1)if(s)s=0;else return r;var a=l.length,u=Math.ceil(a/2);r[i].many=l.slice(u,a),r[s].many=l.slice(0,u),s++}return r}var CP={clone:function(e){for(var t=[],r=1-Math.pow(1-e.path.style.opacity,1/e.count),n=0;n<e.count;n++){var i=Rh(e.path);i.setStyle("opacity",r),t.push(i)}return t},split:null};function Wu(e,t,r,n,i,a){if(!e.length||!t.length)return;var o=fl("update",n,i);if(!(o&&o.duration>0))return;var s=n.getModel("universalTransition").get("delay"),l=Object.assign({setToFinal:!0},o),u,f;Cg(e)&&(u=e,f=t),Cg(t)&&(u=t,f=e);function h(m,y,_,S,w){var b=m.many,x=m.one;if(b.length===1&&!w){var C=y?b[0]:x,T=y?x:b[0];if(Xs(C))h({many:[C],one:T},!0,_,S,!0);else{var D=s?at({delay:s(_,S)},l):l;Tv(C,T,D),a(C,T,C,T,D)}}else for(var A=at({dividePath:CP[r],individualDelay:s&&function(G,F,H,V){return s(G+_,S)}},l),P=y?xP(b,x,A):TP(x,b,A),L=P.fromIndividuals,I=P.toIndividuals,R=L.length,E=0;E<R;E++){var D=s?at({delay:s(E,R)},l):l;a(L[E],I[E],y?b[E]:m.one,y?m.one:b[E],D)}}for(var c=u?u===e:e.length>t.length,v=u?Mg(f,u):Mg(c?t:e,[c?e:t]),d=0,p=0;p<v.length;p++)d+=v[p].many.length;for(var g=0,p=0;p<v.length;p++)h(v[p],c,g,d),g+=v[p].many.length}function yn(e){if(!e)return[];if(z(e)){for(var t=[],r=0;r<e.length;r++)t.push(yn(e[r]));return t}var n=[];return e.traverse(function(i){i instanceof ht&&!i.disableMorphing&&!i.invisible&&!i.ignore&&n.push(i)}),n}var n1=1e4,MP=0,Dg=1,Ag=2,DP=gt();function AP(e,t){for(var r=e.dimensions,n=0;n<r.length;n++){var i=e.getDimensionInfo(r[n]);if(i&&i.otherDims[t]===0)return r[n]}}function LP(e,t,r){var n=e.getDimensionInfo(r),i=n&&n.ordinalMeta;if(n){var a=e.get(n.name,t);return i&&i.categories[a]||a+""}}function Lg(e,t,r,n){var i=n?"itemChildGroupId":"itemGroupId",a=AP(e,i);if(a){var o=LP(e,t,a);return o}var s=e.getRawDataItem(t),l=n?"childGroupId":"groupId";if(s&&s[l])return s[l]+"";if(!n)return r||e.getId(t)}function Ig(e){var t=[];return M(e,function(r){var n=r.data,i=r.dataGroupId;if(!(n.count()>n1))for(var a=n.getIndices(),o=0;o<a.length;o++)t.push({data:n,groupId:Lg(n,o,i,!1),childGroupId:Lg(n,o,i,!0),divide:r.divide,dataIndex:o})}),t}function Uu(e,t,r){e.traverse(function(n){n instanceof ht&&vr(n,{style:{opacity:0}},t,{dataIndex:r,isFrom:!0})})}function Yu(e){if(e.parent){var t=e.getComputedTransform();e.setLocalTransform(t),e.parent.remove(e)}}function ai(e){e.stopAnimation(),e.isGroup&&e.traverse(function(t){t.stopAnimation()})}function IP(e,t,r){var n=fl("update",r,t);n&&e.traverse(function(i){if(i instanceof Oi){var a=Nw(i);a&&i.animateFrom({style:a},n)}})}function PP(e,t){var r=e.length;if(r!==t.length)return!1;for(var n=0;n<r;n++){var i=e[n],a=t[n];if(i.data.getId(i.dataIndex)!==a.data.getId(a.dataIndex))return!1}return!0}function i1(e,t,r){var n=Ig(e),i=Ig(t);function a(_,S,w,b,x){(w||_)&&S.animateFrom({style:w&&w!==_?k(k({},w.style),_.style):_.style},x)}var o=!1,s=MP,l=K(),u=K();n.forEach(function(_){_.groupId&&l.set(_.groupId,!0),_.childGroupId&&u.set(_.childGroupId,!0)});for(var f=0;f<i.length;f++){var h=i[f].groupId;if(u.get(h)){s=Dg;break}var c=i[f].childGroupId;if(c&&l.get(c)){s=Ag;break}}function v(_,S){return function(w){var b=w.data,x=w.dataIndex;return S?b.getId(x):_?s===Dg?w.childGroupId:w.groupId:s===Ag?w.childGroupId:w.groupId}}var d=PP(n,i),p={};if(!d)for(var f=0;f<i.length;f++){var g=i[f],m=g.data.getItemGraphicEl(g.dataIndex);m&&(p[m.id]=!0)}function y(_,S){var w=n[S],b=i[_],x=b.data.hostModel,C=w.data.getItemGraphicEl(w.dataIndex),T=b.data.getItemGraphicEl(b.dataIndex);if(C===T){T&&IP(T,b.dataIndex,x);return}C&&p[C.id]||T&&(ai(T),C?(ai(C),Yu(C),o=!0,Wu(yn(C),yn(T),b.divide,x,_,a)):Uu(T,x,_))}new Af(n,i,v(!0,d),v(!1,d),null,"multiple").update(y).updateManyToOne(function(_,S){var w=i[_],b=w.data,x=b.hostModel,C=b.getItemGraphicEl(w.dataIndex),T=wt($(S,function(D){return n[D].data.getItemGraphicEl(n[D].dataIndex)}),function(D){return D&&D!==C&&!p[D.id]});C&&(ai(C),T.length?(M(T,function(D){ai(D),Yu(D)}),o=!0,Wu(yn(T),yn(C),w.divide,x,_,a)):Uu(C,x,w.dataIndex))}).updateOneToMany(function(_,S){var w=n[S],b=w.data.getItemGraphicEl(w.dataIndex);if(!(b&&p[b.id])){var x=wt($(_,function(T){return i[T].data.getItemGraphicEl(i[T].dataIndex)}),function(T){return T&&T!==b}),C=i[_[0]].data.hostModel;x.length&&(M(x,function(T){return ai(T)}),b?(ai(b),Yu(b),o=!0,Wu(yn(b),yn(x),w.divide,C,_[0],a)):M(x,function(T){return Uu(T,C,_[0])}))}}).updateManyToMany(function(_,S){new Af(S,_,function(w){return n[w].data.getId(n[w].dataIndex)},function(w){return i[w].data.getId(i[w].dataIndex)}).update(function(w,b){y(_[w],S[b])}).execute()}).execute(),o&&M(t,function(_){var S=_.data,w=S.hostModel,b=w&&r.getViewOfSeriesModel(w),x=fl("update",w,0);b&&w.isAnimationEnabled()&&x&&x.duration>0&&b.group.traverse(function(C){C instanceof ht&&!C.animators.length&&C.animateFrom({style:{opacity:0}},x)})})}function Pg(e){var t=e.getModel("universalTransition").get("seriesKey");return t||e.id}function Rg(e){return z(e)?e.sort().join(","):e}function Cr(e){if(e.hostModel)return e.hostModel.getModel("universalTransition").get("divideShape")}function RP(e,t){var r=K(),n=K(),i=K();return M(e.oldSeries,function(a,o){var s=e.oldDataGroupIds[o],l=e.oldData[o],u=Pg(a),f=Rg(u);n.set(f,{dataGroupId:s,data:l}),z(u)&&M(u,function(h){i.set(h,{key:f,dataGroupId:s,data:l})})}),M(t.updatedSeries,function(a){if(a.isUniversalTransitionEnabled()&&a.isAnimationEnabled()){var o=a.get("dataGroupId"),s=a.getData(),l=Pg(a),u=Rg(l),f=n.get(u);if(f)r.set(u,{oldSeries:[{dataGroupId:f.dataGroupId,divide:Cr(f.data),data:f.data}],newSeries:[{dataGroupId:o,divide:Cr(s),data:s}]});else if(z(l)){var h=[];M(l,function(d){var p=n.get(d);p.data&&h.push({dataGroupId:p.dataGroupId,divide:Cr(p.data),data:p.data})}),h.length&&r.set(u,{oldSeries:h,newSeries:[{dataGroupId:o,data:s,divide:Cr(s)}]})}else{var c=i.get(l);if(c){var v=r.get(c.key);v||(v={oldSeries:[{dataGroupId:c.dataGroupId,data:c.data,divide:Cr(c.data)}],newSeries:[]},r.set(c.key,v)),v.newSeries.push({dataGroupId:o,data:s,divide:Cr(s)})}}}}),r}function Eg(e,t){for(var r=0;r<e.length;r++){var n=t.seriesIndex!=null&&t.seriesIndex===e[r].seriesIndex||t.seriesId!=null&&t.seriesId===e[r].id;if(n)return r}}function EP(e,t,r,n){var i=[],a=[];M(Mt(e.from),function(o){var s=Eg(t.oldSeries,o);s>=0&&i.push({dataGroupId:t.oldDataGroupIds[s],data:t.oldData[s],divide:Cr(t.oldData[s]),groupIdDim:o.dimension})}),M(Mt(e.to),function(o){var s=Eg(r.updatedSeries,o);if(s>=0){var l=r.updatedSeries[s].getData();a.push({dataGroupId:t.oldDataGroupIds[s],data:l,divide:Cr(l),groupIdDim:o.dimension})}}),i.length>0&&a.length>0&&i1(i,a,n)}function kP(e){e.registerUpdateLifecycle("series:beforeupdate",function(t,r,n){M(Mt(n.seriesTransition),function(i){M(Mt(i.to),function(a){for(var o=n.updatedSeries,s=0;s<o.length;s++)(a.seriesIndex!=null&&a.seriesIndex===o[s].seriesIndex||a.seriesId!=null&&a.seriesId===o[s].id)&&(o[s][ns]=!0)})})}),e.registerUpdateLifecycle("series:transition",function(t,r,n){var i=DP(r);if(i.oldSeries&&n.updatedSeries&&n.optionChanged){var a=n.seriesTransition;if(a)M(Mt(a),function(v){EP(v,i,n,r)});else{var o=RP(i,n);M(o.keys(),function(v){var d=o.get(v);i1(d.oldSeries,d.newSeries,r)})}M(n.updatedSeries,function(v){v[ns]&&(v[ns]=!1)})}for(var s=t.getSeries(),l=i.oldSeries=[],u=i.oldDataGroupIds=[],f=i.oldData=[],h=0;h<s.length;h++){var c=s[h].getData();c.count()<n1&&(l.push(s[h]),u.push(s[h].get("dataGroupId")),f.push(c))}})}function kg(e,t,r){var n=ur.createCanvas(),i=t.getWidth(),a=t.getHeight(),o=n.style;return o&&(o.position="absolute",o.left="0",o.top="0",o.width=i+"px",o.height=a+"px",n.setAttribute("data-zr-dom-id",e)),n.width=i*r,n.height=a*r,n}var Zu=(function(e){N(t,e);function t(r,n,i){var a=e.call(this)||this;a.motionBlur=!1,a.lastFrameAlpha=.7,a.dpr=1,a.virtual=!1,a.config={},a.incremental=!1,a.zlevel=0,a.maxRepaintRectCount=5,a.__dirty=!0,a.__firstTimePaint=!0,a.__used=!1,a.__drawIndex=0,a.__startIndex=0,a.__endIndex=0,a.__prevStartIndex=null,a.__prevEndIndex=null;var o;i=i||gs,typeof r=="string"?o=kg(r,n,i):X(r)&&(o=r,r=o.id),a.id=r,a.dom=o;var s=o.style;return s&&(Xg(o),o.onselectstart=function(){return!1},s.padding="0",s.margin="0",s.borderWidth="0"),a.painter=n,a.dpr=i,a}return t.prototype.getElementCount=function(){return this.__endIndex-this.__startIndex},t.prototype.afterBrush=function(){this.__prevStartIndex=this.__startIndex,this.__prevEndIndex=this.__endIndex},t.prototype.initContext=function(){this.ctx=this.dom.getContext("2d"),this.ctx.dpr=this.dpr},t.prototype.setUnpainted=function(){this.__firstTimePaint=!0},t.prototype.createBackBuffer=function(){var r=this.dpr;this.domBack=kg("back-"+this.id,this.painter,r),this.ctxBack=this.domBack.getContext("2d"),r!==1&&this.ctxBack.scale(r,r)},t.prototype.createRepaintRects=function(r,n,i,a){if(this.__firstTimePaint)return this.__firstTimePaint=!1,null;var o=[],s=this.maxRepaintRectCount,l=!1,u=new it(0,0,0,0);function f(y){if(!(!y.isFinite()||y.isZero()))if(o.length===0){var _=new it(0,0,0,0);_.copy(y),o.push(_)}else{for(var S=!1,w=1/0,b=0,x=0;x<o.length;++x){var C=o[x];if(C.intersect(y)){var T=new it(0,0,0,0);T.copy(C),T.union(y),o[x]=T,S=!0;break}else if(l){u.copy(y),u.union(C);var D=y.width*y.height,A=C.width*C.height,P=u.width*u.height,L=P-D-A;L<w&&(w=L,b=x)}}if(l&&(o[b].union(y),S=!0),!S){var _=new it(0,0,0,0);_.copy(y),o.push(_)}l||(l=o.length>=s)}}for(var h=this.__startIndex;h<this.__endIndex;++h){var c=r[h];if(c){var v=c.shouldBePainted(i,a,!0,!0),d=c.__isRendered&&(c.__dirty&ue||!v)?c.getPrevPaintRect():null;d&&f(d);var p=v&&(c.__dirty&ue||!c.__isRendered)?c.getPaintRect():null;p&&f(p)}}for(var h=this.__prevStartIndex;h<this.__prevEndIndex;++h){var c=n[h],v=c&&c.shouldBePainted(i,a,!0,!0);if(c&&(!v||!c.__zr)&&c.__isRendered){var d=c.getPrevPaintRect();d&&f(d)}}var g;do{g=!1;for(var h=0;h<o.length;){if(o[h].isZero()){o.splice(h,1);continue}for(var m=h+1;m<o.length;)o[h].intersect(o[m])?(g=!0,o[h].union(o[m]),o.splice(m,1)):m++;h++}}while(g);return this._paintRects=o,o},t.prototype.debugGetPaintRects=function(){return(this._paintRects||[]).slice()},t.prototype.resize=function(r,n){var i=this.dpr,a=this.dom,o=a.style,s=this.domBack;o&&(o.width=r+"px",o.height=n+"px"),a.width=r*i,a.height=n*i,s&&(s.width=r*i,s.height=n*i,i!==1&&this.ctxBack.scale(i,i))},t.prototype.clear=function(r,n,i){var a=this.dom,o=this.ctx,s=a.width,l=a.height;n=n||this.clearColor;var u=this.motionBlur&&!r,f=this.lastFrameAlpha,h=this.dpr,c=this;u&&(this.domBack||this.createBackBuffer(),this.ctxBack.globalCompositeOperation="copy",this.ctxBack.drawImage(a,0,0,s/h,l/h));var v=this.domBack;function d(p,g,m,y){if(o.clearRect(p,g,m,y),n&&n!=="transparent"){var _=void 0;if(Qs(n)){var S=n.global||n.__width===m&&n.__height===y;_=S&&n.__canvasGradient||Yf(o,n,{x:0,y:0,width:m,height:y}),n.__canvasGradient=_,n.__width=m,n.__height=y}else D1(n)&&(n.scaleX=n.scaleX||h,n.scaleY=n.scaleY||h,_=Zf(o,n,{dirty:function(){c.setUnpainted(),c.painter.refresh()}}));o.save(),o.fillStyle=_||n,o.fillRect(p,g,m,y),o.restore()}u&&(o.save(),o.globalAlpha=f,o.drawImage(v,p,g,m,y),o.restore())}!i||u?d(0,0,s,l):i.length&&M(i,function(p){d(p.x*h,p.y*h,p.width*h,p.height*h)})},t})(Ee),Og=1e5,mn=314159,Yo=.01,OP=.001;function BP(e){return e?e.__builtin__?!0:!(typeof e.resize!="function"||typeof e.refresh!="function"):!1}function NP(e,t){var r=document.createElement("div");return r.style.cssText=["position:relative","width:"+e+"px","height:"+t+"px","padding:0","margin:0","border-width:0"].join(";")+";",r}var FP=(function(){function e(t,r,n,i){this.type="canvas",this._zlevelList=[],this._prevDisplayList=[],this._layers={},this._layerConfig={},this._needsManuallyCompositing=!1,this.type="canvas";var a=!t.nodeName||t.nodeName.toUpperCase()==="CANVAS";this._opts=n=k({},n||{}),this.dpr=n.devicePixelRatio||gs,this._singleCanvas=a,this.root=t;var o=t.style;o&&(Xg(t),t.innerHTML=""),this.storage=r;var s=this._zlevelList;this._prevDisplayList=[];var l=this._layers;if(a){var f=t,h=f.width,c=f.height;n.width!=null&&(h=n.width),n.height!=null&&(c=n.height),this.dpr=n.devicePixelRatio||1,f.width=h*this.dpr,f.height=c*this.dpr,this._width=h,this._height=c;var v=new Zu(f,this,this.dpr);v.__builtin__=!0,v.initContext(),l[mn]=v,v.zlevel=mn,s.push(mn),this._domRoot=t}else{this._width=Eo(t,0,n),this._height=Eo(t,1,n);var u=this._domRoot=NP(this._width,this._height);t.appendChild(u)}}return e.prototype.getType=function(){return"canvas"},e.prototype.isSingleCanvas=function(){return this._singleCanvas},e.prototype.getViewportRoot=function(){return this._domRoot},e.prototype.getViewportRootOffset=function(){var t=this.getViewportRoot();if(t)return{offsetLeft:t.offsetLeft||0,offsetTop:t.offsetTop||0}},e.prototype.refresh=function(t){var r=this.storage.getDisplayList(!0),n=this._prevDisplayList,i=this._zlevelList;this._redrawId=Math.random(),this._paintList(r,n,t,this._redrawId);for(var a=0;a<i.length;a++){var o=i[a],s=this._layers[o];if(!s.__builtin__&&s.refresh){var l=a===0?this._backgroundColor:null;s.refresh(l)}}return this._opts.useDirtyRect&&(this._prevDisplayList=r.slice()),this},e.prototype.refreshHover=function(){this._paintHoverList(this.storage.getDisplayList(!1))},e.prototype._paintHoverList=function(t){var r=t.length,n=this._hoverlayer;if(n&&n.clear(),!!r){for(var i={inHover:!0,viewWidth:this._width,viewHeight:this._height},a,o=0;o<r;o++){var s=t[o];s.__inHover&&(n||(n=this._hoverlayer=this.getLayer(Og)),a||(a=n.ctx,a.save()),Cn(a,s,i,o===r-1))}a&&a.restore()}},e.prototype.getHoverLayer=function(){return this.getLayer(Og)},e.prototype.paintOne=function(t,r){W0(t,r)},e.prototype._paintList=function(t,r,n,i){if(this._redrawId===i){n=n||!1,this._updateLayerStatus(t);var a=this._doPaintList(t,r,n),o=a.finished,s=a.needsRefreshHover;if(this._needsManuallyCompositing&&this._compositeManually(),s&&this._paintHoverList(t),o)this.eachLayer(function(u){u.afterBrush&&u.afterBrush()});else{var l=this;Os(function(){l._paintList(t,r,n,i)})}}},e.prototype._compositeManually=function(){var t=this.getLayer(mn).ctx,r=this._domRoot.width,n=this._domRoot.height;t.clearRect(0,0,r,n),this.eachBuiltinLayer(function(i){i.virtual&&t.drawImage(i.dom,0,0,r,n)})},e.prototype._doPaintList=function(t,r,n){for(var i=this,a=[],o=this._opts.useDirtyRect,s=0;s<this._zlevelList.length;s++){var l=this._zlevelList[s],u=this._layers[l];u.__builtin__&&u!==this._hoverlayer&&(u.__dirty||n)&&a.push(u)}for(var f=!0,h=!1,c=function(p){var g=a[p],m=g.ctx,y=o&&g.createRepaintRects(t,r,v._width,v._height),_=n?g.__startIndex:g.__drawIndex,S=!n&&g.incremental&&Date.now,w=S&&Date.now(),b=g.zlevel===v._zlevelList[0]?v._backgroundColor:null;if(g.__startIndex===g.__endIndex)g.clear(!1,b,y);else if(_===g.__startIndex){var x=t[_];(!x.incremental||!x.notClear||n)&&g.clear(!1,b,y)}_===-1&&(console.error("For some unknown reason. drawIndex is -1"),_=g.__startIndex);var C,T=function(L){var I={inHover:!1,allClipped:!1,prevEl:null,viewWidth:i._width,viewHeight:i._height};for(C=_;C<g.__endIndex;C++){var R=t[C];if(R.__inHover&&(h=!0),i._doPaintEl(R,g,o,L,I,C===g.__endIndex-1),S){var E=Date.now()-w;if(E>15)break}}I.prevElClipPaths&&m.restore()};if(y)if(y.length===0)C=g.__endIndex;else for(var D=v.dpr,A=0;A<y.length;++A){var P=y[A];m.save(),m.beginPath(),m.rect(P.x*D,P.y*D,P.width*D,P.height*D),m.clip(),T(P),m.restore()}else m.save(),T(),m.restore();g.__drawIndex=C,g.__drawIndex<g.__endIndex&&(f=!1)},v=this,d=0;d<a.length;d++)c(d);return nt.wxa&&M(this._layers,function(p){p&&p.ctx&&p.ctx.draw&&p.ctx.draw()}),{finished:f,needsRefreshHover:h}},e.prototype._doPaintEl=function(t,r,n,i,a,o){var s=r.ctx;if(n){var l=t.getPaintRect();(!i||l&&l.intersect(i))&&(Cn(s,t,a,o),t.setPrevPaintRect(l))}else Cn(s,t,a,o)},e.prototype.getLayer=function(t,r){this._singleCanvas&&!this._needsManuallyCompositing&&(t=mn);var n=this._layers[t];return n||(n=new Zu("zr_"+t,this,this.dpr),n.zlevel=t,n.__builtin__=!0,this._layerConfig[t]?vt(n,this._layerConfig[t],!0):this._layerConfig[t-Yo]&&vt(n,this._layerConfig[t-Yo],!0),r&&(n.virtual=r),this.insertLayer(t,n),n.initContext()),n},e.prototype.insertLayer=function(t,r){var n=this._layers,i=this._zlevelList,a=i.length,o=this._domRoot,s=null,l=-1;if(!n[t]&&BP(r)){if(a>0&&t>i[0]){for(l=0;l<a-1&&!(i[l]<t&&i[l+1]>t);l++);s=n[i[l]]}if(i.splice(l+1,0,t),n[t]=r,!r.virtual)if(s){var u=s.dom;u.nextSibling?o.insertBefore(r.dom,u.nextSibling):o.appendChild(r.dom)}else o.firstChild?o.insertBefore(r.dom,o.firstChild):o.appendChild(r.dom);r.painter||(r.painter=this)}},e.prototype.eachLayer=function(t,r){for(var n=this._zlevelList,i=0;i<n.length;i++){var a=n[i];t.call(r,this._layers[a],a)}},e.prototype.eachBuiltinLayer=function(t,r){for(var n=this._zlevelList,i=0;i<n.length;i++){var a=n[i],o=this._layers[a];o.__builtin__&&t.call(r,o,a)}},e.prototype.eachOtherLayer=function(t,r){for(var n=this._zlevelList,i=0;i<n.length;i++){var a=n[i],o=this._layers[a];o.__builtin__||t.call(r,o,a)}},e.prototype.getLayers=function(){return this._layers},e.prototype._updateLayerStatus=function(t){this.eachBuiltinLayer(function(h,c){h.__dirty=h.__used=!1});function r(h){a&&(a.__endIndex!==h&&(a.__dirty=!0),a.__endIndex=h)}if(this._singleCanvas)for(var n=1;n<t.length;n++){var i=t[n];if(i.zlevel!==t[n-1].zlevel||i.incremental){this._needsManuallyCompositing=!0;break}}var a=null,o=0,s,l;for(l=0;l<t.length;l++){var i=t[l],u=i.zlevel,f=void 0;s!==u&&(s=u,o=0),i.incremental?(f=this.getLayer(u+OP,this._needsManuallyCompositing),f.incremental=!0,o=1):f=this.getLayer(u+(o>0?Yo:0),this._needsManuallyCompositing),f.__builtin__||mh("ZLevel "+u+" has been used by unkown layer "+f.id),f!==a&&(f.__used=!0,f.__startIndex!==l&&(f.__dirty=!0),f.__startIndex=l,f.incremental?f.__drawIndex=-1:f.__drawIndex=l,r(l),a=f),i.__dirty&ue&&!i.__inHover&&(f.__dirty=!0,f.incremental&&f.__drawIndex<0&&(f.__drawIndex=l))}r(l),this.eachBuiltinLayer(function(h,c){!h.__used&&h.getElementCount()>0&&(h.__dirty=!0,h.__startIndex=h.__endIndex=h.__drawIndex=0),h.__dirty&&h.__drawIndex<0&&(h.__drawIndex=h.__startIndex)})},e.prototype.clear=function(){return this.eachBuiltinLayer(this._clearLayer),this},e.prototype._clearLayer=function(t){t.clear()},e.prototype.setBackgroundColor=function(t){this._backgroundColor=t,M(this._layers,function(r){r.setUnpainted()})},e.prototype.configLayer=function(t,r){if(r){var n=this._layerConfig;n[t]?vt(n[t],r,!0):n[t]=r;for(var i=0;i<this._zlevelList.length;i++){var a=this._zlevelList[i];if(a===t||a===t+Yo){var o=this._layers[a];vt(o,n[t],!0)}}}},e.prototype.delLayer=function(t){var r=this._layers,n=this._zlevelList,i=r[t];i&&(i.dom.parentNode.removeChild(i.dom),delete r[t],n.splice(ft(n,t),1))},e.prototype.resize=function(t,r){if(this._domRoot.style){var n=this._domRoot;n.style.display="none";var i=this._opts,a=this.root;if(t!=null&&(i.width=t),r!=null&&(i.height=r),t=Eo(a,0,i),r=Eo(a,1,i),n.style.display="",this._width!==t||r!==this._height){n.style.width=t+"px",n.style.height=r+"px";for(var o in this._layers)this._layers.hasOwnProperty(o)&&this._layers[o].resize(t,r);this.refresh(!0)}this._width=t,this._height=r}else{if(t==null||r==null)return;this._width=t,this._height=r,this.getLayer(mn).resize(t,r)}return this},e.prototype.clearLayer=function(t){var r=this._layers[t];r&&r.clear()},e.prototype.dispose=function(){this.root.innerHTML="",this.root=this.storage=this._domRoot=this._layers=null},e.prototype.getRenderedCanvas=function(t){if(t=t||{},this._singleCanvas&&!this._compositeManually)return this._layers[mn].dom;var r=new Zu("image",this,t.pixelRatio||this.dpr);r.initContext(),r.clear(!1,t.backgroundColor||this._backgroundColor);var n=r.ctx;if(t.pixelRatio<=this.dpr){this.refresh();var i=r.dom.width,a=r.dom.height;this.eachLayer(function(h){h.__builtin__?n.drawImage(h.dom,0,0,i,a):h.renderToCanvas&&(n.save(),h.renderToCanvas(n),n.restore())})}else for(var o={inHover:!1,viewWidth:this._width,viewHeight:this._height},s=this.storage.getDisplayList(!0),l=0,u=s.length;l<u;l++){var f=s[l];Cn(n,f,o,l===u-1)}return r.dom},e.prototype.getWidth=function(){return this._width},e.prototype.getHeight=function(){return this._height},e})();function zP(e){e.registerPainter("canvas",FP)}const HP={name:"AnalyticsCard",data(){const{t:e}=ch();return{t:e,trendData:[],selectedDays:"1",count:0,averageCount:0,changeRate:0,commandStats:[],chartInstance:null,resizeObserver:null,abortController:new AbortController,loading:!1}},mounted(){this.fetchAnalyticsData(this.selectedDays),this.resizeObserver=new ResizeObserver(()=>{this.resizeChart()}),this.resizeObserver.observe(this.$refs.chartContainer),Nn([jC,_I,gI,U2,rP,jI,sP,kP,zP,HI])},beforeUnmount(){this.abortController.abort(),this.resizeObserver&&this.$refs.chartContainer&&(this.resizeObserver.unobserve(this.$refs.chartContainer),this.resizeObserver.disconnect()),this.chartInstance&&this.chartInstance.dispose()},methods:{async fetchAnalyticsData(e){this.loading=!0;try{const t=await us.get("/api/analytics",{signal:this.abortController.signal,params:{days:e}}),{data:r}=t;this.processData(r,e),this.renderChart(e)}catch(t){us.isCancel(t)?console.log("Request canceled"):Bg.error(this.t("message.error.fetch")+t.message)}finally{this.loading=!1}},processData(e,t){const r=this.groupDataByTimeInterval(e.data);this.fillMissingData(r,t),this.trendData=r.map(a=>({date:this.formatTimestamp(a.date),count:a.count})).sort((a,o)=>new Date(a.date)-new Date(o.date)),this.count=r.reduce((a,o)=>a+o.count,0),this.averageCount=Math.round(this.count/t),this.changeRate=Math.floor(e.change_rate*100);const n={};e.data.forEach(a=>{const o=a.target_id?.split("|")[0]||this.t("unknown");n[o]=(n[o]||0)+1});const i=Object.entries(n).map(([a,o])=>({prefix:a,count:o})).sort((a,o)=>o.count-a.count);this.commandStats=i},fillMissingData(e,t){const r=this.generateAllTimeIntervals(t),n=new Set(e.map(i=>i.date));r.forEach(i=>{n.has(i)||e.push({date:i,count:0})}),e.sort((i,a)=>new Date(i.date)-new Date(a.date))},generateAllTimeIntervals(e){const t=[],r=new Date,n=48*e,i=new Date(r.getTime()-1800*1e3);for(let a=0;a<n;a++){const o=new Date(i.getTime()-a*30*60*1e3);t.push(o.toISOString())}return t},groupDataByTimeInterval(e){const t={},r=new Date,n=new Date(r.getTime()-1800*1e3);return e.forEach(i=>{const a=new Date(i.timestamp),o=n.getTime()-a.getTime(),s=Math.floor(o/(1800*1e3)),u=new Date(n.getTime()-s*30*60*1e3).toISOString();t[u]||(t[u]={date:u,count:0}),t[u].count+=1}),Object.values(t)},formatTimestamp(e){return new Date(e).toLocaleString([],{year:"numeric",month:"numeric",day:"numeric",hour:"2-digit",minute:"2-digit",hour12:!1}).replace(",","")},getPrimaryColor(){return getComputedStyle(document.documentElement).getPropertyValue("--el-color-primary").trim()},renderChart(){this.$nextTick(()=>{this.chartInstance&&this.chartInstance.dispose();const e=this.$refs.chartContainer;if(!e||e.offsetWidth===0)return;const t=this.getPrimaryColor(),r=CA(this.$refs.chartContainer),n={color:[t],tooltip:{trigger:"axis"},dataZoom:[{type:"slider",start:0,end:100},{type:"inside",start:0,end:100}],xAxis:{type:"category",data:this.trendData.map(i=>i.date)},yAxis:{type:"value"},series:[{name:this.t("dashboard.analytics.command.chart.command"),data:this.trendData.map(i=>i.count),type:"line",smooth:!0}]};r.setOption(n),this.chartInstance=r})},resizeChart(){this.$nextTick(()=>{this.chartInstance&&this.chartInstance.resize()})},onTimeRangeChange(e){this.fetchAnalyticsData(e)},getColorByIndex(e){const t=["#F56C6C","#E6A23C","#FAE384","#67C23A","#1ABC9C","#409EFF","#9B59B6","#E84393"];let r=0;for(let n=0;n<e.length;n++)r+=e.charCodeAt(n);return t[r%t.length]}}},VP={class:"card-header"},GP={class:"statistics-content"},WP={class:"data-group"},UP={class:"data-title"},YP={class:"data-text"},ZP={class:"data-group"},XP={class:"data-title"},$P={class:"data-text"},qP={class:"data-group"},KP={class:"data-title"},QP={ref:"chartContainer",class:"chart-container"},JP={class:"card-header"},jP={key:0},tR={class:"proportion-bar"},eR=["title"],rR={class:"ranking-total-label"},nR={class:"ranking-label"};function iR(e,t,r,n,i,a){const o=h1,s=f1,l=Vg,u=Hg,f=v1,h=u1,c=zg,v=Ng;return Jt(),Dr(c,{gutter:20},{default:Ot(()=>[Bt(u,{span:16,xs:24},{default:Ot(()=>[pa((Jt(),Dr(l,{"body-style":{height:"360px"},shadow:"never"},{default:Ot(()=>[O("div",VP,[O("h3",null,[t[1]||(t[1]=O("i",{class:"mdi mdi-chart-line"},null,-1)),_n(" "+j(e.$t("dashboard.analytics.command.title")),1)]),Bt(s,{modelValue:i.selectedDays,"onUpdate:modelValue":t[0]||(t[0]=d=>i.selectedDays=d),onChange:a.onTimeRangeChange,class:"time-range-select"},{default:Ot(()=>[Bt(o,{label:e.$t("dashboard.analytics.command.select.1day"),value:"1"},null,8,["label"]),Bt(o,{label:e.$t("dashboard.analytics.command.select.3days"),value:"3"},null,8,["label"]),Bt(o,{label:e.$t("dashboard.analytics.command.select.7days"),value:"7"},null,8,["label"]),Bt(o,{label:e.$t("dashboard.analytics.command.select.30days"),value:"30"},null,8,["label"]),Bt(o,{label:e.$t("dashboard.analytics.command.select.365days"),value:"365"},null,8,["label"])]),_:1},8,["modelValue","onChange"])]),O("div",GP,[O("div",WP,[O("strong",UP,j(e.$t("dashboard.analytics.command.label.total")),1),O("span",YP,j(i.count||0),1)]),O("div",ZP,[O("strong",XP,j(e.$t("dashboard.analytics.command.label.average")),1),O("span",$P,j(i.averageCount||0),1)]),O("div",qP,[O("strong",KP,j(e.$t("dashboard.analytics.command.label.change_rate")),1),O("span",{class:Fg({positive:i.changeRate>0,negative:i.changeRate<0,"data-text":i.changeRate===0})},j(i.changeRate>0?`+${i.changeRate}%`:i.changeRate===0?"0%":`${i.changeRate}%`),3)])]),O("div",QP,null,512)]),_:1})),[[v,i.loading]])]),_:1}),Bt(u,{span:8,xs:24},{default:Ot(()=>[pa((Jt(),Dr(l,{"body-style":{height:"360px"},shadow:"never"},{default:Ot(()=>[O("div",JP,[O("h3",null,[t[2]||(t[2]=O("i",{class:"mdi mdi-format-list-numbered"},null,-1)),_n(" "+j(e.$t("dashboard.analytics.platform.title")),1)])]),i.commandStats.length>0?(Jt(),oi("div",jP,[O("div",tR,[(Jt(!0),oi(Dv,null,Av(i.commandStats,d=>(Jt(),oi("div",{key:d.prefix,class:"proportion-segment",style:Lv({width:Math.round(d.count/i.count*100*100)/100+"%",backgroundColor:a.getColorByIndex(d.prefix)}),title:`${d.prefix}: ${d.count} (${Math.round(d.count/i.count*100*100)/100}%)`},null,12,eR))),128))]),O("div",rR,[O("strong",null,j(e.$t("dashboard.analytics.command.label.total")),1),O("span",null,j(i.count||0),1)]),Bt(f,{height:"260px"},{default:Ot(()=>[(Jt(!0),oi(Dv,null,Av(i.commandStats,(d,p)=>(Jt(),oi("div",{key:d.prefix,class:"ranking-item"},[O("span",{style:Lv({backgroundColor:a.getColorByIndex(d.prefix),color:"#fff",borderRadius:"100%",padding:"6px 10px",display:"inline-block",marginRight:"8px"})},j(p+1),5),O("div",nR,[O("strong",null,j(d.prefix),1),O("span",null,j(d.count),1)])]))),128))]),_:1})])):(Jt(),Dr(h,{key:1}))]),_:1})),[[v,i.loading]])]),_:1})]),_:1})}const a1=vh(HP,[["render",iR],["__scopeId","data-v-d48bebd9"]]),Xu=["#1989fa","#e6a23c","#f56c6c"],aR={name:"ServerInfoCard",data(){const{t:e}=ch();return{os:{system:"",version:"",machine:"",boot_time:0},bot:{running_time:0,python_version:"",version:"",web_render_status:!1},cpu:{cpu_brand:"",cpu_percent:0},memory:{total:0,used:0,percent:0},disk:{total:0,used:0,percent:0},abortController:new AbortController,loading:!1,dashboardOverflow:!1,t:e}},mounted(){this.checkOverflow(),window.addEventListener("resize",this.checkOverflow),this.fetchServerInfoData()},beforeUnmount(){window.removeEventListener("resize",this.checkOverflow),this.abortController.abort()},methods:{formatRunningTime(e){const t=Math.floor(e/3600),r=Math.floor(e%3600/60),n=Math.floor(e%60);return this.t("dashboard.server_info.text.format_time",{hours:t,minutes:r,seconds:n})},formatTime(e){const t=new Date(e*1e3),r=(localStorage.getItem("language")||"zh_cn").toLowerCase(),i={zh_cn:"zh-CN",zh_tw:"zh-TW",en_us:"en-US",ja_jp:"ja-JP"}[r]||"zh-CN";return i==="ja-JP"?new Intl.DateTimeFormat(i,{calendar:"japanese",era:"short",year:"numeric",month:"2-digit",day:"2-digit",hour:"2-digit",minute:"2-digit",second:"2-digit",hour12:!1}).format(t):new Intl.DateTimeFormat(i,{year:"numeric",month:"2-digit",day:"2-digit",hour:"2-digit",minute:"2-digit",second:"2-digit",hour12:!1}).format(t)},async fetchServerInfoData(){try{this.loading=!0;const t=(await us.get("/api/server-info",{signal:this.abortController.signal})).data;this.os={...this.os,...t.os},this.bot={...this.bot,...t.bot},this.cpu={...this.cpu,...t.cpu},this.memory={...this.memory,...t.memory},this.disk={...this.disk,...t.disk}}catch(e){us.isCancel(e)?console.log("Request canceled"):Bg.error(this.t("message.error.fetch")+e.message)}finally{this.loading=!1}},getProgressColor(e){return e>=90?Xu[2]:e>=60?Xu[1]:Xu[0]},checkOverflow(){this.$nextTick(()=>{const e=this.$el.querySelector(".memory-dashboards");e&&(this.dashboardOverflow=e.scrollWidth>e.clientWidth)})}}},oR={class:"data-title"},sR={class:"data-text"},lR={class:"data-title"},uR={class:"data-text"},fR={class:"data-title"},hR={class:"data-text"},vR={class:"data-title"},cR={class:"data-text"},dR={class:"data-title"},pR={class:"data-text"},gR={class:"data-title"},mR={class:"data-text"},yR={class:"data-title"},_R={class:"data-text"},SR={class:"data-title"},bR={class:"data-text"},wR={class:"data-text"},xR={class:"data-text"},TR={class:"percentage-value"},CR={class:"percentage-label"},MR={class:"percentage-value"},DR={class:"percentage-label"},AR={class:"percentage-value"},LR={class:"percentage-label"};function IR(e,t,r,n,i,a){const o=Vg,s=Hg,l=c1,u=zg,f=Ng;return Jt(),Dr(u,{gutter:20},{default:Ot(()=>[Bt(s,{span:10,xs:24},{default:Ot(()=>[pa((Jt(),Dr(o,{"body-style":{height:"190px"},shadow:"never"},{default:Ot(()=>[O("h3",null,[t[0]||(t[0]=O("i",{class:"mdi mdi-robot-outline"},null,-1)),_n(" "+j(e.$t("dashboard.server_info.bot.title")),1)]),O("p",null,[O("strong",oR,j(e.$t("dashboard.server_info.bot.label.python_version")),1),O("span",sR,j(i.bot.python_version||"-"),1)]),O("p",null,[O("strong",lR,j(e.$t("dashboard.server_info.bot.label.bot_version")),1),O("span",uR,j(i.bot.version?i.bot.version.slice(0,6):"-"),1)]),O("p",null,[O("strong",fR,j(e.$t("dashboard.server_info.bot.label.web_render_status")),1),O("span",hR,j(i.bot.web_render_status?e.$t("true"):e.$t("false")),1)]),O("p",null,[O("strong",vR,j(e.$t("dashboard.server_info.bot.label.running_time")),1),O("span",cR,j(a.formatRunningTime(i.bot.running_time||0)),1)])]),_:1})),[[f,i.loading]]),pa((Jt(),Dr(o,{"body-style":{height:"190px"},shadow:"never"},{default:Ot(()=>[O("h3",null,[t[1]||(t[1]=O("i",{class:"mdi mdi-laptop"},null,-1)),_n(" "+j(e.$t("dashboard.server_info.system.title")),1)]),O("p",null,[O("strong",dR,j(e.$t("dashboard.server_info.system.label.machine")),1),O("span",pR,j(i.os.system||"-")+" "+j(i.os.machine?"-":"")+" "+j(i.os.machine||""),1)]),O("p",null,[O("strong",gR,j(e.$t("dashboard.server_info.system.label.version")),1),O("span",mR,j(i.os.version||"-"),1)]),O("p",null,[O("strong",yR,j(e.$t("dashboard.server_info.system.label.boot_time")),1),O("span",_R,j(a.formatTime(i.os.boot_time||0)),1)])]),_:1})),[[f,i.loading]])]),_:1}),Bt(s,{span:14,xs:24},{default:Ot(()=>[pa((Jt(),Dr(o,{"body-style":{height:"440px"},shadow:"never"},{default:Ot(()=>[O("h3",null,[t[2]||(t[2]=O("i",{class:"mdi mdi-memory"},null,-1)),_n(" "+j(e.$t("dashboard.server_info.cpu.title")),1)]),O("p",null,[O("strong",SR,j(e.$t("dashboard.server_info.cpu.label.brand")),1)]),O("p",null,[O("span",bR,j(i.cpu.cpu_brand||"-"),1)]),O("h3",null,[t[3]||(t[3]=O("i",{class:"mdi mdi-sd"},null,-1)),_n(" "+j(e.$t("dashboard.server_info.memory.title")),1)]),O("p",null,[O("span",wR,j(i.memory.used?i.memory.used.toFixed():0)+" MB / "+j(i.memory.total?i.memory.total.toFixed():0)+" MB",1)]),O("h3",null,[t[4]||(t[4]=O("i",{class:"mdi mdi-server-outline"},null,-1)),_n(" "+j(e.$t("dashboard.server_info.disk.title")),1)]),O("p",null,[O("span",xR,j(i.disk.used?i.disk.used.toFixed(1):0)+" GB / "+j(i.disk.total?i.disk.total.toFixed(1):0)+" GB",1)]),t[5]||(t[5]=O("br",null,null,-1)),O("div",{class:Fg(["memory-dashboards",{leftAlign:i.dashboardOverflow,centerAlign:!i.dashboardOverflow}])},[Bt(l,{type:"dashboard",percentage:i.cpu.cpu_percent?i.cpu.cpu_percent.toFixed(1):0,color:a.getProgressColor(i.cpu.cpu_percent)},{default:Ot(({percentage:h})=>[O("span",TR,j(h)+"%",1),O("span",CR,j(e.$t("dashboard.server_info.cpu.title")),1)]),_:1},8,["percentage","color"]),Bt(l,{type:"dashboard",percentage:i.memory.percent?i.memory.percent.toFixed(1):0,color:a.getProgressColor(i.memory.percent)},{default:Ot(({percentage:h})=>[O("span",MR,j(h)+"%",1),O("span",DR,j(e.$t("dashboard.server_info.memory.title")),1)]),_:1},8,["percentage","color"]),Bt(l,{type:"dashboard",percentage:i.disk.percent?i.disk.percent.toFixed(1):0,color:a.getProgressColor(i.disk.percent)},{default:Ot(({percentage:h})=>[O("span",AR,j(h)+"%",1),O("span",LR,j(e.$t("dashboard.server_info.disk.title")),1)]),_:1},8,["percentage","color"])],2)]),_:1})),[[f,i.loading]])]),_:1})]),_:1})}const o1=vh(aR,[["render",IR],["__scopeId","data-v-7c504df9"]]),PR={name:"DashboardPage",components:{AnalyticsCard:a1,ServerInfoCard:o1},data(){const{t:e}=ch();return{loading:!1,refreshInterval:null,lastUpdateTime:Math.floor(Date.now()/1e3),t:e}},mounted(){this.startAutoRefresh()},beforeUnmount(){this.clearAutoRefresh()},methods:{refreshData(){if(this.loading=!0,this.lastUpdateTime=Math.floor(Date.now()/1e3),this.$refs.serverInfoCard.fetchServerInfoData().finally(()=>{this.loading=!1}),this.$refs.analyticsCard){const e=this.$refs.analyticsCard.selectedDays;this.$refs.analyticsCard.fetchAnalyticsData(e)}this.resetAutoRefresh()},startAutoRefresh(){this.refreshInterval=setInterval(()=>{this.refreshData()},36e5)},resetAutoRefresh(){this.clearAutoRefresh(),this.startAutoRefresh()},clearAutoRefresh(){this.refreshInterval&&(clearInterval(this.refreshInterval),this.refreshInterval=null)},formatTime(e){const t=new Date(e*1e3),r=(localStorage.getItem("language")||"zh_cn").toLowerCase(),i={zh_cn:"zh-CN",zh_tw:"zh-TW",en_us:"en-US",ja_jp:"ja-JP"}[r]||"zh-CN";return i==="ja-JP"?new Intl.DateTimeFormat(i,{calendar:"japanese",era:"short",year:"numeric",month:"2-digit",day:"2-digit",hour:"2-digit",minute:"2-digit",second:"2-digit",hour12:!1}).format(t):new Intl.DateTimeFormat(i,{year:"numeric",month:"2-digit",day:"2-digit",hour:"2-digit",minute:"2-digit",second:"2-digit",hour12:!1}).format(t)}}};function RR(e,t,r,n,i,a){const o=o1,s=a1,l=s1,u=l1;return Jt(),oi("div",null,[Bt(o,{ref:"serverInfoCard"},null,512),Bt(s,{ref:"analyticsCard"},null,512),Bt(u,{content:e.$t("dashboard.update_time.title",{time:a.formatTime(i.lastUpdateTime)}),placement:"left"},{default:Ot(()=>[Bt(l,{class:"refresh-button",circle:"",size:"large",type:"primary",disabled:i.loading,onClick:a.refreshData},{default:Ot(()=>[...t[0]||(t[0]=[O("i",{class:"mdi mdi-refresh"},null,-1)])]),_:1},8,["disabled","onClick"])]),_:1},8,["content"])])}const HR=vh(PR,[["render",RR],["__scopeId","data-v-06870168"]]);export{HR as default};
